@@ -1,6 +1,6 @@
 /* airpcap_loader.c
  *
- * $Id: airpcap_loader.c 41801 2012-03-27 15:17:42Z morriss $
+ * $Id: airpcap_loader.c 43285 2012-06-16 18:35:13Z guy $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -349,11 +349,6 @@ write_wlan_wep_keys_to_registry(airpcap_if_info_t* info_if, GList* key_list)
 
     keys_in_list = g_list_length(key_list);
 
-    /*
-     * Save the encryption keys, if we have any of them
-     */
-    KeysCollectionSize = 0;
-
     /*
      * Calculate the size of the keys collection
      */
@@ -453,11 +448,6 @@ write_wlan_driver_wep_keys_to_registry(GList* key_list)
 	if(((decryption_key_t*)g_list_nth_data(key_list,k))->type == AIRPDCAP_KEY_TYPE_WEP)
 	    keys_in_list++;
 
-    /*
-     * Save the encryption keys, if we have any of them
-     */
-    KeysCollectionSize = 0;
-
     /*
      * Calculate the size of the keys collection
      */
@@ -1346,6 +1336,9 @@ free_airpcap_if_cb(gpointer data, gpointer user_data _U_)
 {
     airpcap_if_info_t *if_info = data;
 
+    if (NULL == if_info)
+	return;
+
     if (if_info->name != NULL)
 	g_free(if_info->name);
 
@@ -1362,8 +1355,7 @@ free_airpcap_if_cb(gpointer data, gpointer user_data _U_)
     if(if_info->ip_addr != NULL)
 	g_slist_free(if_info->ip_addr);
 
-    if(if_info != NULL)
-	g_free(if_info);
+    g_free(if_info);
 }
 
 /*
@@ -1590,14 +1582,12 @@ airpcap_get_if_string_number_from_description(gchar* description)
 airpcap_if_info_t*
 airpcap_get_default_if(GList* airpcap_if_list)
 {
-    gchar* s;
     airpcap_if_info_t* if_info = NULL;
 
     if(prefs.capture_device != NULL)
     {
-	s = g_strdup(get_if_name(prefs.capture_device));
-	if_info = get_airpcap_if_from_name(airpcap_if_list,g_strdup(get_if_name(prefs.capture_device)));
-	g_free(s);
+        if_info = get_airpcap_if_from_name(airpcap_if_list,
+                                           get_if_name(prefs.capture_device));
     }
     return if_info;
 }
@@ -1932,7 +1922,7 @@ get_wireshark_keys(void)
     prefs_pref_foreach(wlan_prefs, get_wep_key, (gpointer)wep_user_data);
 
     /* Copy the list field in the user data structure pointer into the final_list */
-    if(wep_user_data != NULL)  wep_final_list  = wep_user_data->list;
+    wep_final_list = wep_user_data->list;
 
     /* XXX - Merge the three lists!!!!! */
     final_list = wep_final_list;
@@ -1966,7 +1956,6 @@ merge_key_list(GList* list1, GList* list2)
 
     if(list1 == NULL)
     {
-	n1 = 0;
 	n2 = g_list_length(list2);
 
 	for(i=0;i<n2;i++)
@@ -1987,7 +1976,6 @@ merge_key_list(GList* list1, GList* list2)
     else if(list2 == NULL)
     {
 	n1 = g_list_length(list1);
-	n2 = 0;
 
 	for(i=0;i<n1;i++)
 	{
@@ -2204,7 +2192,6 @@ key_lists_are_equal(GList* list1, GList* list2)
     /* if(n1 != n2) return FALSE; */
     if(wep_n1 != wep_n2) return FALSE;
 
-    n1 = wep_n1;
     n2 = wep_n2;
 
     /*for(i=0;i<n1;i++)
@@ -2326,14 +2313,12 @@ static guint
 set_on_off(pref_t *pref, gpointer ud)
 {
     gboolean *is_on;
-    gboolean number;
 
     /* Retrieve user data info */
     is_on = (gboolean*)ud;
 
     if (g_ascii_strncasecmp(pref->name, "enable_decryption", 17) == 0 && pref->type == PREF_BOOL)
     {
-	number = *pref->varp.boolp;
 
 	if(*is_on)
 	    *pref->varp.boolp = TRUE;
