@@ -1,7 +1,7 @@
 /* airpcap_loader.h
  * Declarations of routines for the "About" dialog
  *
- * $Id: airpcap_loader.h 28352 2009-05-13 17:29:13Z jmayer $
+ * $Id: airpcap_loader.h 40321 2011-12-29 00:08:47Z gerald $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -30,6 +30,10 @@
 
 #include <epan/crypt/airpdcap_user.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Error values from "get_airpcap_interface_list()". */
 #define	CANT_GET_AIRPCAP_INTERFACE_LIST	0	/* error getting list */
 #define	NO_AIRPCAP_INTERFACES_FOUND	1	/* list is empty */
@@ -551,4 +555,8 @@ get_compiled_airpcap_version(GString *str);
 void
 get_runtime_airpcap_version(GString *str);
 
+#ifdef __cplusplus
+}
 #endif
+
+#endif /* __AIRPCAP_LOADER_H__ */
