@@ -2,7 +2,7 @@
  * Routines for ACP133 specific syntaxes in X.500 packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-acp133-template.c 32417 2010-04-07 16:54:29Z wmeier $
+ * $Id: packet-acp133-template.c 36013 2011-02-20 17:03:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,7 +37,7 @@
 #include "packet-x509af.h"
 #include "packet-x509if.h"
 #include "packet-x509ce.h"
-#include "packet-x411.h"
+#include "packet-p1.h"
 
 #include "packet-acp133.h"
 
