@@ -13,7 +13,7 @@
  *   Yuriy Sidelnikov <YSidelnikov@hotmail.com>
  *
  *
- * $Id: packet-acse-template.c 32405 2010-04-06 17:01:14Z wmeier $
+ * $Id: packet-acse-template.c 38122 2011-07-19 18:48:31Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -231,7 +231,7 @@ dissect_acse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		/* create display subtree for the connectionless protocol */
 		if(parent_tree)
 		{
-			item = proto_tree_add_item(parent_tree, proto_clacse, tvb, 0, -1, FALSE);
+			item = proto_tree_add_item(parent_tree, proto_clacse, tvb, 0, -1, ENC_NA);
 			tree = proto_item_add_subtree(item, ett_acse);
 		}
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "CL-ACSE");
@@ -242,7 +242,7 @@ dissect_acse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		/* create display subtree for the protocol */
 		if(parent_tree)
 		{
-			item = proto_tree_add_item(parent_tree, proto_acse, tvb, 0, -1, FALSE);
+			item = proto_tree_add_item(parent_tree, proto_acse, tvb, 0, -1, ENC_NA);
 			tree = proto_item_add_subtree(item, ett_acse);
 		}
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "ACSE");
