@@ -4,7 +4,7 @@
  *
  * Copyright 2005, Stig Bjorlykke <stig@bjorlykke.org>, Thales Norway AS
  *
- * $Id: packet-cdt-template.c 36013 2011-02-20 17:03:29Z stig $
+ * $Id: packet-cdt-template.c 38122 2011-07-19 18:48:31Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -81,7 +81,7 @@ void dissect_cdt (tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
   top_tree = parent_tree;
 
   if (parent_tree) {
-    cdt_item = proto_tree_add_item (parent_tree, proto_cdt, tvb, 0, -1, FALSE);
+    cdt_item = proto_tree_add_item (parent_tree, proto_cdt, tvb, 0, -1, ENC_NA);
     tree = proto_item_add_subtree (cdt_item, ett_cdt_CompressedData);
   }
 
