@@ -1,7 +1,7 @@
 /* packet-gprscdr-template.c
  * Copyright 2011 , Anders Broman <anders.broman [AT] ericsson.com>
  *
- * $Id: packet-gprscdr-template.c 39338 2011-10-10 17:42:43Z etxrab $
+ * $Id: packet-gprscdr-template.c 40105 2011-12-06 19:16:10Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,6 +33,7 @@
 
 #include "packet-ber.h"
 #include "packet-gsm_map.h"
+#include "packet-e212.h"
 #include "packet-gprscdr.h"
 
 #define PNAME  "GPRS CDR"
@@ -46,8 +47,17 @@ static int proto_gprscdr = -1;
 
 static int ett_gprscdr = -1;
 static int ett_gprscdr_timestamp = -1;
+static int ett_gprscdr_plmn_id = -1;
 #include "packet-gprscdr-ett.c"
 
+static const value_string gprscdr_daylight_saving_time_vals[] = {
+    {0, "No adjustment"},
+    {1, "+1 hour adjustment for Daylight Saving Time"},
+    {2, "+2 hours adjustment for Daylight Saving Time"},
+    {3, "Reserved"},
+    {0, NULL}
+};
+
 #include "packet-gprscdr-fn.c"
 
 
@@ -65,6 +75,7 @@ proto_register_gprscdr(void)
     static gint *ett[] = {
     &ett_gprscdr,
 	&ett_gprscdr_timestamp,
+	&ett_gprscdr_plmn_id,
 #include "packet-gprscdr-ettarr.c"
         };
 
