@@ -3,7 +3,7 @@
  * Copyright 2004, Tim Endean <endeant@hotmail.com>
  * Built from the gsm-map dissector Copyright 2004, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-inap-template.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-inap-template.c 40459 2012-01-13 16:19:24Z alagoutte $
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -128,12 +128,9 @@ dissect_inap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
     proto_item		*item=NULL;
     proto_tree		*tree=NULL;
 	int				offset = 0;
-	guint			length;
 	asn1_ctx_t asn1_ctx;
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
-	length = tvb_length(tvb);
-
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "INAP");
 
     /* create display subtree for the protocol */
@@ -145,7 +142,7 @@ dissect_inap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	/* Get the length and add 2 */
 	inap_pdu_size = tvb_get_guint8(tvb, offset+1)+2;
 	opcode = 0;
-    offset = dissect_inap_ROS(TRUE, tvb, offset, &asn1_ctx, tree, -1);
+    dissect_inap_ROS(TRUE, tvb, offset, &asn1_ctx, tree, -1);
 
 
 }
