@@ -23,7 +23,7 @@
  *
  * Some structures from RFC2630
  *
- * $Id: packet-kerberos-template.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-kerberos-template.c 40570 2012-01-18 21:20:50Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -72,7 +72,7 @@
 #include <nettle/des.h>
 #include <nettle/cbc.h>
 #endif
-#include <epan/crypt/crypt-md5.h>
+#include <epan/crypt/md5.h>
 #include <sys/stat.h>	/* For keyfile manipulation */
 #endif
 
