@@ -4,7 +4,7 @@
  * (3GPP TS 36.331 V10.5.0 Release 10) packet dissection
  * Copyright 2008, Vincent Helfre
  *
- * $Id: packet-lte-rrc-template.c 41917 2012-04-04 07:47:54Z etxrab $
+ * $Id: packet-lte-rrc-template.c 42913 2012-05-30 08:49:56Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -169,6 +169,7 @@ static gint ett_lte_rrc_featureGroupIndRel9Add = -1;
 static gint ett_lte_rrc_featureGroupIndRel10 = -1;
 static gint ett_lte_rrc_neighCellConfig = -1;
 static gint ett_lte_rrc_absTimeInfo = -1;
+static gint ett_lte_rrc_nas_SecurityParam = -1;
 
 /* Forward declarations */
 static int dissect_DL_DCCH_Message_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_);
@@ -176,12 +177,12 @@ static int dissect_UECapabilityInformation_PDU(tvbuff_t *tvb _U_, packet_info *p
 int dissect_lte_rrc_UE_EUTRA_Capability_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_);
 
 static const true_false_string lte_rrc_eutra_cap_feat_group_ind_1_val = {
-  "Intra-subframe freq hopping for PUSCH scheduled by UL grant; DCI format 3a; PDSCH transmission mode 5; Aperiodic CQI/PMI/RI report on PUSCH: Mode 2-0 and 2-2 - Supported",
-  "Intra-subframe freq hopping for PUSCH scheduled by UL grant; DCI format 3a; PDSCH transmission mode 5; Aperiodic CQI/PMI/RI report on PUSCH: Mode 2-0 and 2-2 - Not supported"
+  "Intra-subframe freq hopping for PUSCH scheduled by UL grant; DCI format 3a; PDSCH transmission mode 5; Aperiodic CQI/PMI/RI report on PUSCH: Mode 2-0 & 2-2 - Supported",
+  "Intra-subframe freq hopping for PUSCH scheduled by UL grant; DCI format 3a; PDSCH transmission mode 5; Aperiodic CQI/PMI/RI report on PUSCH: Mode 2-0 & 2-2 - Not supported"
 };
 static const true_false_string lte_rrc_eutra_cap_feat_group_ind_2_val = {
-  "Simultaneous CQI and ACK/NACK on PUCCH (format 2a/2b); Absolute TPC command for PUSCH; Resource alloc type 1 for PDSCH; Periodic CQI/PMI/RI report on PUCCH: Mode 2-0 and 2-1 - Supported",
-  "Simultaneous CQI and ACK/NACK on PUCCH (format 2a/2b); Absolute TPC command for PUSCH; Resource alloc type 1 for PDSCH; Periodic CQI/PMI/RI report on PUCCH: Mode 2-0 and 2-1 - Not supported"
+  "Simultaneous CQI & ACK/NACK on PUCCH (format 2a/2b); Absolute TPC command for PUSCH; Resource alloc type 1 for PDSCH; Periodic CQI/PMI/RI report on PUCCH: Mode 2-0 & 2-1 - Supported",
+  "Simultaneous CQI & ACK/NACK on PUCCH (format 2a/2b); Absolute TPC command for PUSCH; Resource alloc type 1 for PDSCH; Periodic CQI/PMI/RI report on PUCCH: Mode 2-0 & 2-1 - Not supported"
 };
 static const true_false_string lte_rrc_eutra_cap_feat_group_ind_3_val = {
   "5bit RLC UM SN; 7bit PDCP SN - Supported",
@@ -348,8 +349,8 @@ static const true_false_string lte_rrc_eutra_cap_feat_group_ind_43_val = {
   "Undefined - Not supported"
 };
 static const true_false_string lte_rrc_eutra_cap_feat_group_ind_44_val = {
-  "Undefined - Supported",
-  "Undefined - Not supported"
+  "DCI format 3a; Aperiodic CQI/PMI/RI reporting on PUSCH: Mode 2-0 & 2-2; PUCCH format 2a & 2b; Periodic CQI/PMI/RI reporting on PUCCH: Mode 2-0 & 2-1 - Supported",
+  "DCI format 3a; Aperiodic CQI/PMI/RI reporting on PUSCH: Mode 2-0 & 2-2; PUCCH format 2a & 2b; Periodic CQI/PMI/RI reporting on PUCCH: Mode 2-0 & 2-1 - Not supported"
 };
 static const true_false_string lte_rrc_eutra_cap_feat_group_ind_45_val = {
   "Undefined - Supported",
@@ -559,6 +560,1117 @@ static const true_false_string lte_rrc_eutra_cap_feat_group_ind_132_val = {
   "Undefined - Supported",
   "Undefined - Not supported"
 };
+
+static const value_string lte_rrc_q_RxLevMin_vals[] = {
+  { -70, "-140dBm"},
+  { -69, "-138dBm"},
+  { -68, "-136dBm"},
+  { -67, "-134dBm"},
+  { -66, "-132dBm"},
+  { -65, "-130dBm"},
+  { -64, "-128dBm"},
+  { -63, "-126dBm"},
+  { -62, "-124dBm"},
+  { -61, "-122dBm"},
+  { -60, "-120dBm"},
+  { -59, "-118dBm"},
+  { -58, "-116dBm"},
+  { -57, "-114dBm"},
+  { -56, "-112dBm"},
+  { -55, "-110dBm"},
+  { -54, "-108dBm"},
+  { -53, "-106dBm"},
+  { -52, "-104dBm"},
+  { -51, "-102dBm"},
+  { -50, "-100dBm"},
+  { -49, "-98dBm"},
+  { -48, "-96dBm"},
+  { -47, "-94dBm"},
+  { -46, "-92dBm"},
+  { -45, "-90dBm"},
+  { -44, "-88dBm"},
+  { -43, "-86dBm"},
+  { -42, "-84dBm"},
+  { -41, "-82dBm"},
+  { -40, "-80dBm"},
+  { -39, "-78dBm"},
+  { -38, "-76dBm"},
+  { -37, "-74dBm"},
+  { -36, "-72dBm"},
+  { -35, "-70dBm"},
+  { -34, "-68dBm"},
+  { -33, "-66dBm"},
+  { -32, "-64dBm"},
+  { -31, "-62dBm"},
+  { -30, "-60dBm"},
+  { -29, "-58dBm"},
+  { -28, "-56dBm"},
+  { -27, "-54dBm"},
+  { -26, "-52dBm"},
+  { -25, "-50dBm"},
+  { -24, "-48dBm"},
+  { -23, "-46dBm"},
+  { -22, "-44dBm"},
+  {   0, NULL}
+};
+static value_string_ext lte_rrc_q_RxLevMin_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_q_RxLevMin_vals);
+
+static const value_string lte_rrc_q_RxLevMinOffset_vals[] = {
+  { 1, "2dB"},
+  { 2, "4dB"},
+  { 3, "6dB"},
+  { 4, "8dB"},
+  { 5, "10dB"},
+  { 6, "12dB"},
+  { 7, "14dB"},
+  { 8, "16dB"},
+  { 0, NULL}
+};
+
+static const value_string lte_rrc_utra_q_RxLevMin_vals[] = {
+  { -60, "-119dBm"},
+  { -59, "-117dBm"},
+  { -58, "-115dBm"},
+  { -57, "-113dBm"},
+  { -56, "-111dBm"},
+  { -55, "-109dBm"},
+  { -54, "-107dBm"},
+  { -53, "-105dBm"},
+  { -52, "-103dBm"},
+  { -51, "-101dBm"},
+  { -50, "-99dBm"},
+  { -49, "-97dBm"},
+  { -48, "-95dBm"},
+  { -47, "-93dBm"},
+  { -46, "-91dBm"},
+  { -45, "-89dBm"},
+  { -44, "-87dBm"},
+  { -43, "-85dBm"},
+  { -42, "-83dBm"},
+  { -41, "-81dBm"},
+  { -40, "-79dBm"},
+  { -39, "-77dBm"},
+  { -38, "-75dBm"},
+  { -37, "-73dBm"},
+  { -36, "-71dBm"},
+  { -35, "-69dBm"},
+  { -34, "-67dBm"},
+  { -33, "-65dBm"},
+  { -32, "-63dBm"},
+  { -31, "-61dBm"},
+  { -30, "-59dBm"},
+  { -29, "-57dBm"},
+  { -28, "-55dBm"},
+  { -27, "-53dBm"},
+  { -26, "-51dBm"},
+  { -25, "-49dBm"},
+  { -24, "-47dBm"},
+  { -23, "-45dBm"},
+  { -22, "-43dBm"},
+  { -21, "-41dBm"},
+  { -20, "-39dBm"},
+  { -19, "-37dBm"},
+  { -18, "-35dBm"},
+  { -17, "-33dBm"},
+  { -16, "-31dBm"},
+  { -15, "-29dBm"},
+  { -14, "-27dBm"},
+  { -13, "-25dBm"},
+  {   0, NULL}
+};
+static value_string_ext lte_rrc_utra_q_RxLevMin_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_utra_q_RxLevMin_vals);
+
+static const value_string lte_rrc_geran_q_RxLevMin_vals[] = {
+  { 0 , "-115dBm"},
+  { 1 , "-113dBm"},
+  { 2 , "-111dBm"},
+  { 3 , "-109dBm"},
+  { 4 , "-107dBm"},
+  { 5 , "-105dBm"},
+  { 6 , "-103dBm"},
+  { 7 , "-101dBm"},
+  { 8 , "-99dBm"},
+  { 9 , "-97dBm"},
+  { 10, "-95dBm"},
+  { 11, "-93dBm"},
+  { 12, "-91dBm"},
+  { 13, "-89dBm"},
+  { 14, "-87dBm"},
+  { 15, "-85dBm"},
+  { 16, "-83dBm"},
+  { 17, "-81dBm"},
+  { 18, "-79dBm"},
+  { 19, "-77dBm"},
+  { 20, "-75dBm"},
+  { 21, "-73dBm"},
+  { 22, "-71dBm"},
+  { 23, "-69dBm"},
+  { 24, "-67dBm"},
+  { 25, "-65dBm"},
+  { 26, "-63dBm"},
+  { 27, "-61dBm"},
+  { 28, "-59dBm"},
+  { 29, "-57dBm"},
+  { 30, "-55dBm"},
+  { 31, "-53dBm"},
+  { 32, "-51dBm"},
+  { 33, "-49dBm"},
+  { 34, "-47dBm"},
+  { 35, "-45dBm"},
+  { 36, "-43dBm"},
+  { 37, "-41dBm"},
+  { 38, "-39dBm"},
+  { 39, "-37dBm"},
+  { 40, "-35dBm"},
+  { 41, "-33dBm"},
+  { 42, "-31dBm"},
+  { 43, "-29dBm"},
+  { 44, "-27dBm"},
+  { 45, "-25dBm"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_geran_q_RxLevMin_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_geran_q_RxLevMin_vals);
+
+static const value_string lte_rrc_nomPDSCH_RS_EPRE_Offset_vals[] = {
+  { -1, "-2dB"},
+  {  0, "0dB"},
+  {  1, "2dB"},
+  {  2, "4dB"},
+  {  3, "6dB"},
+  {  4, "8dB"},
+  {  5, "10dB"},
+  {  6, "12dB"},
+  {  0, NULL}
+};
+
+static const value_string lte_rrc_deltaPreambleMsg3_vals[] = {
+  { -1, "-2dB"},
+  {  0, "0dB"},
+  {  1, "2dB"},
+  {  2, "4dB"},
+  {  3, "6dB"},
+  {  4, "8dB"},
+  {  5, "10dB"},
+  {  6, "12dB"},
+  {  0, NULL}
+};
+
+static const value_string lte_rrc_ReselectionThreshold_vals[] = {
+  { 0 , "0dB"},
+  { 1 , "2dB"},
+  { 2 , "4dB"},
+  { 3 , "6dB"},
+  { 4 , "8dB"},
+  { 5 , "10dB"},
+  { 6 , "12dB"},
+  { 7 , "14dB"},
+  { 8 , "16dB"},
+  { 9 , "18dB"},
+  { 10, "20dB"},
+  { 11, "22dB"},
+  { 12, "24dB"},
+  { 13, "26dB"},
+  { 14, "28dB"},
+  { 15, "30dB"},
+  { 16, "32dB"},
+  { 17, "34dB"},
+  { 18, "36dB"},
+  { 19, "38dB"},
+  { 20, "40dB"},
+  { 21, "42dB"},
+  { 22, "44dB"},
+  { 23, "46dB"},
+  { 24, "48dB"},
+  { 25, "50dB"},
+  { 26, "52dB"},
+  { 27, "54dB"},
+  { 28, "56dB"},
+  { 29, "58dB"},
+  { 30, "60dB"},
+  { 31, "62dB"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_ReselectionThreshold_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_ReselectionThreshold_vals);
+
+static const value_string lte_rrc_Hysteresis_vals[] = {
+  { 0 , "0dB"},
+  { 1 , "0.5dB"},
+  { 2 , "1dB"},
+  { 3 , "1.5dB"},
+  { 4 , "2dB"},
+  { 5 , "2.5dB"},
+  { 6 , "3dB"},
+  { 7 , "3.5dB"},
+  { 8 , "4dB"},
+  { 9 , "4.5dB"},
+  { 10, "5dB"},
+  { 11, "5.5dB"},
+  { 12, "6dB"},
+  { 13, "6.5dB"},
+  { 14, "7dB"},
+  { 15, "7.5dB"},
+  { 16, "8dB"},
+  { 17, "8.5dB"},
+  { 18, "9dB"},
+  { 19, "9.5dB"},
+  { 20, "10dB"},
+  { 21, "10.5dB"},
+  { 22, "11dB"},
+  { 23, "11.5dB"},
+  { 24, "12dB"},
+  { 25, "12.5dB"},
+  { 26, "13dB"},
+  { 27, "13.5dB"},
+  { 28, "14dB"},
+  { 29, "14.5dB"},
+  { 30, "15dB"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_Hysteresis_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_Hysteresis_vals);
+
+static const value_string lte_rrc_s_Measure_vals[] = {
+  {  0, "disabled"},
+  {  1, "-139dBm"},
+  {  2, "-138dBm"},
+  {  3, "-137dBm"},
+  {  4, "-136dBm"},
+  {  5, "-135dBm"},
+  {  6, "-134dBm"},
+  {  7, "-133dBm"},
+  {  8, "-132dBm"},
+  {  9, "-131dBm"},
+  { 10, "-130dBm"},
+  { 11, "-129dBm"},
+  { 12, "-128dBm"},
+  { 13, "-127dBm"},
+  { 14, "-126dBm"},
+  { 15, "-125dBm"},
+  { 16, "-124dBm"},
+  { 17, "-123dBm"},
+  { 18, "-122dBm"},
+  { 19, "-121dBm"},
+  { 20, "-120dBm"},
+  { 21, "-119dBm"},
+  { 22, "-118dBm"},
+  { 23, "-117dBm"},
+  { 24, "-116dBm"},
+  { 25, "-115dBm"},
+  { 26, "-114dBm"},
+  { 27, "-113dBm"},
+  { 28, "-112dBm"},
+  { 29, "-111dBm"},
+  { 30, "-110dBm"},
+  { 31, "-109dBm"},
+  { 32, "-108dBm"},
+  { 33, "-107dBm"},
+  { 34, "-106dBm"},
+  { 35, "-105dBm"},
+  { 36, "-104dBm"},
+  { 37, "-103dBm"},
+  { 38, "-102dBm"},
+  { 39, "-101dBm"},
+  { 40, "-100dBm"},
+  { 41, "-99dBm"},
+  { 42, "-98dBm"},
+  { 43, "-97dBm"},
+  { 44, "-96dBm"},
+  { 45, "-95dBm"},
+  { 46, "-94dBm"},
+  { 47, "-93dBm"},
+  { 48, "-92dBm"},
+  { 49, "-91dBm"},
+  { 50, "-90dBm"},
+  { 51, "-89dBm"},
+  { 52, "-88dBm"},
+  { 53, "-87dBm"},
+  { 54, "-86dBm"},
+  { 55, "-85dBm"},
+  { 56, "-84dBm"},
+  { 57, "-83dBm"},
+  { 58, "-82dBm"},
+  { 59, "-81dBm"},
+  { 60, "-80dBm"},
+  { 61, "-79dBm"},
+  { 62, "-78dBm"},
+  { 63, "-77dBm"},
+  { 64, "-76dBm"},
+  { 65, "-75dBm"},
+  { 66, "-74dBm"},
+  { 67, "-73dBm"},
+  { 68, "-72dBm"},
+  { 69, "-71dBm"},
+  { 70, "-70dBm"},
+  { 71, "-69dBm"},
+  { 72, "-68dBm"},
+  { 73, "-67dBm"},
+  { 74, "-66dBm"},
+  { 75, "-65dBm"},
+  { 76, "-64dBm"},
+  { 77, "-63dBm"},
+  { 78, "-62dBm"},
+  { 79, "-61dBm"},
+  { 80, "-60dBm"},
+  { 81, "-59dBm"},
+  { 82, "-58dBm"},
+  { 83, "-57dBm"},
+  { 84, "-56dBm"},
+  { 85, "-55dBm"},
+  { 86, "-54dBm"},
+  { 87, "-53dBm"},
+  { 88, "-52dBm"},
+  { 89, "-51dBm"},
+  { 90, "-50dBm"},
+  { 91, "-49dBm"},
+  { 92, "-48dBm"},
+  { 93, "-47dBm"},
+  { 94, "-46dBm"},
+  { 95, "-45dBm"},
+  { 96, "-44dBm"},
+  { 97, "-43dBm"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_s_Measure_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_s_Measure_vals);
+
+static const value_string lte_rrc_utra_EcN0_vals[] = {
+  { 0 , "CPICH Ec/Io < -24dB"},
+  { 1 , "-24dB <= CPICH Ec/Io < -23.5dB"},
+  { 2 , "-23.5dB <= CPICH Ec/Io < -23dB"},
+  { 3 , "-23dB <= CPICH Ec/Io < -22.5dB"},
+  { 4 , "-22.5dB <= CPICH Ec/Io < -22dB"},
+  { 5 , "-22dB <= CPICH Ec/Io < -21.5dB"},
+  { 6 , "-21.5dB <= CPICH Ec/Io < -21dB"},
+  { 7 , "-21dB <= CPICH Ec/Io < -20.5dB"},
+  { 8 , "-20.5dB <= CPICH Ec/Io < -20dB"},
+  { 9 , "-20dB <= CPICH Ec/Io < -19.5dB"},
+  { 10, "-19.5dB <= CPICH Ec/Io < -19dB"},
+  { 11, "-19dB <= CPICH Ec/Io < -18.5dB"},
+  { 12, "-18.5dB <= CPICH Ec/Io < -18dB"},
+  { 13, "-18dB <= CPICH Ec/Io < -17.5dB"},
+  { 14, "-17.5dB <= CPICH Ec/Io < -17dB"},
+  { 15, "-17dB <= CPICH Ec/Io < -16.5dB"},
+  { 16, "-16.5dB <= CPICH Ec/Io < -16dB"},
+  { 17, "-16dB <= CPICH Ec/Io < -15.5dB"},
+  { 18, "-15.5dB <= CPICH Ec/Io < -15dB"},
+  { 19, "-15dB <= CPICH Ec/Io < -14.5dB"},
+  { 20, "-14.5dB <= CPICH Ec/Io < -14dB"},
+  { 21, "-14dB <= CPICH Ec/Io < -13.5dB"},
+  { 22, "-13.5dB <= CPICH Ec/Io < -13dB"},
+  { 23, "-13dB <= CPICH Ec/Io < -12.5dB"},
+  { 24, "-12.5dB <= CPICH Ec/Io < -12dB"},
+  { 25, "-12dB <= CPICH Ec/Io < -11.5dB"},
+  { 26, "-11.5dB <= CPICH Ec/Io < -11dB"},
+  { 27, "-11dB <= CPICH Ec/Io < -10.5dB"},
+  { 28, "-10.5dB <= CPICH Ec/Io < -10dB"},
+  { 29, "-10dB <= CPICH Ec/Io < -9.5dB"},
+  { 30, "-9.5dB <= CPICH Ec/Io < -9dB"},
+  { 31, "-9dB <= CPICH Ec/Io < -8.5dB"},
+  { 32, "-8.5dB <= CPICH Ec/Io < -8dB"},
+  { 33, "-8dB <= CPICH Ec/Io < -7.5dB"},
+  { 34, "-7.5dB <= CPICH Ec/Io < -7dB"},
+  { 35, "-7dB <= CPICH Ec/Io < -6.5dB"},
+  { 36, "-6.5dB <= CPICH Ec/Io < -6dB"},
+  { 37, "-6dB <= CPICH Ec/Io < -5.5dB"},
+  { 38, "-5.5dB <= CPICH Ec/Io < -5dB"},
+  { 39, "-5dB <= CPICH Ec/Io < -4.5dB"},
+  { 40, "-4.5dB <= CPICH Ec/Io < -4dB"},
+  { 41, "-4dB <= CPICH Ec/Io < -3.5dB"},
+  { 42, "-3.5dB <= CPICH Ec/Io < -3dB"},
+  { 43, "-3dB <= CPICH Ec/Io < -2.5dB"},
+  { 44, "-2.5dB <= CPICH Ec/Io < -2dB"},
+  { 45, "-2dB <= CPICH Ec/Io < -1.5dB"},
+  { 46, "-1.5dB <= CPICH Ec/Io < -1dB"},
+  { 47, "-1dB <= CPICH Ec/Io < -0.5dB"},
+  { 48, "-0.5dB <= CPICH Ec/Io < 0dB"},
+  { 49, "0dB <= CPICH Ec/Io"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_utra_EcN0_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_utra_EcN0_vals);
+
+static const value_string lte_rrc_utra_RSCP_vals[] = {
+  { -5, "RSCP < -120dBm"},
+  { -4, "-120dBm <= RSCP < -119dBm"},
+  { -3, "-119dBm <= RSCP < -118dBm"},
+  { -2, "-118dBm <= RSCP < -117dBm"},
+  { -1, "-117dBm <= RSCP < -116dBm"},
+  {  0, "-116dBm <= RSCP < -115dBm"},
+  {  1, "-115dBm <= RSCP < -114dBm"},
+  {  2, "-114dBm <= RSCP < -113dBm"},
+  {  3, "-113dBm <= RSCP < -112dBm"},
+  {  4, "-112dBm <= RSCP < -111dBm"},
+  {  5, "-111dBm <= RSCP < -110dBm"},
+  {  6, "-110dBm <= RSCP < -109dBm"},
+  {  7, "-109dBm <= RSCP < -108dBm"},
+  {  8, "-108dBm <= RSCP < -107dBm"},
+  {  9, "-107dBm <= RSCP < -106dBm"},
+  { 10, "-106dBm <= RSCP < -105dBm"},
+  { 11, "-105dBm <= RSCP < -104dBm"},
+  { 12, "-104dBm <= RSCP < -103dBm"},
+  { 13, "-103dBm <= RSCP < -102dBm"},
+  { 14, "-102dBm <= RSCP < -101dBm"},
+  { 15, "-101dBm <= RSCP < -100dBm"},
+  { 16, "-100dBm <= RSCP < -99dBm"},
+  { 17, "-99dBm <= RSCP < -98dBm"},
+  { 18, "-98dBm <= RSCP < -97dBm"},
+  { 19, "-97dBm <= RSCP < -96dBm"},
+  { 20, "-96dBm <= RSCP < -95dBm"},
+  { 21, "-95dBm <= RSCP < -94dBm"},
+  { 22, "-94dBm <= RSCP < -93dBm"},
+  { 23, "-93dBm <= RSCP < -92dBm"},
+  { 24, "-92dBm <= RSCP < -91dBm"},
+  { 25, "-91dBm <= RSCP < -90dBm"},
+  { 26, "-90dBm <= RSCP < -89dBm"},
+  { 27, "-89dBm <= RSCP < -88dBm"},
+  { 28, "-88dBm <= RSCP < -87dBm"},
+  { 29, "-87dBm <= RSCP < -86dBm"},
+  { 30, "-86dBm <= RSCP < -85dBm"},
+  { 31, "-85dBm <= RSCP < -84dBm"},
+  { 32, "-84dBm <= RSCP < -83dBm"},
+  { 33, "-83dBm <= RSCP < -82dBm"},
+  { 34, "-82dBm <= RSCP < -81dBm"},
+  { 35, "-81dBm <= RSCP < -80dBm"},
+  { 36, "-80dBm <= RSCP < -79dBm"},
+  { 37, "-79dBm <= RSCP < -78dBm"},
+  { 38, "-78dBm <= RSCP < -77dBm"},
+  { 39, "-77dBm <= RSCP < -76dBm"},
+  { 40, "-76dBm <= RSCP < -75dBm"},
+  { 41, "-75dBm <= RSCP < -74dBm"},
+  { 42, "-74dBm <= RSCP < -73dBm"},
+  { 43, "-73dBm <= RSCP < -72dBm"},
+  { 44, "-72dBm <= RSCP < -71dBm"},
+  { 45, "-71dBm <= RSCP < -70dBm"},
+  { 46, "-70dBm <= RSCP < -69dBm"},
+  { 47, "-69dBm <= RSCP < -68dBm"},
+  { 48, "-68dBm <= RSCP < -67dBm"},
+  { 49, "-67dBm <= RSCP < -66dBm"},
+  { 50, "-66dBm <= RSCP < -65dBm"},
+  { 51, "-65dBm <= RSCP < -64dBm"},
+  { 52, "-64dBm <= RSCP < -63dBm"},
+  { 53, "-63dBm <= RSCP < -62dBm"},
+  { 54, "-62dBm <= RSCP < -61dBm"},
+  { 55, "-61dBm <= RSCP < -60dBm"},
+  { 56, "-60dBm <= RSCP < -59dBm"},
+  { 57, "-59dBm <= RSCP < -58dBm"},
+  { 58, "-58dBm <= RSCP < -57dBm"},
+  { 59, "-57dBm <= RSCP < -56dBm"},
+  { 60, "-56dBm <= RSCP < -55dBm"},
+  { 61, "-55dBm <= RSCP < -54dBm"},
+  { 62, "-54dBm <= RSCP < -53dBm"},
+  { 63, "-53dBm <= RSCP < -52dBm"},
+  { 64, "-52dBm <= RSCP < -51dBm"},
+  { 65, "-51dBm <= RSCP < -50dBm"},
+  { 66, "-50dBm <= RSCP < -49dBm"},
+  { 67, "-49dBm <= RSCP < -48dBm"},
+  { 68, "-48dBm <= RSCP < -47dBm"},
+  { 69, "-47dBm <= RSCP < -46dBm"},
+  { 70, "-46dBm <= RSCP < -45dBm"},
+  { 71, "-45dBm <= RSCP < -44dBm"},
+  { 72, "-44dBm <= RSCP < -43dBm"},
+  { 73, "-43dBm <= RSCP < -42dBm"},
+  { 74, "-42dBm <= RSCP < -41dBm"},
+  { 75, "-41dBm <= RSCP < -40dBm"},
+  { 76, "-40dBm <= RSCP < -39dBm"},
+  { 77, "-39dBm <= RSCP < -38dBm"},
+  { 78, "-38dBm <= RSCP < -37dBm"},
+  { 79, "-37dBm <= RSCP < -36dBm"},
+  { 80, "-36dBm <= RSCP < -35dBm"},
+  { 81, "-35dBm <= RSCP < -34dBm"},
+  { 82, "-34dBm <= RSCP < -33dBm"},
+  { 83, "-33dBm <= RSCP < -32dBm"},
+  { 84, "-32dBm <= RSCP < -31dBm"},
+  { 85, "-31dBm <= RSCP < -30dBm"},
+  { 86, "-30dBm <= RSCP < -29dBm"},
+  { 87, "-29dBm <= RSCP < -28dBm"},
+  { 88, "-28dBm <= RSCP < -27dBm"},
+  { 89, "-27dBm <= RSCP < -26dBm"},
+  { 90, "-26dBm <= RSCP < -25dBm"},
+  { 91, "-25dBm <= RSCP"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_utra_RSCP_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_utra_RSCP_vals);
+
+static const value_string lte_rrc_a3_a6_Offset_vals[] = {
+  { -30, "-15dB"},
+  { -29, "-14.5dB"},
+  { -28, "-14dB"},
+  { -27, "-13.5dB"},
+  { -26, "-13dB"},
+  { -25, "-12.5dB"},
+  { -24, "-12dB"},
+  { -23, "-11.5dB"},
+  { -22, "-11dB"},
+  { -21, "-10.5dB"},
+  { -20, "-10dB"},
+  { -19, "-9.5dB"},
+  { -18, "-9dB"},
+  { -17, "-8.5dB"},
+  { -16, "-8dB"},
+  { -15, "-7.5dB"},
+  { -14, "-7dB"},
+  { -13, "-6.5dB"},
+  { -12, "-6dB"},
+  { -11, "-5.5dB"},
+  { -10, "-5dB"},
+  {  -9, "-4.5dB"},
+  {  -8, "-4dB"},
+  {  -7, "-3.5dB"},
+  {  -6, "-3dB"},
+  {  -5, "-2.5dB"},
+  {  -4, "-2dB"},
+  {  -3, "-1.5dB"},
+  {  -2, "-1dB"},
+  {  -1, "-0.5dB"},
+  {   0, "0dB"},
+  {   1, "0.5dB"},
+  {   2, "1dB"},
+  {   3, "1.5dB"},
+  {   4, "2dB"},
+  {   5, "2.5dB"},
+  {   6, "3dB"},
+  {   7, "3.5dB"},
+  {   8, "4dB"},
+  {   9, "4.5dB"},
+  {  10, "5dB"},
+  {  11, "5.5dB"},
+  {  12, "6dB"},
+  {  13, "6.5dB"},
+  {  14, "7dB"},
+  {  15, "7.5dB"},
+  {  16, "8dB"},
+  {  17, "8.5dB"},
+  {  18, "9dB"},
+  {  19, "9.5dB"},
+  {  20, "10dB"},
+  {  21, "10.5dB"},
+  {  22, "11dB"},
+  {  23, "11.5dB"},
+  {  24, "12dB"},
+  {  25, "12.5dB"},
+  {  26, "13dB"},
+  {  27, "13.5dB"},
+  {  28, "14dB"},
+  {  29, "14.5dB"},
+  {  30, "15dB"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_a3_a6_Offset_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_a3_a6_Offset_vals);
+
+static const value_string lte_rrc_threshold_RSRP_vals[] = {
+  {  0, "-140dBm"},
+  {  1, "-139dBm"},
+  {  2, "-138dBm"},
+  {  3, "-137dBm"},
+  {  4, "-136dBm"},
+  {  5, "-135dBm"},
+  {  6, "-134dBm"},
+  {  7, "-133dBm"},
+  {  8, "-132dBm"},
+  {  9, "-131dBm"},
+  { 10, "-130dBm"},
+  { 11, "-129dBm"},
+  { 12, "-128dBm"},
+  { 13, "-127dBm"},
+  { 14, "-126dBm"},
+  { 15, "-125dBm"},
+  { 16, "-124dBm"},
+  { 17, "-123dBm"},
+  { 18, "-122dBm"},
+  { 19, "-121dBm"},
+  { 20, "-120dBm"},
+  { 21, "-119dBm"},
+  { 22, "-118dBm"},
+  { 23, "-117dBm"},
+  { 24, "-116dBm"},
+  { 25, "-115dBm"},
+  { 26, "-114dBm"},
+  { 27, "-113dBm"},
+  { 28, "-112dBm"},
+  { 29, "-111dBm"},
+  { 30, "-110dBm"},
+  { 31, "-109dBm"},
+  { 32, "-108dBm"},
+  { 33, "-107dBm"},
+  { 34, "-106dBm"},
+  { 35, "-105dBm"},
+  { 36, "-104dBm"},
+  { 37, "-103dBm"},
+  { 38, "-102dBm"},
+  { 39, "-101dBm"},
+  { 40, "-100dBm"},
+  { 41, "-99dBm"},
+  { 42, "-98dBm"},
+  { 43, "-97dBm"},
+  { 44, "-96dBm"},
+  { 45, "-95dBm"},
+  { 46, "-94dBm"},
+  { 47, "-93dBm"},
+  { 48, "-92dBm"},
+  { 49, "-91dBm"},
+  { 50, "-90dBm"},
+  { 51, "-89dBm"},
+  { 52, "-88dBm"},
+  { 53, "-87dBm"},
+  { 54, "-86dBm"},
+  { 55, "-85dBm"},
+  { 56, "-84dBm"},
+  { 57, "-83dBm"},
+  { 58, "-82dBm"},
+  { 59, "-81dBm"},
+  { 60, "-80dBm"},
+  { 61, "-79dBm"},
+  { 62, "-78dBm"},
+  { 63, "-77dBm"},
+  { 64, "-76dBm"},
+  { 65, "-75dBm"},
+  { 66, "-74dBm"},
+  { 67, "-73dBm"},
+  { 68, "-72dBm"},
+  { 69, "-71dBm"},
+  { 70, "-70dBm"},
+  { 71, "-69dBm"},
+  { 72, "-68dBm"},
+  { 73, "-67dBm"},
+  { 74, "-66dBm"},
+  { 75, "-65dBm"},
+  { 76, "-64dBm"},
+  { 77, "-63dBm"},
+  { 78, "-62dBm"},
+  { 79, "-61dBm"},
+  { 80, "-60dBm"},
+  { 81, "-59dBm"},
+  { 82, "-58dBm"},
+  { 83, "-57dBm"},
+  { 84, "-56dBm"},
+  { 85, "-55dBm"},
+  { 86, "-54dBm"},
+  { 87, "-53dBm"},
+  { 88, "-52dBm"},
+  { 89, "-51dBm"},
+  { 90, "-50dBm"},
+  { 91, "-49dBm"},
+  { 92, "-48dBm"},
+  { 93, "-47dBm"},
+  { 94, "-46dBm"},
+  { 95, "-45dBm"},
+  { 96, "-44dBm"},
+  { 97, "-43dBm"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_threshold_RSRP_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_threshold_RSRP_vals);
+
+static const value_string lte_rrc_threshold_RSRQ_vals[] = {
+  {  0, "-20dB"},
+  {  1, "-19.5dB"},
+  {  2, "-19dB"},
+  {  3, "-18.5dB"},
+  {  4, "-18dB"},
+  {  5, "-17.5dB"},
+  {  6, "-17dB"},
+  {  7, "-16.5dB"},
+  {  8, "-16dB"},
+  {  9, "-15.5dB"},
+  { 10, "-15dB"},
+  { 11, "-14.5dB"},
+  { 12, "-14dB"},
+  { 13, "-13.5dB"},
+  { 14, "-13dB"},
+  { 15, "-12.5dB"},
+  { 16, "-12dB"},
+  { 17, "-11.5dB"},
+  { 18, "-11dB"},
+  { 19, "-10.5dB"},
+  { 20, "-10dB"},
+  { 21, "-9.5dB"},
+  { 22, "-9dB"},
+  { 23, "-8.5dB"},
+  { 24, "-8dB"},
+  { 25, "-7.5dB"},
+  { 26, "-7dB"},
+  { 27, "-6.5dB"},
+  { 28, "-6dB"},
+  { 29, "-5.5dB"},
+  { 30, "-5dB"},
+  { 31, "-4.5dB"},
+  { 32, "-4dB"},
+  { 33, "-3.5dB"},
+  { 34, "-3dB"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_threshold_RSRQ_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_threshold_RSRQ_vals);
+
+static const value_string lte_rrc_thresholdGERAN_vals[] = {
+  { 0 , "-110dBm"},
+  { 1 , "-109dBm"},
+  { 2 , "-108dBm"},
+  { 3 , "-107dBm"},
+  { 4 , "-106dBm"},
+  { 5 , "-105dBm"},
+  { 6 , "-104dBm"},
+  { 7 , "-103dBm"},
+  { 8 , "-102dBm"},
+  { 9 , "-101dBm"},
+  { 10, "-100dBm"},
+  { 11, "-99dBm"},
+  { 12, "-98dBm"},
+  { 13, "-97dBm"},
+  { 14, "-96dBm"},
+  { 15, "-95dBm"},
+  { 16, "-94dBm"},
+  { 17, "-93dBm"},
+  { 18, "-92dBm"},
+  { 19, "-91dBm"},
+  { 20, "-90dBm"},
+  { 21, "-89dBm"},
+  { 22, "-88dBm"},
+  { 23, "-87dBm"},
+  { 24, "-86dBm"},
+  { 25, "-85dBm"},
+  { 26, "-84dBm"},
+  { 27, "-83dBm"},
+  { 28, "-82dBm"},
+  { 29, "-81dBm"},
+  { 30, "-80dBm"},
+  { 31, "-79dBm"},
+  { 32, "-78dBm"},
+  { 33, "-77dBm"},
+  { 34, "-76dBm"},
+  { 35, "-75dBm"},
+  { 36, "-74dBm"},
+  { 37, "-73dBm"},
+  { 38, "-72dBm"},
+  { 39, "-71dBm"},
+  { 40, "-70dBm"},
+  { 41, "-69dBm"},
+  { 42, "-68dBm"},
+  { 43, "-67dBm"},
+  { 44, "-66dBm"},
+  { 45, "-65dBm"},
+  { 46, "-64dBm"},
+  { 47, "-63dBm"},
+  { 48, "-62dBm"},
+  { 49, "-61dBm"},
+  { 50, "-60dBm"},
+  { 51, "-59dBm"},
+  { 52, "-58dBm"},
+  { 53, "-57dBm"},
+  { 54, "-56dBm"},
+  { 55, "-55dBm"},
+  { 56, "-54dBm"},
+  { 57, "-53dBm"},
+  { 58, "-52dBm"},
+  { 59, "-51dBm"},
+  { 60, "-50dBm"},
+  { 61, "-49dBm"},
+  { 62, "-48dBm"},
+  { 63, "-47dBm"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_thresholdGERAN_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_thresholdGERAN_vals);
+
+static const value_string lte_rrc_thresholdUTRA_EcN0_vals[] = {
+  { 0 , "-24.5dB"},
+  { 1 , "-24dB"},
+  { 2 , "-23.5dB"},
+  { 3 , "-23dB"},
+  { 4 , "-22.5dB"},
+  { 5 , "-22dB"},
+  { 6 , "-21.5dB"},
+  { 7 , "-21dB"},
+  { 8 , "-20.5dB"},
+  { 9 , "-20dB"},
+  { 10, "-19.5dB"},
+  { 11, "-19dB"},
+  { 12, "-18.5dB"},
+  { 13, "-18dB"},
+  { 14, "-17.5dB"},
+  { 15, "-17dB"},
+  { 16, "-16.5dB"},
+  { 17, "-16dB"},
+  { 18, "-15.5dB"},
+  { 19, "-15dB"},
+  { 20, "-14.5dB"},
+  { 21, "-14dB"},
+  { 22, "-13.5dB"},
+  { 23, "-13dB"},
+  { 24, "-12.5dB"},
+  { 25, "-12dB"},
+  { 26, "-11.5dB"},
+  { 27, "-11dB"},
+  { 28, "-10.5dB"},
+  { 29, "-10dB"},
+  { 30, "-9.5dB"},
+  { 31, "-9dB"},
+  { 32, "-8.5dB"},
+  { 33, "-8dB"},
+  { 34, "-7.5dB"},
+  { 35, "-7dB"},
+  { 36, "-6.5dB"},
+  { 37, "-6dB"},
+  { 38, "-5.5dB"},
+  { 39, "-5dB"},
+  { 40, "-4.5dB"},
+  { 41, "-4dB"},
+  { 42, "-3.5dB"},
+  { 43, "-3dB"},
+  { 44, "-2.5dB"},
+  { 45, "-2dB"},
+  { 46, "-1.5dB"},
+  { 47, "-1dB"},
+  { 48, "-0.5dB"},
+  { 49, "0dB"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_thresholdUTRA_EcN0_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_thresholdUTRA_EcN0_vals);
+
+static const value_string lte_rrc_thresholdUTRA_RSCP_vals[] = {
+  { -5, "-120dBm"},
+  { -4, "-119dBm"},
+  { -3, "-118dBm"},
+  { -2, "-117dBm"},
+  { -1, "-116dBm"},
+  {  0, "-115dBm"},
+  {  1, "-114dBm"},
+  {  2, "-113dBm"},
+  {  3, "-112dBm"},
+  {  4, "-111dBm"},
+  {  5, "-110dBm"},
+  {  6, "-109dBm"},
+  {  7, "-108dBm"},
+  {  8, "-107dBm"},
+  {  9, "-106dBm"},
+  { 10, "-105dBm"},
+  { 11, "-104dBm"},
+  { 12, "-103dBm"},
+  { 13, "-102dBm"},
+  { 14, "-101dBm"},
+  { 15, "-100dBm"},
+  { 16, "-99dBm"},
+  { 17, "-98dBm"},
+  { 18, "-97dBm"},
+  { 19, "-96dBm"},
+  { 20, "-95dBm"},
+  { 21, "-94dBm"},
+  { 22, "-93dBm"},
+  { 23, "-92dBm"},
+  { 24, "-91dBm"},
+  { 25, "-90dBm"},
+  { 26, "-89dBm"},
+  { 27, "-88dBm"},
+  { 28, "-87dBm"},
+  { 29, "-86dBm"},
+  { 30, "-85dBm"},
+  { 31, "-84dBm"},
+  { 32, "-83dBm"},
+  { 33, "-82dBm"},
+  { 34, "-81dBm"},
+  { 35, "-80dBm"},
+  { 36, "-79dBm"},
+  { 37, "-78dBm"},
+  { 38, "-77dBm"},
+  { 39, "-76dBm"},
+  { 40, "-75dBm"},
+  { 41, "-74dBm"},
+  { 42, "-73dBm"},
+  { 43, "-72dBm"},
+  { 44, "-71dBm"},
+  { 45, "-70dBm"},
+  { 46, "-69dBm"},
+  { 47, "-68dBm"},
+  { 48, "-67dBm"},
+  { 49, "-66dBm"},
+  { 50, "-65dBm"},
+  { 51, "-64dBm"},
+  { 52, "-63dBm"},
+  { 53, "-62dBm"},
+  { 54, "-61dBm"},
+  { 55, "-60dBm"},
+  { 56, "-59dBm"},
+  { 57, "-58dBm"},
+  { 58, "-57dBm"},
+  { 59, "-56dBm"},
+  { 60, "-55dBm"},
+  { 61, "-54dBm"},
+  { 62, "-53dBm"},
+  { 63, "-52dBm"},
+  { 64, "-51dBm"},
+  { 65, "-50dBm"},
+  { 66, "-49dBm"},
+  { 67, "-48dBm"},
+  { 68, "-47dBm"},
+  { 69, "-46dBm"},
+  { 70, "-45dBm"},
+  { 71, "-44dBm"},
+  { 72, "-43dBm"},
+  { 73, "-42dBm"},
+  { 74, "-41dBm"},
+  { 75, "-40dBm"},
+  { 76, "-39dBm"},
+  { 77, "-38dBm"},
+  { 78, "-37dBm"},
+  { 79, "-36dBm"},
+  { 80, "-35dBm"},
+  { 81, "-34dBm"},
+  { 82, "-33dBm"},
+  { 83, "-32dBm"},
+  { 84, "-31dBm"},
+  { 85, "-30dBm"},
+  { 86, "-29dBm"},
+  { 87, "-28dBm"},
+  { 88, "-27dBm"},
+  { 89, "-26dBm"},
+  { 90, "-25dBm"},
+  { 91, "-24dBm"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_thresholdUTRA_RSCP_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_thresholdUTRA_RSCP_vals);
+
+static const value_string lte_rrc_RSRP_Range_vals[] = {
+  {  0, "RSRP < -140dBm"},
+  {  1, "-140dBm <= RSRP < -139dBm"},
+  {  2, "-139dBm <= RSRP < -138dBm"},
+  {  3, "-138dBm <= RSRP < -137dBm"},
+  {  4, "-137dBm <= RSRP < -136dBm"},
+  {  5, "-136dBm <= RSRP < -135dBm"},
+  {  6, "-135dBm <= RSRP < -134dBm"},
+  {  7, "-134dBm <= RSRP < -133dBm"},
+  {  8, "-133dBm <= RSRP < -132dBm"},
+  {  9, "-132dBm <= RSRP < -131dBm"},
+  { 10, "-131dBm <= RSRP < -130dBm"},
+  { 11, "-130dBm <= RSRP < -129dBm"},
+  { 12, "-129dBm <= RSRP < -128dBm"},
+  { 13, "-128dBm <= RSRP < -127dBm"},
+  { 14, "-127dBm <= RSRP < -126dBm"},
+  { 15, "-126dBm <= RSRP < -125dBm"},
+  { 16, "-125dBm <= RSRP < -124dBm"},
+  { 17, "-124dBm <= RSRP < -123dBm"},
+  { 18, "-123dBm <= RSRP < -122dBm"},
+  { 19, "-122dBm <= RSRP < -121dBm"},
+  { 20, "-121dBm <= RSRP < -120dBm"},
+  { 21, "-120dBm <= RSRP < -119dBm"},
+  { 22, "-119dBm <= RSRP < -118dBm"},
+  { 23, "-118dBm <= RSRP < -117dBm"},
+  { 24, "-117dBm <= RSRP < -116dBm"},
+  { 25, "-116dBm <= RSRP < -115dBm"},
+  { 26, "-115dBm <= RSRP < -114dBm"},
+  { 27, "-114dBm <= RSRP < -113dBm"},
+  { 28, "-113dBm <= RSRP < -112dBm"},
+  { 29, "-112dBm <= RSRP < -111dBm"},
+  { 30, "-111dBm <= RSRP < -110dBm"},
+  { 31, "-110dBm <= RSRP < -109dBm"},
+  { 32, "-109dBm <= RSRP < -108dBm"},
+  { 33, "-108dBm <= RSRP < -107dBm"},
+  { 34, "-107dBm <= RSRP < -106dBm"},
+  { 35, "-106dBm <= RSRP < -105dBm"},
+  { 36, "-105dBm <= RSRP < -104dBm"},
+  { 37, "-104dBm <= RSRP < -103dBm"},
+  { 38, "-103dBm <= RSRP < -102dBm"},
+  { 39, "-102dBm <= RSRP < -101dBm"},
+  { 40, "-101dBm <= RSRP < -100dBm"},
+  { 41, "-100dBm <= RSRP < -99dBm"},
+  { 42, "-99dBm <= RSRP < -98dBm"},
+  { 43, "-98dBm <= RSRP < -97dBm"},
+  { 44, "-97dBm <= RSRP < -96dBm"},
+  { 45, "-96dBm <= RSRP < -95dBm"},
+  { 46, "-95dBm <= RSRP < -94dBm"},
+  { 47, "-94dBm <= RSRP < -93dBm"},
+  { 48, "-93dBm <= RSRP < -92dBm"},
+  { 49, "-92dBm <= RSRP < -91dBm"},
+  { 50, "-91dBm <= RSRP < -90dBm"},
+  { 51, "-90dBm <= RSRP < -89dBm"},
+  { 52, "-89dBm <= RSRP < -88dBm"},
+  { 53, "-88dBm <= RSRP < -87dBm"},
+  { 54, "-87dBm <= RSRP < -86dBm"},
+  { 55, "-86dBm <= RSRP < -85dBm"},
+  { 56, "-85dBm <= RSRP < -84dBm"},
+  { 57, "-84dBm <= RSRP < -83dBm"},
+  { 58, "-83dBm <= RSRP < -82dBm"},
+  { 59, "-82dBm <= RSRP < -81dBm"},
+  { 60, "-81dBm <= RSRP < -80dBm"},
+  { 61, "-80dBm <= RSRP < -79dBm"},
+  { 62, "-79dBm <= RSRP < -78dBm"},
+  { 63, "-78dBm <= RSRP < -77dBm"},
+  { 64, "-77dBm <= RSRP < -76dBm"},
+  { 65, "-76dBm <= RSRP < -75dBm"},
+  { 66, "-75dBm <= RSRP < -74dBm"},
+  { 67, "-74dBm <= RSRP < -73dBm"},
+  { 68, "-73dBm <= RSRP < -72dBm"},
+  { 69, "-72dBm <= RSRP < -71dBm"},
+  { 70, "-71dBm <= RSRP < -70dBm"},
+  { 71, "-70dBm <= RSRP < -69dBm"},
+  { 72, "-69dBm <= RSRP < -68dBm"},
+  { 73, "-68dBm <= RSRP < -67dBm"},
+  { 74, "-67dBm <= RSRP < -66dBm"},
+  { 75, "-66dBm <= RSRP < -65dBm"},
+  { 76, "-65dBm <= RSRP < -64dBm"},
+  { 77, "-64dBm <= RSRP < -63dBm"},
+  { 78, "-63dBm <= RSRP < -62dBm"},
+  { 79, "-62dBm <= RSRP < -61dBm"},
+  { 80, "-61dBm <= RSRP < -60dBm"},
+  { 81, "-60dBm <= RSRP < -59dBm"},
+  { 82, "-59dBm <= RSRP < -58dBm"},
+  { 83, "-58dBm <= RSRP < -57dBm"},
+  { 84, "-57dBm <= RSRP < -56dBm"},
+  { 85, "-56dBm <= RSRP < -55dBm"},
+  { 86, "-55dBm <= RSRP < -54dBm"},
+  { 87, "-54dBm <= RSRP < -53dBm"},
+  { 88, "-53dBm <= RSRP < -52dBm"},
+  { 89, "-52dBm <= RSRP < -51dBm"},
+  { 90, "-51dBm <= RSRP < -50dBm"},
+  { 91, "-50dBm <= RSRP < -49dBm"},
+  { 92, "-49dBm <= RSRP < -48dBm"},
+  { 93, "-48dBm <= RSRP < -47dBm"},
+  { 94, "-47dBm <= RSRP < -46dBm"},
+  { 95, "-46dBm <= RSRP < -45dBm"},
+  { 96, "-45dBm <= RSRP < -44dBm"},
+  { 97, "-44dBm <= RSRP"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_RSRP_Range_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_RSRP_Range_vals);
+
+static const value_string lte_rrc_RSRQ_Range_vals[] = {
+  {  0, "RSRQ < -19.5dB"},
+  {  1, "-19.5dB <= RSRQ < -19dB"},
+  {  2, "-19dB <= RSRQ < -18.5dB"},
+  {  3, "-18.5dB <= RSRQ < -18dB"},
+  {  4, "-18dB <= RSRQ < -17.5dB"},
+  {  5, "-17.5dB <= RSRQ < -17dB"},
+  {  6, "-17dB <= RSRQ < -16.5dB"},
+  {  7, "-16.5dB <= RSRQ < -16dB"},
+  {  8, "-16dB <= RSRQ < -15.5dB"},
+  {  9, "-15.5dB <= RSRQ < -15dB"},
+  { 10, "-15dB <= RSRQ < -14.5dB"},
+  { 11, "-14.5dB <= RSRQ < -14dB"},
+  { 12, "-14dB <= RSRQ < -13.5dB"},
+  { 13, "-13.5dB <= RSRQ < -13dB"},
+  { 14, "-13dB <= RSRQ < -12.5dB"},
+  { 15, "-12.5dB <= RSRQ < -12dB"},
+  { 16, "-12dB <= RSRQ < -11.5dB"},
+  { 17, "-11.5dB <= RSRQ < -11dB"},
+  { 18, "-11dB <= RSRQ < -10.5dB"},
+  { 19, "-10.5dB <= RSRQ < -10dB"},
+  { 20, "-10dB <= RSRQ < -9.5dB"},
+  { 21, "-9.5dB <= RSRQ < -9dB"},
+  { 22, "-9dB <= RSRQ < -8.5dB"},
+  { 23, "-8.5dB <= RSRQ < -8dB"},
+  { 24, "-8dB <= RSRQ < -7.5dB"},
+  { 25, "-7.5dB <= RSRQ < -7dB"},
+  { 26, "-7dB <= RSRQ < -6.5dB"},
+  { 27, "-6.5dB <= RSRQ < -6dB"},
+  { 28, "-6dB <= RSRQ < -5.5dB"},
+  { 29, "-5.5dB <= RSRQ < -5dB"},
+  { 30, "-5dB <= RSRQ < -4.5dB"},
+  { 31, "-4.5dB <= RSRQ < -4dB"},
+  { 32, "-4dB <= RSRQ < -3.5dB"},
+  { 33, "-3.5dB <= RSRQ < -3dB"},
+  { 34, "-3dB <= RSRQ"},
+  {  0, NULL}
+};
+static value_string_ext lte_rrc_RSRQ_Range_vals_ext = VALUE_STRING_EXT_INIT(lte_rrc_RSRQ_Range_vals);
+
+static const true_false_string lte_rrc_duration_val = {
+  "indefinite",
+  "single"
+};
+
 #include "packet-lte-rrc-fn.c"
 
 static void
