@@ -1,7 +1,7 @@
 /* packet-m3ap.c
  * Routines for M3 Application Protocol packet dissection
  *
- * $Id: packet-m3ap-template.c 40790 2012-02-01 19:27:08Z etxrab $
+ * $Id: packet-m3ap-template.c 42494 2012-05-08 00:24:07Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,8 @@
 #include "packet-ber.h"
 #include "packet-per.h"
 #include "packet-e212.h"
+#include "packet-gtpv2.h"
+#include "packet-ntp.h"
 
 #define PNAME  "M3 Application Protocol"
 #define PSNAME "M3AP"
@@ -53,6 +55,9 @@ static dissector_handle_t m3ap_handle=NULL;
 /* Initialize the protocol and registered fields */
 static int proto_m3ap = -1;
 
+static int hf_m3ap_Absolute_Time_ofMBMS_Data_value = -1;
+static int hf_m3ap_IPAddress = -1;
+
 #include "packet-m3ap-hf.c"
 
 /* Initialize the subtree pointers */
@@ -61,9 +66,9 @@ static int ett_m3ap = -1;
 #include "packet-m3ap-ett.c"
 
 enum{
-	INITIATING_MESSAGE,
-	SUCCESSFUL_OUTCOME,
-	UNSUCCESSFUL_OUTCOME
+  INITIATING_MESSAGE,
+  SUCCESSFUL_OUTCOME,
+  UNSUCCESSFUL_OUTCOME
 };
 
 /* Global variables */
@@ -90,53 +95,63 @@ static int dissect_UnsuccessfulOutcomeValue(tvbuff_t *tvb, packet_info *pinfo, p
 
 static int dissect_ProtocolIEFieldValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	return (dissector_try_uint(m3ap_ies_dissector_table, ProtocolIE_ID, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
+  return (dissector_try_uint(m3ap_ies_dissector_table, ProtocolIE_ID, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
 }
 
 static int dissect_ProtocolExtensionFieldExtensionValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	return (dissector_try_uint(m3ap_extension_dissector_table, ProtocolExtensionID, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
+  return (dissector_try_uint(m3ap_extension_dissector_table, ProtocolIE_ID, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
 }
 
 static int dissect_InitiatingMessageValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	return (dissector_try_uint(m3ap_proc_imsg_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
+  return (dissector_try_uint(m3ap_proc_imsg_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
 }
 
 static int dissect_SuccessfulOutcomeValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	return (dissector_try_uint(m3ap_proc_sout_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
+  return (dissector_try_uint(m3ap_proc_sout_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
 }
 
 static int dissect_UnsuccessfulOutcomeValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	return (dissector_try_uint(m3ap_proc_uout_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
+  return (dissector_try_uint(m3ap_proc_uout_dissector_table, ProcedureCode, tvb, pinfo, tree)) ? tvb_length(tvb) : 0;
 }
 
 
 static void
 dissect_m3ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-        proto_item      *m3ap_item = NULL;
-        proto_tree      *m3ap_tree = NULL;
+  proto_item      *m3ap_item = NULL;
+  proto_tree      *m3ap_tree = NULL;
 
-        /* make entry in the Protocol column on summary display */
-        if (check_col(pinfo->cinfo, COL_PROTOCOL))
-                col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);
+  /* make entry in the Protocol column on summary display */
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);
 
-    /* create the m3ap protocol tree */
-    if (tree) {
-        m3ap_item = proto_tree_add_item(tree, proto_m3ap, tvb, 0, -1, FALSE);
-        m3ap_tree = proto_item_add_subtree(m3ap_item, ett_m3ap);
+  /* create the m3ap protocol tree */
+  if (tree) {
+    m3ap_item = proto_tree_add_item(tree, proto_m3ap, tvb, 0, -1, ENC_NA);
+    m3ap_tree = proto_item_add_subtree(m3ap_item, ett_m3ap);
 
-        dissect_M3AP_PDU_PDU(tvb, pinfo, m3ap_tree);
-    }
+    dissect_M3AP_PDU_PDU(tvb, pinfo, m3ap_tree);
+  }
 }
 /*--- proto_register_m3ap -------------------------------------------*/
 void proto_register_m3ap(void) {
 
   /* List of fields */
   static hf_register_info hf[] = {
+    { &hf_m3ap_Absolute_Time_ofMBMS_Data_value,
+      { "Absolute-Time-ofMBMS-Data-value", "m3ap.Absolute_Time_ofMBMS_Data_value",
+         FT_STRING, BASE_NONE, NULL, 0,
+         NULL, HFILL }
+    },
+    { &hf_m3ap_IPAddress,
+      { "IPAddress", "m3ap.IPAddress",
+         FT_IPv6, BASE_NONE, NULL, 0,
+         NULL, HFILL }
+    },
 
 #include "packet-m3ap-hfarr.c"
   };
@@ -160,8 +175,6 @@ void proto_register_m3ap(void) {
   m3ap_proc_imsg_dissector_table = register_dissector_table("m3ap.proc.imsg", "M3AP-ELEMENTARY-PROCEDURE InitiatingMessage", FT_UINT32, BASE_DEC);
   m3ap_proc_sout_dissector_table = register_dissector_table("m3ap.proc.sout", "M3AP-ELEMENTARY-PROCEDURE SuccessfulOutcome", FT_UINT32, BASE_DEC);
   m3ap_proc_uout_dissector_table = register_dissector_table("m3ap.proc.uout", "M3AP-ELEMENTARY-PROCEDURE UnsuccessfulOutcome", FT_UINT32, BASE_DEC); 
-
-
 }
 
 
@@ -169,24 +182,24 @@ void proto_register_m3ap(void) {
 void
 proto_reg_handoff_m3ap(void)
 {
-	static gboolean inited = FALSE;
-	static guint SctpPort;
+  static gboolean inited = FALSE;
+  static guint SctpPort;
 
-	if( !inited ) {
-		m3ap_handle = create_dissector_handle(dissect_m3ap, proto_m3ap);
-		dissector_add_uint("sctp.ppi", PROTO_3GPP_M3AP_PROTOCOL_ID, m3ap_handle);
-		inited = TRUE;
+  if( !inited ) {
+    m3ap_handle = create_dissector_handle(dissect_m3ap, proto_m3ap);
+    dissector_add_uint("sctp.ppi", PROTO_3GPP_M3AP_PROTOCOL_ID, m3ap_handle);
+    inited = TRUE;
 #include "packet-m3ap-dis-tab.c"
-	}
-	else {
-		if (SctpPort != 0) {
-			dissector_delete_uint("sctp.port", SctpPort, m3ap_handle);
-		}
-	}
-
-	SctpPort = global_m3ap_port;
-	if (SctpPort != 0) {
-		dissector_add_uint("sctp.port", SctpPort, m3ap_handle);
-	}
+    dissector_add_uint("m3ap.extension", 17, new_create_dissector_handle(dissect_AllocationAndRetentionPriority_PDU, proto_m3ap));
+  }
+  else {
+    if (SctpPort != 0) {
+      dissector_delete_uint("sctp.port", SctpPort, m3ap_handle);
+    }
+  }
 
+  SctpPort = global_m3ap_port;
+  if (SctpPort != 0) {
+    dissector_add_uint("sctp.port", SctpPort, m3ap_handle);
+  }
 }
