@@ -2,7 +2,7 @@
  * Written by Shaun Jackman <sjackman@gmail.com>.
  * Copyright 2007 Shaun Jackman
  *
- * $Id: packet-mpeg-pes-template.c 40458 2012-01-13 16:18:39Z alagoutte $
+ * $Id: packet-mpeg-pes-template.c 42496 2012-05-08 00:31:56Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -473,7 +473,7 @@ dissect_mpeg_pes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	} else if (stream == STREAM_SYSTEM || stream == STREAM_PRIVATE2) {
 		unsigned data_length = tvb_get_ntohs(tvb, offset / 8);
 		proto_tree_add_item(tree, hf_mpeg_pes_length, tvb,
-				offset / 8, 2, FALSE);
+				offset / 8, 2, ENC_BIG_ENDIAN);
 		offset += 2 * 8;
 
 		proto_tree_add_item(tree, hf_mpeg_pes_data, tvb,
@@ -481,7 +481,7 @@ dissect_mpeg_pes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	} else if (stream == STREAM_PADDING) {
 		unsigned padding_length = tvb_get_ntohs(tvb, offset / 8);
 		proto_tree_add_item(tree, hf_mpeg_pes_length, tvb,
-				offset / 8, 2, FALSE);
+				offset / 8, 2, ENC_BIG_ENDIAN);
 		offset += 2 * 8;
 
 		proto_tree_add_item(tree, hf_mpeg_pes_padding, tvb,
@@ -536,7 +536,7 @@ dissect_mpeg_pes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		} else {
 			unsigned data_length = tvb_get_ntohs(tvb, offset / 8);
 			proto_tree_add_item(tree, hf_mpeg_pes_length, tvb,
-					offset / 8, 2, FALSE);
+					offset / 8, 2, ENC_BIG_ENDIAN);
 			offset += 2 * 8;
 
 			proto_tree_add_item(tree, hf_mpeg_pes_data, tvb,
