@@ -2,7 +2,7 @@
  * Routines for Online Certificate Status Protocol (RFC2560) packet dissection
  *  Ronnie Sahlberg 2004
  *
- * $Id: packet-ocsp-template.c 35657 2011-01-26 09:07:11Z etxrab $
+ * $Id: packet-ocsp-template.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -72,7 +72,7 @@ dissect_ocsp_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
 
 	if(parent_tree){
-		item=proto_tree_add_item(parent_tree, proto_ocsp, tvb, 0, -1, FALSE);
+		item=proto_tree_add_item(parent_tree, proto_ocsp, tvb, 0, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_ocsp);
 	}
 
@@ -94,7 +94,7 @@ dissect_ocsp_response(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree
 
 
 	if(parent_tree){
-		item=proto_tree_add_item(parent_tree, proto_ocsp, tvb, 0, -1, FALSE);
+		item=proto_tree_add_item(parent_tree, proto_ocsp, tvb, 0, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_ocsp);
 	}
 
