@@ -2,7 +2,7 @@
  * Routines for PKCS#12: Personal Information Exchange packet dissection
  * Graeme Lunt 2006
  *
- * $Id: packet-pkcs12-template.c 37433 2011-05-27 11:03:04Z stig $
+ * $Id: packet-pkcs12-template.c 39954 2011-11-20 08:59:19Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -90,7 +90,7 @@ static void append_oid(proto_tree *tree, const char *oid)
 
 #ifdef HAVE_LIBGCRYPT
 
-int
+static int
 generate_key_or_iv(unsigned int id, tvbuff_t *salt_tvb, unsigned int iter,
 		       const char *pw, unsigned int req_keylen, char * keybuf)
 {
@@ -383,7 +383,7 @@ int PBE_decrypt_data(const char *object_identifier_id _U_, tvbuff_t *encrypted_t
 
 static int strip_octet_string(tvbuff_t *tvb)
 {
-  gint8 class;
+  gint8 ber_class;
   gboolean pc, ind;
   gint32 tag;
   guint32 len;
@@ -393,10 +393,10 @@ static int strip_octet_string(tvbuff_t *tvb)
   /* if we use CMS (rather than PKCS#7) - which we are - we need to strip the OCTET STRING tag */
   /* before proceeding */
 
-  offset = get_ber_identifier(tvb, 0, &class, &pc, &tag);
+  offset = get_ber_identifier(tvb, 0, &ber_class, &pc, &tag);
   offset = get_ber_length(tvb, offset, &len, &ind);
 
-  if((class == BER_CLASS_UNI) && (tag == BER_UNI_TAG_OCTETSTRING))
+  if((ber_class == BER_CLASS_UNI) && (tag == BER_UNI_TAG_OCTETSTRING))
     return offset;
 
   return 0;
