@@ -2,7 +2,7 @@
  * Routines for RFC3820 PKIXProxy packet dissection
  *  Ronnie Sahlberg 2004
  *
- * $Id: packet-pkixproxy-template.c 23324 2007-10-31 21:24:16Z etxrab $
+ * $Id: packet-pkixproxy-template.c 32417 2010-04-07 16:54:29Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,9 +32,6 @@
 #include <epan/oids.h>
 #include <epan/asn1.h>
 
-#include <stdio.h>
-#include <string.h>
-
 #include "packet-ber.h"
 #include "packet-pkixproxy.h"
 
