@@ -2,7 +2,7 @@
  * Routines for ROS packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-ros-template.c 38122 2011-07-19 18:48:31Z stig $
+ * $Id: packet-ros-template.c 40462 2012-01-13 16:22:50Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -137,7 +137,6 @@ static gboolean ros_try_string(const char *oid, tvbuff_t *tvb, packet_info *pinf
 	gint32     opcode_lcl = 0;
 	const gchar *opname = NULL;
 	const gchar *suffix = NULL;
-	int offset = 0;
 	new_dissector_t opdissector = NULL;
 	const value_string *lookup;
 	proto_item *item=NULL;
@@ -196,7 +195,7 @@ static gboolean ros_try_string(const char *oid, tvbuff_t *tvb, packet_info *pinf
 					col_append_str(pinfo->cinfo, COL_INFO, suffix);
 			}
 
-			offset = (*opdissector)(tvb, pinfo, ros_tree);
+			(*opdissector)(tvb, pinfo, ros_tree);
 
 			return TRUE;
 		}
@@ -439,7 +438,6 @@ dissect_ros(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 				dissect_unknown_ber(pinfo, tvb, offset, next_tree);
 			}
 
-			offset = tvb_length(tvb);
 			break;
 		}
 	}
