@@ -2,7 +2,7 @@
  * Routines for SMRSE Short Message Relay Service packet dissection
  *   Ronnie Sahlberg 2004
  *
- * $Id: packet-smrse-template.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-smrse-template.c 39803 2011-11-12 12:37:38Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -76,13 +76,11 @@ dissect_smrse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	proto_item *item = NULL;
 	proto_tree *tree = NULL;
 	guint8 reserved, tag;
-	guint16 length;
 	int offset=0;
 	asn1_ctx_t asn1_ctx;
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	reserved=tvb_get_guint8(tvb, 0);
-	length=tvb_get_ntohs(tvb,1);
 	tag=tvb_get_guint8(tvb, 3);
 
 	if( reserved!= 126 )
