@@ -4,7 +4,7 @@
  * 2004  Alejandro Vaquero, add support Conversations for SDP
  * 2006  Alejandro Vaquero, add T30 reassemble and dissection
  *
- * $Id: packet-t38-template.c 39164 2011-09-27 12:05:32Z etxrab $
+ * $Id: packet-t38-template.c 40872 2012-02-05 16:19:21Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -458,6 +458,8 @@ init_t38_info_conv(packet_info *pinfo)
 			p_t38_conv->src_t38_info.packet_lost = 0;
 			p_t38_conv->src_t38_info.burst_lost = 0;
 			p_t38_conv->src_t38_info.time_first_t4_data = 0;
+			p_t38_conv->src_t38_info.additional_hdlc_data_field_counter = 0;
+			p_t38_conv->src_t38_info.seqnum_prev_data_field = -1;
 
 			p_t38_conv->dst_t38_info.reass_ID = 0;
 			p_t38_conv->dst_t38_info.reass_start_seqnum = -1;
@@ -466,6 +468,8 @@ init_t38_info_conv(packet_info *pinfo)
 			p_t38_conv->dst_t38_info.packet_lost = 0;
 			p_t38_conv->dst_t38_info.burst_lost = 0;
 			p_t38_conv->dst_t38_info.time_first_t4_data = 0;
+			p_t38_conv->dst_t38_info.additional_hdlc_data_field_counter = 0;
+			p_t38_conv->dst_t38_info.seqnum_prev_data_field = -1;
 
 			conversation_add_proto_data(p_conv, proto_t38, p_t38_conv);
 		}
