@@ -1,7 +1,7 @@
 /* packet-tetra.c
  * Routines for TETRA packet dissection
  *
- *$Id: packet-tetra-template.c 39294 2011-10-06 16:50:13Z wmeier $
+ *$Id: packet-tetra-template.c 41590 2012-03-16 02:31:42Z wmeier $
  *
  * Copyright (c) 2007 - 2011 Professional Mobile Communication Research Group,
  *    Beijing Institute of Technology, China
@@ -34,9 +34,10 @@
 
 #include <glib.h>
 #include <epan/packet.h>
+#include <epan/prefs.h>
+#include <epan/oids.h>
 #include <epan/conversation.h>
 #include <epan/asn1.h>
-#include <epan/prefs.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -78,6 +79,7 @@ static gint hf_tetra_rvstr = -1;
 static gint hf_tetra_carriernumber = -1;
 static gint hf_tetra_rxchannel1 = -1;
 static gint hf_tetra_rxchannel2 = -1;
+static gint hf_tetra_rxchannel3 = -1;
 static gint hf_tetra_crc = -1;
 static gint hf_tetra_len0 = -1;
 
@@ -321,12 +323,12 @@ static void dissect_tetra_UNITDATA_IND(tvbuff_t *tvb, packet_info *pinfo, proto_
 
 	/* Length */
 	rxreg = tvb_get_letohl(tvb, offset);
-	tetra_sub_item = proto_tree_add_uint(tetra_tree, hf_tetra_len0, tvb, offset, 4, rxreg);
+	proto_tree_add_uint(tetra_tree, hf_tetra_len0, tvb, offset, 4, rxreg);
 
 	/* RvSteR */
 	offset += 4;
 	rxreg = tvb_get_letohl(tvb, offset);
-	tetra_sub_item = proto_tree_add_uint(tetra_tree, hf_tetra_rvstr, tvb, offset, 4, rxreg);
+	proto_tree_add_uint(tetra_tree, hf_tetra_rvstr, tvb, offset, 4, rxreg);
 
 	/* Logical channels */
 	channels = rxreg & 0x3;
@@ -335,7 +337,11 @@ static void dissect_tetra_UNITDATA_IND(tvbuff_t *tvb, packet_info *pinfo, proto_
 
 	pdu_offset = offset + 4;
 	for(i = 0; i < channels; i++) {
-		gint hf_channel[] = {hf_tetra_rxchannel1, hf_tetra_rxchannel2};
+		gint hf_channel[] = {
+		    hf_tetra_rxchannel1,
+		    hf_tetra_rxchannel2,
+		    hf_tetra_rxchannel3
+		};
 		gint byte_len, bits_len, remaining_bits;
 
 		/* Channel type */
@@ -373,7 +379,7 @@ void dissect_tetra_UNITDATA_REQ(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
 	/* TxR */
 	txreg = tvb_get_letohl(tvb, offset);
-	tetra_sub_item = proto_tree_add_uint(tetra_tree, hf_tetra_txreg, tvb, offset, 4, txreg);
+	proto_tree_add_uint(tetra_tree, hf_tetra_txreg, tvb, offset, 4, txreg);
 
 	/* Logical channels */
 	channels = (txreg & 0x3) + 1;
@@ -486,13 +492,12 @@ dissect_tetra(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		tetra_item = proto_tree_add_item(tree, proto_tetra, tvb, 0, -1, ENC_NA);
 		tetra_tree = proto_item_add_subtree(tetra_item, ett_tetra);
-		tetra_header_tree = proto_item_add_subtree(tetra_item, ett_tetra);
 
 		offset ++;
 
 		/* Carrier number */
 		if(include_carrier_number) {
-			tetra_sub_item = proto_tree_add_uint(tetra_tree, hf_tetra_carriernumber, tvb, offset, 1, carriernumber);
+			proto_tree_add_uint(tetra_tree, hf_tetra_carriernumber, tvb, offset, 1, carriernumber);
 			offset ++;
 		}
 
@@ -589,11 +594,14 @@ void proto_register_tetra (void)
 		{ &hf_tetra_rxchannel2,
 		{ "Channel 2", "tetra.rxchannel2", FT_UINT8, BASE_DEC, VALS(recvchanneltypenames), 0x0,
 		"Logical channels type", HFILL }},
+		{ &hf_tetra_rxchannel3,
+		{ "Channel 3", "tetra.rxchannel3", FT_UINT8, BASE_DEC, VALS(recvchanneltypenames), 0x0,
+		"Logical channels type", HFILL }},
 		{ &hf_tetra_timer,
 		{ "Timer", "tetra.timer", FT_UINT16, BASE_HEX, NULL, 0x0,
 		 "Timer Register", HFILL }},
 		{ &hf_tetra_crc,
-		{ "CRC", "tetra.crc", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+		{ "CRC", "tetra.crc", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		 "CRC result", HFILL }},
 		{ &hf_tetra_len0,
 		{ "Length", "tetra.len0", FT_UINT16, BASE_DEC, NULL, 0x0,
