@@ -1,7 +1,7 @@
 /* capture-pcap-util.c
  * Utility routines for packet capture
  *
- * $Id: capture-pcap-util.c 32853 2010-05-18 02:36:02Z guy $
+ * $Id: capture-pcap-util.c 36861 2011-04-26 02:47:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,7 +82,7 @@ if_info_add_address(if_info_t *if_info, struct sockaddr *addr)
 	switch (addr->sa_family) {
 
 	case AF_INET:
-		ai = (struct sockaddr_in *)addr;
+		ai = (struct sockaddr_in *)(void *)addr;
 		if_addr = (if_addr_t *)g_malloc(sizeof(*if_addr));
 		if_addr->ifat_type = IF_AT_IPv4;
 		if_addr->addr.ip4_addr =
@@ -92,7 +92,7 @@ if_info_add_address(if_info_t *if_info, struct sockaddr *addr)
 
 #ifdef INET6
 	case AF_INET6:
-		ai6 = (struct sockaddr_in6 *)addr;
+		ai6 = (struct sockaddr_in6 *)(void *)addr;
 		if_addr = (if_addr_t *)g_malloc(sizeof(*if_addr));
 		if_addr->ifat_type = IF_AT_IPv6;
 		memcpy((void *)&if_addr->addr.ip6_addr,
