@@ -1,12 +1,11 @@
 /* capture-wpcap.h
  *
- * $Id: capture-wpcap.h 24034 2008-01-08 22:54:51Z stig $
+ * $Id: capture-wpcap.h 40335 2011-12-29 23:09:42Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 2001 Gerald Combs
  *
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -25,10 +24,21 @@
 #ifndef CAPTURE_WPCAP_H
 #define CAPTURE_WPCAP_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 extern gboolean has_wpcap;
 
 
-void
-load_wpcap(void);
+extern void load_wpcap(void);
 
-#endif
+/* error message, if WinPcap couldn't be loaded */
+/* will use g_strdup, don't forget to g_free the returned string! */
+extern char *cant_load_winpcap_err(const char *app_name);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* CAPTURE_WPCAP_H */
