@@ -1,7 +1,7 @@
 /* capture_ifinfo.h
  * Definitions for routines to get information about capture interfaces
  *
- * $Id: capture_ifinfo.h 38350 2011-08-05 07:19:17Z tuexen $
+ * $Id: capture_ifinfo.h 40334 2011-12-29 22:49:49Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,6 +25,10 @@
 #ifndef __CAPTURE_IFINFO_H__
 #define __CAPTURE_IFINFO_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /*
  * The list of interfaces returned by "get_interface_list()" is
  * a list of these structures.
@@ -60,6 +64,7 @@ extern GList *capture_interface_list(int *err, char **err_str);
 /* Error values from "get_interface_list()/capture_interface_list()". */
 #define	CANT_GET_INTERFACE_LIST	1	/* error getting list */
 #define	NO_INTERFACES_FOUND	2	/* list is empty */
+#define	DONT_HAVE_PCAP		3	/* couldn't load WinPcap */
 
 void free_interface_list(GList *if_list);
 
@@ -93,4 +98,8 @@ void free_if_capabilities(if_capabilities_t *caps);
 
 void add_interface_to_remote_list(if_info_t *if_info);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* __CAPTURE_IFINFO_H__ */
