@@ -1,7 +1,7 @@
 /* capture_info.h
  * capture info functions
  *
- * $Id: capture_info.h 25574 2008-06-24 03:38:15Z guy $
+ * $Id: capture_info.h 40321 2011-12-29 00:08:47Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -24,7 +24,7 @@
 
 
 /** @file
- *  
+ *
  * capture info functions
  *
  */
@@ -34,6 +34,10 @@
 
 #include "capture_opts.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* open the info - init values (wtap, counts), create dialog */
 extern void capture_info_open(capture_options *capture_opts);
 
@@ -73,5 +77,8 @@ capture_info    *cinfo);
 extern void capture_info_ui_destroy(
 capture_info    *cinfo);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* capture_info.h */
