@@ -1,7 +1,7 @@
 /* capture_opts.h
  * Capture options (all parameters needed to do the actual capture)
  *
- * $Id: capture_opts.h 39498 2011-10-20 19:44:40Z tuexen $
+ * $Id: capture_opts.h 41712 2012-03-21 06:31:39Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,6 +38,10 @@
 
 #include "capture_ifinfo.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* Current state of capture engine. XXX - differentiate states */
 typedef enum {
     CAPTURE_STOPPED,        /**< stopped */
@@ -73,6 +77,75 @@ typedef enum {
 } capture_sampling;
 #endif
 
+typedef enum {
+    IF_WIRED,
+    IF_AIRPCAP,
+    IF_PIPE,
+    IF_STDIN,
+    IF_BLUETOOTH,
+    IF_WIRELESS,
+    IF_DIALUP,
+    IF_USB,
+    IF_VIRTUAL
+} interface_type;
+
+#ifdef HAVE_PCAP_REMOTE
+struct remote_host_info {
+    gchar *remote_host;          /**< Host name or network address for remote capturing */
+    gchar *remote_port;          /**< TCP port of remote RPCAP server */
+    gint auth_type;              /**< Authentication type */
+    gchar *auth_username;        /**< Remote authentication parameters */
+    gchar *auth_password;        /**< Remote authentication parameters */
+    gboolean datatx_udp;
+    gboolean nocap_rpcap;
+    gboolean nocap_local;
+};
+
+typedef struct remote_options_tag {
+    capture_source src_type;
+    struct remote_host_info remote_host_opts;
+#ifdef HAVE_PCAP_SETSAMPLING
+    capture_sampling sampling_method;
+    int sampling_param;
+#endif
+} remote_options;
+#endif /* HAVE_PCAP_REMOTE */
+
+typedef struct interface_tag {
+    gchar *name;
+    gchar *display_name;
+    guint type;
+    gchar *addresses;
+    gint no_addresses;
+    gchar *cfilter;
+    GList *links;
+    gint active_dlt;
+    gboolean pmode;
+    gboolean has_snaplen;
+    guint snaplen;
+    gboolean local;
+#if defined(_WIN32) || defined(HAVE_PCAP_CREATE)
+    gint buffer;
+#endif
+#ifdef HAVE_PCAP_CREATE
+    gboolean monitor_mode_enabled;
+    gboolean monitor_mode_supported;
+#endif
+#ifdef HAVE_PCAP_REMOTE
+    remote_options remote_opts;
+#endif
+    guint32     last_packets;
+    if_info_t   if_info;
+    gboolean    selected;
+    gboolean    hidden;
+    gboolean    locked;
+} interface_t;
+
+typedef struct link_row_tag {
+    gchar *name;
+    gint dlt;
+} link_row;
+
 typedef struct interface_options_tag {
     gchar *name;
     gchar *descr;
@@ -108,6 +181,8 @@ typedef struct capture_options_tag {
     void     *cf;                   /**< handle to cfile (note: untyped handle) */
     GArray   *ifaces;               /**< array of interfaces.
                                          Currently only used by dumpcap. */
+    GArray   *all_ifaces;
+    guint    num_selected;
     interface_options default_options;
     gboolean saving_to_file;        /**< TRUE if capture is writing to a file */
     gchar    *save_file;            /**< the capture file name */
@@ -190,4 +265,23 @@ capture_opts_trim_ring_num_files(capture_options *capture_opts);
 extern gboolean
 capture_opts_trim_iface(capture_options *capture_opts, const char *capture_device);
 
+extern void
+collect_ifaces(capture_options *capture_opts);
+
+typedef struct {
+    gboolean monitor_mode;
+    int linktype;
+} cap_settings_t;
+
+/** Get capture settings for interface
+ *
+ * @param if_name interface name
+ */
+cap_settings_t
+capture_get_cap_settings (gchar *if_name);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* capture_opts.h */
