@@ -1,7 +1,7 @@
 /* capture_stop_conditions.c
  * Implementation for 'stop condition handler'.
  *
- * $Id: capture_stop_conditions.c 25722 2008-07-12 17:23:18Z sake $
+ * $Id: capture_stop_conditions.c 40806 2012-02-02 11:54:33Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -22,6 +22,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <time.h>
 #include <string.h>
 #include <stdlib.h>
