@@ -1,7 +1,7 @@
 /* capture_ui_utils.c
  * Declarations of utilities for capture user interfaces
  *
- * $Id: capture_ui_utils.h 37794 2011-06-27 00:09:03Z tuexen $
+ * $Id: capture_ui_utils.h 40321 2011-12-29 00:08:47Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,6 +27,10 @@
 
 #include "capture_opts.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /** @file
  *  GList of available capture interfaces.
  */
@@ -99,4 +103,8 @@ char *build_capture_combo_name(GList *if_list, gchar *if_name);
  */
 const char *get_iface_description_for_interface(capture_options *capture_opts, guint i);
 
-#endif
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* __CAPTURE_UI_UTILS_H__ */
