@@ -2,7 +2,7 @@
  * capture_file GUI-independent manipulation
  * Vassilii Khachaturov <vassilii@tarunz.org>
  *
- * $Id: cfile.c 36881 2011-04-27 02:54:44Z guy $
+ * $Id: cfile.c 42721 2012-05-20 08:56:06Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,16 +37,16 @@ void
 cap_file_init(capture_file *cf)
 {
   /* Initialize the capture file struct */
-  cf->filename      = NULL;
-  cf->source        = NULL;
-  cf->is_tempfile   = FALSE;
-  cf->user_saved    = FALSE;
-  cf->count         = 0;
-  cf->has_snap      = FALSE;
-  cf->snap          = WTAP_MAX_PACKET_SIZE;
-  cf->wth           = NULL;
-  cf->rfcode        = NULL;
-  cf->dfilter       = NULL;
-  cf->redissecting  = FALSE;
-  cf->frames        = NULL;
+  cf->filename        = NULL;
+  cf->source          = NULL;
+  cf->is_tempfile     = FALSE;
+  cf->unsaved_changes = FALSE;
+  cf->count           = 0;
+  cf->has_snap        = FALSE;
+  cf->snap            = WTAP_MAX_PACKET_SIZE;
+  cf->wth             = NULL;
+  cf->rfcode          = NULL;
+  cf->dfilter         = NULL;
+  cf->redissecting    = FALSE;
+  cf->frames          = NULL;
 }
