@@ -1,7 +1,7 @@
 /* cfile.h
  * capture_file definition & GUI-independent manipulation
  *
- * $Id: cfile.h 41321 2012-03-02 11:41:50Z guy $
+ * $Id: cfile.h 43393 2012-06-20 01:13:06Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -70,11 +70,14 @@ typedef struct _capture_file {
   gchar       *filename;        /* Name of capture file */
   gchar       *source;          /* Temp file source, e.g. "Pipe from elsewhere" */
   gboolean     is_tempfile;     /* Is capture file a temporary file? */
-  gboolean     user_saved;      /* If capture file is temporary or modified, has it been saved by user yet? */
+  gboolean     unsaved_changes; /* Does the capture file have changes that have not been saved? */
   gint64       f_datalen;       /* Size of capture file data (uncompressed) */
   guint16      cd_t;            /* File type of capture file */
-  int          lnk_t;           /* Link-layer type with which to save capture */
+  gboolean     iscompressed;    /* TRUE if the file is compressed */
+  int          lnk_t;           /* File link-layer type; could be WTAP_ENCAP_PER_PACKET */
+  GArray      *linktypes;       /* Array of packet link-layer types */
   guint32      count;           /* Total number of frames */
+  guint64      packet_comment_count; /* Number of comments in frames (could be >1 per frame... */
   guint32      displayed_count; /* Number of displayed frames */
   guint32      marked_count;    /* Number of marked frames */
   guint32      ignored_count;   /* Number of ignored frames */
