@@ -1,7 +1,7 @@
 /* color_filters.c
  * Routines for color filters
  *
- * $Id: color_filters.c 38573 2011-08-17 07:10:33Z etxrab $
+ * $Id: color_filters.c 40529 2012-01-16 01:07:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,10 +43,11 @@
 #include "color_filters.h"
 #include "file.h"
 #include <epan/dfilter/dfilter.h>
-#include "simple_dialog.h"
-#include "ui_util.h"
 #include <epan/prefs.h>
 
+#include "ui/simple_dialog.h"
+#include "ui/ui_util.h"
+
 #define RED_COMPONENT(x)   (guint16) (((((x) >> 16) & 0xff) * 65535 / 255))
 #define GREEN_COMPONENT(x) (guint16) (((((x) >>  8) & 0xff) * 65535 / 255))
 #define BLUE_COMPONENT(x)  (guint16) ( (((x)        & 0xff) * 65535 / 255))
