@@ -1,7 +1,7 @@
 /* color_filters.h
  * Definitions for color filters
  *
- * $Id: color_filters.h 37859 2011-07-01 21:13:40Z stig $
+ * $Id: color_filters.h 40321 2011-12-29 00:08:47Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -24,6 +24,10 @@
 #ifndef  __COLOR_FILTERS_H__
 #define  __COLOR_FILTERS_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define CONVERSATION_COLOR_PREFIX       "___conversation_color_filter___"
 /** @file
  *  Color filters.
@@ -190,6 +194,8 @@ void color_filter_delete(color_filter_t *colorf);
  */
 void color_filter_list_delete(GSList **cfl);
 
-
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif
