@@ -1,7 +1,7 @@
 /* address_to_str.c
  * Routines for utilities to convert addresses to strings.
  *
- * $Id: address_to_str.c 37015 2011-05-08 10:23:53Z alagoutte $
+ * $Id: address_to_str.c 37679 2011-06-16 07:02:23Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -334,9 +334,9 @@ eui64_to_str(const guint64 ad) {
   buf=ep_alloc(EUI64_STR_LEN);
 
   /* Copy and convert the address to network byte order. */
-  *(guint64 *)(p_eui64) = pntoh64(&(ad));
+  *(guint64 *)(void *)(p_eui64) = pntoh64(&(ad));
 
-  sprintf(buf, "%.2x:%.2x:%.2x:%.2x:%.2x:%.2x:%.2x:%.2x", 
+  g_snprintf(buf, EUI64_STR_LEN, "%.2x:%.2x:%.2x:%.2x:%.2x:%.2x:%.2x:%.2x", 
   p_eui64[0], p_eui64[1], p_eui64[2], p_eui64[3],
   p_eui64[4], p_eui64[5], p_eui64[6], p_eui64[7] );
   return buf;
@@ -395,7 +395,9 @@ ib_addr_to_str_buf( const address *addr, gchar *buf, int buf_len){
 						  buf_len - PREAMBLE_STR_LEN) == NULL ) /* Returns NULL if no space and does not touch buf */
 			g_snprintf ( buf, buf_len, BUF_TOO_SMALL_ERR ); /* Let the unexpected value alert user */
 	} else {	/* this is a LID (16 bits) */
-		guint16 lid_number = *((guint16*) addr->data);
+		guint16 lid_number;
+		
+		memcpy((void *)&lid_number, addr->data, sizeof lid_number);
 		g_snprintf(buf,buf_len,"LID: %u",lid_number);
 	}
 }
