@@ -4,7 +4,7 @@
  * for calculation of delays in camel calls
  * Copyright 2006 Florent Drouin
  *
- * $Id: camel-persistentdata.c 27392 2009-02-07 16:01:26Z wmeier $
+ * $Id: camel-persistentdata.c 40507 2012-01-14 20:14:43Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,12 +34,12 @@
 #include <string.h>
 
 #include <epan/emem.h>
-#include "epan/packet.h"
-#include "epan/tap.h"
+#include <epan/packet.h>
+#include <epan/tap.h>
 #include <epan/asn1.h>
-#include "epan/camel-persistentdata.h"
-#include "epan/dissectors/packet-tcap.h"
-#include "epan/dissectors/packet-mtp3.h"
+#include <epan/camel-persistentdata.h>
+#include <epan/dissectors/packet-tcap.h>
+#include <epan/dissectors/packet-mtp3.h>
 
 const value_string  camelSRTtype_naming[]= {
   { CAMELSRT_SESSION,         "TCAP_Session" },
@@ -233,7 +233,7 @@ void
 camelsrt_init_routine(void)
 {
 
-  /* free hash-tables and mem_chunks for SRT */
+  /* free hash-table for SRT */
   if (srt_calls != NULL) {
 #ifdef DEBUG_CAMELSRT
     dbg(16,"Destroy hash ");
@@ -241,7 +241,7 @@ camelsrt_init_routine(void)
     g_hash_table_destroy(srt_calls);
   }
 
-  /* create new hash-tables and mem_chunks for SRT */
+  /* create new hash-table for SRT */
   srt_calls = g_hash_table_new(camelsrt_call_hash, camelsrt_call_equal);
 #ifdef DEBUG_CAMELSRT
   dbg(16,"Create hash ");
