@@ -1,7 +1,7 @@
 /* column-utils.h
  * Definitions for column utility structures and routines
  *
- * $Id: column-utils.h 39036 2011-09-19 05:15:58Z etxrab $
+ * $Id: column-utils.h 40743 2012-01-28 02:21:03Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,12 +52,6 @@ extern void	col_setup(column_info *cinfo, const gint num_cols);
  */
 extern void	col_init(column_info *cinfo);
 
-/** Set the format of the "variable time format".
- *
- * Internal, don't use this in dissectors!
- */
-extern void	col_set_fmt_time(const frame_data *fd, column_info *cinfo, const gint fmt, const gint col);
-
 /** Fill in all columns of the given packet which are based on values from frame_data.
  *
  * Internal, don't use this in dissectors!
