@@ -1,7 +1,7 @@
 /* column_info.h
  * Definitions for column structures and routines
  *
- * $Id: column_info.h 35311 2010-12-30 20:16:33Z stig $
+ * $Id: column_info.h 37898 2011-07-04 21:43:34Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -132,8 +132,10 @@ enum {
   COL_RES_SRC_PORT,   /**< 55) Resolved source port */
   COL_UNRES_SRC_PORT, /**< 56) Unresolved source port */
   COL_TEI,            /**< 57) Q.921 TEI */
-  COL_CLS_TIME,       /**< 58) Command line-specified time (default relative) */
-  NUM_COL_FMTS        /**< 59) Should always be last */
+  COL_UTC_DATE_TIME,  /**< 58) UTC date and time */
+  COL_UTC_TIME,       /**< 59) UTC time */
+  COL_CLS_TIME,       /**< 60) Command line-specified time (default relative) */
+  NUM_COL_FMTS        /**< 61) Should always be last */
 };
 
 #ifdef __cplusplus
