@@ -1,6 +1,6 @@
 /* airpdcap.c
  *
- * $Id: airpdcap.c 39081 2011-09-21 17:49:11Z wmeier $
+ * $Id: airpdcap.c 40511 2012-01-15 12:29:44Z jmayer $
  * Copyright (c) 2006 CACE Technologies, Davis (California)
  * All rights reserved.
  *
@@ -45,14 +45,14 @@
 #include <epan/strutil.h>
 #include <epan/emem.h>
 #include <epan/pint.h>
-#include <epan/crypt/crypt-rc4.h>
+#include <epan/crypt/rc4.h>
 #include <epan/crypt/airpdcap_rijndael.h>
 
 #include "airpdcap_system.h"
 #include "airpdcap_int.h"
 
-#include "crypt-sha1.h"
-#include "crypt-md5.h"
+#include "sha1.h"
+#include "md5.h"
 
 #include "airpdcap_debug.h"
 
