@@ -1,6 +1,6 @@
 /* airpdcap_system.h
  *
- * $Id: airpdcap_system.h 33930 2010-08-26 15:24:49Z etxrab $
+ * $Id: airpdcap_system.h 38969 2011-09-12 08:23:15Z etxrab $
  *
  * Copyright (c) 2006 CACE Technologies, Davis (California)
  * All rights reserved.
@@ -336,13 +336,6 @@ INT AirPDcapDestroyContext(
 	PAIRPDCAP_CONTEXT ctx)
 	;
 
-
-extern INT AirPDcapWepDecrypt(
-	const UCHAR *seed,
-	const size_t seed_len,	/* max AIRPDCAP_KEYBUF_SIZE	*/
-	UCHAR *cypher_text,
-	const size_t data_len)
-	;
 extern INT AirPDcapCcmpDecrypt(
 	UINT8 *m,
         gint mac_header_len,
