@@ -1,6 +1,6 @@
 /* dfilter-macro.h
  *
- * $Id: dfilter-macro.h 22427 2007-07-30 23:32:47Z lego $
+ * $Id: dfilter-macro.h 39838 2011-11-15 04:26:38Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,7 @@ void dfilter_macro_save(const gchar*, gchar**);
 void dfilter_macro_dump(void);
 
 /* applies all macros to the given text and returns the resulting string or NULL on failure */
-gchar* dfilter_macro_apply(const gchar* text, guint depth, const gchar** error);
+gchar* dfilter_macro_apply(const gchar* text, const gchar** error);
 
 void dfilter_macro_init(void);
 
