@@ -1,5 +1,5 @@
 /*
- * $Id: sttype-range.c 18197 2006-05-21 05:12:17Z sahlberg $
+ * $Id: sttype-range.c 43019 2012-06-03 09:26:15Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,7 +62,7 @@ range_new(gpointer junk)
 static void
 range_free(gpointer value)
 {
-	range_t	*range = value;
+	range_t	*range = (range_t*)value;
 	assert_magic(range, RANGE_MAGIC);
 
 	if (range->drange)
@@ -76,7 +76,7 @@ sttype_range_remove_drange(stnode_t *node)
 {
 	range_t		*range;
 
-	range = stnode_data(node);
+	range = (range_t*)stnode_data(node);
 	assert_magic(range, RANGE_MAGIC);
 
 	range->drange = NULL;
@@ -89,10 +89,10 @@ sttype_range_set(stnode_t *node, stnode_t *field, GSList* drange_list)
 {
 	range_t		*range;
 
-	range = stnode_data(node);
+	range = (range_t*)stnode_data(node);
 	assert_magic(range, RANGE_MAGIC);
 
-	range->hfinfo = stnode_data(field);
+	range->hfinfo = (header_field_info *)stnode_data(field);
 	stnode_free(field);
 
 	range->drange = drange_new_from_list(drange_list);
