@@ -1,7 +1,7 @@
 /* packet-3com-njack.c
  * Routines for the disassembly of the 3com NetworkJack management protocol
  *
- * $Id: packet-3com-njack.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-3com-njack.c 40511 2012-01-15 12:29:44Z jmayer $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  *
@@ -512,7 +512,7 @@ dissect_tlvs(tvbuff_t *tvb, proto_tree *njack_tree, guint32 offset)
 }
 
 #if 0
-#include <epan/crypt/crypt-md5.h>
+#include <epan/crypt/md5.h>
 
 static gboolean
 verify_password(tvbuff_t *tvb, const char *password)
