@@ -1,7 +1,7 @@
 /* packet-aarp.c
  * Routines for Appletalk ARP packet disassembly
  *
- * $Id: packet-aarp.c 39640 2011-10-27 20:30:38Z wmeier $
+ * $Id: packet-aarp.c 43066 2012-06-04 13:52:46Z etxrab $
  *
  * Simon Wilkinson <sxw@dcs.ed.ac.uk>
  *
@@ -107,7 +107,7 @@ tvb_atalkid_to_str(tvbuff_t *tvb, gint offset)
   gint node;
   gchar *cur;
 
-  cur=ep_alloc(16);
+  cur=(gchar *)ep_alloc(16);
   node=tvb_get_guint8(tvb, offset)<<8|tvb_get_guint8(tvb, offset+1);
   g_snprintf(cur, 16, "%d.%d",node,tvb_get_guint8(tvb, offset+2));
   return cur;
