@@ -2,7 +2,7 @@
  * Routines for ADwin configuration protocol dissection
  * Copyright 2010, Thomas Boehne <TBoehne[AT]ADwin.de>
  *
- * $Id: packet-adwin-config.c 41385 2012-03-06 22:12:42Z wmeier $
+ * $Id: packet-adwin-config.c 41998 2012-04-09 19:12:17Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -372,15 +372,15 @@ dissect_TCPFlashUpdate(tvbuff_t *tvb,  packet_info *pinfo _U_, proto_tree *adwin
 }
 
 /* 00:50:c2:0a:2*:** */
-static char mac_iab_start[] = { 0x00, 0x50, 0xc2, 0x0a, 0x20, 0x00 };
-static char mac_iab_end[]   = { 0x00, 0x50, 0xc2, 0x0a, 0x2f, 0xff };
+static const unsigned char mac_iab_start[] = { 0x00, 0x50, 0xc2, 0x0a, 0x20, 0x00 };
+static const unsigned char mac_iab_end[]   = { 0x00, 0x50, 0xc2, 0x0a, 0x2f, 0xff };
 
 /* 00:22:71:**:**:** */
-static char mac_oui_start[] = { 0x00, 0x22, 0x71, 0x00, 0x00, 0x00 };
-static char mac_oui_end[]   = { 0x00, 0x22, 0x71, 0xff, 0xff, 0xff };
+static const unsigned char mac_oui_start[] = { 0x00, 0x22, 0x71, 0x00, 0x00, 0x00 };
+static const unsigned char mac_oui_end[]   = { 0x00, 0x22, 0x71, 0xff, 0xff, 0xff };
 
 /* ff:ff:ff:ff:ff:ff */
-static char mac_broadcast[] = { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
+static const unsigned char mac_broadcast[] = { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
 
 /* return TRUE if mac is in mac address range assigned to ADwin or if
  * mac is broadcast */
