@@ -2,7 +2,7 @@
  * Routines for Agent Extensibility (AgentX) Protocol disassembly
  * RFC 2257
  *
- * $Id: packet-agentx.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-agentx.c 41993 2012-04-09 17:53:04Z darkjames $
  *
  * Copyright (c) 2005 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -364,8 +364,8 @@ dissect_object_id(tvbuff_t *tvb, proto_tree *tree, int offset, guint8 flags, enu
 		g_snprintf(&str_oid[0], 2048, "(null)");
 
 	if(tree) {
-		char *range = "";
-		char *inclusion = (include) ? " (Inclusive)" : " (Exclusive)";
+		const char *range = "";
+		const char *inclusion = (include) ? " (Inclusive)" : " (Exclusive)";
 		switch (oid_usage) {
 			case OID_START_RANGE:	range = "(Range Start) ";	break;
 			case OID_END_RANGE:	range = "  (Range End) ";	break;
