@@ -3,7 +3,7 @@
  * Copyright 2004, Jelmer Vernooij <jelmer@samba.org>
  * Copyright 2000, Ralf Hoelzer <ralf@well.com>
  *
- * $Id: packet-aim-chat.c 34412 2010-10-07 21:23:36Z wmeier $
+ * $Id: packet-aim-chat.c 43066 2012-06-04 13:52:46Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,9 +28,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
@@ -89,8 +86,8 @@ static int dissect_aim_chat_outgoing_msg(tvbuff_t *tvb, packet_info *pinfo, prot
 	guchar *msg;
 	int buddyname_length;
 
-	buddyname=ep_alloc(MAX_BUDDYNAME_LENGTH+1);
-	msg=ep_alloc(1000);
+	buddyname=(guchar *)ep_alloc(MAX_BUDDYNAME_LENGTH+1);
+	msg=(guchar *)ep_alloc(1000);
 	buddyname_length = aim_get_buddyname( buddyname, tvb, 30, 31 );
 
 	/* channel message from client */
@@ -110,8 +107,8 @@ static int dissect_aim_chat_incoming_msg(tvbuff_t *tvb, packet_info *pinfo, prot
 	/* channel message to client */
 	int buddyname_length;
 
-	buddyname=ep_alloc(MAX_BUDDYNAME_LENGTH+1);
-	msg=ep_alloc(1000);
+	buddyname=(guchar *)ep_alloc(MAX_BUDDYNAME_LENGTH+1);
+	msg=(guchar *)ep_alloc(1000);
 	buddyname_length = aim_get_buddyname( buddyname, tvb, 30, 31 );
 
 	aim_get_message( msg, tvb, 36 + buddyname_length, tvb_length(tvb)
