@@ -2,7 +2,7 @@
  * Routines for AJP13 dissection
  * Copyright 2002, Christopher K. St. John <cks@distributopia.com>
  *
- * $Id: packet-ajp13.c 43066 2012-06-04 13:52:46Z etxrab $
+ * $Id: packet-ajp13.c 44506 2012-08-14 21:39:49Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -733,7 +733,7 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
       if (ajp13_tree) {
         proto_tree_add_string_format(ajp13_tree, hf_ajp13_req_attribute,
                                      tvb, apos, 1+aname_len+2+aval_len+2,
-                                     g_strdup_printf("%s: %s", aname, aval),
+                                     ep_strdup_printf("%s: %s", aname, aval),
                                      "%s: %s", aname, aval);
       }
     } else if (aid == 0x0B ) {
