@@ -2,7 +2,7 @@
  * Routines for AMR dissection
  * Copyright 2005-2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-amr.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-amr.c 42094 2012-04-16 13:29:57Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -819,7 +819,7 @@ proto_register_amr(void)
 	prefs_register_enum_preference(amr_module, "encoding.version",
 				       "Type of AMR encoding of the payload",
 				       "Type of AMR encoding of the payload",
-				       &amr_encoding_type, encoding_types, ENC_BIG_ENDIAN);
+				       &amr_encoding_type, encoding_types, FALSE);
 
 	prefs_register_enum_preference(amr_module, "mode",
 				       "The AMR mode",
