@@ -8,7 +8,7 @@
  *
  * Copyright 2010, Aniruddha.A (anira@cisco.com)
  *
- * $Id: packet-ancp.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-ancp.c 42128 2012-04-18 10:11:33Z tuexen $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -219,7 +219,7 @@ static const value_string techtype_str[] = {
 
 static const value_string dsl_line_attrs[] = {
     { 0x91,  "DSL-Type" },
-    { 0x81,  "Actual-Net-Data-Upstream" },
+    { 0x81,  "Actual-Net-Data-Rate-Upstream" },
     { 0x82,  "Actual-Net-Data-Rate-Downstream" },
     { 0x83,  "Minimum-Net-Data-Rate-Upstream" },
     { 0x84,  "Minimum-Net-Data-Rate-Downstream" },
