@@ -2,7 +2,7 @@
  * Routines for the disassembly of Aruba encapsulated remote mirroring frames
  * (Adapted from packet-hp-erm.c and packet-cisco-erspan.c)
  *
- * $Id: packet-aruba-erm.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-aruba-erm.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2010  Alexis La Goutte <alexis.lagoutte at gmail dot com>
  *
@@ -75,14 +75,14 @@ dissect_aruba_erm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_INFO, PROTO_SHORT_NAME ":");
 
     if (tree) {
-        ti = proto_tree_add_item(tree, proto_aruba_erm, tvb, 0, -1, FALSE);
+        ti = proto_tree_add_item(tree, proto_aruba_erm, tvb, 0, -1, ENC_NA);
         aruba_erm_tree = proto_item_add_subtree(ti, ett_aruba_erm);
 
         ts.secs = tvb_get_ntohl(tvb, 0);
         ts.nsecs = tvb_get_ntohl(tvb,4)*1000;
         proto_tree_add_time(aruba_erm_tree, hf_aruba_erm_time, tvb, 0, 8,&ts);
-        proto_tree_add_item(aruba_erm_tree, hf_aruba_erm_incl_len, tvb, 8, 4, FALSE);
-        proto_tree_add_item(aruba_erm_tree, hf_aruba_erm_orig_len, tvb, 12, 4, FALSE);
+        proto_tree_add_item(aruba_erm_tree, hf_aruba_erm_incl_len, tvb, 8, 4, ENC_BIG_ENDIAN);
+        proto_tree_add_item(aruba_erm_tree, hf_aruba_erm_orig_len, tvb, 12, 4, ENC_BIG_ENDIAN);
     }
 
     eth_tvb = tvb_new_subset_remaining(tvb, 16);
