@@ -1,7 +1,7 @@
 /* packet-atm.c
  * Routines for ATM packet disassembly
  *
- * $Id: packet-atm.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-atm.c 40750 2012-01-28 16:34:22Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -453,7 +453,7 @@ dissect_le_verify_frame(tvbuff_t *tvb, int offset, proto_tree *tree)
   dissect_le_control_tlvs(tvb, offset, num_tlvs, tree);
 }
 
-static void
+static int
 dissect_le_flush_frame(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
   dissect_lan_destination(tvb, offset, "Source", tree);
@@ -475,6 +475,8 @@ dissect_le_flush_frame(tvbuff_t *tvb, int offset, proto_tree *tree)
 
   /* Reserved */
   offset += 32;
+
+  return offset;
 }
 
 static void
@@ -610,7 +612,6 @@ dissect_le_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       proto_tree_add_text(flags_tree, tvb, offset, 2, "%s",
                           decode_boolean_bitfield(flags, 0x0100, 8*2,
                                                   "Topology change", "No topology change"));
-      offset += 2;
       /* 92 reserved bytes */
       break;
 
@@ -728,6 +729,7 @@ static const value_string aal5_hltype_vals[] = {
   { TRAF_SPANS,             "FORE SPANS" },
   { TRAF_IPSILON,           "Ipsilon" },
   { TRAF_GPRS_NS,           "GPRS NS" },
+  { TRAF_SSCOP,             "SSCOP" },
   { 0,              NULL }
 };
 
@@ -1096,6 +1098,10 @@ dissect_reassembled_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   case AAL_5:
     switch (pinfo->pseudo_header->atm.type) {
 
+    case TRAF_SSCOP:
+      call_dissector(sscop_handle, next_tvb, pinfo, tree);
+      break;
+
     case TRAF_FR:
       call_dissector(fr_handle, next_tvb, pinfo, tree);
       break;
@@ -1667,7 +1673,9 @@ dissect_atm_cell(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   {
     offset = 0; /* For PWs. Header is decoded by PW dissector.*/
     pwpd = pinfo->private_data;
+/*  Not used !
     vpi = pwpd->vpi;
+*/
     vci = pwpd->vci;
     pt  = pwpd->pti;
   }
