@@ -2,7 +2,7 @@
  * Anything in Anything protocol
  * Copyright 2008, Jelmer Vernooij <jelmer@samba.org>
  *
- * $Id: packet-ayiya.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-ayiya.c 39539 2011-10-24 19:57:53Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -112,12 +112,12 @@ dissect_ayiya(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 											 offset, ayiya_len, "AYIYA" );
 		ayiya_tree = proto_item_add_subtree(ti, ett_ayiya);
 
-		proto_tree_add_bits_item(ayiya_tree, hf_id_len, tvb, 0, 4, FALSE);
-		proto_tree_add_bits_item(ayiya_tree, hf_id_type, tvb, 4, 4, FALSE);
-		proto_tree_add_bits_item(ayiya_tree, hf_sig_len, tvb, 8, 4, FALSE);
-		proto_tree_add_bits_item(ayiya_tree, hf_hash_method, tvb, 12, 4, FALSE);
-		proto_tree_add_bits_item(ayiya_tree, hf_auth_method, tvb, 16, 4, FALSE);
-		proto_tree_add_bits_item(ayiya_tree, hf_opcode, tvb, 20, 4, FALSE);
+		proto_tree_add_bits_item(ayiya_tree, hf_id_len, tvb, 0, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_bits_item(ayiya_tree, hf_id_type, tvb, 4, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_bits_item(ayiya_tree, hf_sig_len, tvb, 8, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_bits_item(ayiya_tree, hf_hash_method, tvb, 12, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_bits_item(ayiya_tree, hf_auth_method, tvb, 16, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_bits_item(ayiya_tree, hf_opcode, tvb, 20, 4, ENC_BIG_ENDIAN);
 		proto_tree_add_uint_format(ayiya_tree, hf_next_header, tvb,
 								   3, 1, next_header,
 								   "Next header: %s (0x%02x)",
@@ -125,8 +125,8 @@ dissect_ayiya(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		tv.secs = tvb_get_ntohl(tvb, 4);
 		tv.nsecs = 0;
 		proto_tree_add_time(ayiya_tree, hf_epoch, tvb, 4, 4, &tv);
-		proto_tree_add_item(ayiya_tree, hf_identity, tvb, 8, idlen, FALSE);
-		proto_tree_add_item(ayiya_tree, hf_signature, tvb, 8+idlen, siglen, FALSE);
+		proto_tree_add_item(ayiya_tree, hf_identity, tvb, 8, idlen, ENC_NA);
+		proto_tree_add_item(ayiya_tree, hf_signature, tvb, 8+idlen, siglen, ENC_NA);
 	}
 	offset = ayiya_len;
 	switch (opcode) {
