@@ -4,7 +4,7 @@
  *
  *  (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-bctp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-bctp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,7 +26,7 @@
  *
  * Ref ITU-T Rec. Q.1990 (07/2001)
  */
- 
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -70,16 +70,16 @@ static const value_string bvei_vals[] = {
 
 
 static void dissect_bctp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
-	proto_item* pi = proto_tree_add_item(tree, proto_bctp, tvb,0,2, FALSE);
+	proto_item* pi = proto_tree_add_item(tree, proto_bctp, tvb,0,2, ENC_NA);
 	proto_tree* pt = proto_item_add_subtree(pi,ett_bctp);
 	tvbuff_t* sub_tvb = tvb_new_subset_remaining(tvb, 2);
 	guint8 tpi = tvb_get_guint8(tvb,1) & 0x3f;
-	
-	proto_tree_add_item(pt, hf_bctp_bvei, tvb,0,2, FALSE);
-	proto_tree_add_item(pt, hf_bctp_bvi, tvb,0,2, FALSE);
-	proto_tree_add_item(pt, hf_bctp_tpei, tvb,0,2, FALSE);
-	proto_tree_add_item(pt, hf_bctp_tpi, tvb,0,2, FALSE);
-	
+
+	proto_tree_add_item(pt, hf_bctp_bvei, tvb,0,2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(pt, hf_bctp_bvi, tvb,0,2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(pt, hf_bctp_tpei, tvb,0,2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(pt, hf_bctp_tpi, tvb,0,2, ENC_BIG_ENDIAN);
+
 	if ( dissector_try_uint(bctp_dissector_table, tpi, sub_tvb, pinfo, tree) ) {
 		return;
 	} else if (tpi <= 0x22) {
