@@ -1,7 +1,7 @@
 /* packet-bpdu.c
  * Routines for BPDU (Spanning Tree Protocol) disassembly
  *
- * $Id: packet-bpdu.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-bpdu.c 39426 2011-10-15 18:46:26Z wmeier $
  *
  * Copyright 1999 Christophe Tronche <ch.tronche@computer.org>
  *
@@ -291,24 +291,18 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       pinfo->current_proto = "GARP";
 
-      if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "GARP");
+      col_set_str(pinfo->cinfo, COL_PROTOCOL, "GARP");
         /* Generic Attribute Registration Protocol */
-      }
 
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-        col_add_fstr(pinfo->cinfo, COL_INFO,
-                     "Unknown GARP application (0x%02X)",
-                     dstaddr[5]);
-      }
+      col_add_fstr(pinfo->cinfo, COL_INFO,
+                   "Unknown GARP application (0x%02X)",
+                   dstaddr[5]);
 
       return;
     }
   }
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "STP"); /* Spanning Tree Protocol */
-  }
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "STP"); /* Spanning Tree Protocol */
   col_clear(pinfo->cinfo, COL_INFO);
 
   bpdu_type = tvb_get_guint8(tvb, BPDU_TYPE);
@@ -342,55 +336,53 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     break;
   }
 
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    switch (bpdu_type) {
+  switch (bpdu_type) {
 
-    case BPDU_TYPE_CONF:
-      if (bpdu_use_system_id_extensions ) {
-        col_add_fstr(pinfo->cinfo, COL_INFO,
-                     "Conf. %sRoot = %d/%d/%s  Cost = %d  Port = 0x%04x",
-                     flags & 0x1 ? "TC + " : "",
-                     root_identifier_bridge_priority, 
-                     root_identifier_system_id_extension, 
-                     root_identifier_mac_str,
-                     root_path_cost, port_identifier);
-      } else {
-        col_add_fstr(pinfo->cinfo, COL_INFO,
-                     "Conf. %sRoot = %d/%s  Cost = %d  Port = 0x%04x",
-                     flags & 0x1 ? "TC + " : "",
-                     root_identifier_bridge_priority, root_identifier_mac_str,
-                     root_path_cost, port_identifier);
-      }
-      break;
+  case BPDU_TYPE_CONF:
+    if (bpdu_use_system_id_extensions ) {
+      col_add_fstr(pinfo->cinfo, COL_INFO,
+                   "Conf. %sRoot = %d/%d/%s  Cost = %d  Port = 0x%04x",
+                   flags & 0x1 ? "TC + " : "",
+                   root_identifier_bridge_priority,
+                   root_identifier_system_id_extension,
+                   root_identifier_mac_str,
+                   root_path_cost, port_identifier);
+    } else {
+      col_add_fstr(pinfo->cinfo, COL_INFO,
+                   "Conf. %sRoot = %d/%s  Cost = %d  Port = 0x%04x",
+                   flags & 0x1 ? "TC + " : "",
+                   root_identifier_bridge_priority, root_identifier_mac_str,
+                   root_path_cost, port_identifier);
+    }
+    break;
 
-    case BPDU_TYPE_TOPOLOGY_CHANGE:
-      col_set_str(pinfo->cinfo, COL_INFO, "Topology Change Notification");
-      break;
+  case BPDU_TYPE_TOPOLOGY_CHANGE:
+    col_set_str(pinfo->cinfo, COL_INFO, "Topology Change Notification");
+    break;
 
-    case BPDU_TYPE_RST:
-      if (bpdu_use_system_id_extensions ) {
-        col_add_fstr(pinfo->cinfo, COL_INFO,
-                     "%cST. %sRoot = %d/%d/%s  Cost = %d  Port = 0x%04x",
+  case BPDU_TYPE_RST:
+    if (bpdu_use_system_id_extensions ) {
+      col_add_fstr(pinfo->cinfo, COL_INFO,
+                   "%cST. %sRoot = %d/%d/%s  Cost = %d  Port = 0x%04x",
                      protocol_version_identifier == 3 ? 'M':'R',
                      flags & 0x1 ? "TC + " : "",
                      root_identifier_bridge_priority,
                      root_identifier_system_id_extension,
                      root_identifier_mac_str,
                      root_path_cost, port_identifier);
-      } else {
-        col_add_fstr(pinfo->cinfo, COL_INFO,
-                     "%cST. %sRoot = %d/%s  Cost = %d  Port = 0x%04x",
-                     protocol_version_identifier == 3 ? 'M':'R',
-                     flags & 0x1 ? "TC + " : "",
-                     root_identifier_bridge_priority, root_identifier_mac_str,
-                     root_path_cost, port_identifier);
-      }
-      break;
-
-    default:
-      col_add_fstr(pinfo->cinfo, COL_INFO, "Unknown BPDU type (%u)", bpdu_type);
-      break;
+    } else {
+      col_add_fstr(pinfo->cinfo, COL_INFO,
+                   "%cST. %sRoot = %d/%s  Cost = %d  Port = 0x%04x",
+                   protocol_version_identifier == 3 ? 'M':'R',
+                   flags & 0x1 ? "TC + " : "",
+                   root_identifier_bridge_priority, root_identifier_mac_str,
+                   root_path_cost, port_identifier);
     }
+    break;
+
+  default:
+    col_add_fstr(pinfo->cinfo, COL_INFO, "Unknown BPDU type (%u)", bpdu_type);
+    break;
   }
 
   if (tree) {
@@ -499,10 +491,10 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  root_identifier_mac_str);
       root_id_tree = proto_item_add_subtree(root_id_item, ett_root_id);
       proto_tree_add_uint(root_id_tree, hf_bpdu_root_prio, tvb,
-			      BPDU_ROOT_IDENTIFIER , 1, 
+			      BPDU_ROOT_IDENTIFIER , 1,
 			      root_identifier_bridge_priority);
       proto_tree_add_uint(root_id_tree, hf_bpdu_root_sys_id_ext, tvb,
-			      BPDU_ROOT_IDENTIFIER , 2, 
+			      BPDU_ROOT_IDENTIFIER , 2,
 			      root_identifier_system_id_extension);
       proto_tree_add_ether_format_value(root_id_tree, hf_bpdu_root_mac,
                               tvb, BPDU_ROOT_IDENTIFIER + 2, 6,
@@ -516,7 +508,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  root_identifier_mac_str);
       root_id_tree = proto_item_add_subtree(root_id_item, ett_root_id);
       proto_tree_add_uint(root_id_tree, hf_bpdu_root_prio, tvb,
-			      BPDU_ROOT_IDENTIFIER , 2, 
+			      BPDU_ROOT_IDENTIFIER , 2,
 			      root_identifier_bridge_priority);
       proto_tree_add_ether_format_value(root_id_tree, hf_bpdu_root_mac,
                               tvb, BPDU_ROOT_IDENTIFIER + 2, 6,
@@ -540,24 +532,24 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  bridge_identifier_mac_str);
       bridge_id_tree = proto_item_add_subtree(bridge_id_item, ett_bridge_id);
       proto_tree_add_uint(bridge_id_tree, hf_bpdu_bridge_prio, tvb,
-			      BPDU_BRIDGE_IDENTIFIER , 1, 
+			      BPDU_BRIDGE_IDENTIFIER , 1,
 			      bridge_identifier_bridge_priority);
       proto_tree_add_uint(bridge_id_tree, hf_bpdu_bridge_sys_id_ext, tvb,
-			      BPDU_BRIDGE_IDENTIFIER , 2, 
+			      BPDU_BRIDGE_IDENTIFIER , 2,
 			      bridge_identifier_system_id_extension);
       proto_tree_add_ether_format_value(bridge_id_tree, hf_bpdu_bridge_mac,
                               tvb, BPDU_BRIDGE_IDENTIFIER + 2, 6,
                               bridge_identifier_mac,
                               "%s", bridge_identifier_mac_str);
     } else {
-      bridge_id_item = proto_tree_add_text(bpdu_tree, tvb, 
+      bridge_id_item = proto_tree_add_text(bpdu_tree, tvb,
                           BPDU_BRIDGE_IDENTIFIER, 8,
 			  "Bridge Identifier: %d / %s",
 			  bridge_identifier_bridge_priority,
 			  bridge_identifier_mac_str);
       bridge_id_tree = proto_item_add_subtree(bridge_id_item, ett_bridge_id);
       proto_tree_add_uint(bridge_id_tree, hf_bpdu_bridge_prio, tvb,
-                              BPDU_BRIDGE_IDENTIFIER , 2, 
+                              BPDU_BRIDGE_IDENTIFIER , 2,
 			      bridge_identifier_bridge_priority);
       proto_tree_add_ether_format_value(bridge_id_tree, hf_bpdu_bridge_mac,
                               tvb, BPDU_BRIDGE_IDENTIFIER + 2, 6,
@@ -607,8 +599,8 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       /*
        * Check the Version 3 Length, and see whether it's a
        * multiple of the MSTI Configuration Message length. Also
-       * check the config_format_selector because some MST BPDU's 
-       * have BPDU_VERSION_3_LENGTH set to 0 and use the 
+       * check the config_format_selector because some MST BPDU's
+       * have BPDU_VERSION_3_LENGTH set to 0 and use the
        * field BPDU_MST_CONFIG_FORMAT_SELECTOR as a length-field
        * for the MSTI data.
        */
@@ -648,7 +640,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  msti_format = MSTI_FORMAT_ALTERNATIVE;
 	  total_msti_length = config_format_selector - VERSION_3_STATIC_LENGTH;
 	} else {
-	  /* 
+	  /*
 	   * XXX - Unknown MSTI format, since version_3_length is 0
 	   * lets assume there are no msti instances in the packet.
 	   */
@@ -664,20 +656,20 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       mstp_tree = proto_item_add_subtree(mstp_item, ett_mstp);
 
       proto_tree_add_item(mstp_tree, hf_bpdu_mst_config_format_selector, tvb,
-                          BPDU_MST_CONFIG_FORMAT_SELECTOR, 1, FALSE);
+                          BPDU_MST_CONFIG_FORMAT_SELECTOR, 1, ENC_BIG_ENDIAN);
       proto_tree_add_item(mstp_tree, hf_bpdu_mst_config_name, tvb,
-                          BPDU_MST_CONFIG_NAME, 32, FALSE);
+                          BPDU_MST_CONFIG_NAME, 32, ENC_ASCII|ENC_NA);
 
       proto_tree_add_item(mstp_tree, hf_bpdu_mst_config_revision_level, tvb,
-                          BPDU_MST_CONFIG_REVISION_LEVEL, 2, FALSE);
+                          BPDU_MST_CONFIG_REVISION_LEVEL, 2, ENC_BIG_ENDIAN);
       proto_tree_add_item(mstp_tree, hf_bpdu_mst_config_digest, tvb,
-                          BPDU_MST_CONFIG_DIGEST, 16, FALSE);
+                          BPDU_MST_CONFIG_DIGEST, 16, ENC_NA);
 
       switch(msti_format) {
 
       case MSTI_FORMAT_IEEE_8021S:
 	proto_tree_add_item(mstp_tree, hf_bpdu_cist_internal_root_path_cost, tvb,
-			    BPDU_CIST_INTERNAL_ROOT_PATH_COST, 4, FALSE);
+			    BPDU_CIST_INTERNAL_ROOT_PATH_COST, 4, ENC_BIG_ENDIAN);
 
 	cist_bridge_identifier_bridge_priority = tvb_get_ntohs(tvb,BPDU_CIST_BRIDGE_IDENTIFIER);
 	cist_bridge_identifier_mac = tvb_get_ptr(tvb, BPDU_CIST_BRIDGE_IDENTIFIER + 2, 6);
@@ -698,10 +690,10 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                               cist_bridge_identifier_mac_str);
           cist_bridge_id_tree = proto_item_add_subtree(cist_bridge_id_item, ett_cist_bridge_id);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_prio, tvb,
-                                  BPDU_CIST_BRIDGE_IDENTIFIER , 1, 
+                                  BPDU_CIST_BRIDGE_IDENTIFIER , 1,
                                   cist_bridge_identifier_bridge_priority);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_sys_id_ext, tvb,
-                                  BPDU_CIST_BRIDGE_IDENTIFIER , 2, 
+                                  BPDU_CIST_BRIDGE_IDENTIFIER , 2,
                                   cist_bridge_identifier_system_id_extension);
           proto_tree_add_ether_format_value(cist_bridge_id_tree, hf_bpdu_cist_bridge_mac,
                                   tvb, BPDU_CIST_BRIDGE_IDENTIFIER + 2, 6,
@@ -715,7 +707,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                               cist_bridge_identifier_mac_str);
           cist_bridge_id_tree = proto_item_add_subtree(cist_bridge_id_item, ett_cist_bridge_id);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_prio, tvb,
-                                  BPDU_CIST_BRIDGE_IDENTIFIER , 2, 
+                                  BPDU_CIST_BRIDGE_IDENTIFIER , 2,
                                   cist_bridge_identifier_bridge_priority);
           proto_tree_add_ether_format_value(cist_bridge_id_tree, hf_bpdu_cist_bridge_mac,
                                   tvb, BPDU_CIST_BRIDGE_IDENTIFIER + 2, 6,
@@ -746,10 +738,10 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                               cist_bridge_identifier_mac_str);
           cist_bridge_id_tree = proto_item_add_subtree(cist_bridge_id_item, ett_cist_bridge_id);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_prio, tvb,
-                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 1, 
+                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 1,
                                   cist_bridge_identifier_bridge_priority);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_sys_id_ext, tvb,
-                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 2, 
+                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 2,
                                   cist_bridge_identifier_system_id_extension);
           proto_tree_add_ether_format_value(cist_bridge_id_tree, hf_bpdu_cist_bridge_mac,
                                   tvb, ALT_BPDU_CIST_BRIDGE_IDENTIFIER + 2, 6,
@@ -763,7 +755,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                               cist_bridge_identifier_mac_str);
           cist_bridge_id_tree = proto_item_add_subtree(cist_bridge_id_item, ett_cist_bridge_id);
           proto_tree_add_uint(cist_bridge_id_tree, hf_bpdu_cist_bridge_prio, tvb,
-                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 2, 
+                                  ALT_BPDU_CIST_BRIDGE_IDENTIFIER , 2,
                                   cist_bridge_identifier_bridge_priority);
           proto_tree_add_ether_format_value(cist_bridge_id_tree, hf_bpdu_cist_bridge_mac,
                                   tvb, ALT_BPDU_CIST_BRIDGE_IDENTIFIER + 2, 6,
@@ -773,13 +765,13 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         /* end of Identifier formatting */
 
 	proto_tree_add_item(mstp_tree, hf_bpdu_cist_internal_root_path_cost, tvb,
-			    ALT_BPDU_CIST_INTERNAL_ROOT_PATH_COST, 4, FALSE);
+			    ALT_BPDU_CIST_INTERNAL_ROOT_PATH_COST, 4, ENC_BIG_ENDIAN);
 
 	break;
       }
 
       proto_tree_add_item(mstp_tree, hf_bpdu_cist_remaining_hops, tvb,
-                          BPDU_CIST_REMAINING_HOPS, 1, FALSE);
+                          BPDU_CIST_REMAINING_HOPS, 1, ENC_BIG_ENDIAN);
       /* MSTI messages */
       offset = BPDU_MSTI;
       msti = 1;
@@ -853,7 +845,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 
 	  proto_tree_add_item(msti_tree, hf_bpdu_msti_internal_root_path_cost, tvb,
-			      offset+MSTI_INTERNAL_ROOT_PATH_COST, 4, FALSE);
+			      offset+MSTI_INTERNAL_ROOT_PATH_COST, 4, ENC_BIG_ENDIAN);
 
 	  msti_bridge_identifier_priority = tvb_get_guint8(tvb, offset+MSTI_BRIDGE_IDENTIFIER_PRIORITY) >> 4;
 	  msti_port_identifier_priority = tvb_get_guint8(tvb, offset+MSTI_PORT_IDENTIFIER_PRIORITY) >> 4;
@@ -866,7 +858,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			      msti_port_identifier_priority);
 
 	  proto_tree_add_item(msti_tree, hf_bpdu_msti_remaining_hops, tvb,
-			      offset + MSTI_REMAINING_HOPS, 1, FALSE);
+			      offset + MSTI_REMAINING_HOPS, 1, ENC_BIG_ENDIAN);
 
 	  total_msti_length -= MSTI_MESSAGE_SIZE;
 	  offset += MSTI_MESSAGE_SIZE;
@@ -888,7 +880,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  msti_tree = proto_item_add_subtree(msti_item, ett_msti);
 
 	  msti_mstid = tvb_get_ntohs(tvb,  offset+ ALT_MSTI_MSTID);
-	  proto_tree_add_text(msti_tree, tvb, offset+ALT_MSTI_MSTID, 2, 
+	  proto_tree_add_text(msti_tree, tvb, offset+ALT_MSTI_MSTID, 2,
 			      "MSTID: %d", msti_mstid);
 
 	  /* flags */
@@ -943,7 +935,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 
 	  proto_tree_add_item(msti_tree, hf_bpdu_msti_internal_root_path_cost, tvb,
-			      offset+ALT_MSTI_INTERNAL_ROOT_PATH_COST, 4, FALSE);
+			      offset+ALT_MSTI_INTERNAL_ROOT_PATH_COST, 4, ENC_BIG_ENDIAN);
 
 	  msti_bridge_identifier_priority = tvb_get_ntohs(tvb, offset+ALT_MSTI_BRIDGE_IDENTIFIER);
 	  msti_bridge_identifier_mac = tvb_get_ptr(tvb, offset+ALT_MSTI_BRIDGE_IDENTIFIER + 2, 6);
@@ -955,11 +947,11 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			      msti_bridge_identifier_mac_str);
 
 	  msti_port_identifier_priority = tvb_get_ntohs(tvb, offset+ALT_MSTI_PORT_IDENTIFIER);
-	  proto_tree_add_uint(msti_tree, hf_bpdu_msti_port_id, tvb, 
+	  proto_tree_add_uint(msti_tree, hf_bpdu_msti_port_id, tvb,
 			      offset+ALT_MSTI_PORT_IDENTIFIER, 2, msti_port_identifier_priority);
 
 	  proto_tree_add_item(msti_tree, hf_bpdu_msti_remaining_hops, tvb,
-			      offset + ALT_MSTI_REMAINING_HOPS, 1, FALSE);
+			      offset + ALT_MSTI_REMAINING_HOPS, 1, ENC_BIG_ENDIAN);
 
 	  total_msti_length -= ALT_MSTI_MESSAGE_SIZE;
 	  offset += ALT_MSTI_MESSAGE_SIZE;
@@ -974,7 +966,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 void
 proto_register_bpdu(void)
-{      
+{
 
   static hf_register_info hf[] = {
     { &hf_bpdu_proto_id,
