@@ -2,7 +2,7 @@
  * Routines for Base Station Subsystem GPRS Protocol dissection
  * Copyright 2006, Anders Broman <anders.broman [at] ericsson.com>
  *
- * $Id: packet-bssgp.h 39740 2011-11-06 08:18:26Z etxrab $
+ * $Id: packet-bssgp.h 40119 2011-12-08 21:17:03Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,8 +30,11 @@
 
 WS_VAR_IMPORT value_string_ext bssgp_cause_vals_ext;
 
-void bssgp_suspend_ack(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo _U_, guint32 offset, guint len);
-guint16 de_bssgp_cell_id(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 offset, guint len _U_, gchar *add_string, int string_len);
+void bssgp_suspend_ack(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 offset, guint len);
+guint16 de_bssgp_cell_id(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 offset, guint len, gchar *add_string, int string_len);
+guint16 de_bssgp_source_BSS_to_target_BSS_transp_cont(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 offset, guint len, gchar *add_string, int string_len);
+guint16 de_bssgp_target_BSS_to_source_BSS_transp_cont(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 offset, guint len, gchar *add_string, int string_len);
+
 
 #endif /* __PACKET_BSSGP_H__ */
 
