@@ -4,7 +4,7 @@
  *
  * http://doc.bazaar.canonical.com/developers/network-protocol.html
  *
- * $Id: packet-bzr.c 41090 2012-02-20 22:22:48Z wmeier $
+ * $Id: packet-bzr.c 43219 2012-06-11 23:22:50Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -222,7 +222,7 @@ dissect_bzr_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (bzr_tree)
     {
         proto_tree_add_item(bzr_tree, hf_bzr_packet_protocol_version, tvb, 0,
-                            protocol_version_len+1, ENC_NA);
+                            protocol_version_len+1, ENC_ASCII|ENC_NA);
     }
 
     offset += dissect_prefixed_bencode(tvb, offset, pinfo, bzr_tree);
@@ -261,7 +261,7 @@ proto_register_bzr(void)
 {
     static hf_register_info hf[] = {
         { &hf_bzr_packet_kind,
-          { "Packet kind", "bzr.kind", FT_UINT8, BASE_NONE,
+          { "Packet kind", "bzr.kind", FT_UINT8, BASE_DEC,
             VALS(message_part_kind), 0x0, NULL, HFILL },
         },
         { &hf_bzr_packet_protocol_version,
