@@ -3,7 +3,7 @@
  *
  * Copyright 2011, Mike Morrin <mike.morrin [AT] ipaccess.com>
  *
- * $Id: packet-cell_broadcast.c 40737 2012-01-26 22:14:19Z gerald $
+ * $Id: packet-cell_broadcast.c 43258 2012-06-14 13:43:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,12 +28,10 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <string.h>
 #include <glib.h>
+
 #include <epan/packet.h>
 
-#include <epan/emem.h>
 #include <epan/strutil.h>
 #include <epan/asn1.h>
 
@@ -366,7 +364,7 @@ dissect_gsm_cell_broadcast(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                             frag_data, &gsm_page_items, NULL, cbs_page_tree);
      }
    }
-   if ((tree != NULL) && (cbs_msg_tvb != NULL))
+   if (cbs_msg_tvb != NULL)
    {
       guint16 len;
       proto_item     *cbs_msg_item = NULL;
@@ -563,8 +561,3 @@ proto_register_cbs(void)
     /* subtree array */
     proto_register_subtree_array(ett, array_length(ett));
 }
-
-void
-proto_reg_handoff_gsm_cbs(void)
-{
-}
