@@ -1,7 +1,7 @@
 /* packet-cgmp.c
  * Routines for the disassembly of the Cisco Group Management Protocol
  *
- * $Id: packet-cgmp.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-cgmp.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -22,11 +22,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
-
-#include <stdlib.h>
+#endif
 
 #include <glib.h>
+
 #include <epan/packet.h>
 
 /*
