@@ -1,7 +1,7 @@
 /* packet-erspan.c
  * Routines for the disassembly of Cisco's ERSPAN protocol
  *
- * $Id: packet-cisco-erspan.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-cisco-erspan.c 39721 2011-11-02 20:43:10Z gerald $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  * Updates for newer versions by Jason Masker <jason at masker.net>
@@ -53,7 +53,7 @@
  * 0000030:                     1002 0001 0000 0380 <-- ERSPAN header (01: erspan-id)
  * 0000040: 00d0 b7a7 7480 0015 c721 75c0 0800 4500 <-- Ethernet packet
  * ...
- * 
+ *
  *
  */
 
@@ -64,6 +64,8 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/greproto.h>
+#include <epan/prefs.h>
+#include <epan/expert.h>
 
 static int proto_erspan = -1;
 
@@ -87,6 +89,9 @@ static int hf_erspan_unknown7 = -1;
 #define PROTO_SHORT_NAME "ERSPAN"
 #define PROTO_LONG_NAME "Encapsulated Remote Switch Packet ANalysis"
 
+/* Global ERSPAN Preference */
+static gboolean pref_fake_erspan = FALSE;
+
 #define ERSPAN_DIRECTION_INCOMING 0
 #define ERSPAN_DIRECTION_OUTGOING 1
 static const value_string erspan_direction_vals[] = {
@@ -97,7 +102,7 @@ static const value_string erspan_direction_vals[] = {
 
 static const value_string erspan_truncated_vals[] = {
 	{0, "Not truncated"},
-	{1, "Trunkated"},
+	{1, "Truncated"},
 	{0, NULL},
 };
 
@@ -119,7 +124,7 @@ static void
 dissect_erspan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_item *ti;
-	proto_item *unknown_version;
+	proto_item *ti_ver;
 	proto_tree *erspan_tree = NULL;
 	tvbuff_t *eth_tvb;
 	guint32 offset = 0;
@@ -128,61 +133,69 @@ dissect_erspan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_SHORT_NAME);
         col_set_str(pinfo->cinfo, COL_INFO, PROTO_SHORT_NAME ":");
 
+
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_erspan, tvb, offset, -1,
-		    FALSE);
+		    ENC_NA);
 		erspan_tree = proto_item_add_subtree(ti, ett_erspan);
+	}
 
+	if(pref_fake_erspan) {
+		/* Some vendor don't include ERSPAN Header...*/
+		eth_tvb = tvb_new_subset_remaining(tvb, offset);
+		call_dissector(ethnofcs_handle, eth_tvb, pinfo, tree);
+		return;
+	}
+
+	if (tree) {
 		version = tvb_get_ntohs(tvb, offset) >> 12;
-		proto_tree_add_item(erspan_tree, hf_erspan_version, tvb, offset, 2,
-			FALSE);
+		ti_ver = proto_tree_add_item(erspan_tree, hf_erspan_version, tvb, offset, 2,
+			ENC_BIG_ENDIAN);
 		if ((version != 1) && (version != 2 )) {
-			unknown_version = proto_tree_add_text(erspan_tree, tvb, 0, 0,
-				"Unknown version, please report");
-			PROTO_ITEM_SET_GENERATED(unknown_version);
+			expert_add_info_format(pinfo, ti_ver, PI_UNDECODED, PI_WARN, "Unknown version, please report or test to use fake ERSPAN preference");
                 	return;
 		}
 		proto_tree_add_item(erspan_tree, hf_erspan_vlan, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 2;
 
 		proto_tree_add_item(erspan_tree, hf_erspan_priority, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		proto_tree_add_item(erspan_tree, hf_erspan_unknown2, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		if (version == 1)
 			proto_tree_add_item(erspan_tree, hf_erspan_direction, tvb,
-				offset, 2, FALSE);
+				offset, 2, ENC_BIG_ENDIAN);
 		else /* version = 2 */
 			proto_tree_add_item(erspan_tree, hf_erspan_unknown3, tvb,
-				offset, 2, FALSE);
+				offset, 2, ENC_BIG_ENDIAN);
 		proto_tree_add_item(erspan_tree, hf_erspan_truncated, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		proto_tree_add_item(erspan_tree, hf_erspan_spanid, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 2;
 
 		if (version == 2) {
 			proto_tree_add_item(erspan_tree, hf_erspan_timestamp, tvb,
-				offset, 4, FALSE);
+				offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 
 			proto_tree_add_item(erspan_tree, hf_erspan_unknown4, tvb,
-				offset, 2, FALSE);
+				offset, 2, ENC_NA);
 			offset += 2;
 
 			proto_tree_add_item(erspan_tree, hf_erspan_direction2, tvb,
-				offset, 2, FALSE);
+				offset, 2, ENC_BIG_ENDIAN);
 			proto_tree_add_item(erspan_tree, hf_erspan_unknown5, tvb,
-				offset, 2, FALSE);
+				offset, 2, ENC_BIG_ENDIAN);
 			offset += 2;
 
 			proto_tree_add_item(erspan_tree, hf_erspan_unknown6, tvb,
-				offset, 4, FALSE);
+				offset, 4, ENC_NA);
 			offset += 4;
 		}
 		proto_tree_add_item(erspan_tree, hf_erspan_unknown7, tvb, offset, 4,
-			FALSE);
+			ENC_NA);
 		offset += 4;
 	}
 	else {
@@ -198,6 +211,8 @@ dissect_erspan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 void
 proto_register_erspan(void)
 {
+	module_t *erspan_module;
+
 	static hf_register_info hf[] = {
 
 		{ &hf_erspan_version,
@@ -265,6 +280,15 @@ proto_register_erspan(void)
 	    PROTO_SHORT_NAME, "erspan");
         proto_register_field_array(proto_erspan, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	/* register dissection preferences */
+	erspan_module = prefs_register_protocol(proto_erspan, NULL);
+
+	prefs_register_bool_preference(erspan_module, "fake_erspan",
+				"FORCE to decode fake ERSPAN frame",
+				"When set, dissector will FORCE to decode directly Ethernet Frame"
+				"Some vendor use fake ERSPAN frame (with not ERSPAN Header)",
+				&pref_fake_erspan);
 }
 
 void
