@@ -2,7 +2,7 @@
  * Routines for dissecting wireless ids packets sent from a Cisco
  * access point to the WLSE (or whatever)
  *
- * $Id: packet-cisco-wids.c 36698 2011-04-18 15:29:25Z stig $
+ * $Id: packet-cisco-wids.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2006 Joerg Mayer (see AUTHORS file)
  *
@@ -86,23 +86,23 @@ dissect_cwids(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	cwids_tree = NULL;
 
 	while(tvb_length_remaining(tvb, offset) > 0) {
-		ti = proto_tree_add_item(tree, proto_cwids, tvb, offset, 28, FALSE);
+		ti = proto_tree_add_item(tree, proto_cwids, tvb, offset, 28, ENC_NA);
 		cwids_tree = proto_item_add_subtree(ti, ett_cwids);
 
-		proto_tree_add_item(cwids_tree, hf_cwids_version, tvb, offset, 2, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_version, tvb, offset, 2, ENC_BIG_ENDIAN);
 		offset += 2;
-		proto_tree_add_item(cwids_tree, hf_cwids_unknown1, tvb, offset, 7, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_unknown1, tvb, offset, 7, ENC_NA);
 		offset += 7;
-		proto_tree_add_item(cwids_tree, hf_cwids_channel, tvb, offset, 1, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_channel, tvb, offset, 1, ENC_BIG_ENDIAN);
 		offset += 1;
-		proto_tree_add_item(cwids_tree, hf_cwids_unknown2, tvb, offset, 6, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_unknown2, tvb, offset, 6, ENC_NA);
 		offset += 6;
-		proto_tree_add_item(cwids_tree, hf_cwids_reallength, tvb, offset, 2, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_reallength, tvb, offset, 2, ENC_BIG_ENDIAN);
 		offset += 2;
 		capturelen = tvb_get_ntohs(tvb, offset);
-		proto_tree_add_item(cwids_tree, hf_cwids_capturelen, tvb, offset, 2, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_capturelen, tvb, offset, 2, ENC_BIG_ENDIAN);
 		offset += 2;
-		proto_tree_add_item(cwids_tree, hf_cwids_unknown3, tvb, offset, 8, FALSE);
+		proto_tree_add_item(cwids_tree, hf_cwids_unknown3, tvb, offset, 8, ENC_NA);
 		offset += 8;
 
 		wlan_tvb = tvb_new_subset(tvb, offset, capturelen, capturelen);
@@ -122,17 +122,16 @@ dissect_cwids(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			 */
 			pinfo->private_data = pd_save;
 
-			if (check_col(pinfo->cinfo, COL_INFO)) {
-				col_append_str(pinfo->cinfo, COL_INFO,
-					" [Malformed or short IEEE80211 subpacket] " );
-				col_set_fence(pinfo->cinfo, COL_INFO);
-			}
-
-	wlan_tvb = tvb_new_subset(tvb, offset, capturelen, capturelen);
+			col_append_str(pinfo->cinfo, COL_INFO,
+				" [Malformed or short IEEE80211 subpacket] " );
+			col_set_fence(pinfo->cinfo, COL_INFO);
 #if 0
+	wlan_tvb = tvb_new_subset(tvb, offset, capturelen, capturelen);
 			/* FIXME: Why does this throw an exception? */
 			proto_tree_add_text(cwids_tree, wlan_tvb, offset, capturelen,
 				"[Malformed or short IEEE80211 subpacket]");
+#else
+			tvb_new_subset(tvb, offset, capturelen, capturelen);
 #endif
 	;
 		} ENDTRY;
