@@ -1,4 +1,3 @@
-#include <stdio.h>
 /* packet-coap.c
  * Routines for COAP packet disassembly
  * draft-ietf-core-coap-07.txt
@@ -7,7 +6,7 @@
  * draft-ietf-core-link-format-06.txt
  * Shoichi Sakane <sakane@tanu.org>
  *
- * $Id: packet-coap.c 39635 2011-10-27 15:59:12Z wmeier $
+ * $Id: packet-coap.c 42480 2012-05-07 18:59:18Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -208,7 +207,7 @@ dissect_coap_opt_string(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *subtr
 {
 	guint8 *hoststr = NULL;
 
-	proto_tree_add_item(subtree, hfindex, tvb, offset, opt_length, FALSE);
+	proto_tree_add_item(subtree, hfindex, tvb, offset, opt_length, ENC_UTF_8|ENC_NA);
 
 	/* forming a uri-string */
 	switch (opt_code) {
@@ -520,7 +519,7 @@ dissect_coap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		proto_item *payload_item = NULL;
 		tvbuff_t *payload_tvb;
 		guint payload_length = coap_length - offset;
-		char *ctype_str_default = "";
+		const char *ctype_str_default = "";
 
 		/*
 		 * TODO: should the content type be canonicalized ?
