@@ -4,7 +4,7 @@
  * Copyright 2008 Bruno Premont <bonbons at linux-vserver.org>
  * Copyright 2009 Florian Forster <octo at verplant.org>
  *
- * $Id: packet-collectd.c 36784 2011-04-21 22:38:41Z morriss $
+ * $Id: packet-collectd.c 39640 2011-10-27 20:30:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -307,7 +307,7 @@ dissect_collectd_string (tvbuff_t *tvb, packet_info *pinfo, gint type_hf,
 	pt = proto_item_add_subtree (pi, ett_collectd_string);
 	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
 	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2, length);
-	proto_tree_add_item (pt, type_hf, tvb, *ret_offset, *ret_length, FALSE);
+	proto_tree_add_item (pt, type_hf, tvb, *ret_offset, *ret_length, ENC_ASCII|ENC_NA);
 
 	return (0);
 } /* int dissect_collectd_string */
@@ -385,7 +385,7 @@ dissect_collectd_integer (tvbuff_t *tvb, packet_info *pinfo, gint type_hf,
 	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
 	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2,
 			     length);
-	proto_tree_add_item (pt, type_hf, tvb, offset + 4, 8, FALSE);
+	proto_tree_add_item (pt, type_hf, tvb, offset + 4, 8, ENC_BIG_ENDIAN);
 
 	return (0);
 } /* int dissect_collectd_integer */
@@ -432,10 +432,10 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			value_tree = proto_item_add_subtree (pi,
 					ett_collectd_valinfo);
 			proto_tree_add_item (value_tree, hf_collectd_val_type,
-					     tvb, value_type_offset, 1, FALSE);
+					     tvb, value_type_offset, 1, ENC_BIG_ENDIAN);
 			proto_tree_add_item (value_tree,
 					     hf_collectd_val_counter, tvb,
-					     value_offset, 8, FALSE);
+					     value_offset, 8, ENC_BIG_ENDIAN);
 			break;
 		}
 
@@ -451,11 +451,11 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			value_tree = proto_item_add_subtree (pi,
 					ett_collectd_valinfo);
 			proto_tree_add_item (value_tree, hf_collectd_val_type,
-					     tvb, value_type_offset, 1, FALSE);
+					     tvb, value_type_offset, 1, ENC_BIG_ENDIAN);
 			/* Set the `little endian' flag to TRUE here, because
 			 * collectd stores doubles in x86 representation. */
 			proto_tree_add_item (value_tree, hf_collectd_val_gauge,
-					     tvb, value_offset, 8, TRUE);
+					     tvb, value_offset, 8, ENC_LITTLE_ENDIAN);
 			break;
 		}
 
@@ -471,10 +471,10 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			value_tree = proto_item_add_subtree (pi,
 					ett_collectd_valinfo);
 			proto_tree_add_item (value_tree, hf_collectd_val_type,
-					     tvb, value_type_offset, 1, FALSE);
+					     tvb, value_type_offset, 1, ENC_BIG_ENDIAN);
 			proto_tree_add_item (value_tree,
 					     hf_collectd_val_derive, tvb,
-					     value_offset, 8, FALSE);
+					     value_offset, 8, ENC_BIG_ENDIAN);
 			break;
 		}
 
@@ -490,10 +490,10 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			value_tree = proto_item_add_subtree (pi,
 					ett_collectd_valinfo);
 			proto_tree_add_item (value_tree, hf_collectd_val_type,
-					     tvb, value_type_offset, 1, FALSE);
+					     tvb, value_type_offset, 1, ENC_BIG_ENDIAN);
 			proto_tree_add_item (value_tree,
 					     hf_collectd_val_absolute, tvb,
-					     value_offset, 8, FALSE);
+					     value_offset, 8, ENC_BIG_ENDIAN);
 			break;
 		}
 
@@ -510,9 +510,9 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			value_tree = proto_item_add_subtree (pi,
 					ett_collectd_valinfo);
 			proto_tree_add_item (value_tree, hf_collectd_val_type,
-					     tvb, value_type_offset, 1, FALSE);
+					     tvb, value_type_offset, 1, ENC_BIG_ENDIAN);
 			proto_tree_add_item (value_tree, hf_collectd_val_unknown,
-					     tvb, value_offset, 8, FALSE);
+					     tvb, value_offset, 8, ENC_BIG_ENDIAN);
 			break;
 		}
 		} /* switch (value_type) */
@@ -602,7 +602,7 @@ dissect_collectd_part_values (tvbuff_t *tvb, packet_info *pinfo, gint offset,
 	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2, length);
 
 	pi = proto_tree_add_item (pt, hf_collectd_data_valcnt, tvb,
-				  offset + 4, 2, FALSE);
+				  offset + 4, 2, ENC_BIG_ENDIAN);
 	if (values_count != corrected_values_count)
 		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_WARN,
 					"Number of values and length of part do not match. "
@@ -703,8 +703,8 @@ dissect_collectd_signature (tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
 	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2,
 			     length);
-	proto_tree_add_item (pt, hf_collectd_data_sighash, tvb, offset + 4, 32, FALSE);
-	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 36, length - 36, FALSE);
+	proto_tree_add_item (pt, hf_collectd_data_sighash, tvb, offset + 4, 32, ENC_NA);
+	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 36, length - 36, ENC_ASCII|ENC_NA);
 
 	return (0);
 } /* int dissect_collectd_signature */
@@ -793,12 +793,12 @@ dissect_collectd_encrypted (tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
 	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2, length);
 	proto_tree_add_uint (pt, hf_collectd_data_username_len, tvb, offset + 4, 2, username_length);
-	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 6, username_length, FALSE);
+	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 6, username_length, ENC_ASCII|ENC_NA);
 	proto_tree_add_item (pt, hf_collectd_data_initvec, tvb,
-			     offset + (6 + username_length), 16, FALSE);
+			     offset + (6 + username_length), 16, ENC_NA);
 	proto_tree_add_item (pt, hf_collectd_data_encrypted, tvb,
 			     offset + (22 + username_length),
-			     length - (22 + username_length), FALSE);
+			     length - (22 + username_length), ENC_NA);
 
 	return (0);
 } /* int dissect_collectd_encrypted */
@@ -857,7 +857,7 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	size = tvb_reported_length(tvb);
 
 	/* create the collectd protocol tree */
-	pi = proto_tree_add_item(tree, proto_collectd, tvb, 0, -1, FALSE);
+	pi = proto_tree_add_item(tree, proto_collectd, tvb, 0, -1, ENC_NA);
 	collectd_tree = proto_item_add_subtree(pi, ett_collectd);
 
 	memset (&tap_data, 0, sizeof (tap_data));
@@ -1254,7 +1254,7 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_uint (pt, hf_collectd_length, tvb,
 						  offset + 2, 2, part_length);
 			proto_tree_add_item (pt, hf_collectd_data, tvb,
-					     offset + 4, part_length - 4, FALSE);
+					     offset + 4, part_length - 4, ENC_NA);
 
 			expert_add_info_format (pinfo, pi,
 						PI_UNDECODED, PI_NOTE,
