@@ -2,7 +2,7 @@
  * Routines for Digital Audio Access Protocol dissection
  * Copyright 2004, Kelly Byrd <kbyrd@memcpy.com>
  *
- * $Id: packet-daap.c 36987 2011-05-04 19:42:51Z sfisher $
+ * $Id: packet-daap.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -408,22 +408,20 @@ dissect_daap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     * XXX - what if the body is gzipped?  This isn't the only protocol
     * running atop HTTP that might have a problem with that....
     */
-   if (check_col(pinfo->cinfo, COL_INFO)) {
-      if (is_request) {
-         col_set_str(pinfo->cinfo, COL_INFO, "DAAP Request");
-      } else {
-         /* This is done in two functions on purpose. If the tvb_get_xxx()
-          * functions fail, at least something will be in the info column
-          */
-         col_set_str(pinfo->cinfo, COL_INFO, "DAAP Response");
-         col_append_fstr(pinfo->cinfo, COL_INFO, " [first tag: %s, size: %d]",
-                         tvb_format_text(tvb, 0, 4),
-                         tvb_get_ntohl(tvb, 4));
-      }
+   if (is_request) {
+      col_set_str(pinfo->cinfo, COL_INFO, "DAAP Request");
+   } else {
+      /* This is done in two functions on purpose. If the tvb_get_xxx()
+       * functions fail, at least something will be in the info column
+       */
+      col_set_str(pinfo->cinfo, COL_INFO, "DAAP Response");
+      col_append_fstr(pinfo->cinfo, COL_INFO, " [first tag: %s, size: %d]",
+                      tvb_format_text(tvb, 0, 4),
+                      tvb_get_ntohl(tvb, 4));
    }
 
    if (tree) {
-      ti = proto_tree_add_item(tree, proto_daap, tvb, 0, -1, FALSE);
+      ti = proto_tree_add_item(tree, proto_daap, tvb, 0, -1, ENC_NA);
       daap_tree = proto_item_add_subtree(ti, ett_daap);
       dissect_daap_one_tag(daap_tree, tvb);
    }
@@ -453,14 +451,14 @@ dissect_daap_one_tag(proto_tree *tree, tvbuff_t *tvb)
                                tagsize,
                                plurality(tagsize, ' ', 's'));
 
-      ti2 = proto_tree_add_item(tree, hf_daap_name, tvb, offset, 4, FALSE);
+      ti2 = proto_tree_add_item(tree, hf_daap_name, tvb, offset, 4, ENC_ASCII|ENC_NA);
       PROTO_ITEM_SET_HIDDEN(ti2);
-      ti2 = proto_tree_add_item(tree, hf_daap_size, tvb, offset+4, 4, FALSE);
+      ti2 = proto_tree_add_item(tree, hf_daap_size, tvb, offset+4, 4, ENC_BIG_ENDIAN);
       PROTO_ITEM_SET_HIDDEN(ti2);
 
       offset += 8;
 
-      len = reported_length - offset; /* should be >= 0 since no exception above */ 
+      len = reported_length - offset; /* should be >= 0 since no exception above */
       DISSECTOR_ASSERT(len >= 0);
       if (tagsize <= (unsigned)len) {
          len = tagsize;
@@ -687,7 +685,7 @@ dissect_daap_one_tag(proto_tree *tree, tvbuff_t *tvb)
          /* now playing */
          /* bytes  4-7  contain uint32 playlist id */
          /* bytes 12-15 contain uint32 track id */
-         proto_item_append_text(ti, 
+         proto_item_append_text(ti,
                                 "; unknown: %d, playlist id: %d, unknown: %d, track id: %d",
                                 tvb_get_ntohl(tvb, offset),
                                 tvb_get_ntohl(tvb, offset+4),
@@ -743,6 +741,6 @@ proto_reg_handoff_daap(void)
 
    daap_handle = create_dissector_handle(dissect_daap, proto_daap);
    http_dissector_add(TCP_PORT_DAAP, daap_handle);
-   
+
    png_handle = find_dissector("png");
 }
