@@ -2,7 +2,7 @@
  * Routines for raw data (default case)
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-data.c 40511 2012-01-15 12:29:44Z jmayer $
+ * $Id: packet-data.c 42462 2012-05-07 13:13:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -59,7 +59,7 @@ dissect_data(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 	if (tree) {
 		bytes = tvb_length_remaining(tvb, 0);
 		if (bytes > 0) {
-			tvbuff_t *data_tvb;
+			tvbuff_t   *data_tvb;
 			proto_item *ti;
 			proto_tree *data_tree;
 			if (new_pane) {
@@ -84,9 +84,9 @@ dissect_data(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 
 			if(generate_md5_hash) {
 				const guint8 *cp;
-				md5_state_t md_ctx;
-				md5_byte_t digest[16];
-				gchar *digest_string;
+				md5_state_t   md_ctx;
+				md5_byte_t    digest[16];
+				gchar        *digest_string;
 
 				cp = tvb_get_ptr(tvb, 0, bytes);
 
@@ -122,9 +122,9 @@ proto_register_data(void)
 	static gint *ett[] = {
 		&ett_data
 	};
-	
+
 	module_t *module_data;
-	
+
 	proto_data = proto_register_protocol (
 		"Data",		/* name */
 		"Data",		/* short name */
@@ -135,8 +135,8 @@ proto_register_data(void)
 
 	proto_register_field_array(proto_data, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
-	
-	module_data = prefs_register_protocol( proto_data, proto_reg_handoff_data);
+
+	module_data = prefs_register_protocol( proto_data, NULL);
 	prefs_register_bool_preference(module_data,
 		"datapref.newpane",
 		"Show not dissected data on new Packet Bytes pane",
@@ -159,8 +159,3 @@ proto_register_data(void)
 	 */
 	proto_set_cant_toggle(proto_data);
 }
-
-void
-proto_reg_handoff_data(void)
-{
-}
