@@ -4,7 +4,7 @@
  *
  * Copyright 1999, Nathan Neulinger <nneul@umr.edu>
  *
- * $Id: packet-dcc.c 36894 2011-04-27 05:55:54Z etxrab $
+ * $Id: packet-dcc.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -80,7 +80,7 @@ static gint ett_dcc_trace = -1;
 /* Utility macros */
 #define D_SIGNATURE() \
 	proto_tree_add_item(dcc_optree, hf_dcc_signature, tvb, \
-		offset, sizeof(DCC_SIGNATURE), FALSE); \
+		offset, sizeof(DCC_SIGNATURE), ENC_NA); \
 	offset += sizeof(DCC_SIGNATURE);
 
 #define D_LABEL(label,len) \
@@ -103,7 +103,7 @@ static gint ett_dcc_trace = -1;
 
 #define D_TARGET() \
 	hidden_item = proto_tree_add_item(dcc_tree, hf_dcc_target, tvb, \
-		offset, sizeof(DCC_TGTS), FALSE); \
+		offset, sizeof(DCC_TGTS), ENC_BIG_ENDIAN); \
 	PROTO_ITEM_SET_HIDDEN(hidden_item); \
 	proto_tree_add_text(dcc_optree, tvb, offset, sizeof(DCC_TGTS), "%s", \
 		val_to_str(tvb_get_ntohl(tvb,offset), dcc_target_vals, "Targets (%u)")); \
@@ -125,12 +125,12 @@ static gint ett_dcc_trace = -1;
 		dcc_cktype_vals, \
 		"Unknown Type: %u")); \
 	cktree = proto_item_add_subtree(ckti, ett_dcc_ck); \
-	proto_tree_add_item(cktree, hf_dcc_ck_type, tvb, offset, 1, FALSE); \
+	proto_tree_add_item(cktree, hf_dcc_ck_type, tvb, offset, 1, ENC_BIG_ENDIAN); \
 	offset += 1; \
-	proto_tree_add_item(cktree, hf_dcc_ck_len, tvb, offset, 1, FALSE); \
+	proto_tree_add_item(cktree, hf_dcc_ck_len, tvb, offset, 1, ENC_BIG_ENDIAN); \
 	offset += 1; \
 	proto_tree_add_item(cktree, hf_dcc_ck_sum, tvb, offset, \
-		sizeof(DCC_SUM), FALSE); \
+		sizeof(DCC_SUM), ENC_NA); \
 	offset += sizeof(DCC_SUM); \
 }
 
@@ -239,11 +239,11 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_dcc, tvb, offset, -1,
-			FALSE);
+			ENC_NA);
 		dcc_tree = proto_item_add_subtree(ti, ett_dcc);
 
 		proto_tree_add_item(dcc_tree, hf_dcc_len, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 
 		if ( tvb_length(tvb) < tvb_get_ntohs(tvb, offset)) {
 			/* Doesn't have number of bytes that header claims. */
@@ -252,16 +252,16 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		offset += 2;
 
 		proto_tree_add_item(dcc_tree, hf_dcc_pkt_vers, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 		offset += 1;
 
 		op = tvb_get_guint8(tvb, offset);
 		proto_tree_add_item(dcc_tree, hf_dcc_op, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(dcc_tree, hf_dcc_clientid, tvb,
-			offset, 4, FALSE);
+			offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 
 		ti = proto_tree_add_text(dcc_tree, tvb, offset, -1, "Operation Numbers (Opaque to Server)");
@@ -348,7 +348,7 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 					aop = tvb_get_guint8(tvb, offset+4);
 					proto_tree_add_item(dcc_optree, hf_dcc_adminop, tvb, offset+4,
-						1, FALSE);
+						1, ENC_BIG_ENDIAN);
 					col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 						val_to_str(tvb_get_guint8(tvb,offset+4),
 						dcc_adminop_vals, "Unknown (%u)"));
@@ -356,20 +356,20 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					if (aop == DCC_AOP_TRACE_ON || aop == DCC_AOP_TRACE_OFF )
 					{
 						ti = proto_tree_add_item(dcc_optree, hf_dcc_trace, tvb, offset,
-							4, FALSE);
+							4, ENC_BIG_ENDIAN);
 						dcc_tracetree = proto_item_add_subtree(ti, ett_dcc_trace);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_admin, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_anon, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_client, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_rlim, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_query, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_ridc, tvb, offset, 4, FALSE);
-						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_flood, tvb, offset, 4, FALSE);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_admin, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_anon, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_client, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_rlim, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_query, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_ridc, tvb, offset, 4, ENC_BIG_ENDIAN);
+						proto_tree_add_item(dcc_tracetree, hf_dcc_trace_flood, tvb, offset, 4, ENC_BIG_ENDIAN);
 					}
 					else if ( aop == DCC_AOP_FLOD )
 					{
 						proto_tree_add_item(dcc_optree, hf_dcc_floodop,
-							tvb, offset, 4, FALSE);
+							tvb, offset, 4, ENC_BIG_ENDIAN);
 						col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 							val_to_str(tvb_get_ntohl(tvb,offset),
 							dcc_floodop_vals, "Unknown (%u)"));
@@ -377,7 +377,7 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					else
 					{
 						proto_tree_add_item(dcc_optree, hf_dcc_adminval,
-							tvb, offset, 4, FALSE);
+							tvb, offset, 4, ENC_BIG_ENDIAN);
 					}
 					offset += 4;
 
@@ -389,17 +389,17 @@ dissect_dcc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 			case DCC_OP_OK:
 				proto_tree_add_item(dcc_optree, hf_dcc_max_pkt_vers, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				offset += 1;
 
 				D_LABEL("Unused", 1);
 
 				proto_tree_add_item(dcc_optree, hf_dcc_qdelay_ms, tvb,
-					offset, 2, FALSE);
+					offset, 2, ENC_BIG_ENDIAN);
 				offset += 2;
 
 				proto_tree_add_item(dcc_optree, hf_dcc_brand, tvb,
-					offset, sizeof(DCC_BRAND), FALSE);
+					offset, sizeof(DCC_BRAND), ENC_ASCII|ENC_NA);
 				offset += sizeof(DCC_BRAND);
 
 				D_SIGNATURE();
