@@ -3,8 +3,8 @@
  * Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/directory.tar.gz directory/cds/stubs/cds_solicit.idl
- *      
- * $Id: packet-dcerpc-cds_solicit.c 32410 2010-04-06 21:14:01Z wmeier $
+ *
+ * $Id: packet-dcerpc-cds_solicit.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,10 +30,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-dcerpc.h"
