@@ -3,7 +3,7 @@
  * Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
  * This information is based off the released idl files from opengroup.
  *
- * $Id: packet-dcerpc-dce122.h 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-dcerpc-dce122.h 34500 2010-10-13 17:56:05Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,6 +27,6 @@
 #ifndef __PACKET_DCERPC__DCE122_H__
 #define __PACKET_DCERPC__DCE122_H__
 
-extern const value_string dce_error_vals[];
+extern value_string_ext dce_error_vals_ext;
 
 #endif
