@@ -1,10 +1,10 @@
 /* packet-dcerpc-dtsstime_req.c
- * Routines for Time services stuff.     
+ * Routines for Time services stuff.
  * Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/time.tar.gz time/service/dtsstime_req.idl
- *           
- * $Id: packet-dcerpc-dtsstime_req.c 32735 2010-05-10 15:54:57Z wmeier $
+ *
+ * $Id: packet-dcerpc-dtsstime_req.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,10 +30,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-dcerpc.h"
