@@ -2,7 +2,7 @@
  * Routines for dcerpc endpoint mapper dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc-epm.c 39426 2011-10-15 18:46:26Z wmeier $
+ * $Id: packet-dcerpc-epm.c 40003 2011-11-25 17:19:00Z sfisher $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -320,11 +320,12 @@ static const value_string proto_id_vals[] = {
 static int
 epm_dissect_tower_data (tvbuff_t *tvb, int offset,
                              packet_info *pinfo, proto_tree *tree,
-                             guint8 *drep)
+                             guint8 *drep _U_)
 {
     guint16 num_floors, i;
     dcerpc_info *di;
     const char *uuid_name;
+    guint8   u8little_endian = DREP_LITTLE_ENDIAN;
 
     di=pinfo->private_data;
     if(di->conformant_run){
@@ -356,7 +357,7 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
 
         switch(proto_id){
         case PROTO_ID_UUID:
-            dcerpc_tvb_get_uuid (tvb, offset+1, drep, &uuid);
+            dcerpc_tvb_get_uuid (tvb, offset+1, &u8little_endian, &uuid);
 
             uuid_name = guids_get_uuid_name(&uuid);
 
