@@ -4,8 +4,8 @@
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/file.tar.gz icl_rpc.idl
  *
- * $Id: packet-dcerpc-icl_rpc.c 32410 2010-04-06 21:14:01Z wmeier $
- *      
+ * $Id: packet-dcerpc-icl_rpc.c 42429 2012-05-04 21:29:00Z wmeier $
+ *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -30,10 +30,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-dcerpc.h"
