@@ -4,8 +4,8 @@
  * Copyright 2004, Jaime Fournier <jaime.fournier@hush.com>
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/admin.tar.gz ./admin/dced/idl/llb.idl
- *      
- * $Id: packet-dcerpc-llb.c 32410 2010-04-06 21:14:01Z wmeier $
+ *
+ * $Id: packet-dcerpc-llb.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,10 +31,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-dcerpc.h"
