@@ -2,7 +2,7 @@
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  * Copyright 2003, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc.h 35259 2010-12-23 23:50:14Z jake $
+ * $Id: packet-dcerpc.h 38128 2011-07-19 23:02:02Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,17 @@
 
 #include <epan/conversation.h>
 
+/*
+ * Data representation.
+ */
+#define DREP_LITTLE_ENDIAN	0x10
+
+/*
+ * Data representation to integer byte order.
+ */
+#define DREP_ENC_INTEGER(drep)	\
+	(((drep)[0] & DREP_LITTLE_ENDIAN) ? ENC_LITTLE_ENDIAN : ENC_BIG_ENDIAN)
+
 #ifdef PT_R4
 /* now glib always includes signal.h and on linux PPC 
  * signal.h defines PT_R4
