@@ -2,7 +2,7 @@
  * Routines for ETSI Distribution & Communication Protocol
  * Copyright 2006, British Broadcasting Corporation
  *
- * $Id: packet-dcp-etsi.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-dcp-etsi.c 44309 2012-08-07 19:29:44Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -326,6 +326,8 @@ dissect_pft_fec_detailed(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
         }
         current_findex++; /* skip over the fragment we have */
       }
+      tvb_free(dummytvb);
+
       if(frag)
         new_tvb = process_reassembled_data (tvb, offset, pinfo,
                                             "Reassembled DCP (ETSI)",
@@ -509,14 +511,13 @@ dissect_pft(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
     gboolean save_fragmented = pinfo->fragmented;
     guint16 real_len = tvb_length(tvb)-offset;
     proto_tree_add_item (pft_tree, hf_edcp_pft_payload, tvb, offset, real_len, ENC_NA);
-    if(real_len != payload_len) {
+    if(real_len != payload_len || real_len == 0) {
       if(li)
         proto_item_append_text(li, " (length error (%d))", real_len);
     }
-    next_tvb = dissect_pft_fragmented(tvb, pinfo, pft_tree,
-                                      findex, fcount, seq, offset, real_len,
-                                      fec, rsk, rsz
-                                      );
+    if (real_len)
+      next_tvb = dissect_pft_fragmented(tvb, pinfo, pft_tree, findex, fcount,
+                                        seq, offset, real_len, fec, rsk, rsz);
     pinfo->fragmented = save_fragmented;
   } else {
     next_tvb = tvb_new_subset_remaining (tvb, offset);
