@@ -3,7 +3,7 @@
  * see http://ddt.sourceforge.net/
  * Olivier Abad <oabad@noos.fr>
  *
- * $Id: packet-ddtp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-ddtp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -108,16 +108,16 @@ dissect_ddtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_clear (pinfo->cinfo, COL_INFO);
 
     if (tree) {
-	ti = proto_tree_add_item(tree, proto_ddtp, tvb, 0, -1, FALSE);
+	ti = proto_tree_add_item(tree, proto_ddtp, tvb, 0, -1, ENC_NA);
 	ddtp_tree = proto_item_add_subtree(ti, ett_ddtp);
 
-	proto_tree_add_item(ddtp_tree, hf_ddtp_version, tvb, 0, 4, FALSE);
-	proto_tree_add_item(ddtp_tree, hf_ddtp_encrypt, tvb, 4, 4, FALSE);
-	proto_tree_add_item(ddtp_tree, hf_ddtp_hostid, tvb, 8, 4, FALSE);
+	proto_tree_add_item(ddtp_tree, hf_ddtp_version, tvb, 0, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(ddtp_tree, hf_ddtp_encrypt, tvb, 4, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(ddtp_tree, hf_ddtp_hostid, tvb, 8, 4, ENC_BIG_ENDIAN);
     }
     if (tvb_get_ntohl(tvb, 4) == DDTP_ENCRYPT_PLAINTEXT) {
 	if (tree)
-	    proto_tree_add_item(ddtp_tree, hf_ddtp_msgtype, tvb, 12, 4, FALSE);
+	    proto_tree_add_item(ddtp_tree, hf_ddtp_msgtype, tvb, 12, 4, ENC_BIG_ENDIAN);
 	switch (tvb_get_ntohl(tvb, 12)) {
 	case DDTP_MESSAGE_ERROR :
 	    col_set_str(pinfo->cinfo, COL_INFO, "Message Error");
@@ -126,16 +126,16 @@ dissect_ddtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    col_set_str(pinfo->cinfo, COL_INFO, "Update Query");
 	    if (tree) {
 		proto_tree_add_item(ddtp_tree, hf_ddtp_opcode, tvb, 16, 4,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		proto_tree_add_item(ddtp_tree, hf_ddtp_ipaddr, tvb, 20, 4,
-			FALSE);
+			ENC_BIG_ENDIAN);
 	    }
 	    break;
 	case DDTP_UPDATE_REPLY :
 	    col_set_str(pinfo->cinfo, COL_INFO, "Update Reply");
 	    if (tree) {
 		proto_tree_add_item(ddtp_tree, hf_ddtp_status, tvb, 16, 4,
-			FALSE);
+			ENC_BIG_ENDIAN);
 	    }
 	    break;
 	case DDTP_ALIVE_QUERY :
