@@ -1,7 +1,7 @@
 /* packet-diameter.c
  * Routines for Diameter packet disassembly
  *
- * $Id: packet-diameter.c 41675 2012-03-19 17:12:04Z morriss $
+ * $Id: packet-diameter.c 43219 2012-06-11 23:22:50Z gerald $
  *
  * Copyright (c) 2001 by David Frascone <dave@frascone.com>
  * Copyright (c) 2007 by Luis E. Garcia Ontanon <luis@ontanon.org>
@@ -180,9 +180,7 @@ typedef struct _proto_avp_t {
 
 static const char* simple_avp(diam_ctx_t*, diam_avp_t*, tvbuff_t*);
 
-static const value_string no_vs[] = {{0, NULL} };
-static GArray no_garr = { (void*)no_vs, 0 };
-static diam_vnd_t unknown_vendor = { 0xffffffff, &no_garr, NULL,  &no_garr };
+static diam_vnd_t unknown_vendor = { 0xffffffff, NULL, NULL, NULL };
 static diam_vnd_t no_vnd = { 0, NULL, NULL, NULL };
 static diam_avp_t unknown_avp = {0, &unknown_vendor, simple_avp, simple_avp, -1, -1, NULL };
 static GArray* all_cmds;
@@ -349,23 +347,23 @@ dissect_diameter_eap_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 static int
 dissect_diameter_base_framed_ipv6_prefix(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
-    guint8 prefix_len, prefix_len_bytes;
+	guint8 prefix_len, prefix_len_bytes;
 
-    proto_tree_add_item(tree, hf_framed_ipv6_prefix_reserved, tvb, 0, 1, ENC_BIG_ENDIAN);
-    proto_tree_add_item(tree, hf_framed_ipv6_prefix_length, tvb, 1, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_framed_ipv6_prefix_reserved, tvb, 0, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_framed_ipv6_prefix_length, tvb, 1, 1, ENC_BIG_ENDIAN);
 
-    prefix_len = tvb_get_guint8(tvb, 1);
-    prefix_len_bytes = prefix_len / 8;
-    if (prefix_len % 8)
-	    prefix_len_bytes++;
+	prefix_len = tvb_get_guint8(tvb, 1);
+	prefix_len_bytes = prefix_len / 8;
+	if (prefix_len % 8)
+		prefix_len_bytes++;
 
-    proto_tree_add_item(tree, hf_framed_ipv6_prefix_bytes, tvb, 2, prefix_len_bytes, ENC_NA);
+	proto_tree_add_item(tree, hf_framed_ipv6_prefix_bytes, tvb, 2, prefix_len_bytes, ENC_NA);
 
-    /* If we have a fully IPv6 address, display it as such */
-    if (prefix_len_bytes == 16)
-	proto_tree_add_item(tree, hf_framed_ipv6_prefix_ipv6, tvb, 2, prefix_len_bytes, ENC_NA);
+	/* If we have a fully IPv6 address, display it as such */
+	if (prefix_len_bytes == 16)
+		proto_tree_add_item(tree, hf_framed_ipv6_prefix_ipv6, tvb, 2, prefix_len_bytes, ENC_NA);
 
-    return(prefix_len_bytes+2);
+	return(prefix_len_bytes+2);
 }
 
 /* Dissect an AVP at offset */
@@ -839,11 +837,11 @@ dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 	guint32 flags_bits = (tvb_get_ntohl(tvb,4) & 0xff000000) >> 24;
 	int packet_len = first_word & 0x00ffffff;
 	proto_item *pi, *cmd_item, *app_item, *version_item;
-	proto_tree* diam_tree;
-	diam_ctx_t* c = ep_alloc0(sizeof(diam_ctx_t));
+	proto_tree *diam_tree;
+	diam_ctx_t *c = ep_alloc0(sizeof(diam_ctx_t));
 	int offset;
-	value_string* cmd_vs;
-	const char* cmd_str;
+	value_string *cmd_vs;
+	const char *cmd_str;
 	guint32 cmd = tvb_get_ntoh24(tvb,5);
 	guint32 fourth = tvb_get_ntohl(tvb,8);
 	guint32 hop_by_hop_id = 0;
@@ -852,7 +850,7 @@ dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 	diameter_req_ans_pair_t *diameter_pair;
 	proto_item *it;
 	nstime_t ns;
-	void* pd_save;
+	void *pd_save;
 
 	pd_save = pinfo->private_data;
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DIAMETER");
@@ -901,24 +899,21 @@ dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 			break;
 		}
 		case DIAMETER_RFC: {
-			guint32 application_id;
-			application_id = tvb_get_ntohl(tvb,8);
-			cmd_vs = (value_string*)(void*)all_cmds->data;
 			/* Store the application id to be used by subdissectors */
-			pinfo->private_data = &application_id;
-			app_item = proto_tree_add_item(diam_tree, hf_diameter_application_id,tvb,8,4,ENC_BIG_ENDIAN);
-			if (strcmp(val_to_str(tvb_get_ntohl(tvb, 8), dictionary.applications,
-				                  "Unknown"), "Unknown") == 0) {
-				proto_tree* tu = proto_item_add_subtree(app_item,ett_unknown);
-				proto_item* iu = proto_tree_add_text(tu,tvb, 8 ,4,"Unknown Application Id, "
+			pinfo->private_data = &fourth;
+
+			cmd_vs = (value_string*)(void*)all_cmds->data;
+
+			app_item = proto_tree_add_item(diam_tree, hf_diameter_application_id, tvb, 8, 4, ENC_BIG_ENDIAN);
+			if (match_strval(fourth, dictionary.applications) == NULL) {
+				proto_tree *tu = proto_item_add_subtree(app_item,ett_unknown);
+				proto_item *iu = proto_tree_add_text(tu, tvb, 8, 4, "Unknown Application Id, "
 				                                     "if you know what this is you can add it to dictionary.xml");
 				expert_add_info_format(c->pinfo, iu, PI_UNDECODED, PI_WARN,
-				                       "Unknown Application Id (%u)",
-				                       tvb_get_ntohl(tvb, 8));
+				                       "Unknown Application Id (%u)", fourth);
 				PROTO_ITEM_SET_GENERATED(iu);
 			}
 
-
 			c->version_rfc = TRUE;
 			break;
 		}
@@ -1233,15 +1228,15 @@ RFC3588
 		NULL, FT_UINT16, BASE_DEC|BASE_EXT_STRING, &diameter_avp_data_addrfamily_vals_ext, 0);
 
 	reginfo(&(t->hf_ipv4), ep_strdup_printf("%s Address",name),
-		alnumerize(ep_strdup_printf("diameter.%s",name)),
+		alnumerize(ep_strdup_printf("diameter.%s.IPv4",name)),
 		NULL, FT_IPv4, BASE_NONE, NULL, 0);
 
 	reginfo(&(t->hf_ipv6), ep_strdup_printf("%s Address",name),
-		alnumerize(ep_strdup_printf("diameter.%s",name)),
+		alnumerize(ep_strdup_printf("diameter.%s.IPv6",name)),
 		NULL, FT_IPv6, BASE_NONE, NULL, 0);
 
 	reginfo(&(t->hf_other), ep_strdup_printf("%s Address",name),
-		alnumerize(ep_strdup_printf("diameter.%s",name)),
+		alnumerize(ep_strdup_printf("diameter.%s.Bytes",name)),
 		NULL, FT_BYTES, BASE_NONE, NULL, 0);
 
 	g_ptr_array_add(build_dict.ett,ettp);
@@ -1391,6 +1386,11 @@ strcase_equal(gconstpointer ka, gconstpointer kb)
 }
 
 
+/* Note: Dynamic "value string arrays" (e.g., vs_cmds, vs_avps, ...) are constructed using */
+/*       "zero-terminated" GArrays so that they will have the same form as standard        */
+/*       value_string arrays created at compile time. Since the last entry in a            */
+/*       value_string array must be {0, NULL}, we are assuming that NULL == 0 (hackish).   */
+
 static int
 dictionary_load(void)
 {
@@ -1418,6 +1418,8 @@ dictionary_load(void)
 	dictionary.vnds = pe_tree_create(EMEM_TREE_TYPE_RED_BLACK,"diameter_vnds");
 	dictionary.avps = pe_tree_create(EMEM_TREE_TYPE_RED_BLACK,"diameter_avps");
 
+	unknown_vendor.vs_cmds = g_array_new(TRUE,TRUE,sizeof(value_string));
+	unknown_vendor.vs_avps = g_array_new(TRUE,TRUE,sizeof(value_string));
 	no_vnd.vs_cmds = g_array_new(TRUE,TRUE,sizeof(value_string));
 	no_vnd.vs_avps = g_array_new(TRUE,TRUE,sizeof(value_string));
 
@@ -1561,7 +1563,7 @@ dictionary_load(void)
 			if ( (strcase_equal(x->name,"avp-proto") && strcase_equal(x->key,a->name))
 				 || (a->type && strcase_equal(x->name,"type-proto") && strcase_equal(x->key,a->type))
 				 ) {
-				static avp_type_t proto_type = {"proto", proto_avp, proto_avp, FT_UINT32, BASE_NONE, build_proto_avp};
+				static avp_type_t proto_type = {"proto", proto_avp, proto_avp, FT_UINT32, BASE_HEX, build_proto_avp};
 				type =  &proto_type;
 
 				avp_data = x->value;
