@@ -3,7 +3,7 @@
  * Copyright 2005, Scientific Research Corporation
  * Initial implementation by Jeremy Ouellette <jouellet@scires.com>
  *
- * $Id: packet-dis-pdus.h 32306 2010-03-27 15:23:16Z etxrab $
+ * $Id: packet-dis-pdus.h 32758 2010-05-11 19:03:33Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,6 +37,9 @@ extern DIS_ParserNode DIS_PARSER_ENTITY_STATE_PDU[];
 extern DIS_ParserNode DIS_PARSER_FIRE_PDU[];
 extern DIS_ParserNode DIS_PARSER_DETONATION_PDU[];
 
+/* DIS Distributed Emission Regeneration PDUs */
+extern DIS_ParserNode DIS_PARSER_ELECTROMAGNETIC_EMISSION_PDU[];
+
 /* DIS Radio Communications protocol (RCP) family PDUs */
 extern DIS_ParserNode DIS_PARSER_TRANSMITTER_PDU[];
 extern DIS_ParserNode DIS_PARSER_SIGNAL_PDU[];
