@@ -2,7 +2,7 @@
  * Routines for dlm3 dissection
  * Copyright 2007, Masatake YAMATO <jet@gyve.org>
  *
- * $Id: packet-dlm3.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-dlm3.c 41645 2012-03-18 22:24:24Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1133,7 +1133,7 @@ proto_register_dlm3(void)
     DLM3_REGISTER_HF_EXFLAGS(rf_lsflags, "rf.lsflags"),
 
     { &hf_dlm3_rf_unused,
-      { "Unsed area", "dlm3.rf.lsflags.unused",
+      { "Unused area", "dlm3.rf.lsflags.unused",
         FT_UINT64, BASE_HEX, NULL, 0x0,
         NULL, HFILL}},
 
