@@ -2,7 +2,7 @@
  * This is a dissector for the DirectPlay protocol.
  * Copyright 2006 - 2008 by Kai Blin
  *
- * $Id: packet-dplay.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-dplay.c 40590 2012-01-19 20:19:28Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1382,7 +1382,7 @@ void proto_register_dplay(void)
         { "PackedPlayer short name", "dplay.pp.short_name", FT_STRING, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_long_name,
-        { "PackedPlayer long name", "dplay.pp.short_name", FT_STRING, BASE_NONE,
+        { "PackedPlayer long name", "dplay.pp.long_name", FT_STRING, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_player_data,
         { "PackedPlayer player data", "dplay.pp.player_data", FT_BYTES, BASE_NONE,
@@ -1453,7 +1453,7 @@ void proto_register_dplay(void)
         { "SuperPackedPlayer short name", "dplay.spp.short_name", FT_STRING, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_long_name,
-        { "SuperPackedPlayer long name", "dplay.spp.short_name", FT_STRING, BASE_NONE,
+        { "SuperPackedPlayer long name", "dplay.spp.long_name", FT_STRING, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_data_length,
         { "SuperPackedPlayer player data length", "dplay.spp.pd_length", FT_UINT32, BASE_HEX,
@@ -1603,7 +1603,7 @@ void proto_register_dplay(void)
         { "Player ID", "dplay.type_0f.player_id", FT_BYTES, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_data_size,
-        { "Data Size", "dplay.multi.group_id", FT_UINT32, BASE_DEC,
+        { "Data Size", "dplay.type_0f.data_size", FT_UINT32, BASE_DEC,
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_data_offset,
         { "Data Offset", "dplay.type_0f.data_offset", FT_UINT32, BASE_DEC,
