@@ -2,7 +2,7 @@
  * Routines for dsi packet dissection
  * Copyright 2001, Randy McEoin <rmceoin@pe.com>
  *
- * $Id: packet-dsi.c 40590 2012-01-19 20:19:28Z cmaynard $
+ * $Id: packet-dsi.c 42362 2012-04-30 21:15:17Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -331,7 +331,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 	proto_tree_add_item(sub_tree, hf_dsi_server_flag_ext_sleep     , tvb, ofs, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sub_tree, hf_dsi_server_flag_fast_copy     , tvb, ofs, 2, ENC_BIG_ENDIAN);
 
-	proto_tree_add_item(tree, hf_dsi_server_name, tvb, offset +AFPSTATUS_PRELEN, 1, ENC_ASCII|ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_dsi_server_name, tvb, offset +AFPSTATUS_PRELEN, 1, ENC_ASCII|ENC_NA);
 
 	flag = tvb_get_ntohs(tvb, ofs);
 	if ((flag & AFPSRVRINFO_SRVSIGNATURE)) {
@@ -366,7 +366,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 
 	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_MACHOFF);
 	if (ofs)
-		proto_tree_add_item(tree, hf_dsi_server_type, tvb, ofs, 1, ENC_ASCII|ENC_BIG_ENDIAN);
+		proto_tree_add_item(tree, hf_dsi_server_type, tvb, ofs, 1, ENC_ASCII|ENC_NA);
 
 	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
 	if (ofs) {
@@ -376,7 +376,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		sub_tree = proto_item_add_subtree(ti, ett_dsi_vers);
 		for (i = 0; i < nbe; i++) {
 			len = tvb_get_guint8(tvb, ofs);
-			proto_tree_add_item(sub_tree, hf_dsi_server_vers, tvb, ofs, 1, ENC_ASCII|ENC_BIG_ENDIAN);
+			proto_tree_add_item(sub_tree, hf_dsi_server_vers, tvb, ofs, 1, ENC_ASCII|ENC_NA);
 			ofs += len + 1;
 		}
 	}
@@ -389,7 +389,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		sub_tree = proto_item_add_subtree(ti, ett_dsi_uams);
 		for (i = 0; i < nbe; i++) {
 			len = tvb_get_guint8(tvb, ofs);
-			proto_tree_add_item(sub_tree, hf_dsi_server_uams, tvb, ofs, 1, ENC_ASCII|ENC_BIG_ENDIAN);
+			proto_tree_add_item(sub_tree, hf_dsi_server_uams, tvb, ofs, 1, ENC_ASCII|ENC_NA);
 			ofs += len + 1;
 		}
 	}
@@ -478,7 +478,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		sub_tree = proto_item_add_subtree(ti, ett_dsi_directory);
 		for (i = 0; i < nbe; i++) {
 			len = tvb_get_guint8(tvb, ofs);
-			proto_tree_add_item(sub_tree, hf_dsi_server_directory, tvb, ofs, 1, ENC_ASCII|ENC_BIG_ENDIAN);
+			proto_tree_add_item(sub_tree, hf_dsi_server_directory, tvb, ofs, 1, ENC_ASCII|ENC_NA);
 			ofs += len + 1;
 		}
 	}
@@ -497,7 +497,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		ofs += ulen;
 	}
 
-	return offset;
+	return ofs;
 }
 
 static void
