@@ -9,7 +9,7 @@
  * names of its contributors may be used to endorse or promote products 
  * derived from this software without specific prior written permission.
  *
- * $Id: packet-dtn.h 31929 2010-02-20 11:06:16Z etxrab $
+ * $Id: packet-dtn.h 42804 2012-05-23 06:25:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -94,7 +94,15 @@
 #define HEADER_PROCFLAGS_LAST_HEADER    0x08
 
 /* Header Types (excluding Primary Header) */
-#define PAYLOAD_HEADER_TYPE             0x01
+#define BUNDLE_BLOCK_TYPE_PAYLOAD               0x01 /* RFC5050 */
+#define BUNDLE_BLOCK_TYPE_AUTHENTICATION        0x02 /* RFC6257 */
+#define BUNDLE_BLOCK_TYPE_INTEGRITY             0x03 /* RFC6257 */
+#define BUNDLE_BLOCK_TYPE_CONFIDENTIALITY       0x04 /* RFC6257 */
+#define BUNDLE_BLOCK_TYPE_PREVIOUS_HOP_INSERT   0x05 /* RFC6259 */
+#define BUNDLE_BLOCK_TYPE_METADATA_EXTENSION    0x08 /* RFC6258 */
+#define BUNDLE_BLOCK_TYPE_EXTENSION_SECURITY    0x09 /* RFC6257 */
+#define BUNDLE_BLOCK_TYPE_CUSTODY_TRANSFER      0x0a /* http://bioserve.colorado.edu/bp-acs/ */
+#define BUNDLE_BLOCK_TYPE_EXTENDED_COS          0x13 /* http://tools.ietf.org/html/draft-irtf-dtnrg-ecos-02 */
 
 /* Payload Header Processing Flags */
 #define PAYLOAD_PROCFLAGS_REPLICATE_MASK        0x01
@@ -109,8 +117,10 @@
 #define TCP_CONV_HDR_SHUTDOWN_LENGTH    1
 
 /* Administrative Record Definitions */
-#define ADMIN_REC_TYPE_STATUS_REPORT    0x01
-#define ADMIN_REC_TYPE_CUSTODY_SIGNAL   0x02
+#define ADMIN_REC_TYPE_STATUS_REPORT            0x01
+#define ADMIN_REC_TYPE_CUSTODY_SIGNAL           0x02
+#define ADMIN_REC_TYPE_AGGREGATE_CUSTODY_SIGNAL 0x04
+#define ADMIN_REC_TYPE_ANNOUNCE_BUNDLE          0x05
 
 #define ADMIN_REC_FLAGS_FRAGMENT        0x01
 #define ADMIN_REC_CUSTODY_REASON_MASK   0x7f
@@ -132,6 +142,11 @@
 #define BLOCK_CONTROL_NOT_PROCESSED     0x20
 #define BLOCK_CONTROL_EID_REFERENCE     0x40
 
+/* ECOS Flags */
+#define ECOS_FLAGS_CRITICAL             0x01
+#define ECOS_FLAGS_STREAMING            0x02
+#define ECOS_FLAGS_ORDINAL              0x04
+
 #define IPN_SCHEME_STR			"ipn"
 
 int evaluate_sdnv(tvbuff_t *tvb, int offset, int *bytecount);
