@@ -2,7 +2,7 @@
  * Routines for DVB-DATA (ETSI EN 301 192) MultiProtocol Encapsulation
  * Copyright 2012, Guy Martin <gmsoft@tuxicoman.be>
  *
- * $Id: packet-dvb-data-mpe.c 41523 2012-03-13 08:57:04Z etxrab $
+ * $Id: packet-dvb-data-mpe.c 43258 2012-06-14 13:43:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,9 +84,6 @@ dissect_dvb_data_mpe(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DVB-DATA");
 	col_set_str(pinfo->cinfo, COL_INFO, "MultiProtocol Encapsulation");
 
-	if (!tree)
-		return;
-
 	ti = proto_tree_add_item(tree, proto_dvb_data_mpe, tvb, offset, -1, ENC_NA);
 	dvb_data_mpe_tree = proto_item_add_subtree(ti, ett_dvb_data_mpe);
 
