@@ -1,7 +1,7 @@
 /* packet-dvmrp.c   2001 Ronnie Sahlberg <See AUTHORS for email>
  * Routines for IGMP/DVMRP packet disassembly
  *
- * $Id: packet-dvmrp.c 48713 2013-04-02 21:25:51Z cmaynard $
+ * $Id: packet-dvmrp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -249,7 +249,7 @@ dissect_v3_report(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 		int old_offset_a = offset;
 
 		item = proto_tree_add_item(parent_tree, hf_route,
-				tvb, offset, -1, FALSE);
+				tvb, offset, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_route);
 
 		m0 = 0xff;
@@ -356,7 +356,7 @@ dissect_dvmrp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 		proto_item *item;
 
 		item = proto_tree_add_item(parent_tree, hf_capabilities,
-				tvb, offset, 1, FALSE);
+				tvb, offset, 1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_capabilities);
 
 		count = tvb_get_guint8(tvb, offset);
@@ -370,22 +370,22 @@ dissect_dvmrp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 	offset += 1;
 
 	/* minor version */
-	proto_tree_add_item(parent_tree, hf_min_ver, tvb, offset, 1, FALSE);
+	proto_tree_add_item(parent_tree, hf_min_ver, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset += 1;
 
 	/* major version */
-	proto_tree_add_item(parent_tree, hf_maj_ver, tvb, offset, 1, FALSE);
+	proto_tree_add_item(parent_tree, hf_maj_ver, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset += 1;
 
 	switch (code) {
 	case DVMRP_V3_PROBE:
 		/* generation id */
 		proto_tree_add_item(parent_tree, hf_genid, tvb,
-			offset, 4, FALSE);
+			offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		while (tvb_reported_length_remaining(tvb, offset)>=4) {
 			proto_tree_add_item(parent_tree, hf_neighbor,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 		}
 		break;
@@ -395,52 +395,52 @@ dissect_dvmrp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 	case DVMRP_V3_PRUNE:
 		/* source address */
 		proto_tree_add_item(parent_tree, hf_saddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* group address */
 		proto_tree_add_item(parent_tree, hf_maddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* prune lifetime */
 		proto_tree_add_item(parent_tree, hf_life,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* source netmask */
 		if (tvb_reported_length_remaining(tvb, offset)>=4) {
 			proto_tree_add_item(parent_tree, hf_netmask,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 		}
 		break;
 	case DVMRP_V3_GRAFT:
 		/* source address */
 		proto_tree_add_item(parent_tree, hf_saddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* group address */
 		proto_tree_add_item(parent_tree, hf_maddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* source netmask */
 		if (tvb_reported_length_remaining(tvb, offset)>=4) {
 			proto_tree_add_item(parent_tree, hf_netmask,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 		}
 		break;
 	case DVMRP_V3_GRAFT_ACK:
 		/* source address */
 		proto_tree_add_item(parent_tree, hf_saddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* group address */
 		proto_tree_add_item(parent_tree, hf_maddr,
-			tvb, offset, 4, FALSE);
+			tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 		/* source netmask */
 		if (tvb_reported_length_remaining(tvb, offset)>=4) {
 			proto_tree_add_item(parent_tree, hf_netmask,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 		}
 		break;
@@ -457,15 +457,15 @@ dissect_dvmrp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 
 			/* local address */
 			proto_tree_add_item(parent_tree, hf_local,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 			/* Metric */
 			proto_tree_add_item(parent_tree, hf_metric,
-				tvb, offset, 1, FALSE);
+				tvb, offset, 1, ENC_BIG_ENDIAN);
 			offset += 1;
 			/* Threshold */
 			proto_tree_add_item(parent_tree, hf_threshold,
-				tvb, offset, 1, FALSE);
+				tvb, offset, 1, ENC_BIG_ENDIAN);
 			offset += 1;
 			/* Flags */
 			{
@@ -473,33 +473,33 @@ dissect_dvmrp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 				proto_item *item;
 
 				item = proto_tree_add_item(parent_tree, hf_flags,
-					tvb, offset, 1, FALSE);
+					tvb, offset, 1, ENC_NA);
 				tree = proto_item_add_subtree(item, ett_flags);
 
 				proto_tree_add_item(tree, hf_flag_tunnel, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_item(tree, hf_flag_srcroute, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_item(tree, hf_flag_down, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_item(tree, hf_flag_disabled, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_item(tree, hf_flag_querier, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_item(tree, hf_flag_leaf, tvb,
-					offset, 1, FALSE);
+					offset, 1, ENC_BIG_ENDIAN);
 			}
 			offset += 1;
 			/* Neighbor count */
 			neighbor_count = tvb_get_guint8(tvb, offset);
 			proto_tree_add_item(parent_tree, hf_ncount,
-				tvb, offset, 1, FALSE);
+				tvb, offset, 1, ENC_BIG_ENDIAN);
 			offset += 1;
 
 			while ((tvb_reported_length_remaining(tvb, offset)>=4)
 				&& (neighbor_count>0)) {
 				proto_tree_add_item(parent_tree, hf_neighbor,
-					tvb, offset, 4, FALSE);
+					tvb, offset, 4, ENC_BIG_ENDIAN);
 				offset += 4;
 				neighbor_count--;
 			}
@@ -539,14 +539,14 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 	offset += 2;
 
 	/* decode all the v1 commands */
-	while (tvb_reported_length_remaining(tvb, offset) > 0) {
+	while (tvb_reported_length_remaining(tvb, offset)) {
 		proto_tree *tree;
 		proto_item *item;
 		guint8 cmd,count;
 		int old_offset = offset;
 
 		item = proto_tree_add_item(parent_tree, hf_commands,
-				tvb, offset, -1, FALSE);
+				tvb, offset, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_commands);
 
 		cmd = tvb_get_guint8(tvb, offset);
@@ -580,7 +580,7 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			offset += 1;
 			if (count) { /* must be 0 or 1 */
 				proto_tree_add_item(tree, hf_netmask,
-					tvb, offset, 4, FALSE);
+					tvb, offset, 4, ENC_BIG_ENDIAN);
 				if (item) {
 					proto_item_set_text(item, "%s: %d.%d.%d.%d",
 						val_to_str(cmd, command, "Unknown Command:0x%02x"),
@@ -599,7 +599,7 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			break;
 		case V1_COMMAND_METRIC:
 			proto_tree_add_item(tree, hf_metric, tvb,
-				offset, 1, FALSE);
+				offset, 1, ENC_BIG_ENDIAN);
 			if (item) {
 				proto_item_set_text(item, "%s: %d",
 					val_to_str(cmd, command, "Unknown Command:0x%02x"),
@@ -619,7 +619,7 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			break;
 		case V1_COMMAND_INFINITY:
 			proto_tree_add_item(tree, hf_infinity, tvb,
-				offset, 1, FALSE);
+				offset, 1, ENC_BIG_ENDIAN);
 			if (item) {
 				proto_item_set_text(item, "%s: %d",
 					val_to_str(cmd, command, "Unknown Command:0x%02x"), tvb_get_guint8(tvb, offset));
@@ -634,7 +634,7 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			offset += 1;
 			while (count--) {
 				proto_tree_add_item(tree, hf_daddr,
-					tvb, offset, 4, FALSE);
+					tvb, offset, 4, ENC_BIG_ENDIAN);
 				offset += 4;
 			}
 			if (item) {
@@ -649,10 +649,10 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			offset += 1;
 			while (count--) {
 				proto_tree_add_item(tree, hf_maddr,
-					tvb, offset, 4, FALSE);
+					tvb, offset, 4, ENC_BIG_ENDIAN);
 				offset += 4;
 				proto_tree_add_item(tree, hf_hold, tvb,
-					offset, 4, FALSE);
+					offset, 4, ENC_BIG_ENDIAN);
 				offset += 4;
 			}
 			if (item) {
@@ -667,7 +667,7 @@ dissect_dvmrp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 			offset += 1;
 			while (count--) {
 				proto_tree_add_item(tree, hf_maddr,
-					tvb, offset, 4, FALSE);
+					tvb, offset, 4, ENC_BIG_ENDIAN);
 				offset += 4;
 			}
 			if (item) {
@@ -697,7 +697,7 @@ dissect_dvmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int of
 		return offset+tvb_length_remaining(tvb, offset);
 	}
 
-	item = proto_tree_add_item(parent_tree, proto_dvmrp, tvb, offset, -1, FALSE);
+	item = proto_tree_add_item(parent_tree, proto_dvmrp, tvb, offset, -1, ENC_NA);
 	tree = proto_item_add_subtree(item, ett_dvmrp);
 
 
