@@ -2,7 +2,7 @@
  * E212 tables
  * Copyright 2006, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-e212.h 32257 2010-03-20 23:53:22Z dimeg $
+ * $Id: packet-e212.h 35360 2011-01-04 16:58:07Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,8 +28,9 @@
 
 #include <epan/value_string.h>
 
-extern const value_string E212_codes[];
+extern value_string_ext E212_codes_ext;
 
+gchar* dissect_e212_mcc_mnc_ep_str(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, gboolean little_endian);
 int dissect_e212_mcc_mnc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, gboolean little_endian);
 int dissect_e212_mcc_mnc_in_address(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset);
 
