@@ -3,7 +3,7 @@
  * Routines for ETV-AM EISS (OC-SP-ETV-AM1.0-I05)
  * Copyright 2012, Weston Schmidt <weston_schmidt@alumni.purdue.edu>
  *
- * $Id: packet-eiss.c 41617 2012-03-16 16:35:55Z alagoutte $
+ * $Id: packet-eiss.c 42297 2012-04-27 18:58:37Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -205,7 +205,7 @@ dissect_eiss_descriptors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 					2, ENC_BIG_ENDIAN);
 		offset += 2;
 		proto_tree_add_item(sub_tree, hf_eiss_irl_string, tvb, offset, 2,
-					ENC_ASCII|ENC_BIG_ENDIAN);
+					ENC_ASCII|ENC_NA);
 		return (2+total_length);
 	} else if (0xe1 == tag) {
 		pi = proto_tree_add_text(tree, tvb, offset, 6,
