@@ -1,7 +1,7 @@
 /* packet-enttec.c
  * Routines for ENTTEC packet disassembly
  *
- * $Id: packet-enttec.c 41923 2012-04-04 12:47:08Z cmaynard $
+ * $Id: packet-enttec.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Copyright (c) 2003,2004 by Erwin Rol <erwin@erwinrol.com>
  *
@@ -30,9 +30,8 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <time.h>
+#include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
