@@ -14,7 +14,7 @@
  *                     http://www.systec-electronic.com
  *                     - Daniel Krueger <daniel.krueger[AT]systec-electronic.com>
  *
- * $Id: packet-epl.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-epl.c 41645 2012-03-18 22:24:24Z wmeier $
  *
  * A plugin for:
  * Wireshark - Network traffic analyzer
@@ -476,7 +476,7 @@ static gint dissect_epl_sdo_command_read_by_index(proto_tree *epl_tree, tvbuff_t
 
 static const gchar* decode_epl_address(guchar adr);
 
-static gboolean dissect_epl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+static gint dissect_epl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
 
 /* Initialize the protocol and registered fields */
@@ -661,7 +661,7 @@ gboolean show_soc_flags = FALSE;
 
 
 /* Code to actually dissect the packets */
-static gboolean
+static int
 dissect_epl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     guint8 epl_mtyp, epl_src, epl_dest;
@@ -813,7 +813,7 @@ dissect_epl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             return FALSE;
     }
 
-    return TRUE;
+    return offset;
 }
 
 
@@ -1245,7 +1245,7 @@ dissect_epl_asnd_ires(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo, g
     profile    = tvb_get_letohs(tvb, offset);
     additional = tvb_get_letohs(tvb, offset+2);
     proto_tree_add_string_format(epl_tree, hf_epl_asnd_identresponse_dt, tvb, offset,
-                                 4, "", "Device Type: Profil %d (%s), Additional Information: 0x%4.4X",
+                                 4, "", "Device Type: Profile %d (%s), Additional Information: 0x%4.4X",
                                  profile, val_to_str(profile, epl_device_profiles, "Unknown Profile"), additional);
 
     proto_tree_add_item(epl_tree, hf_epl_asnd_identresponse_profile, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -1480,7 +1480,6 @@ dissect_epl_sdo_command(proto_tree *epl_tree, tvbuff_t *tvb, packet_info *pinfo,
     guint16 segment_size;
 
     offset += 1;
-    segmented = FALSE;
 
     command_id = tvb_get_guint8(tvb, offset + 2);
 
