@@ -1,7 +1,7 @@
 /* packet-erf.c
  * Routines for ERF encapsulation dissection
  *
- * $Id: packet-erf.c 41587 2012-03-16 02:00:29Z wmeier $
+ * $Id: packet-erf.c 44431 2012-08-10 17:59:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,8 +43,6 @@
 #define EXT_HDR_TYPE_CHANNELISED    12
 #define EXT_HDR_TYPE_SIGNATURE      14
 
-#define DECHAN_MAX_AUG_INDEX 4
-
 struct erf_mc_hdlc_hdrx {
   guint16 byte01;
   guint8 byte2;
@@ -92,16 +90,19 @@ struct erf_eth_hdrx {
   guint8 byte1;
 };
 
+#define DECHAN_MAX_LINE_RATE 5
+#define DECHAN_MAX_VC_SIZE 5
+#define DECHAN_MAX_AUG_INDEX 4
+
 typedef struct sdh_g707_format_s
 {
   guint8 m_sdh_line_rate;
   guint8 m_vc_size ;
-    gint8 m_vc_index_array[DECHAN_MAX_AUG_INDEX];
-        /* i = 4 --> ITU-T letter #E - index of AUG-64
-         * i = 3 --> ITU-T letter #D - index of AUG-16
+  gint8 m_vc_index_array[DECHAN_MAX_AUG_INDEX];
+        /* i = 3 --> ITU-T letter #D - index of AUG-16
          * i = 2 --> ITU-T letter #C - index of AUG-4,
-         * i = 1 --> ITU-T letter #B  -index of AUG-1
-         * i = 0 --> ITU-T letter #A  - index of AU3*/
+         * i = 1 --> ITU-T letter #B - index of AUG-1
+         * i = 0 --> ITU-T letter #A - index of AU3*/
 } sdh_g707_format_t;
 
 /* Initialize the protocol and registered fields */
@@ -159,7 +160,7 @@ static int hf_erf_ehdr_chan_seqnum                    = -1;
 static int hf_erf_ehdr_chan_res                       = -1;
 static int hf_erf_ehdr_chan_virt_container_id         = -1;
 static int hf_erf_ehdr_chan_assoc_virt_container_size = -1;
-static int hf_erf_ehdr_chan_speed                     = -1;
+static int hf_erf_ehdr_chan_rate                      = -1;
 static int hf_erf_ehdr_chan_type                      = -1;
 
 /* Filter Hash extension header */
@@ -299,6 +300,8 @@ static dissector_handle_t atm_untruncated_handle;
 static gboolean erf_ethfcs = TRUE;
 static dissector_handle_t ethwithfcs_handle, ethwithoutfcs_handle;
 
+static dissector_handle_t sdh_handle;
+
 /* ERF Header */
 #define ERF_HDR_TYPES_MASK 0xff
 #define ERF_HDR_TYPE_MASK 0x7f
@@ -479,7 +482,7 @@ static const value_string channelised_assoc_virt_container_size[] = {
   { 0, NULL }
 };
 
-static const value_string channelised_speed[] = {
+static const value_string channelised_rate[] = {
   { 0x00, "Reserved"},
   { 0x01, "STM-0 / STS-1"},
   { 0x02, "STM-1 / STS-3"},
@@ -693,27 +696,28 @@ dissect_bfs_ex_header(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *pseudo_hdr
 }
 
 static int
-channelised_fill_sdh_g707_format(sdh_g707_format_t* in_fmt, guint16 bit_flds, guint8 vc_size, guint8 speed)
+channelised_fill_sdh_g707_format(sdh_g707_format_t* in_fmt, guint16 bit_flds, guint8 vc_size, guint8 rate)
 {
-  int i = 0; /* i = 4 --> ITU-T letter #E - index of AUG-64
-              * i = 3 --> ITU-T letter #D - index of AUG-16
+  int i = 0; /* i = 3 --> ITU-T letter #D - index of AUG-16
               * i = 2 --> ITU-T letter #C - index of AUG-4,
-              * i = 1 --> ITU-T letter #B  -index of AUG-1
-              * i = 0 --> ITU-T letter #A  - index of AU3*/
+              * i = 1 --> ITU-T letter #B - index of AUG-1
+              * i = 0 --> ITU-T letter #A - index of AU3*/
 
-  if (0 == vc_size)
+  if ( (0 == vc_size) || (vc_size > DECHAN_MAX_VC_SIZE) || (rate > DECHAN_MAX_LINE_RATE) )
   {
-    /* unknown / unsed container size*/
+    /* unknown / unused / invalid container size or invalid line rate */
+    in_fmt->m_vc_size = 0;
+    in_fmt->m_sdh_line_rate = 0;
+    memset(&(in_fmt->m_vc_index_array[0]), 0x00, DECHAN_MAX_AUG_INDEX);
     return -1;
   }
+
   in_fmt->m_vc_size = vc_size;
-  in_fmt->m_sdh_line_rate = speed;
+  in_fmt->m_sdh_line_rate = rate;
   memset(&(in_fmt->m_vc_index_array[0]), 0xff, DECHAN_MAX_AUG_INDEX);
 
-  /* for STM64 traffic, start from #E index shoud be 0 */
-  in_fmt->m_vc_index_array[ speed - 1] = 0;
   /* for STM64 traffic,from #D and so on .. */
-    for (i = (speed - 2); i >= 0; i--)
+    for (i = (rate - 2); i >= 0; i--)
   {
     guint8 aug_n_index = 0;
 
@@ -733,10 +737,9 @@ channelised_fill_sdh_g707_format(sdh_g707_format_t* in_fmt, guint16 bit_flds, gu
 }
 
 static void
-channelised_fill_vc_id_string(char* out_string, int maxstrlen, sdh_g707_format_t* in_fmt)
+channelised_fill_vc_id_string(emem_strbuf_t* out_string, sdh_g707_format_t* in_fmt)
 {
   int      i;
-  int      print_index;
   gboolean is_printed  = FALSE;
 
   static char* g_vc_size_strings[] = {
@@ -745,26 +748,28 @@ channelised_fill_vc_id_string(char* out_string, int maxstrlen, sdh_g707_format_t
     "VC4",      /*0x2*/
     "VC4-4c",   /*0x3*/
     "VC4-16c",  /*0x4*/
-    "VC4-64c",  /*0x5*/
-    "VC4-256c", /*0x6*/};
+    "VC4-64c",  /*0x5*/};
 
-  print_index = g_snprintf(out_string, maxstrlen, "%s(",
-                           (in_fmt->m_vc_size < array_length(g_vc_size_strings)) ?
-                           g_vc_size_strings[in_fmt->m_vc_size] : g_vc_size_strings[0] );
+  if ( (in_fmt->m_vc_size > DECHAN_MAX_VC_SIZE) || (in_fmt->m_sdh_line_rate > DECHAN_MAX_LINE_RATE) )
+  {
+    ep_strbuf_printf(out_string, "Malformed");
+    return;
+  }
+
+  ep_strbuf_printf(out_string, "%s(",
+                   (in_fmt->m_vc_size < array_length(g_vc_size_strings)) ?
+                   g_vc_size_strings[in_fmt->m_vc_size] : g_vc_size_strings[0] );
 
   if (in_fmt->m_sdh_line_rate <= 0 )
   {
     /* line rate is not given */
     for (i = (DECHAN_MAX_AUG_INDEX -1); i >= 0; i--)
     {
-      if (print_index >= (maxstrlen-1))
-        break;
       if ((in_fmt->m_vc_index_array[i] > 0) || (is_printed) )
       {
-        print_index += g_snprintf(out_string+print_index, maxstrlen-print_index,
-                                  "%s%d",
-                                  ((is_printed)?", ":""),
-                                  in_fmt->m_vc_index_array[i]);
+        ep_strbuf_append_printf(out_string, "%s%d",
+                                ((is_printed)?", ":""),
+                                in_fmt->m_vc_index_array[i]);
         is_printed = TRUE;
       }
     }
@@ -774,10 +779,7 @@ channelised_fill_vc_id_string(char* out_string, int maxstrlen, sdh_g707_format_t
   {
     for (i = in_fmt->m_sdh_line_rate - 2; i >= 0; i--)
     {
-      if (print_index >= (maxstrlen-1))
-        break;
-      print_index += g_snprintf(out_string+print_index, maxstrlen-print_index,
-                                "%s%d",
+      ep_strbuf_append_printf(out_string, "%s%d",
                                 ((is_printed)?", ":""),
                                 in_fmt->m_vc_index_array[i]);
       is_printed = TRUE;
@@ -788,16 +790,12 @@ channelised_fill_vc_id_string(char* out_string, int maxstrlen, sdh_g707_format_t
     /* Not printed . possibly its a ocXc packet with (0,0,0...) */
     for ( i =0; i < in_fmt->m_vc_size - 2; i++)
     {
-      if (print_index >= (maxstrlen-1))
-        break;
-      print_index += g_snprintf(out_string+print_index, maxstrlen-print_index,
-                                "%s0",
+      ep_strbuf_append_printf(out_string, "%s0",
                                 ((is_printed)?", ":""));
       is_printed = TRUE;
     }
   }
-  if (print_index < (maxstrlen-1))
-    g_snprintf(out_string+print_index, maxstrlen-print_index, ")");
+  ep_strbuf_append_c(out_string, ')');
   return;
 }
 
@@ -807,12 +805,12 @@ dissect_channelised_ex_header(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *ps
   guint64            hdr              = pinfo->pseudo_header->erf.ehdr_list[idx].ehdr;
   guint8             vc_id            = (guint8)((hdr >> 24) & 0xFF);
   guint8             vc_size          = (guint8)((hdr >> 16) & 0xFF);
-  guint8             line_speed       = (guint8)((hdr >> 8) & 0xFF);
+  guint8             line_rate        = (guint8)((hdr >> 8) & 0xFF);
   sdh_g707_format_t  g707_format;
-  char               vc_id_string[64] = {'\0'};
+  emem_strbuf_t     *vc_id_string = ep_strbuf_new_label("");
 
-  channelised_fill_sdh_g707_format(&g707_format, vc_id, vc_size, line_speed);
-  channelised_fill_vc_id_string(vc_id_string, 64, &g707_format);
+  channelised_fill_sdh_g707_format(&g707_format, vc_id, vc_size, line_rate);
+  channelised_fill_vc_id_string(vc_id_string, &g707_format);
 
   if (pseudo_hdr_tree) {
     proto_item *int_item;
@@ -828,9 +826,9 @@ dissect_channelised_ex_header(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *ps
     proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_seqnum, tvb, 0, 0, (guint16)((hdr >> 40) & 0x7FFF));
     proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_res, tvb, 0, 0, (guint8)((hdr >> 32) & 0xFF));
     proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_virt_container_id, tvb, 0, 0, vc_id);
-    proto_tree_add_text(int_tree, tvb, 0, 0, "Virtual Container ID (g.707): %s", vc_id_string);
+    proto_tree_add_text(int_tree, tvb, 0, 0, "Virtual Container ID (g.707): %s", vc_id_string->str);
     proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_assoc_virt_container_size, tvb, 0, 0, vc_size);
-    proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_speed, tvb, 0, 0, line_speed);
+    proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_rate, tvb, 0, 0, line_rate);
     proto_tree_add_uint(int_tree, hf_erf_ehdr_chan_type, tvb, 0, 0, (guint8)((hdr >> 0) & 0xFF));
   }
 }
@@ -1240,7 +1238,12 @@ dissect_erf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   switch (erf_type) {
 
   case ERF_TYPE_RAW_LINK:
-    call_dissector(data_handle, tvb, pinfo, erf_tree);
+    if(sdh_handle){
+      call_dissector(sdh_handle, tvb, pinfo, tree);
+    }
+    else{
+      call_dissector(data_handle, tvb, pinfo, erf_tree);
+    }
     break;
 
   case ERF_TYPE_IPV4:
@@ -1632,9 +1635,9 @@ proto_register_erf(void)
     { &hf_erf_ehdr_chan_assoc_virt_container_size,
       { "Associated Virtual Container Size", "erf.ehdr.chan.vcsize",
         FT_UINT8, BASE_HEX, VALS(channelised_assoc_virt_container_size), 0, NULL, HFILL } },
-    { &hf_erf_ehdr_chan_speed,
+    { &hf_erf_ehdr_chan_rate,
       { "Origin Line Type/Rate", "erf.ehdr.chan.rate",
-        FT_UINT8, BASE_HEX, VALS(channelised_speed), 0, NULL, HFILL } },
+        FT_UINT8, BASE_HEX, VALS(channelised_rate), 0, NULL, HFILL } },
     { &hf_erf_ehdr_chan_type,
       { "Frame Part Type", "erf.ehdr.chan.type",
         FT_UINT8, BASE_HEX, VALS(channelised_type), 0, NULL, HFILL } },
@@ -1955,4 +1958,6 @@ proto_reg_handoff_erf(void)
   /* Get handles for Ethernet dissectors */
   ethwithfcs_handle    = find_dissector("eth_withfcs");
   ethwithoutfcs_handle = find_dissector("eth_withoutfcs");
+
+  sdh_handle = find_dissector("sdh");
 }
