@@ -3,7 +3,7 @@
  * payloads (i.e., payloads when there could be an Ethernet trailer and
  * possibly an FCS).
  *
- * $Id: packet-ethertype.c 42266 2012-04-26 16:05:05Z wmeier $
+ * $Id: packet-ethertype.c 43932 2012-07-23 16:16:03Z gerald $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -110,6 +110,8 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_MMRP,                 "802.1ak Multiple Mac Registration Protocol" },
 	{ ETHERTYPE_AVBTP,                "IEEE 1722 Audio Video Bridging Transport Protocol" },
 	{ ETHERTYPE_ROHC,                 "Robust Header Compression(RoHC)" },
+	{ ETHERTYPE_TRILL,                "TRansparent Interconnection of Lots of Links" },
+	{ ETHERTYPE_L2ISIS,               "Intermediate System to Intermediate System" },
 	{ ETHERTYPE_MAC_CONTROL,          "MAC Control" },
 	{ ETHERTYPE_SLOW_PROTOCOLS,       "Slow Protocols" },
 	{ ETHERTYPE_RTMAC,                "Real-Time Media Access Control" },
@@ -130,6 +132,7 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_LLDP,                 "802.1 Link Layer Discovery Protocol (LLDP)" },
 	{ ETHERTYPE_3GPP2,                "CDMA2000 A10 3GPP2 Packet" },
 	{ ETHERTYPE_TTE_PCF,              "TTEthernet Protocol Control Frame" },
+	{ ETHERTYPE_CESOETH,              "Circuit Emulation Services over Ethernet (MEF8)" },
 	{ ETHERTYPE_LLTD,                 "Link Layer Topology Discovery (LLTD)" },
 	{ ETHERTYPE_WSMP,                 "(WAVE) Short Message Protocol (WSM)" },
 	{ ETHERTYPE_VMLAB,                "VMware Lab Manager" },
@@ -161,6 +164,7 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_IEEE80211_DATA_ENCAP, "IEEE 802.11 data encapsulation" },
 	{ ETHERTYPE_LINX,                 "LINX IPC Protocol" },
 	{ ETHERTYPE_FIP,                  "FCoE Initialization Protocol" },
+	{ ETHERTYPE_ELMI,                 "Ethernet Local Management Interface (MEF16)" },
 	{ ETHERTYPE_PTP,                  "PTPv2 over Ethernet (IEEE1588)" },
 	{ ETHERTYPE_PRP,                  "Parallel Redundancy Protocol (PRP) and HSR Supervision (IEC62439 Part 3)" },
 	{ ETHERTYPE_FLIP,                 "Flow Layer Internal Protocol" },
