@@ -2,7 +2,7 @@
  * Routines for FC Common Transport Protocol (used by GS3 services)
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-fcct.c 39288 2011-10-06 03:35:44Z wmeier $
+ * $Id: packet-fcct.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,16 +27,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 
 #include <epan/packet.h>
