@@ -2,7 +2,7 @@
  * Routines for FC Link Control Frames
  * Copyright 2001, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id: packet-fclctl.c 42632 2012-05-15 19:23:35Z wmeier $
+ * $Id: packet-fclctl.c 44506 2012-08-14 21:39:49Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -131,13 +131,13 @@ const gchar *
 fclctl_get_paramstr (guint32 linkctl_type, guint32 param)
 {
     if (linkctl_type == FC_LCTL_PBSY) {
-      return g_strdup_printf("%s, %s",
+      return ep_strdup_printf("%s, %s",
                  val_to_str (((param & 0xFF000000) >> 24), fc_lctl_pbsy_acode_val, "0x%x"),
 		 val_to_str (((param & 0x00FF0000) >> 16), fc_lctl_pbsy_rjt_val, "0x%x"));
     }
     if ((linkctl_type == FC_LCTL_FRJT) ||
              (linkctl_type == FC_LCTL_PRJT)) {
-      return g_strdup_printf("%s, %s",
+      return ep_strdup_printf("%s, %s",
                  val_to_str (((param & 0xFF000000) >> 24), fc_lctl_rjt_acode_val, "0x%x"),
                  val_to_str (((param & 0x00FF0000) >> 16), fc_lctl_rjt_val, "%x"));
     }
