@@ -1,6 +1,6 @@
 /* packet-force10-oui.c
  *
- * $Id: packet-force10-oui.c 27571 2009-03-01 15:32:17Z jake $
+ * $Id: packet-force10-oui.c 28830 2009-06-24 02:11:11Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,12 +41,13 @@ static const value_string force10_pid_vals[] = {
 void
 proto_register_force10_oui(void)
 {
-	static hf_register_info hf = {
-	    &hf_llc_force10_pid,
+	static hf_register_info hf[] = {
+	  { &hf_llc_force10_pid,
 		{ "PID",	"llc.force10_pid",  FT_UINT16, BASE_HEX,
-		  VALS(force10_pid_vals), 0x0, NULL, HFILL },
+		  VALS(force10_pid_vals), 0x0, NULL, HFILL }
+	  }
 	};
 
-	llc_add_oui(OUI_FORCE10, "llc.force10_pid", "FORCE10 OUI PID", &hf);
+	llc_add_oui(OUI_FORCE10, "llc.force10_pid", "FORCE10 OUI PID", hf);
 }
 
