@@ -3,7 +3,7 @@
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  * Copyright 2001, Juan Toledo <toledo@users.sourceforge.net> (Passive FTP)
  *
- * $Id: packet-ftp.c 41640 2012-03-18 14:58:38Z wmeier $
+ * $Id: packet-ftp.c 42317 2012-04-28 16:48:11Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -609,8 +609,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             /*
              * Find the end of the line.
              */
-            linelen = tvb_find_line_end(tvb, offset, -1,
-                &next_offset, FALSE);
+            tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
 
             /*
              * Put this line.
