@@ -4,7 +4,7 @@
  *
  * Based on CORBAv2.4.2  Chapter 15 GIOP Description.
  *
- * $Id: packet-giop.h 29805 2009-09-08 18:46:47Z etxrab $
+ * $Id: packet-giop.h 43058 2012-06-04 09:04:36Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -136,8 +136,8 @@ extern void delete_giop_user(giop_sub_dissector_t *sub, gchar *name);
  * This is for explicit dissection.
  */
 
-extern void register_giop_user_module(giop_sub_dissector_t *sub, gchar *name,
-    gchar *module, int sub_proto);
+extern void register_giop_user_module(giop_sub_dissector_t *sub, const gchar *name,
+    const gchar *module, int sub_proto);
 
 /*
  * GIOP Users remove their module and interface names via this function.
