@@ -3,7 +3,7 @@
  * Described in Microsoft document MS-GPEF.pdf
  * Copyright 2008, Ronnie Sahlberg
  *
- * $Id: packet-gpef.c 28770 2009-06-18 21:30:42Z stig $
+ * $Id: packet-gpef.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -63,22 +63,22 @@ dissect_gpef_efskey(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *p
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	if (parent_tree) {
-		item = proto_tree_add_item(parent_tree, hf_gpef_efskey, tvb, -1, -1, FALSE);
+		item = proto_tree_add_item(parent_tree, hf_gpef_efskey, tvb, -1, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_gpef_efskey);
 	}
 
 	/* length 1 */
 	length1 = tvb_get_letohl(tvb, offset);
-	proto_tree_add_item(tree, hf_gpef_efskey_length1, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_efskey_length1, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	/* length 2 */
-	proto_tree_add_item(tree, hf_gpef_efskey_length2, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_efskey_length2, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	/* sid offset */
 	sid_offset = tvb_get_letohl(tvb, offset);
-	proto_tree_add_item(tree, hf_gpef_efskey_sid_offset, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_efskey_sid_offset, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	/* reserved */
@@ -86,12 +86,12 @@ dissect_gpef_efskey(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *p
 
 	/* cert length */
 	cert_length = tvb_get_letohl(tvb, offset);
-	proto_tree_add_item(tree, hf_gpef_efskey_cert_length, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_efskey_cert_length, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	/* cert offset */
 	cert_offset = tvb_get_letohl(tvb, offset);
-	proto_tree_add_item(tree, hf_gpef_efskey_cert_offset, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_efskey_cert_offset, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	/* reserved, must be 0x20 0x00 0x00 0x00 */
@@ -120,7 +120,7 @@ dissect_gpef_efsblob(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *parent_t
 	guint32 count;
 
 	if (parent_tree) {
-		item = proto_tree_add_item(parent_tree, proto_gpef, tvb, 0, -1, FALSE);
+		item = proto_tree_add_item(parent_tree, proto_gpef, tvb, 0, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_gpef);
 	}
 
@@ -129,7 +129,7 @@ dissect_gpef_efsblob(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *parent_t
 
 	/* key count */
 	count = tvb_get_letohl(tvb, offset);
-	proto_tree_add_item(tree, hf_gpef_keycount, tvb, offset, 4, TRUE);
+	proto_tree_add_item(tree, hf_gpef_keycount, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 	offset += 4;
 
 	while (count--) {
