@@ -11,7 +11,7 @@
  *   support on mobile radio interface
  *   (3GPP TS 24.011 version 4.1.1 Release 4)
  *
- * $Id: packet-gsm_a_rp.c 36713 2011-04-19 08:22:58Z stig $
+ * $Id: packet-gsm_a_rp.c 42755 2012-05-21 19:27:38Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,7 +36,7 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
+#include <glib.h>
 
 #include <epan/packet.h>
 #include <epan/tap.h>
@@ -539,7 +539,7 @@ proto_register_gsm_a_rp(void)
 	},
 	{ &hf_gsm_a_rp_elem_id,
 		{ "Element ID",	"gsm_a_rp.elem_id",
-		FT_UINT8, BASE_DEC, NULL, 0,
+		FT_UINT8, BASE_HEX, NULL, 0,
 		NULL, HFILL }
 	},
 	};
