@@ -4,7 +4,7 @@
  * Copyright 2009 by Holger Hans Peter Freyther <zecke@selfish.org>
  * based on A-bis OML code in OpenBSC
  *
- * $Id: packet-gsm_abis_oml.c 41645 2012-03-18 22:24:24Z wmeier $
+ * $Id: packet-gsm_abis_oml.c 42447 2012-05-05 21:47:55Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,8 +38,6 @@
 
 #include "packet-gsm_a_common.h"
 
-#include <sys/types.h>
-
 /* From openbsc/include/openbsc/abis_nm.h */
 
 #define ABIS_OM_MDISC_FOM		0x80
@@ -1870,9 +1868,6 @@ dissect_abis_oml(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	return offset;
 }
 
-void
-proto_reg_handoff_abis_oml(void);
-
 void
 proto_register_abis_oml(void)
 {
@@ -2368,7 +2363,7 @@ proto_register_abis_oml(void)
 
 	new_register_dissector("gsm_abis_oml", dissect_abis_oml, proto_abis_oml);
 
-	oml_module = prefs_register_protocol(proto_abis_oml, proto_reg_handoff_abis_oml);
+	oml_module = prefs_register_protocol(proto_abis_oml, NULL);
 	prefs_register_enum_preference(oml_module, "oml_dialect",
 		    "A-bis OML dialect to be used",
 		    "Use ipaccess nanoBTS specific definitions for OML",
@@ -2380,19 +2375,12 @@ proto_register_abis_oml(void)
 void
 proto_reg_handoff_abis_oml(void)
 {
-	static gboolean initialized = FALSE;
+	dissector_handle_t abis_oml_handle;
 
-	if (!initialized) {
-		dissector_handle_t abis_oml_handle;
-
-		abis_oml_handle = new_create_dissector_handle(dissect_abis_oml,
-							  proto_abis_oml);
-		dissector_add_uint("lapd.gsm.sapi", LAPD_GSM_SAPI_OM_PROC,
-				   abis_oml_handle);
-
-	} else {
-		/* preferences have been changed */
-	}
+	abis_oml_handle = new_create_dissector_handle(dissect_abis_oml,
+						      proto_abis_oml);
+	dissector_add_uint("lapd.gsm.sapi", LAPD_GSM_SAPI_OM_PROC,
+			   abis_oml_handle);
 
 	sub_om2000 = find_dissector("gsm_abis_om2000");
 }
