@@ -2,7 +2,7 @@
  * Routines for Location Services (LCS) Serving Mobile Location Centre - Base Station System (SMLC-BSS) dissection
  * Copyright 2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-gsm_bsslap.c 41362 2012-03-06 02:04:10Z morriss $
+ * $Id: packet-gsm_bsslap.c 42755 2012-05-21 19:27:38Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,8 +29,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
@@ -875,7 +873,7 @@ proto_register_gsm_bsslap(void)
 		},
 		{ &hf_gsm_a_bsslap_elem_id,
 			{ "Element ID",	"gsm_bsslap.elem_id",
-			FT_UINT8, BASE_DEC, NULL, 0,
+			FT_UINT8, BASE_HEX, NULL, 0,
 			NULL, HFILL }
 		},
 		{ &hf_gsm_bsslap_ta,
