@@ -5,7 +5,7 @@
  *
  * 3GPP TS 49.031 version v7.4.0 (2009-09)
  *
- * $Id: packet-gsm_bssmap_le.c 41463 2012-03-10 17:47:07Z alagoutte $
+ * $Id: packet-gsm_bssmap_le.c 42755 2012-05-21 19:27:38Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
+#include <glib.h>
 
 #include <epan/packet.h>
 #include <epan/tap.h>
@@ -1024,7 +1024,7 @@ proto_register_gsm_bssmap_le(void)
 		},
 		{ &hf_gsm_bssmap_le_elem_id,
 		  { "Element ID",	"bssmap_le.elem_id",
-		    FT_UINT8, BASE_DEC, NULL, 0,
+		    FT_UINT8, BASE_HEX, NULL, 0,
 		    NULL, HFILL }
 		},
 		{ &hf_gsm_bssmap_le_apdu_protocol_id,
