@@ -2,7 +2,7 @@
  * Routines for GSM Um packet disassembly
  * Duncan Salerno <duncan.salerno@googlemail.com>
  *
- * $Id: packet-gsm_um.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-gsm_um.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -140,7 +140,7 @@ dissect_gsm_um(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 		const char *channel;
 
-		ti = proto_tree_add_item(tree, proto_gsm_um, tvb, 0, 0, FALSE);
+		ti = proto_tree_add_item(tree, proto_gsm_um, tvb, 0, 0, ENC_NA);
 		gsm_um_tree = proto_item_add_subtree(ti, ett_gsm_um);
 
 		switch( pinfo->pseudo_header->gsm_um.channel ) {
