@@ -1,10 +1,10 @@
 /* packet-gsmtap.c
  * Routines for GSMTAP captures
  *
- * (C) 2008-2011 by Harald Welte <laforge@gnumonks.org>
+ * (C) 2008-2012 by Harald Welte <laforge@gnumonks.org>
  * (C) 2011 by Holger Hans Peter Freyther
  *
- * $Id: packet-gsmtap.c 39366 2011-10-11 18:21:27Z etxrab $
+ * $Id: packet-gsmtap.c 41449 2012-03-09 12:33:16Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -74,6 +74,7 @@
 #define GSMTAP_TYPE_WMX_BURST		0x07	/* WiMAX burst */
 #define GSMTAP_TYPE_GB_LLC			0x08 /* GPRS Gb interface: LLC */
 #define GSMTAP_TYPE_GB_SNDCP		0x09 /* GPRS Gb interface: SNDCP */
+#define GSMTAP_TYPE_GMR1_UM				0x0a	/* GMR-1 L2 packets */
 
 /* ====== DO NOT MAKE UNAPPROVED MODIFICATIONS HERE ===== */
 #define GSMTAP_BURST_UNKNOWN		0x00
@@ -95,20 +96,32 @@
 #define GSMTAP_BURST_PHY_ATTRIBUTES     0x15	/* WiMAX PHY Attributes burst */
 
 /* ====== DO NOT MAKE UNAPPROVED MODIFICATIONS HERE ===== */
-#define GSMTAP_CHANNEL_UNKNOWN		0x00
-#define GSMTAP_CHANNEL_BCCH			0x01
-#define GSMTAP_CHANNEL_CCCH			0x02
-#define GSMTAP_CHANNEL_RACH			0x03
-#define GSMTAP_CHANNEL_AGCH			0x04
-#define GSMTAP_CHANNEL_PCH			0x05
-#define GSMTAP_CHANNEL_SDCCH		0x06
-#define GSMTAP_CHANNEL_SDCCH4		0x07
-#define GSMTAP_CHANNEL_SDCCH8		0x08
-#define GSMTAP_CHANNEL_TCH_F		0x09
-#define GSMTAP_CHANNEL_TCH_H		0x0a
-#define GSMTAP_CHANNEL_PACCH		0x0b
-#define GSMTAP_CHANNEL_ACCH			0x80
+/* sub-types for TYPE_UM */
+#define GSMTAP_CHANNEL_UNKNOWN    0x00
+#define GSMTAP_CHANNEL_BCCH       0x01
+#define GSMTAP_CHANNEL_CCCH       0x02
+#define GSMTAP_CHANNEL_RACH       0x03
+#define GSMTAP_CHANNEL_AGCH       0x04
+#define GSMTAP_CHANNEL_PCH        0x05
+#define GSMTAP_CHANNEL_SDCCH      0x06
+#define GSMTAP_CHANNEL_SDCCH4     0x07
+#define GSMTAP_CHANNEL_SDCCH8     0x08
+#define GSMTAP_CHANNEL_TCH_F      0x09
+#define GSMTAP_CHANNEL_TCH_H      0x0a
+#define GSMTAP_CHANNEL_PACCH      0x0b
+#define GSMTAP_CHANNEL_CBCH52     0x0c
+#define GSMTAP_CHANNEL_PDCH       0x0d
+#define GSMTAP_CHANNEL_PTCCH      0x0e
+#define GSMTAP_CHANNEL_CBCH51     0x0f
 
+/* GPRS Coding Scheme CS1..4 */
+#define GSMTAP_GPRS_CS_BASE	0x20
+#define GSMTAP_GPRS_CS(N)	(GSMTAP_GPRS_CS_BASE + N)
+/* (E) GPRS Coding Scheme MCS0..9 */
+#define GSMTAP_GPRS_MCS_BASE	0x30
+#define GSMTAP_GPRS_MCS(N)	(GSMTAP_GPRS_MCS_BASE + N)
+
+#define GSMTAP_CHANNEL_ACCH       0x80
 
 /* ====== DO NOT MAKE UNAPPROVED MODIFICATIONS HERE ===== */
 /* sub-types for TYPE_TETRA_AIR */
@@ -121,6 +134,28 @@
 #define GSMTAP_TETRA_STCH			0x07
 #define GSMTAP_TETRA_TCH_F			0x08
 
+/* ====== DO NOT MAKE UNAPPROVED MODIFICATIONS HERE ===== */
+/* sub-types for TYPE_GMR1 */
+#define GSMTAP_GMR1_UNKNOWN			0x00
+#define GSMTAP_GMR1_BCCH			0x01
+#define GSMTAP_GMR1_CCCH			0x02	/* either AGCH or PCH */
+#define GSMTAP_GMR1_PCH				0x03
+#define GSMTAP_GMR1_AGCH			0x04
+#define GSMTAP_GMR1_BACH			0x05
+#define GSMTAP_GMR1_RACH			0x06
+#define GSMTAP_GMR1_CBCH			0x07
+#define GSMTAP_GMR1_SDCCH			0x08
+#define GSMTAP_GMR1_TACCH			0x09
+#define GSMTAP_GMR1_GBCH			0x0a
+
+#define GSMTAP_GMR1_SACCH			0x01	/* to be combined with _TCH{6,9}   */
+#define GSMTAP_GMR1_FACCH			0x02	/* to be combines with _TCH{3,6,9} */
+#define GSMTAP_GMR1_DKAB			0x03	/* to be combined with _TCH3 */
+#define GSMTAP_GMR1_TCH3			0x10
+#define GSMTAP_GMR1_TCH6			0x14
+#define GSMTAP_GMR1_TCH9			0x18
+
+
 #define GSMTAP_ARFCN_F_PCS			0x8000
 #define GSMTAP_ARFCN_F_UPLINK		0x4000
 #define GSMTAP_ARFCN_MASK			0x3fff
@@ -163,6 +198,7 @@ static int hf_gsmtap_frame_nr = -1;
 static int hf_gsmtap_burst_type = -1;
 static int hf_gsmtap_channel_type = -1;
 static int hf_gsmtap_tetra_channel_type = -1;
+static int hf_gsmtap_gmr1_channel_type = -1;
 static int hf_gsmtap_antenna = -1;
 
 static int hf_sacch_l1h_power_lev = -1;
@@ -181,18 +217,26 @@ enum {
 	GSMTAP_SUB_SNDCP,
 	GSMTAP_SUB_ABIS,
 	/* WiMAX sub handles */
-	GSMTAP_SUB_CDMA_CODE, 
+	GSMTAP_SUB_CDMA_CODE,
 	GSMTAP_SUB_FCH,
 	GSMTAP_SUB_FFB,
 	GSMTAP_SUB_PDU,
 	GSMTAP_SUB_HACK,
 	GSMTAP_SUB_PHY_ATTRIBUTES,
+	GSMTAP_SUB_CBCH,
+	GSMTAP_SUB_SIM,
+	/* GMR-1 sub handles */
+	GSMTAP_SUB_GMR1_BCCH,
+	GSMTAP_SUB_GMR1_CCCH,
+	GSMTAP_SUB_GMR1_LAPSAT,
 
 	GSMTAP_SUB_MAX
 };
 
 static dissector_handle_t sub_handles[GSMTAP_SUB_MAX];
 
+static dissector_table_t gsmtap_dissector_table;
+
 static const value_string gsmtap_bursts[] = {
 	{ GSMTAP_BURST_UNKNOWN,		"UNKNOWN" },
 	{ GSMTAP_BURST_FCCH,		"FCCH" },
@@ -204,7 +248,7 @@ static const value_string gsmtap_bursts[] = {
 	{ GSMTAP_BURST_DUMMY,		"DUMMY" },
 	{ GSMTAP_BURST_ACCESS,		"RACH" },
 	/* WiMAX bursts */
- 	{ GSMTAP_BURST_CDMA_CODE,       "CDMA Code"  },
+	{ GSMTAP_BURST_CDMA_CODE,       "CDMA Code"  },
 	{ GSMTAP_BURST_FCH,             "FCH"  },
 	{ GSMTAP_BURST_FFB,             "Fast Feedback" },
 	{ GSMTAP_BURST_PDU,             "PDU" },
@@ -225,8 +269,13 @@ static const value_string gsmtap_channels[] = {
 	{ GSMTAP_CHANNEL_SDCCH8,	"SDCCH/8" },
 	{ GSMTAP_CHANNEL_TCH_F,		"FACCH/F" },
 	{ GSMTAP_CHANNEL_TCH_H,		"FACCH/H" },
-	{ GSMTAP_CHANNEL_PACCH,		"PACCH"},
-	{ GSMTAP_CHANNEL_ACCH|
+	{ GSMTAP_CHANNEL_PACCH,		"PACCH" },
+	{ GSMTAP_CHANNEL_CBCH52,    "CBCH" },
+	{ GSMTAP_CHANNEL_PDCH,      "PDCH" },
+	{ GSMTAP_CHANNEL_PTCCH,     "PTTCH" },
+	{ GSMTAP_CHANNEL_CBCH51,    "CBCH" },
+
+    { GSMTAP_CHANNEL_ACCH|
 	  GSMTAP_CHANNEL_SDCCH,		"LSACCH" },
 	{ GSMTAP_CHANNEL_ACCH|
 	  GSMTAP_CHANNEL_SDCCH4,	"SACCH/4" },
@@ -251,6 +300,35 @@ static const value_string gsmtap_tetra_channels[] = {
 	{ 0,				NULL     },
 };
 
+static const value_string gsmtap_gmr1_channels[] = {
+	{ GSMTAP_GMR1_BCCH,		"BCCH" },
+	{ GSMTAP_GMR1_CCCH,		"CCCH" },
+	{ GSMTAP_GMR1_PCH,		"PCH" },
+	{ GSMTAP_GMR1_AGCH,		"AGCH" },
+	{ GSMTAP_GMR1_BACH,		"BACH" },
+	{ GSMTAP_GMR1_RACH,		"RACH" },
+	{ GSMTAP_GMR1_CBCH,		"CBCH" },
+	{ GSMTAP_GMR1_SDCCH,		"SDCCH" },
+	{ GSMTAP_GMR1_TACCH,		"TACCH" },
+	{ GSMTAP_GMR1_GBCH,		"GBCH" },
+	{ GSMTAP_GMR1_TCH3,		"TCH3" },
+	{ GSMTAP_GMR1_TCH3|
+	  GSMTAP_GMR1_FACCH,		"FACCH3" },
+	{ GSMTAP_GMR1_TCH3|
+	  GSMTAP_GMR1_DKAB,		"DKAB" },
+	{ GSMTAP_GMR1_TCH6,		"TCH6" },
+	{ GSMTAP_GMR1_TCH6|
+	  GSMTAP_GMR1_FACCH,		"FACCH6" },
+	{ GSMTAP_GMR1_TCH6|
+	  GSMTAP_GMR1_SACCH,		"SACCH6" },
+	{ GSMTAP_GMR1_TCH9,		"TCH9" },
+	{ GSMTAP_GMR1_TCH9|
+	  GSMTAP_GMR1_FACCH,		"FACCH9" },
+	{ GSMTAP_GMR1_TCH9|
+	  GSMTAP_GMR1_SACCH,		"SACCH9" },
+	{ 0,				NULL },
+};
+
 /* the mapping is not complete */
 static const int gsmtap_to_tetra[9] = {
 	0,
@@ -272,6 +350,7 @@ static const value_string gsmtap_types[] = {
 	{ GSMTAP_TYPE_TETRA_I1, "TETRA V+D"},
 	{ GSMTAP_TTPE_TETRA_I1_BURST, "TETRA V+D burst"},
 	{ GSMTAP_TYPE_WMX_BURST,"WiMAX burst" },
+	{ GSMTAP_TYPE_GMR1_UM, "GMR-1 air interfeace (MES-MS<->GTS)" },
 	{ 0,			NULL },
 };
 
@@ -322,15 +401,17 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item *ti;
 	proto_tree *gsmtap_tree = NULL;
 	tvbuff_t *payload_tvb, *l1h_tvb = NULL;
-	guint8 hdr_len, type, sub_type;
+	guint8 hdr_len, type, sub_type, timeslot, subslot;
 	guint16 arfcn;
 
 	len = tvb_length(tvb);
 
 	hdr_len = tvb_get_guint8(tvb, offset + 1) <<2;
 	type = tvb_get_guint8(tvb, offset + 2);
-	sub_type = tvb_get_guint8(tvb, offset + 12);
+	timeslot = tvb_get_guint8(tvb, offset + 3);
 	arfcn = tvb_get_ntohs(tvb, offset + 4);
+	sub_type = tvb_get_guint8(tvb, offset + 12);
+	subslot = tvb_get_guint8(tvb, offset + 14);
 
 	/* In case of a SACCH, there is a two-byte L1 header in front
 	 * of the packet (see TS 04.04) */
@@ -350,6 +431,11 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "GSMTAP");
 
+	/* Some GSMTAP types are completely unrelated to the Um air interface */
+	if (dissector_try_uint(gsmtap_dissector_table, type, payload_tvb,
+			       pinfo, tree))
+		return;
+
 	if (arfcn & GSMTAP_ARFCN_F_UPLINK) {
 		col_append_str(pinfo->cinfo, COL_RES_NET_SRC, "MS");
 		col_append_str(pinfo->cinfo, COL_RES_NET_DST, "BTS");
@@ -362,6 +448,8 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		case GSMTAP_CHANNEL_CCCH:
 		case GSMTAP_CHANNEL_PCH:
 		case GSMTAP_CHANNEL_AGCH:
+		case GSMTAP_CHANNEL_CBCH51:
+        case GSMTAP_CHANNEL_CBCH52:
 			col_set_str(pinfo->cinfo, COL_RES_NET_DST, "Broadcast");
 			break;
 		default:
@@ -372,12 +460,18 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		pinfo->p2p_dir = P2P_DIR_RECV;
 	}
 
+	/* Try to build an identifier of different 'streams' */
+	/* (AFCN _cant_ be used because of hopping */
+	pinfo->circuit_id = (timeslot << 3) | subslot;
+
 	if (tree) {
 		guint8 channel;
 		const char *channel_str;
 		channel = tvb_get_guint8(tvb, offset+12);
 		if (type == GSMTAP_TYPE_TETRA_I1)
 			channel_str = val_to_str(channel, gsmtap_tetra_channels, "Unknown: %d");
+		else if (type == GSMTAP_TYPE_GMR1_UM)
+			channel_str = val_to_str(channel, gsmtap_gmr1_channels, "Unknown: %d");
 		else
 			channel_str = val_to_str(channel, gsmtap_channels, "Unknown: %d");
 
@@ -420,6 +514,9 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		else if (type == GSMTAP_TYPE_WMX_BURST)
 			proto_tree_add_item(gsmtap_tree, hf_gsmtap_burst_type,
 					    tvb, offset+12, 1, ENC_BIG_ENDIAN);
+		else if (type == GSMTAP_TYPE_GMR1_UM)
+			proto_tree_add_item(gsmtap_tree, hf_gsmtap_gmr1_channel_type,
+					    tvb, offset+12, 1, ENC_BIG_ENDIAN);
 		proto_tree_add_item(gsmtap_tree, hf_gsmtap_antenna,
 				    tvb, offset+13, 1, ENC_BIG_ENDIAN);
 		proto_tree_add_item(gsmtap_tree, hf_gsmtap_subslot,
@@ -454,6 +551,12 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				sub_handle = GSMTAP_SUB_UM_RLC_MAC_DL;
 			}
 			break;
+
+	        case GSMTAP_CHANNEL_CBCH51:
+		case GSMTAP_CHANNEL_CBCH52:
+			sub_handle = GSMTAP_SUB_CBCH;
+			break;
+
 		case GSMTAP_CHANNEL_RACH:
 		default:
 			sub_handle = GSMTAP_SUB_DATA;
@@ -473,30 +576,51 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		handle_tetra(tvb_get_guint8(tvb, offset+12), payload_tvb, pinfo, tree);
 		return;
 	case GSMTAP_TYPE_WMX_BURST:
-		switch (sub_type) { 
-	        case GSMTAP_BURST_CDMA_CODE: 
+		switch (sub_type) {
+	        case GSMTAP_BURST_CDMA_CODE:
 			sub_handle = GSMTAP_SUB_CDMA_CODE;
 			break;
-	        case GSMTAP_BURST_FCH: 
+	        case GSMTAP_BURST_FCH:
 			sub_handle = GSMTAP_SUB_FCH;
 			break;
-	        case GSMTAP_BURST_FFB: 
+	        case GSMTAP_BURST_FFB:
 			sub_handle = GSMTAP_SUB_FFB;
 			break;
-	        case GSMTAP_BURST_PDU: 
+	        case GSMTAP_BURST_PDU:
 			sub_handle = GSMTAP_SUB_PDU;
 			break;
-	        case GSMTAP_BURST_HACK: 
+	        case GSMTAP_BURST_HACK:
 			sub_handle = GSMTAP_SUB_HACK;
 			break;
-	        case GSMTAP_BURST_PHY_ATTRIBUTES: 
+	        case GSMTAP_BURST_PHY_ATTRIBUTES:
 			sub_handle = GSMTAP_SUB_PHY_ATTRIBUTES;
 			break;
-	        default: 
-	                sub_handle = GSMTAP_SUB_DATA; 
-	                break; 
+	        default:
+	                sub_handle = GSMTAP_SUB_DATA;
+	                break;
 	        }
  		break;
+	case GSMTAP_TYPE_GMR1_UM:
+		switch (sub_type) {
+		case GSMTAP_GMR1_BCCH:
+			sub_handle = GSMTAP_SUB_GMR1_BCCH;
+			break;
+		case GSMTAP_GMR1_CCCH:
+		case GSMTAP_GMR1_AGCH:
+		case GSMTAP_GMR1_PCH:
+			sub_handle = GSMTAP_SUB_GMR1_CCCH;
+			break;
+		case GSMTAP_GMR1_SDCCH:
+		case GSMTAP_GMR1_TCH3 | GSMTAP_GMR1_FACCH:
+		case GSMTAP_GMR1_TCH6 | GSMTAP_GMR1_FACCH:
+		case GSMTAP_GMR1_TCH9 | GSMTAP_GMR1_FACCH:
+			sub_handle = GSMTAP_SUB_GMR1_LAPSAT;
+			break;
+		default:
+			sub_handle = GSMTAP_SUB_DATA;
+			break;
+		}
+		break;
 	case GSMTAP_TYPE_UM_BURST:
 	default:
 		sub_handle = GSMTAP_SUB_DATA;
@@ -538,6 +662,8 @@ proto_register_gsmtap(void)
 		  FT_UINT8, BASE_DEC, VALS(gsmtap_channels), 0, NULL, HFILL }},
 		{ &hf_gsmtap_tetra_channel_type, { "Channel Type", "gsmtap.tetra_chan_type",
 		  FT_UINT8, BASE_DEC, VALS(gsmtap_tetra_channels), 0, NULL, HFILL }},
+		{ &hf_gsmtap_gmr1_channel_type, { "Channel Type", "gsmtap.gmr1_chan_type",
+		  FT_UINT8, BASE_DEC, VALS(gsmtap_gmr1_channels), 0, NULL, HFILL }},
 		{ &hf_gsmtap_antenna, { "Antenna Number", "gsmtap.antenna",
 		  FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL } },
 		{ &hf_gsmtap_subslot, { "Sub-Slot", "gsmtap.sub_slot",
@@ -558,6 +684,9 @@ proto_register_gsmtap(void)
 	proto_gsmtap = proto_register_protocol("GSM Radiotap", "GSMTAP", "gsmtap");
 	proto_register_field_array(proto_gsmtap, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	gsmtap_dissector_table = register_dissector_table("gsmtap.type",
+						"GSMTAP type", FT_UINT8, BASE_HEX);
 }
 
 void
@@ -573,12 +702,16 @@ proto_reg_handoff_gsmtap(void)
 	sub_handles[GSMTAP_SUB_LLC] = find_dissector("llcgprs");
 	sub_handles[GSMTAP_SUB_SNDCP] = find_dissector("sndcp");
 	sub_handles[GSMTAP_SUB_ABIS] = find_dissector("gsm_a_dtap");
-	sub_handles[GSMTAP_SUB_CDMA_CODE] = find_dissector("wimax_cdma_code_burst_handler"); 
-	sub_handles[GSMTAP_SUB_FCH] = find_dissector("wimax_fch_burst_handler"); 
-	sub_handles[GSMTAP_SUB_FFB] = find_dissector("wimax_ffb_burst_handler"); 
+	sub_handles[GSMTAP_SUB_CDMA_CODE] = find_dissector("wimax_cdma_code_burst_handler");
+	sub_handles[GSMTAP_SUB_FCH] = find_dissector("wimax_fch_burst_handler");
+	sub_handles[GSMTAP_SUB_FFB] = find_dissector("wimax_ffb_burst_handler");
 	sub_handles[GSMTAP_SUB_PDU] = find_dissector("wimax_pdu_burst_handler");
 	sub_handles[GSMTAP_SUB_HACK] = find_dissector("wimax_hack_burst_handler");
 	sub_handles[GSMTAP_SUB_PHY_ATTRIBUTES] = find_dissector("wimax_phy_attributes_burst_handler");
+	sub_handles[GSMTAP_SUB_CBCH] = find_dissector("gsm_cbch");
+	sub_handles[GSMTAP_SUB_GMR1_BCCH] = find_dissector("gmr1_bcch");
+	sub_handles[GSMTAP_SUB_GMR1_CCCH] = find_dissector("gmr1_ccch");
+	sub_handles[GSMTAP_SUB_GMR1_LAPSAT] = find_dissector("lapsat");
 	gsmtap_handle = create_dissector_handle(dissect_gsmtap, proto_gsmtap);
 	dissector_add_uint("udp.port", GSMTAP_UDP_PORT, gsmtap_handle);
 }
