@@ -4,7 +4,7 @@
  * Copyright 2002, Richard Sharpe <rsharpe@samba.org> Added a few
  *		   bits and pieces ...
  *
- * $Id: packet-gssapi.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-gssapi.c 42883 2012-05-28 15:59:00Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,10 +29,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <glib.h>
@@ -137,7 +133,7 @@ gssapi_oid_hash(gconstpointer k)
 	const char *key = (const char *)k;
 	guint hash = 0, i;
 
-	for (i = 0; i < strlen(key); i++)
+	for (i = 0; key[i]; i++)
 		hash += key[i];
 
 	return hash;
