@@ -2,7 +2,7 @@
  * Routines for H.223 packet dissection
  * Copyright (c) 2004-5 MX Telecom Ltd <richardv@mxtelecom.com>
  *
- * $Id: packet-h223.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-h223.c 41148 2012-02-23 08:40:23Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -673,7 +673,7 @@ dissect_mux_al_pdu( tvbuff_t *tvb, packet_info *pinfo, proto_tree *vc_tree,
 
             al_item = proto_tree_add_item(vc_tree,
                                           al2_sequenced?hf_h223_al2_sequenced:hf_h223_al2_unsequenced,
-                                          tvb, 0, -1,FALSE);
+                                          tvb, 0, -1, ENC_NA);
             al_tree = proto_item_add_subtree (al_item, ett_h223_al2);
 
             PROTO_ITEM_SET_GENERATED(tmp_item);
@@ -825,14 +825,14 @@ dissect_mux_sdu_fragment(tvbuff_t *volatile next_tvb, packet_info *pinfo,
 static guint32
 mux_element_sublist_size( h223_mux_element* me )
 {
-    h223_mux_element *current_me = me;
+    h223_mux_element *current_me = me->next;
     guint32 length = 0;
     while ( current_me ) {
-        current_me = current_me->next;
         if ( current_me->sublist )
             length += current_me->repeat_count * mux_element_sublist_size( current_me->sublist );
         else
             length += current_me->repeat_count;
+        current_me = current_me->next;
     }
     if ( length == 0 ) { /* should never happen, but to avoid infinite loops... */
         DISSECTOR_ASSERT_NOT_REACHED();
