@@ -4,7 +4,7 @@
  *
  *  (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-h248_annex_c.c 41527 2012-03-13 13:41:28Z etxrab $
+ * $Id: packet-h248_annex_c.c 43107 2012-06-05 10:54:21Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1510,6 +1510,6 @@ void proto_register_h248_annex_c(void) {
 
 	proto_register_subtree_array(ett, array_length(ett));
 
-	h248_register_package(&h248_annexc_package);
+	h248_register_package(&h248_annexc_package,MERGE_PKG_HIGH);
 
 }
