@@ -2,7 +2,7 @@
  *
  * Routines for ITU-T Recommendation H.261 dissection
  *
- * $Id: packet-h261.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-h261.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2000, Philips Electronics N.V.
  * Andreas Sikkema <h323@ramdyne.nl>
@@ -70,7 +70,7 @@ dissect_h261( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	col_set_str(pinfo->cinfo, COL_INFO, "H.261 message");
 
 	if ( tree ) {
-		ti = proto_tree_add_item( tree, proto_h261, tvb, offset, -1, FALSE );
+		ti = proto_tree_add_item( tree, proto_h261, tvb, offset, -1, ENC_NA );
 		h261_tree = proto_item_add_subtree( ti, ett_h261 );
 		/* SBIT 1st octet, 3 bits */
 		proto_tree_add_uint( h261_tree, hf_h261_sbit, tvb, offset, 1, tvb_get_guint8( tvb, offset ) >> 5 );
@@ -104,7 +104,7 @@ dissect_h261( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		offset++;
 
 		/* The rest of the packet is the H.261 stream */
-		proto_tree_add_item( h261_tree, hf_h261_data, tvb, offset, -1, FALSE );
+		proto_tree_add_item( h261_tree, hf_h261_data, tvb, offset, -1, ENC_NA );
 	}
 }
 
