@@ -8,7 +8,7 @@
  * Copyright 2008 Richard van der Hoff, MX Telecom
  * <richardv@mxtelecom.com>
  *
- * $Id: packet-h263p.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-h263p.c 39609 2011-10-26 18:01:42Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -88,15 +88,15 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "H.263 RFC4629 ");
 
 	if ( tree ) {
-	  ti = proto_tree_add_item( tree, proto_h263P, tvb, offset, -1, FALSE );
+	  ti = proto_tree_add_item( tree, proto_h263P, tvb, offset, -1, ENC_NA );
 	  h263P_tree = proto_item_add_subtree( ti, ett_h263P );
-          
+
 	  data16 = tvb_get_ntohs(tvb,offset);
-	  proto_tree_add_item( h263P_tree, hf_h263P_rr, tvb, offset, 2, FALSE );
-	  proto_tree_add_item( h263P_tree, hf_h263P_pbit, tvb, offset, 2, FALSE );
-	  proto_tree_add_item( h263P_tree, hf_h263P_vbit, tvb, offset, 2, FALSE );
-	  proto_tree_add_item( h263P_tree, hf_h263P_plen, tvb, offset, 2, FALSE );
-	  proto_tree_add_item( h263P_tree, hf_h263P_pebit, tvb, offset, 2, FALSE );
+	  proto_tree_add_item( h263P_tree, hf_h263P_rr, tvb, offset, 2, ENC_BIG_ENDIAN );
+	  proto_tree_add_item( h263P_tree, hf_h263P_pbit, tvb, offset, 2, ENC_BIG_ENDIAN );
+	  proto_tree_add_item( h263P_tree, hf_h263P_vbit, tvb, offset, 2, ENC_BIG_ENDIAN );
+	  proto_tree_add_item( h263P_tree, hf_h263P_plen, tvb, offset, 2, ENC_BIG_ENDIAN );
+	  proto_tree_add_item( h263P_tree, hf_h263P_pebit, tvb, offset, 2, ENC_BIG_ENDIAN );
 	  offset = offset +2;
 	  /*
 	   *   V: 1 bit
@@ -108,7 +108,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	   */
 
 	  if ((data16&0x0200)==0x0200){
-		  /* V bit = 1 
+		  /* V bit = 1
 		   *   The format of the VRC header extension is as follows:
 		   *
 		   *         0 1 2 3 4 5 6 7
@@ -136,26 +136,26 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		   *
 		   *   S: 1 bit
 		   *
-		   *   A bit that indicates that the packet content is for a sync frame.  
+		   *   A bit that indicates that the packet content is for a sync frame.
 		   *   :
 		   */
-		  proto_tree_add_item( h263P_tree, hf_h263P_tid, tvb, offset, 1, FALSE );
-		  proto_tree_add_item( h263P_tree, hf_h263P_trun, tvb, offset, 1, FALSE );
-		  proto_tree_add_item( h263P_tree, hf_h263P_s, tvb, offset, 1, FALSE );
+		  proto_tree_add_item( h263P_tree, hf_h263P_tid, tvb, offset, 1, ENC_BIG_ENDIAN );
+		  proto_tree_add_item( h263P_tree, hf_h263P_trun, tvb, offset, 1, ENC_BIG_ENDIAN );
+		  proto_tree_add_item( h263P_tree, hf_h263P_s, tvb, offset, 1, ENC_BIG_ENDIAN );
 		  offset++;
 	  }
 
 	  /* Length, in bytes, of the extra picture header. */
 	  plen = (data16 & 0x01f8) >> 3;
 	  if (plen != 0){
-		  extra_hdr_item = proto_tree_add_item( h263P_tree, hf_h263P_extra_hdr, tvb, offset, plen, FALSE );
+		  extra_hdr_item = proto_tree_add_item( h263P_tree, hf_h263P_extra_hdr, tvb, offset, plen, ENC_NA );
 		  h263P_extr_hdr_tree = proto_item_add_subtree( extra_hdr_item, ett_h263P_extra_hdr );
 		  dissect_h263_picture_layer( tvb, pinfo, h263P_extr_hdr_tree, offset, plen, TRUE);
-		  offset += plen;		
+		  offset += plen;
 	  }
 	  if ((data16&0x0400)!=0){
 		  /* P bit = 1 */
-		  data_item = proto_tree_add_item( h263P_tree, hf_h263P_payload, tvb, offset, -1, FALSE );
+		  data_item = proto_tree_add_item( h263P_tree, hf_h263P_payload, tvb, offset, -1, ENC_NA );
 		  h263P_data_tree = proto_item_add_subtree( data_item, ett_h263P_data );
 		  /* Startc code holds bit 17 -23 of the codeword */
 		  startcode = tvb_get_guint8(tvb,offset)&0xfe;
@@ -165,7 +165,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 			   */
 			  switch(startcode){
 			  case 0xf8:
-				  /* End Of Sub-Bitstream code (EOSBS) 
+				  /* End Of Sub-Bitstream code (EOSBS)
 				   * EOSBS codes shall be byte aligned
 				   * ( 1111 100. )
 				   */
@@ -176,7 +176,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 				   * ( 1000 00x.)
 				   */
 				  col_append_str( pinfo->cinfo, COL_INFO, "(PSC) ");
-				  offset = dissect_h263_picture_layer( tvb, pinfo, h263P_data_tree, offset, -1, TRUE);
+				  dissect_h263_picture_layer( tvb, pinfo, h263P_data_tree, offset, -1, TRUE);
 				  break;
 			  case 0xfc:
 			  case 0xfe:
@@ -196,7 +196,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		  }
 		  return;
 	  }
-	  proto_tree_add_item( h263P_tree, hf_h263P_payload, tvb, offset, -1, FALSE );
+	  proto_tree_add_item( h263P_tree, hf_h263P_payload, tvb, offset, -1, ENC_NA );
 	}
 }
 
