@@ -2,7 +2,7 @@
  * Routines for hclnfsd (Hummingbird NFS Daemon) dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id: packet-hclnfsd.c 34227 2010-09-23 21:46:31Z morriss $
+ * $Id: packet-hclnfsd.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -173,7 +173,7 @@ dissect_hclnfsd_authorize_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_
 	proto_item *ident_item = NULL;
 	proto_tree *ident_tree = NULL;
 
-	proto_tree_add_item(tree, hf_hclnfsd_server_ip, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_hclnfsd_server_ip, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset += 4;
 
 	request_type = tvb_get_ntohl(tvb, offset);
@@ -291,7 +291,7 @@ dissect_hclnfsd_grp_to_number_reply(tvbuff_t *tvb, int offset, packet_info *pinf
 static int
 dissect_hclnfsd_return_host_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_hclnfsd_host_ip, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_hclnfsd_host_ip, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset += 4;
 
 	return offset;
@@ -614,19 +614,19 @@ dissect_hclnfsd_get_printq_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _
 
 		jobtree = proto_item_add_subtree(jobitem, ett_hclnfsd_printjob);
 
-		offset = dissect_rpc_string(tvb, tree,
+		offset = dissect_rpc_string(tvb, jobtree,
 			hf_hclnfsd_username, offset, NULL);
 
-		offset = dissect_rpc_string(tvb, tree,
+		offset = dissect_rpc_string(tvb, jobtree,
 			hf_hclnfsd_printparams, offset, NULL);
 
-		offset = dissect_rpc_uint32(tvb, tree, hf_hclnfsd_queuestatus, offset);
+		offset = dissect_rpc_uint32(tvb, jobtree, hf_hclnfsd_queuestatus, offset);
 
-		offset = dissect_rpc_uint32(tvb, tree, hf_hclnfsd_jobstatus, offset);
-		offset = dissect_rpc_uint32(tvb, tree, hf_hclnfsd_timesubmitted, offset);
-		offset = dissect_rpc_uint32(tvb, tree, hf_hclnfsd_size, offset);
-		offset = dissect_rpc_uint32(tvb, tree, hf_hclnfsd_copies, offset);
-		offset = dissect_rpc_string(tvb, tree,
+		offset = dissect_rpc_uint32(tvb, jobtree, hf_hclnfsd_jobstatus, offset);
+		offset = dissect_rpc_uint32(tvb, jobtree, hf_hclnfsd_timesubmitted, offset);
+		offset = dissect_rpc_uint32(tvb, jobtree, hf_hclnfsd_size, offset);
+		offset = dissect_rpc_uint32(tvb, jobtree, hf_hclnfsd_copies, offset);
+		offset = dissect_rpc_string(tvb, jobtree,
 			hf_hclnfsd_queuecomment, offset, NULL);
 
 		datafollows = tvb_get_ntohl(tvb, offset);
