@@ -4,7 +4,7 @@
  * Copyright 2006, Sebastien Tandel <sebastien[AT]tandel.be>
  * Copyright 2009, Luca Ceresoli <luca[AT]lucaceresoli.net>
  *
- * $Id: packet-homeplug.c 39566 2011-10-25 16:04:31Z wmeier $
+ * $Id: packet-homeplug.c 40592 2012-01-19 21:57:24Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1029,7 +1029,7 @@ static void dissect_homeplug_ns(ptvcursor_t * cursor, packet_info * pinfo)
   if (!ptvcursor_tree(cursor))
     return;
 
-  ptvcursor_add_with_subtree(cursor, hf_homeplug_ns, homeplug_melen, FALSE,
+  ptvcursor_add_with_subtree(cursor, hf_homeplug_ns, homeplug_melen, ENC_BIG_ENDIAN,
       ett_homeplug_ns);
   {
     ti = proto_tree_add_boolean(ptvcursor_tree(cursor), hf_homeplug_ns_extended,
@@ -1683,12 +1683,12 @@ proto_register_homeplug(void)
     },
 
     { &hf_homeplug_loader_lwnvm,
-      { "Write NVM Data", "homeplug.loader.lrnvm",
+      { "Write NVM Data", "homeplug.loader.lwnvm",
       FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
     },
 
     { &hf_homeplug_loader_lreset,
-      { "Reset", "homeplug.loader.mid",
+      { "Reset", "homeplug.loader.lreset",
       FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
     },
 
@@ -1748,7 +1748,7 @@ proto_register_homeplug(void)
     },
 
     { &hf_homeplug_loader_gnvmp,
-      { "Get NVM Parameters", "homeplug.loader.nvmp",
+      { "Get NVM Parameters", "homeplug.loader.gnvmp",
       FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
     },
 
@@ -1773,7 +1773,7 @@ proto_register_homeplug(void)
     },
 
     { &hf_homeplug_loader_snvmp,
-      { "Set NVM Parameters", "homeplug.loader.nvmp",
+      { "Set NVM Parameters", "homeplug.loader.snvmp",
       FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
     },
 
