@@ -2,7 +2,7 @@
  * Routines for HP extended IEEE 802.2 LLC layer
  * Jochen Friedrich <jochen@scram.de>
  *
- * $Id: packet-hpext.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-hpext.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,7 +67,7 @@ dissect_hpext(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	sxsap = tvb_get_ntohs(tvb, 5);
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_hpext, tvb, 0, 7, FALSE);
+		ti = proto_tree_add_item(tree, proto_hpext, tvb, 0, 7, ENC_NA);
 		hpext_tree = proto_item_add_subtree(ti, ett_hpext);
 		proto_tree_add_text(hpext_tree, tvb, 0, 3, "Reserved");
 		proto_tree_add_uint(hpext_tree, hf_hpext_dxsap, tvb, 3,
