@@ -2,7 +2,7 @@
  * Routines for HP Switch Config protocol
  * Charlie Lenahan <clenahan@fortresstech.com>
  *
- * $Id: packet-hpsw.c 36124 2011-03-03 02:24:44Z morriss $
+ * $Id: packet-hpsw.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -94,12 +94,12 @@ dissect_hpsw(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 		guint16 offset =0;
 
-		ti = proto_tree_add_item(tree, proto_hpsw, tvb, 0, -1, FALSE);
+		ti = proto_tree_add_item(tree, proto_hpsw, tvb, 0, -1, ENC_NA);
 		hp_tree = proto_item_add_subtree(ti, ett_hpsw);
 		proto_tree_add_uint(hp_tree, hf_hpsw_version, tvb, 0, 1, version);
 		offset++;
 
-		proto_tree_add_item(hp_tree, hf_hpsw_type, tvb, 1, 1, FALSE);
+		proto_tree_add_item(hp_tree, hf_hpsw_type, tvb, 1, 1, ENC_BIG_ENDIAN);
 		offset++;
 
 		while ( tvb_reported_length_remaining(tvb, offset) > 0 )
