@@ -3,7 +3,7 @@
  *
  * Pigeon Point Systems <www.pigeonpoint.com>
  *
- * $Id: packet-i2c.c 30088 2009-09-23 14:43:23Z krj $
+ * $Id: packet-i2c.c 41172 2012-02-24 07:57:48Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 #include <epan/prefs.h>
 
 #include "packet-i2c.h"
+#include "packet-hdcp.h"
 
 static int proto_i2c = -1;
 
@@ -48,6 +49,7 @@ static gint ett_i2c = -1;
 enum {
 	SUB_DATA = 0,
 	SUB_IPMB,
+	SUB_HDCP,
 
 	SUB_MAX
 };
@@ -178,7 +180,8 @@ sub_check_ipmb(packet_info *pinfo)
 
 static sub_checkfunc_t sub_check[SUB_MAX] = {
 	NULL, /* raw data */
-	sub_check_ipmb /* IPMI */
+	sub_check_ipmb, /* IPMI */
+	sub_check_hdcp  /* HDCP */
 };
 
 static void
@@ -254,7 +257,7 @@ dissect_i2c(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	if (!is_event) {
-		if (!sub_check[sub_selected] || sub_check[sub_selected](pinfo)) {
+		if (sub_check[sub_selected] && sub_check[sub_selected](pinfo)) {
 			call_dissector(sub_handles[sub_selected], tvb, pinfo, tree);
 		} else {
 			call_dissector(sub_handles[SUB_DATA], tvb, pinfo, tree);
@@ -277,6 +280,7 @@ proto_register_i2c(void)
 	static const enum_val_t sub_enum_vals[] = {
 		{ "none", "None (raw I2C)", SUB_DATA },
 		{ "ipmb", "IPMB", SUB_IPMB },
+		{ "hdcp", "HDCP", SUB_HDCP },
 		{ NULL, NULL, 0 }
 	};
 	module_t *m;
@@ -286,7 +290,8 @@ proto_register_i2c(void)
 	proto_register_subtree_array(ett, array_length(ett));
 
 	m = prefs_register_protocol(proto_i2c, NULL);
-	prefs_register_enum_preference(m, "type", "Bus type", "How the I2C messages are interpreted",
+	prefs_register_enum_preference(m, "type", "Bus/Data type",
+         "How the I2C messages are interpreted",
 			&sub_selected, sub_enum_vals, FALSE);
 }
 
@@ -297,6 +302,7 @@ proto_reg_handoff_i2c(void)
 
 	sub_handles[SUB_DATA] = find_dissector("data");
 	sub_handles[SUB_IPMB] = find_dissector("ipmi");
+	sub_handles[SUB_HDCP] = find_dissector("hdcp");
 	i2c_handle = create_dissector_handle(dissect_i2c, proto_i2c);
-	dissector_add("wtap_encap", WTAP_ENCAP_I2C, i2c_handle);
+	dissector_add_uint("wtap_encap", WTAP_ENCAP_I2C, i2c_handle);
 }
