@@ -2,7 +2,7 @@
  * Routines for IAPP dissection
  * Copyright 2002, Alfred Arnold <aarnold@elsa.de>
  *
- * $Id: packet-iapp.c 36125 2011-03-03 02:32:18Z morriss $
+ * $Id: packet-iapp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -425,7 +425,7 @@ dissect_iapp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree)
 	{
-		ti = proto_tree_add_item(tree, proto_iapp, tvb, 0, -1, FALSE);
+		ti = proto_tree_add_item(tree, proto_iapp, tvb, 0, -1, ENC_NA);
 		iapp_tree = proto_item_add_subtree(ti, ett_iapp);
 
                 /* common header for all IAPP frames */
