@@ -3,7 +3,7 @@
  * Copyright 2004 _FF_
  * Francesco Fondelli <fondelli dot francesco, tiscali dot it>
  *
- * $Id: packet-icep.c 40995 2012-02-12 18:05:22Z alagoutte $
+ * $Id: packet-icep.c 42513 2012-05-08 17:42:36Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -331,7 +331,7 @@ static void dissect_ice_facet(proto_tree *tree, int hf_icep,
 			return;
 		}
 
-		offset += consumed_facet;
+		/*offset += consumed_facet;*/
 		(*consumed) += consumed_facet;
 		return;
 	}
