@@ -2,7 +2,7 @@
  * Routines for XNS IDP
  * Based on the Netware IPX dissector by Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-idp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-idp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -85,37 +85,37 @@ dissect_idp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16		length;
 	guint8		type;
 	tvbuff_t	*next_tvb;
-	
+
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IDP");
 	col_clear(pinfo->cinfo, COL_INFO);
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_idp, tvb, 0, IDP_HEADER_LEN, FALSE);
+		ti = proto_tree_add_item(tree, proto_idp, tvb, 0, IDP_HEADER_LEN, ENC_NA);
 		idp_tree = proto_item_add_subtree(ti, ett_idp);
 	}
 
-	proto_tree_add_item(idp_tree, hf_idp_checksum, tvb, 0, 2, FALSE);
+	proto_tree_add_item(idp_tree, hf_idp_checksum, tvb, 0, 2, ENC_BIG_ENDIAN);
 	length = tvb_get_ntohs(tvb, 2);
 	proto_tree_add_uint_format(idp_tree, hf_idp_len, tvb, 2, 2, length,
 		"Length: %u bytes", length);
 	/* Adjust the tvbuff length to include only the IDP datagram. */
 	set_actual_length(tvb, length);
-	proto_tree_add_item(idp_tree, hf_idp_hops, tvb, 4, 1, FALSE);
+	proto_tree_add_item(idp_tree, hf_idp_hops, tvb, 4, 1, ENC_BIG_ENDIAN);
 	type = tvb_get_guint8(tvb, 5);
 	proto_tree_add_uint(idp_tree, hf_idp_packet_type, tvb, 5, 1, type);
 
 	pinfo->ptype = PT_IDP;
 
 	/* Destination */
-	proto_tree_add_item(idp_tree, hf_idp_dnet, tvb, 6, 4, FALSE);
-	proto_tree_add_item(idp_tree, hf_idp_dnode, tvb, 10, 6, FALSE);
+	proto_tree_add_item(idp_tree, hf_idp_dnet, tvb, 6, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(idp_tree, hf_idp_dnode, tvb, 10, 6, ENC_NA);
 	pinfo->destport = tvb_get_ntohs(tvb, 16);
 	proto_tree_add_uint(idp_tree, hf_idp_dsocket, tvb, 16, 2,
 	    pinfo->destport);
 
 	/* Source */
-	proto_tree_add_item(idp_tree, hf_idp_snet, tvb, 18, 4, FALSE);
-	proto_tree_add_item(idp_tree, hf_idp_snode, tvb, 22, 6, FALSE);
+	proto_tree_add_item(idp_tree, hf_idp_snet, tvb, 18, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(idp_tree, hf_idp_snode, tvb, 22, 6, ENC_NA);
 	pinfo->srcport = tvb_get_ntohs(tvb, 28);
 	proto_tree_add_uint(idp_tree, hf_idp_ssocket, tvb, 28, 2,
 	    pinfo->srcport);
