@@ -1,7 +1,7 @@
 /* packet-ieee80211-prism.c
  * Routines for Prism monitoring mode header dissection
  *
- * $Id: packet-ieee80211-prism.c 39850 2011-11-15 15:16:37Z wmeier $
+ * $Id: packet-ieee80211-prism.c 42379 2012-05-02 03:11:00Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -460,7 +460,7 @@ void proto_reg_handoff_ieee80211_prism(void)
   dissector_handle_t prism_handle;
 
   prism_handle = create_dissector_handle(dissect_prism, proto_prism);
-  dissector_add_uint("wtap_encap", WTAP_ENCAP_PRISM_HEADER, prism_handle);
+  dissector_add_uint("wtap_encap", WTAP_ENCAP_IEEE_802_11_PRISM, prism_handle);
   ieee80211_handle = find_dissector("wlan");
   wlancap_handle = find_dissector("wlancap");
 }
