@@ -9,7 +9,7 @@
  * Significantly based on packet-fcip.c by
  *       Copyright 2001, Dinesh G Dutt (ddutt@cisco.com)
  *
- * $Id: packet-ifcp.c 39288 2011-10-06 03:35:44Z wmeier $
+ * $Id: packet-ifcp.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,8 +34,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
@@ -276,7 +274,6 @@ dissect_ifcpflags(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 	if(flags&IFCP_FLAGS_SPC){
 		proto_item_append_text(item, "  SPC");
 	}
-	flags&=(~IFCP_FLAGS_SPC);
 
 
 	offset++;
@@ -310,7 +307,6 @@ dissect_commonflags(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 	if(flags&IFCP_COMMON_FLAGS_CRCV){
 		proto_item_append_text(item, "  CRCV");
 	}
-	flags&=(~IFCP_COMMON_FLAGS_CRCV);
 }
 
 static void
