@@ -2,7 +2,7 @@
  * Routines for IGMP/IGAP packet disassembly
  * 2003, Endoh Akria (see AUTHORS for email)
  *
- * $Id: packet-igap.c 34227 2010-09-23 21:46:31Z morriss $
+ * $Id: packet-igap.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -143,7 +143,7 @@ dissect_igap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int off
 	return offset + tvb_length_remaining(tvb, offset);
     }
 
-    item = proto_tree_add_item(parent_tree, proto_igap, tvb, offset, -1, FALSE);
+    item = proto_tree_add_item(parent_tree, proto_igap, tvb, offset, -1, ENC_NA);
     tree = proto_item_add_subtree(item, ett_igap);
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "IGAP");
@@ -165,7 +165,7 @@ dissect_igap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int off
     igmp_checksum(tree, tvb, hf_checksum, hf_checksum_bad, pinfo, 0);
     offset += 2;
 
-    proto_tree_add_item(tree, hf_maddr, tvb, offset, 4, FALSE);
+    proto_tree_add_item(tree, hf_maddr, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset += 4;
 
     proto_tree_add_uint(tree, hf_version, tvb, offset, 1,
