@@ -2,7 +2,7 @@
  *
  * Routines for PNG (Portable Network Graphics) image file dissection
  *
- * $Id: packet-image-png.c 48713 2013-04-02 21:25:51Z cmaynard $
+ * $Id: packet-image-png.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2006 Ronnie Sahlberg
  *
@@ -100,25 +100,25 @@ dissect_png_ihdr(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
 	int offset=0;
 
-	proto_tree_add_item(tree, hf_png_ihdr_width, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_width, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset+=4;
 
-	proto_tree_add_item(tree, hf_png_ihdr_height, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_height, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset+=4;
 
-	proto_tree_add_item(tree, hf_png_ihdr_bitdepth, tvb, offset, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_bitdepth, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset+=1;
 
-	proto_tree_add_item(tree, hf_png_ihdr_colour_type, tvb, offset, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_colour_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset+=1;
 
-	proto_tree_add_item(tree, hf_png_ihdr_compression_method, tvb, offset, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_compression_method, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset+=1;
 
-	proto_tree_add_item(tree, hf_png_ihdr_filter_method, tvb, offset, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_filter_method, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset+=1;
 
-	proto_tree_add_item(tree, hf_png_ihdr_interlace_method, tvb, offset, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_ihdr_interlace_method, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset+=1;
 
 	return;
@@ -137,22 +137,22 @@ dissect_png_text(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 		offset++;
 	}
 
-	proto_tree_add_item(tree, hf_png_text_keyword, tvb, 0, offset, FALSE);
+	proto_tree_add_item(tree, hf_png_text_keyword, tvb, 0, offset, ENC_ASCII|ENC_NA);
 	offset++;
 
-	proto_tree_add_item(tree, hf_png_text_string, tvb, offset, tvb_length_remaining(tvb, offset), FALSE);
+	proto_tree_add_item(tree, hf_png_text_string, tvb, offset, tvb_length_remaining(tvb, offset), ENC_ASCII|ENC_NA);
 
 }
 
 static void
 dissect_png_time(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_png_time_year, tvb, 0, 2, FALSE);
-	proto_tree_add_item(tree, hf_png_time_month, tvb, 2, 1, FALSE);
-	proto_tree_add_item(tree, hf_png_time_day, tvb, 3, 1, FALSE);
-	proto_tree_add_item(tree, hf_png_time_hour, tvb, 4, 1, FALSE);
-	proto_tree_add_item(tree, hf_png_time_minute, tvb, 5, 1, FALSE);
-	proto_tree_add_item(tree, hf_png_time_second, tvb, 6, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_time_year, tvb, 0, 2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_time_month, tvb, 2, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_time_day, tvb, 3, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_time_hour, tvb, 4, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_time_minute, tvb, 5, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_time_second, tvb, 6, 1, ENC_BIG_ENDIAN);
 }
 
 static const value_string phys_unit_vals[] = {
@@ -163,9 +163,9 @@ static const value_string phys_unit_vals[] = {
 static void
 dissect_png_phys(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_png_phys_horiz, tvb, 0, 4, FALSE);
-	proto_tree_add_item(tree, hf_png_phys_vert, tvb, 4, 4, FALSE);
-	proto_tree_add_item(tree, hf_png_phys_unit, tvb, 8, 1, FALSE);
+	proto_tree_add_item(tree, hf_png_phys_horiz, tvb, 0, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_phys_vert, tvb, 4, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_png_phys_unit, tvb, 8, 1, ENC_BIG_ENDIAN);
 }
 
 static void
@@ -173,15 +173,15 @@ dissect_png_bkgd(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
 	switch(tvb_reported_length(tvb)){
 	case 1: /* colour type 3 */
-		proto_tree_add_item(tree, hf_png_bkgd_palette_index, tvb, 0, 1, FALSE);
+		proto_tree_add_item(tree, hf_png_bkgd_palette_index, tvb, 0, 1, ENC_BIG_ENDIAN);
 		break;
 	case 2: /* colour type 0, 4 */
-		proto_tree_add_item(tree, hf_png_bkgd_greyscale, tvb, 0, 2, FALSE);
+		proto_tree_add_item(tree, hf_png_bkgd_greyscale, tvb, 0, 2, ENC_BIG_ENDIAN);
 		break;
 	case 6: /* colour type 2, 6 */
-		proto_tree_add_item(tree, hf_png_bkgd_red, tvb, 0, 2, FALSE);
-		proto_tree_add_item(tree, hf_png_bkgd_green, tvb, 2, 2, FALSE);
-		proto_tree_add_item(tree, hf_png_bkgd_blue, tvb, 4, 2, FALSE);
+		proto_tree_add_item(tree, hf_png_bkgd_red, tvb, 0, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(tree, hf_png_bkgd_green, tvb, 2, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(tree, hf_png_bkgd_blue, tvb, 4, 2, ENC_BIG_ENDIAN);
 		break;
 	}
 }
@@ -236,14 +236,14 @@ dissect_png(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	col_append_str(pinfo->cinfo, COL_INFO, " (PNG)");
 
 	if(parent_tree){
-		ti=proto_tree_add_item(parent_tree, proto_png, tvb, offset, -1, FALSE);
+		ti=proto_tree_add_item(parent_tree, proto_png, tvb, offset, -1, ENC_NA);
 		tree=proto_item_add_subtree(ti, ett_png);
 	}
 
-	proto_tree_add_item(tree, hf_png_signature, tvb, offset, 8, FALSE);
+	proto_tree_add_item(tree, hf_png_signature, tvb, offset, 8, ENC_NA);
 	offset+=8;
 
-	while(tvb_reported_length_remaining(tvb, offset) > 0){
+	while(tvb_reported_length_remaining(tvb, offset)){
 		proto_tree *chunk_tree=NULL;
 		proto_item *it=NULL;
 		guint32 len, type;
@@ -263,14 +263,14 @@ dissect_png(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			chunk_tree=proto_item_add_subtree(it, ett_png_chunk);
 		}
 
-		proto_tree_add_item(chunk_tree, hf_png_chunk_len, tvb, offset, 4, FALSE);
+		proto_tree_add_item(chunk_tree, hf_png_chunk_len, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
 
 
-		it=proto_tree_add_item(chunk_tree, hf_png_chunk_type, tvb, offset, 4, FALSE);
-		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_anc, tvb, offset, 4, FALSE);
-		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_priv, tvb, offset, 4, FALSE);
-		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_stc, tvb, offset, 4, FALSE);
+		it=proto_tree_add_item(chunk_tree, hf_png_chunk_type, tvb, offset, 4, ENC_ASCII|ENC_NA);
+		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_anc, tvb, offset, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_priv, tvb, offset, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_item(chunk_tree, hf_png_chunk_flag_stc, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
 
 		if (len >= 1000000000)
@@ -291,7 +291,7 @@ dissect_png(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		}
 
 		if(!cd){
-			proto_tree_add_item(chunk_tree, hf_png_chunk_data, tvb, offset, len, FALSE);
+			proto_tree_add_item(chunk_tree, hf_png_chunk_data, tvb, offset, len, ENC_NA);
 		} else {
 			if(cd->dissector){
 				tvbuff_t *next_tvb;
@@ -306,7 +306,7 @@ dissect_png(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		}
 		offset+=len;
 
-		proto_tree_add_item(chunk_tree, hf_png_chunk_crc, tvb, offset, 4, FALSE);
+		proto_tree_add_item(chunk_tree, hf_png_chunk_crc, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
 	}
 	return offset;
