@@ -1,7 +1,7 @@
 /* packet-imf.c
  * Routines for Internet Message Format (IMF) packet disassembly
  *
- * $Id: packet-imf.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-imf.c 41840 2012-03-30 08:57:57Z stig $
  *
  * Copyright (c) 2007 by Graeme Lunt
  *
@@ -282,17 +282,29 @@ static void
 header_fields_update_cb(void *r, const char **err)
 {
   header_field_t *rec = r;
+  char c;
 
   if (rec->header_name == NULL) {
     *err = ep_strdup_printf("Header name can't be empty");
-  } else {
-    g_strstrip(rec->header_name);
-    if (rec->header_name[0] == 0) {
-      *err = ep_strdup_printf("Header name can't be empty");
-    } else {
-      *err = NULL;
-    }
+    return;
   }
+
+  g_strstrip(rec->header_name);
+  if (rec->header_name[0] == 0) {
+    *err = ep_strdup_printf("Header name can't be empty");
+    return;
+  }
+
+  /* Check for invalid characters (to avoid asserting out when
+   * registering the field).
+   */
+  c = proto_check_field_name(rec->header_name);
+  if (c) {
+    *err = ep_strdup_printf("Header name can't contain '%c'", c);
+    return;
+  }
+
+  *err = NULL;
 }
 
 static void *
@@ -758,7 +770,7 @@ dissect_imf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       } else {
         /* remove 2 bytes to take off the final CRLF to make things a little prettier */
-        item = proto_tree_add_item(tree, hf_id, tvb, value_offset, end_offset - value_offset - 2, FALSE);
+        item = proto_tree_add_item(tree, hf_id, tvb, value_offset, end_offset - value_offset - 2, ENC_ASCII|ENC_NA);
       }
       if(f_info->add_to_col_info && check_col(pinfo->cinfo, COL_INFO)) {
 
@@ -851,7 +863,7 @@ header_fields_initialize_cb (void)
   guint i;
   gchar *header_name;
 
-  if (custom_field_table) {
+  if (custom_field_table && hf) {
     guint hf_size = g_hash_table_size (custom_field_table);
     /* Unregister all fields */
     for (i = 0; i < hf_size; i++) {
@@ -1204,7 +1216,7 @@ proto_register_imf(void)
                                TRUE,
                                (void*) &header_fields,
                                &num_header_fields,
-                               UAT_CAT_GENERAL,
+                               UAT_CAT_FIELDS,
                                NULL,
                                header_fields_copy_cb,
                                header_fields_update_cb,
