@@ -1,7 +1,7 @@
 /* packet-ip.h
  * Definitions for IP packet disassembly structures and routines
  *
- * $Id: packet-ip.h 29035 2009-07-09 11:32:50Z stig $
+ * $Id: packet-ip.h 43336 2012-06-18 17:26:50Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,7 +43,8 @@ typedef struct _ws_ip
 void capture_ip(const guchar *, int, int, packet_counts *);
 guint16 ip_checksum(const guint8 *ptr, int len);
 
-/* Export the DSCP value-string table for other protocols */
+/* Export the DSCP extended value-string table for other protocols */
+WS_VAR_IMPORT value_string_ext dscp_vals_ext;
 WS_VAR_IMPORT const value_string dscp_vals[];
 
 #endif
