@@ -2,7 +2,7 @@
  * Sub-dissectors for IPMI messages (netFn=Group, defining body = PICMG)
  * Copyright 2007-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  *
- * $Id: packet-ipmi-picmg.c 40285 2011-12-23 14:31:24Z cmaynard $
+ * $Id: packet-ipmi-picmg.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <epan/packet.h>
 
 #include "packet-ipmi.h"
