@@ -3,7 +3,7 @@
  * Copyright 2007-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  * Copyright Duncan Laurie <duncan@sun.com>
  *
- * $Id: packet-ipmi-session.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-ipmi-session.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -183,7 +183,7 @@ dissect_ipmi_session(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				authtype == IPMI_AUTH_RMCPP ? "2.0+" : "1.5",
 				session_id);
 		sess_tree = proto_item_add_subtree(ti, ett_ipmi_session);
-		proto_tree_add_item(sess_tree, hf_ipmi_session_authtype, tvb, offset, 1, TRUE);
+		proto_tree_add_item(sess_tree, hf_ipmi_session_authtype, tvb, offset, 1, ENC_LITTLE_ENDIAN);
 		offset++;
 
 		if (authtype == IPMI_AUTH_RMCPP) {
@@ -195,35 +195,35 @@ dissect_ipmi_session(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					payloadtype_enc ? "" : "not ",
 					payloadtype_auth ? "" : "not ");
 			s_tree = proto_item_add_subtree(ti, ett_ipmi_session_payloadtype);
-			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype_enc, tvb, offset, 1, TRUE);
-			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype_auth, tvb, offset, 1, TRUE);
-			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype, tvb, offset, 1, TRUE);
+			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype_enc, tvb, offset, 1, ENC_LITTLE_ENDIAN);
+			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype_auth, tvb, offset, 1, ENC_LITTLE_ENDIAN);
+			proto_tree_add_item(s_tree, hf_ipmi_session_payloadtype, tvb, offset, 1, ENC_LITTLE_ENDIAN);
 			offset++;
 
 			if (payloadtype == IPMI_OEM_EXPLICIT) {
-				proto_tree_add_item(sess_tree, hf_ipmi_session_oem_iana, tvb, offset, 4, TRUE);
+				proto_tree_add_item(sess_tree, hf_ipmi_session_oem_iana, tvb, offset, 4, ENC_NA);
 				offset += 4;
-				proto_tree_add_item(sess_tree, hf_ipmi_session_oem_payload_id, tvb, offset, 2, TRUE);
+				proto_tree_add_item(sess_tree, hf_ipmi_session_oem_payload_id, tvb, offset, 2, ENC_NA);
 				offset += 2;
 			}
-			proto_tree_add_item(sess_tree, hf_ipmi_session_id, tvb, offset, 4, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_id, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
-			proto_tree_add_item(sess_tree, hf_ipmi_session_sequence, tvb, offset, 4, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_sequence, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
-			proto_tree_add_item(sess_tree, hf_ipmi_session_msg_len_2b, tvb, offset, 2, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_msg_len_2b, tvb, offset, 2, ENC_LITTLE_ENDIAN);
 			offset += 2;
 		} else {
 			/* IPMI v1.5 */
-			proto_tree_add_item(sess_tree, hf_ipmi_session_sequence, tvb, offset, 4, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_sequence, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
-			proto_tree_add_item(sess_tree, hf_ipmi_session_id, tvb, offset, 4, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_id, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
 			if (authtype != IPMI_AUTH_NONE) {
 				proto_tree_add_item(sess_tree, hf_ipmi_session_authcode,
-						tvb, offset, 16, TRUE);
+						tvb, offset, 16, ENC_NA);
 				offset += 16;
 			}
-			proto_tree_add_item(sess_tree, hf_ipmi_session_msg_len_1b, tvb, offset, 1, TRUE);
+			proto_tree_add_item(sess_tree, hf_ipmi_session_msg_len_1b, tvb, offset, 1, ENC_LITTLE_ENDIAN);
 			offset++;
 		}
 	}
@@ -258,7 +258,7 @@ dissect_ipmi_session(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/* Show the rest of the session wrapper as binary data */
 		if (offset < tvb_length(tvb)) {
 			proto_tree_add_item(sess_tree, hf_ipmi_session_trailer,
-					tvb, offset, tvb_length(tvb) - offset, TRUE);
+					tvb, offset, tvb_length(tvb) - offset, ENC_NA);
 		}
 	}
 	return tvb_length(tvb);
