@@ -2,7 +2,7 @@
  * Routines for IPMI dissection
  * Copyright 2002-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  *
- * $Id: packet-ipmi.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-ipmi.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,16 +27,13 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
 #include <string.h>
 #include <time.h>
 #include <math.h>
 
+#include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/emem.h>
-#include <epan/packet.h>
 #include <epan/to_str.h>
 #include <epan/prefs.h>
 #include <epan/addr_resolv.h>
