@@ -2,7 +2,7 @@
  * Routines for the disassembly of the proprietary Cisco IPSEC in
  * TCP encapsulation protocol
  *
- * $Id: packet-ipsec-tcp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-ipsec-tcp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2007 Joerg Mayer (see AUTHORS file)
  *
@@ -103,7 +103,7 @@ packet_is_tcpencap(tvbuff_t *tvb, packet_info *pinfo, guint32 offset)
 }
 
 /*
- * TCP Encapsulation of IPsec Packets	
+ * TCP Encapsulation of IPsec Packets
  * as supported by the cisco vpn3000 concentrator series
  */
 static int
@@ -130,7 +130,7 @@ dissect_tcpencap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	/* If the first 4 bytes are 0x01f401f4 (udp src and dst port = 500)
 	   we most likely have UDP (isakmp) traffic */
-	
+
 	if (tvb_get_ntohl(tvb, 0) == 0x01f401f4) { /* UDP means ISAKMP */
 		protocol = TCP_ENCAP_P_UDP;
 	} else { /* Hopefully ESP */
@@ -138,25 +138,25 @@ dissect_tcpencap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	if (tree) {
-		tree_item = proto_tree_add_item(tree, proto_tcpencap, tvb, 0, -1, FALSE);
+		tree_item = proto_tree_add_item(tree, proto_tcpencap, tvb, 0, -1, ENC_NA);
 		tcpencap_tree = proto_item_add_subtree(tree_item, ett_tcpencap);
 
 		/* Dissect the trailer following the encapsulated IPSEC/ISAKMP packet */
 		offset = reported_length - TRAILERLENGTH;
 		unknown_item = proto_tree_add_item(tcpencap_tree, hf_tcpencap_unknown, tvb,
-			offset, TRAILERLENGTH, FALSE);
+			offset, TRAILERLENGTH, ENC_NA);
 		/* Try to guess the contents of the trailer */
 		tcpencap_unknown_tree = proto_item_add_subtree(unknown_item, ett_tcpencap_unknown);
-		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_zero, tvb, offset + 0, 4, FALSE);
-		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_seq, tvb, offset + 4, 2, FALSE);
+		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_zero, tvb, offset + 0, 4, ENC_NA);
+		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_seq, tvb, offset + 4, 2, ENC_BIG_ENDIAN);
 		if (protocol == TCP_ENCAP_P_UDP) {
-			proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_ike_direction, tvb, offset + 6, 2, FALSE);
+			proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_ike_direction, tvb, offset + 6, 2, ENC_BIG_ENDIAN);
 		} else {
-			proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_esp_zero, tvb, offset + 6, 2, FALSE);
+			proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_esp_zero, tvb, offset + 6, 2, ENC_BIG_ENDIAN);
 		}
-		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_magic, tvb, offset + 8, 5, FALSE);
-		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_proto, tvb, offset + 13, 1, FALSE);
-		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_magic2, tvb, offset + 14, 2, FALSE);
+		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_magic, tvb, offset + 8, 5, ENC_NA);
+		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_proto, tvb, offset + 13, 1, ENC_BIG_ENDIAN);
+		proto_tree_add_item(tcpencap_unknown_tree, hf_tcpencap_magic2, tvb, offset + 14, 2, ENC_NA);
 	}
 
 	/* Create the tvbuffer for the next dissector */
