@@ -5,7 +5,7 @@
  *
  * Copyright 2008, Randy McEoin <rmceoin@ahbelo.com>
  *
- * $Id: packet-ipsi-ctl.c 35546 2011-01-16 03:35:29Z morriss $
+ * $Id: packet-ipsi-ctl.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -73,7 +73,7 @@ static void dissect_ipsictl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (tree) {
 
-      ti = proto_tree_add_item(tree, proto_ipsictl, tvb, offset, remaining_length, FALSE);
+      ti = proto_tree_add_item(tree, proto_ipsictl, tvb, offset, remaining_length, ENC_NA);
       ipsictl_tree = proto_item_add_subtree(ti, ett_ipsictl);
 
   }
