@@ -1,7 +1,7 @@
 /* packet-isis-clv.h
  * Declares for common clv decoding functions.
  *
- * $Id: packet-isis-clv.h 41751 2012-03-24 00:07:49Z morriss $
+ * $Id: packet-isis-clv.h 42385 2012-05-02 14:23:35Z etxrab $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Wireshark - Network traffic analyzer
@@ -59,6 +59,13 @@
 #define ISIS_CLV_EXTD_IP_REACH       135 /* draft-ietf-isis-traffic-05 */
 #define ISIS_CLV_HOSTNAME            137 /* rfc2763 */
 #define ISIS_CLV_SHARED_RISK_GROUP   138 /* draft-ietf-isis-gmpls-extensions */
+#define ISIS_GRP_ADDR                142 /* draft-ieft-trill-isis-05*//* Our sub-packet dismantle structure for CLV's */
+#define ISIS_CLV_MT_PORT_CAP         143 /* MT port capability (draft-ietf-isis-layer2-11) */
+#define ISIS_CLV_MT_CAP              144 /* MT capability (draft-ietf-isis-ieee-aq-05)
+                                          *   also: IEEE P802.1aq/D3.6,
+                                          *         http://www.ietf.org/mail-archive/web/spb-isis/current/msg00007.html
+                                          *         http://www.iana.org/assignments/isis-tlv-codepoints/isis-tlv-codepoints.xml#tlv-143,
+                                          */
 #define ISIS_CLV_RESTART             211 /* draft-ietf-isis-restart-01 */
 #define ISIS_CLV_MT_IS_REACH         222 /* draft-ietf-isis-wg-multi-topology-05 */
 #define ISIS_CLV_MT_SUPPORTED        229 /* draft-ietf-isis-wg-multi-topology-05 */
@@ -70,7 +77,6 @@
 #define ISIS_CLV_IIH_SEQNR           241 /* draft-shen-isis-iih-sequence-00 */
 #define ISIS_CLV_RT_CAPABLE          242 /* TRILL use of IS-IS RFC 6326 */
 #define ISIS_CLV_VENDOR_PRIVATE      250 /* draft-ietf-isis-proprietary-tlv-00 */
-#define ISIS_GRP_ADDR                142 /*draft-ieft-trill-isis-05*//* Our sub-packet dismantle structure for CLV's */
 
 /*
  * Our sub-packet dismantle structure for CLV's
