@@ -8,7 +8,7 @@
  * (c) 2004 Ronnie Sahlberg   updates
  * (c) 2004 Ming Zhang   updates
  *
- * $Id: packet-isns.c 41465 2012-03-10 17:48:17Z alagoutte $
+ * $Id: packet-isns.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,14 +34,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 
 #include <epan/packet.h>
