@@ -4,7 +4,7 @@
  *
  * Copyright 2008, Dan Gora <dg [AT] adax.com>
  *
- * $Id: packet-itdm.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-itdm.c 42053 2012-04-13 20:22:31Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -476,7 +476,7 @@ proto_reg_handoff_itdm(void)
 	static guint ItdmMPLSLabel;
 
 	if (!Initialized) {
-		itdm_handle = find_dissector("itdm");;
+		itdm_handle = find_dissector("itdm");
 		data_handle = find_dissector("data");
 		Initialized=TRUE;
 	} else {
