@@ -4,7 +4,7 @@
  * Copyright 2008, Yves Geissbuehler <yves.geissbuehler@gmx.net>
  * Copyright 2008, Philip Frey <frey.philip@gmail.com>
  *
- * $Id: packet-iwarp-mpa.c 36988 2011-05-04 21:19:04Z darkjames $
+ * $Id: packet-iwarp-mpa.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,7 +36,7 @@
 #include <epan/conversation.h>
 #include <epan/dissectors/packet-tcp.h>
 #include <epan/expert.h>
-#include <epan/crc32.h>
+#include <wsutil/crc32.h>
 
 /* DEFINES */
 
@@ -481,40 +481,40 @@ dissect_mpa_req_rep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	if (tree) {
 		mpa_item = proto_tree_add_item(tree, proto_iwarp_mpa, tvb, 0,
-				-1, FALSE);
+				-1, ENC_NA);
 		mpa_tree = proto_item_add_subtree(mpa_item, ett_mpa);
 
 		if (message_type == MPA_REQUEST_FRAME) {
 			mpa_header_item = proto_tree_add_item(mpa_tree,
-					hf_mpa_req, tvb, offset, -1, FALSE);
+					hf_mpa_req, tvb, offset, -1, ENC_NA);
 			mpa_header_tree = proto_item_add_subtree(
 					mpa_header_item, ett_mpa);
 			proto_tree_add_item(mpa_header_tree, hf_mpa_key_req,
-					tvb, offset, MPA_REQ_REP_KEY_LEN, FALSE);
+					tvb, offset, MPA_REQ_REP_KEY_LEN, ENC_NA);
 		}
 
 		if (message_type == MPA_REPLY_FRAME) {
 			mpa_header_item = proto_tree_add_item(mpa_tree,
-					hf_mpa_rep, tvb, offset, -1, FALSE);
+					hf_mpa_rep, tvb, offset, -1, ENC_NA);
 			mpa_header_tree = proto_item_add_subtree(
 					mpa_header_item, ett_mpa);
 			proto_tree_add_item(mpa_header_tree, hf_mpa_key_rep,
-					tvb, offset, MPA_REQ_REP_KEY_LEN, FALSE);
+					tvb, offset, MPA_REQ_REP_KEY_LEN, ENC_NA);
 		}
 		offset += MPA_REQ_REP_KEY_LEN;
 
 		proto_tree_add_item(mpa_header_tree, hf_mpa_flag_m, tvb,
-				offset, MPA_REQ_REP_FLAG_LEN, FALSE);
+				offset, MPA_REQ_REP_FLAG_LEN, ENC_BIG_ENDIAN);
 		proto_tree_add_item(mpa_header_tree, hf_mpa_flag_c, tvb,
-				offset, MPA_REQ_REP_FLAG_LEN, FALSE);
+				offset, MPA_REQ_REP_FLAG_LEN, ENC_BIG_ENDIAN);
 		proto_tree_add_item(mpa_header_tree, hf_mpa_flag_r, tvb,
-				offset, MPA_REQ_REP_FLAG_LEN, FALSE);
+				offset, MPA_REQ_REP_FLAG_LEN, ENC_BIG_ENDIAN);
 		proto_tree_add_item(mpa_header_tree, hf_mpa_flag_res, tvb,
-				offset, MPA_REQ_REP_FLAG_LEN, FALSE);
+				offset, MPA_REQ_REP_FLAG_LEN, ENC_BIG_ENDIAN);
 		offset += MPA_REQ_REP_FLAG_LEN;
 
 		proto_tree_add_item(mpa_header_tree, hf_mpa_rev, tvb,
-				offset, MPA_REQ_REP_REV_LEN, FALSE);
+				offset, MPA_REQ_REP_REV_LEN, ENC_BIG_ENDIAN);
 		offset += MPA_REQ_REP_REV_LEN;
 
 		/* check whether the Private Data Length conforms to RFC 5044 */
@@ -536,7 +536,7 @@ dissect_mpa_req_rep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		if (pd_length) {
 			proto_tree_add_item(mpa_header_tree,
 					hf_mpa_private_data, tvb, offset,
-					pd_length, FALSE);
+					pd_length, ENC_NA);
 		}
 	}
 	return TRUE;
@@ -606,7 +606,7 @@ dissect_fpdu_crc(tvbuff_t *tvb, proto_tree *tree, mpa_state_t *state,
 		}
 	} else {
 		proto_tree_add_item(tree, hf_mpa_crc, tvb, offset, MPA_CRC_LEN,
-				FALSE);
+				ENC_BIG_ENDIAN);
 	}
 }
 
@@ -621,14 +621,14 @@ dissect_fpdu_markers(tvbuff_t *tvb, proto_tree *tree, mpa_state_t *state,
 	guint32 offset, i;
 
 	mpa_marker_item = proto_tree_add_item(tree, hf_mpa_marker, tvb,
-			0, -1, FALSE);
+			0, -1, ENC_NA);
 	mpa_marker_tree = proto_item_add_subtree(mpa_marker_item, ett_mpa);
 
 	offset = get_first_marker_offset(state, tcpinfo, endpoint);
 
 	for (i=0; i<number_of_markers(state, tcpinfo, endpoint); i++) {
 		proto_tree_add_item(mpa_marker_tree, hf_mpa_marker_res, tvb,
-				offset, MPA_MARKER_RSVD_LEN, FALSE);
+				offset, MPA_MARKER_RSVD_LEN, ENC_BIG_ENDIAN);
 		fpduptr = (guint16) tvb_get_ntohs(tvb, offset+MPA_MARKER_RSVD_LEN);
 		proto_tree_add_uint_format_value(mpa_marker_tree,
 				hf_mpa_marker_fpduptr, tvb,
@@ -735,11 +735,11 @@ dissect_mpa_fpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		}
 
 		mpa_item = proto_tree_add_item(tree, proto_iwarp_mpa, tvb, 0,
-				-1, FALSE);
+				-1, ENC_NA);
 		mpa_tree = proto_item_add_subtree(mpa_item, ett_mpa);
 
 		mpa_header_item = proto_tree_add_item(mpa_tree, hf_mpa_fpdu,
-				tvb, offset, -1, FALSE);
+				tvb, offset, -1, ENC_NA);
 		mpa_header_tree = proto_item_add_subtree(mpa_header_item,
 				ett_mpa);
 
@@ -761,7 +761,7 @@ dissect_mpa_fpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 						tvb, pad_offset(tcpinfo,
 								total_length,
 								pad_length),
-								pad_length, FALSE);
+								pad_length, ENC_NA);
 			}
 
 			dissect_fpdu_crc(tvb, mpa_header_tree, state,
@@ -776,7 +776,7 @@ dissect_mpa_fpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 			if (pad_length > 0) {
 				proto_tree_add_item(mpa_header_tree, hf_mpa_pad, tvb, offset,
-						pad_length, FALSE);
+						pad_length, ENC_NA);
 				offset += pad_length;
 			}
 
