@@ -2,7 +2,7 @@
  *
  * Routines for RFC 2435 JPEG dissection
  *
- * $Id: packet-jpeg.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-jpeg.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2006
  * Erwin Rol <erwin@erwinrol.com>
@@ -88,21 +88,21 @@ dissect_jpeg( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	col_set_str(pinfo->cinfo, COL_INFO, "JPEG message");
 
 	if ( tree ) {
-		ti = proto_tree_add_item( tree, proto_jpeg, tvb, offset, -1, FALSE );
+		ti = proto_tree_add_item( tree, proto_jpeg, tvb, offset, -1, ENC_NA );
 		jpeg_tree = proto_item_add_subtree( ti, ett_jpeg );
 
-		ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_main_hdr, tvb, offset, 8, FALSE);
+		ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_main_hdr, tvb, offset, 8, ENC_NA);
 		main_hdr_tree = proto_item_add_subtree(ti, ett_jpeg);
 
-		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_ts, tvb, offset, 1, FALSE);
+		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_ts, tvb, offset, 1, ENC_BIG_ENDIAN);
 		offset += 1;
-		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_offs, tvb, offset, 3, FALSE);
+		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_offs, tvb, offset, 3, ENC_BIG_ENDIAN);
 		fragment_offset = tvb_get_ntoh24(tvb, offset);
 		offset += 3;
-		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		type = tvb_get_guint8(tvb, offset);
 		offset += 1;
-		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_q, tvb, offset, 1, FALSE);
+		proto_tree_add_item(main_hdr_tree, hf_rtp_jpeg_main_hdr_q, tvb, offset, 1, ENC_BIG_ENDIAN);
 		q = tvb_get_guint8(tvb, offset);
 		offset += 1;
 		w = tvb_get_guint8(tvb, offset) * 8;
@@ -113,35 +113,35 @@ dissect_jpeg( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		offset += 1;
 
 		if (type >= 64 && type <= 127) {
-			ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_restart_hdr, tvb, offset, 4, FALSE);
+			ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_restart_hdr, tvb, offset, 4, ENC_NA);
 			restart_hdr_tree = proto_item_add_subtree(ti, ett_jpeg);
-			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_interval, tvb, offset, 2, FALSE);
+			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_interval, tvb, offset, 2, ENC_BIG_ENDIAN);
 			offset += 2;
-			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_f, tvb, offset, 2, FALSE);
-			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_l, tvb, offset, 2, FALSE);
-			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_count, tvb, offset, 2, FALSE);
+			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_f, tvb, offset, 2, ENC_BIG_ENDIAN);
+			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_l, tvb, offset, 2, ENC_BIG_ENDIAN);
+			proto_tree_add_item(restart_hdr_tree, hf_rtp_jpeg_restart_hdr_count, tvb, offset, 2, ENC_BIG_ENDIAN);
 			offset += 2;
 		}
 
 		if (q >= 128 && fragment_offset == 0) {
-			ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_qtable_hdr, tvb, offset, -1, FALSE);
+			ti = proto_tree_add_item(jpeg_tree, hf_rtp_jpeg_qtable_hdr, tvb, offset, -1, ENC_NA);
 			qtable_hdr_tree = proto_item_add_subtree(ti, ett_jpeg);
-			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_mbz, tvb, offset, 1, FALSE);
+			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_mbz, tvb, offset, 1, ENC_BIG_ENDIAN);
 			offset += 1;
-			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_prec, tvb, offset, 1, FALSE);
+			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_prec, tvb, offset, 1, ENC_BIG_ENDIAN);
 			offset += 1;
-			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_length, tvb, offset, 2, FALSE);
+			proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_length, tvb, offset, 2, ENC_BIG_ENDIAN);
 			len = tvb_get_ntohs(tvb, offset);
 			offset += 2;
 			if (len > 0) {
-				proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_data, tvb, offset, len, FALSE);
+				proto_tree_add_item(qtable_hdr_tree, hf_rtp_jpeg_qtable_hdr_data, tvb, offset, len, ENC_NA);
 				offset += len;
 			}
 			proto_item_set_len(ti, len + 4);
 		}
 
 		/* The rest of the packet is the JPEG data */
-		proto_tree_add_item( jpeg_tree, hf_rtp_jpeg_payload, tvb, offset, -1, FALSE );
+		proto_tree_add_item( jpeg_tree, hf_rtp_jpeg_payload, tvb, offset, -1, ENC_NA );
 	}
 }
 
@@ -151,113 +151,113 @@ proto_register_jpeg(void)
 
 	static hf_register_info hf[] =
 	{
-		{ &hf_rtp_jpeg_main_hdr, { 
+		{ &hf_rtp_jpeg_main_hdr, {
 			"Main Header",
 			"jpeg.main_hdr",
 			FT_NONE, BASE_NONE, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_ts, { 
+		{ &hf_rtp_jpeg_main_hdr_ts, {
 			"Type Specific",
 			"jpeg.main_hdr.ts",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_offs, { 
+		{ &hf_rtp_jpeg_main_hdr_offs, {
 			"Fragment Offset",
 			"jpeg.main_hdr.offset",
 			FT_UINT24, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_type, { 
+		{ &hf_rtp_jpeg_main_hdr_type, {
 			"Type",
 			"jpeg.main_hdr.type",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_q, { 
+		{ &hf_rtp_jpeg_main_hdr_q, {
 			"Q",
 			"jpeg.main_hdr.q",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_width, { 
+		{ &hf_rtp_jpeg_main_hdr_width, {
 			"Width",
 			"jpeg.main_hdr.width",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_main_hdr_height, { 
+		{ &hf_rtp_jpeg_main_hdr_height, {
 			"Height",
 			"jpeg.main_hdr.height",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_restart_hdr, { 
+		{ &hf_rtp_jpeg_restart_hdr, {
 			"Restart Marker Header",
 			"jpeg.restart_hdr",
 			FT_NONE, BASE_NONE, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_restart_hdr_interval, { 
+		{ &hf_rtp_jpeg_restart_hdr_interval, {
 			"Restart Interval",
 			"jpeg.restart_hdr.interval",
 			FT_UINT16, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_restart_hdr_f, { 
+		{ &hf_rtp_jpeg_restart_hdr_f, {
 			"F",
 			"jpeg.restart_hdr.f",
 			FT_UINT16, BASE_DEC, NULL, 0x8000,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_restart_hdr_l, { 
+		{ &hf_rtp_jpeg_restart_hdr_l, {
 			"L",
 			"jpeg.restart_hdr.l",
 			FT_UINT16, BASE_DEC, NULL, 0x4000,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_restart_hdr_count, { 
+		{ &hf_rtp_jpeg_restart_hdr_count, {
 			"Restart Count",
 			"jpeg.restart_hdr.count",
 			FT_UINT16, BASE_DEC, NULL, 0x3FFF,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_qtable_hdr, { 
+		{ &hf_rtp_jpeg_qtable_hdr, {
 			"Quantization Table Header",
 			"jpeg.qtable_hdr",
 			FT_NONE, BASE_NONE, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_qtable_hdr_mbz, { 
+		{ &hf_rtp_jpeg_qtable_hdr_mbz, {
 			"MBZ",
 			"jpeg.qtable_hdr.mbz",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_qtable_hdr_prec, { 
+		{ &hf_rtp_jpeg_qtable_hdr_prec, {
 			"Precision",
 			"jpeg.qtable_hdr.precision",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_qtable_hdr_length, { 
+		{ &hf_rtp_jpeg_qtable_hdr_length, {
 			"Length",
 			"jpeg.qtable_hdr.length",
 			FT_UINT16, BASE_DEC, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_qtable_hdr_data, { 
+		{ &hf_rtp_jpeg_qtable_hdr_data, {
 			"Quantization Table Data",
 			"jpeg.qtable_hdr.data",
 			FT_BYTES, BASE_NONE, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
-		{ &hf_rtp_jpeg_payload, { 
+		{ &hf_rtp_jpeg_payload, {
 			"Payload",
 			"jpeg.payload",
 			FT_BYTES, BASE_NONE, NULL, 0,
-			NULL, HFILL 
+			NULL, HFILL
 		}},
 	};
 
