@@ -3,7 +3,7 @@
  *
  * Ronnie Sahlberg 2004
  *
- * $Id: packet-kerberos4.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-kerberos4.c 39774 2011-11-09 17:33:18Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -101,7 +101,7 @@ static const value_string m_type_vals[] = {
 static int
 dissect_krb4_string(packet_info *pinfo _U_, int hf_index, proto_tree *tree, tvbuff_t *tvb, int offset)
 {
-	proto_tree_add_item(tree, hf_index, tvb, offset, -1, FALSE);
+	proto_tree_add_item(tree, hf_index, tvb, offset, -1, ENC_ASCII|ENC_NA);
 	while(tvb_get_guint8(tvb, offset)!=0){
 		offset++;
 	}
