@@ -2,9 +2,9 @@
  * Routines for kpasswd packet dissection
  *    Ronnie Sahlberg 2003
  *
- * See RFC 3244 
+ * See RFC 3244
  *
- * $Id: packet-kpasswd.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-kpasswd.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -75,7 +75,7 @@ dissect_kpasswd_ap_req_data(packet_info *pinfo _U_, tvbuff_t *tvb, proto_tree *p
 	proto_tree *tree=NULL;
 
 	if(parent_tree){
-		it=proto_tree_add_item(parent_tree, hf_kpasswd_ap_req_data, tvb, 0, -1, FALSE);
+		it=proto_tree_add_item(parent_tree, hf_kpasswd_ap_req_data, tvb, 0, -1, ENC_NA);
 		tree=proto_item_add_subtree(it, ett_ap_req_data);
 	}
 	dissect_kerberos_main(tvb, pinfo, tree, FALSE, NULL);
@@ -92,9 +92,9 @@ static int dissect_kpasswd_newpassword(proto_tree *tree, tvbuff_t *tvb, int offs
 static ber_old_sequence_t ChangePasswdData_sequence[] = {
 	{ BER_CLASS_CON, 0, 0,
 		dissect_kpasswd_newpassword },
-	{ BER_CLASS_CON, 1, BER_FLAGS_OPTIONAL, 
+	{ BER_CLASS_CON, 1, BER_FLAGS_OPTIONAL,
 		dissect_krb5_cname },
-	{ BER_CLASS_CON, 2, BER_FLAGS_OPTIONAL, 
+	{ BER_CLASS_CON, 2, BER_FLAGS_OPTIONAL,
 		dissect_krb5_realm },
 	{ 0, 0, 0, NULL }
 };
@@ -147,13 +147,13 @@ dissect_kpasswd_user_data_reply(packet_info *pinfo, tvbuff_t *tvb, proto_tree *t
     proto_tree_add_uint(tree, hf_kpasswd_result, tvb, offset, 2, result);
     offset+=2;
     if (check_col(pinfo->cinfo, COL_INFO))
-        col_add_str(pinfo->cinfo, COL_INFO, 
+        col_add_str(pinfo->cinfo, COL_INFO,
                    val_to_str(result, kpasswd_result_types, "Result: %u"));
 
-   
+
     /* optional result string */
     if(tvb_length_remaining(tvb, offset)){
-        proto_tree_add_item(tree, hf_kpasswd_result_string, tvb, offset, tvb_length_remaining(tvb, offset), FALSE); 
+        proto_tree_add_item(tree, hf_kpasswd_result_string, tvb, offset, tvb_length_remaining(tvb, offset), ENC_ASCII|ENC_NA);
 	offset+=tvb_length_remaining(tvb, offset);
     }
 
@@ -174,7 +174,7 @@ dissect_kpasswd_krb_priv_message(packet_info *pinfo _U_, tvbuff_t *tvb, proto_tr
         gint offset;
 
 	if(parent_tree){
-		it=proto_tree_add_item(parent_tree, hf_kpasswd_krb_priv_message, tvb, 0, -1, FALSE);
+		it=proto_tree_add_item(parent_tree, hf_kpasswd_krb_priv_message, tvb, 0, -1, ENC_NA);
 		tree=proto_item_add_subtree(it, ett_krb_priv_message);
 	}
 	if(isrequest){
@@ -231,7 +231,7 @@ dissect_kpasswd_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboo
 	version=tvb_get_ntohs(tvb, offset+2);
 	ap_req_len=tvb_get_ntohs(tvb, offset+4);
 	if(tree){
-		kpasswd_item=proto_tree_add_item(tree, proto_kpasswd, tvb, offset-krb_rm_size, message_len+krb_rm_size, FALSE);
+		kpasswd_item=proto_tree_add_item(tree, proto_kpasswd, tvb, offset-krb_rm_size, message_len+krb_rm_size, ENC_NA);
 		kpasswd_tree=proto_item_add_subtree(kpasswd_item, ett_kpasswd);
                 if (have_rm) {
                     show_krb_recordmark(kpasswd_tree, tvb, offset-krb_rm_size, krb_rm);
