@@ -6,7 +6,7 @@
  * Based on pktgen dissectory by:
  * Francesco Fondelli <francesco dot fondelli, gmail dot com>
  *
- * $Id: packet-lanforge.c 34227 2010-09-23 21:46:31Z morriss $
+ * $Id: packet-lanforge.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -99,52 +99,52 @@ static gboolean dissect_lanforge(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 
         /* create display subtree for the protocol */
 
-        ti = proto_tree_add_item(tree, proto_lanforge, tvb, 0, -1, FALSE);
+        ti = proto_tree_add_item(tree, proto_lanforge, tvb, 0, -1, ENC_NA);
 
         lanforge_tree = proto_item_add_subtree(ti, ett_lanforge);
 
         /* add items to the subtree */
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_crc, tvb, offset, 4, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_crc, tvb, offset, 4, ENC_BIG_ENDIAN);
         offset+=4;
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_magic, tvb, offset, 4, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_magic, tvb, offset, 4, ENC_BIG_ENDIAN);
         offset+=4;
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_src_session, tvb, offset, 2, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_src_session, tvb, offset, 2, ENC_BIG_ENDIAN);
         offset+=2;
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_dst_session, tvb, offset, 2, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_dst_session, tvb, offset, 2, ENC_BIG_ENDIAN);
         offset+=2;
 
         pld_len = tvb_get_ntohs(tvb, offset);
-        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_pld_len_l, tvb, offset, 2, FALSE);
+        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_pld_len_l, tvb, offset, 2, ENC_BIG_ENDIAN);
         PROTO_ITEM_SET_GENERATED(tmp);
         offset+=2;
 
         tmpi = tvb_get_guint8(tvb, offset);
-        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_pld_len_h, tvb, offset, 1, FALSE);
+        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_pld_len_h, tvb, offset, 1, ENC_BIG_ENDIAN);
         PROTO_ITEM_SET_GENERATED(tmp);
         offset+=1;
         pld_len |= (tmpi << 16);
 
         proto_tree_add_uint(lanforge_tree, hf_lanforge_pld_len, tvb, offset-3, 3, pld_len);
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_pld_pattern, tvb, offset, 1, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_pld_pattern, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset+=1;
 
-        proto_tree_add_item(lanforge_tree, hf_lanforge_seq, tvb, offset, 4, FALSE);
+        proto_tree_add_item(lanforge_tree, hf_lanforge_seq, tvb, offset, 4, ENC_BIG_ENDIAN);
         offset+=4;
 
         tss = tvb_get_ntohl(tvb, offset);
         tstamp.secs = tss;
-        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_tx_time_s, tvb, offset, 4, FALSE);
+        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_tx_time_s, tvb, offset, 4, ENC_BIG_ENDIAN);
         PROTO_ITEM_SET_GENERATED(tmp);
         offset+=4;
 
         tss = tvb_get_ntohl(tvb, offset);
         tstamp.nsecs = tss;
-        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_tx_time_ns, tvb, offset, 4, FALSE);
+        tmp = proto_tree_add_item(lanforge_tree, hf_lanforge_tx_time_ns, tvb, offset, 4, ENC_BIG_ENDIAN);
         PROTO_ITEM_SET_GENERATED(tmp);
         offset+=4;
 
@@ -174,7 +174,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_crc,
           {
-              "CRC", "LANforge.CRC",
+              "CRC", "lanforge.CRC",
               FT_UINT32, BASE_HEX, NULL, 0x0,
               "The LANforge CRC number", HFILL
           }
@@ -182,7 +182,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_magic,
           {
-              "Magic number", "LANforge.magic",
+              "Magic number", "lanforge.magic",
               FT_UINT32, BASE_HEX, NULL, 0x0,
               "The LANforge magic number", HFILL
           }
@@ -190,7 +190,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_src_session,
           {
-              "Source session ID", "LANforge.source-session-id",
+              "Source session ID", "lanforge.source-session-id",
               FT_UINT16, BASE_DEC, NULL, 0x0,
               "The LANforge source session ID", HFILL
           }
@@ -198,7 +198,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_dst_session,
           {
-              "Dest session ID", "LANforge.dest-session-id",
+              "Dest session ID", "lanforge.dest-session-id",
               FT_UINT16, BASE_DEC, NULL, 0x0,
               "The LANforge dest session ID", HFILL
           }
@@ -206,7 +206,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_pld_len_l,
           {
-              "Payload Length(L)", "LANforge.pld-len-L",
+              "Payload Length(L)", "lanforge.pld-len-L",
               FT_UINT16, BASE_DEC, NULL, 0x0,
               "The LANforge payload length (low bytes)", HFILL
           }
@@ -214,7 +214,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_pld_len_h,
           {
-              "Payload Length(H)", "LANforge.pld-len-H",
+              "Payload Length(H)", "lanforge.pld-len-H",
               FT_UINT8, BASE_DEC, NULL, 0x0,
               "The LANforge payload length (high byte)", HFILL
           }
@@ -222,7 +222,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_pld_len,
           {
-              "Payload Length", "LANforge.pld-length",
+              "Payload Length", "lanforge.pld-length",
               FT_UINT32, BASE_DEC, NULL, 0x0,
               "The LANforge payload length", HFILL
           }
@@ -230,7 +230,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_pld_pattern,
           {
-              "Payload Pattern", "LANforge.pld-pattern",
+              "Payload Pattern", "lanforge.pld-pattern",
               FT_UINT16, BASE_DEC, NULL, 0x0,
               "The LANforge payload pattern", HFILL
           }
@@ -238,7 +238,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_seq,
           {
-              "Sequence Number", "LANforge.seqno",
+              "Sequence Number", "lanforge.seqno",
               FT_UINT32, BASE_DEC, NULL, 0x0,
               "The LANforge Sequence Number", HFILL
           }
@@ -246,7 +246,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_tx_time_s,
           {
-              "Timestamp Secs", "LANforge.ts-secs",
+              "Timestamp Secs", "lanforge.ts-secs",
               FT_UINT32, BASE_DEC, NULL, 0x0,
               NULL, HFILL
           }
@@ -254,7 +254,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_tx_time_ns,
           {
-              "Timestamp nsecs", "LANforge.ts-nsecs",
+              "Timestamp nsecs", "lanforge.ts-nsecs",
               FT_UINT32, BASE_DEC, NULL, 0x0,
               NULL, HFILL
           }
@@ -262,7 +262,7 @@ void proto_register_lanforge(void)
 
         { &hf_lanforge_timestamp,
           {
-              "Timestamp", "LANforge.timestamp",
+              "Timestamp", "lanforge.timestamp",
               FT_ABSOLUTE_TIME, ABSOLUTE_TIME_LOCAL, NULL, 0x0,
               NULL, HFILL
           }
