@@ -2,7 +2,7 @@
  * Routines for LISP Data Message dissection
  * Copyright 2010, Lorand Jakab <lj@lispmon.net>
  *
- * $Id: packet-lisp-data.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-lisp-data.c 41724 2012-03-21 18:20:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,10 +82,10 @@ static dissector_handle_t data_handle;
 static int
 dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    gint offset = 0;
-    guint8 flags;
-    guint8 ip_ver;
-    tvbuff_t *next_tvb;
+    gint        offset = 0;
+    guint8      flags;
+    guint8      ip_ver;
+    tvbuff_t   *next_tvb;
     proto_item *ti;
     proto_item *tif;
     proto_tree *lisp_data_tree;
@@ -180,7 +180,7 @@ dissect_lisp_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     /* Check if there is stuff left in the buffer, and return if not */
 
     /* Determine if encapsulated packet is IPv4 or IPv6, and call dissector */
-    next_tvb = tvb_new_subset(tvb, LISP_DATA_HEADER_LEN, -1, -1);
+    next_tvb = tvb_new_subset_remaining(tvb, LISP_DATA_HEADER_LEN);
     ip_ver = tvb_get_bits8(next_tvb, 0, 4);
     switch (ip_ver) {
         case 4:
@@ -293,10 +293,10 @@ proto_reg_handoff_lisp_data(void)
  *
  * Local variables:
  * c-basic-offset: 4
- * tab-width: 4
+ * tab-width: 8
  * indent-tabs-mode: nil
  * End:
  *
- * vi: set shiftwidth=4 tabstop=4 expandtab:
- * :indentSize=4:tabSize=4:noTabs=true:
+ * vi: set shiftwidth=4 tabstop=8 expandtab:
+ * :indentSize=4:tabSize=8:noTabs=true:
  */
