@@ -2,7 +2,7 @@
  * Routines for LISP Control Message dissection
  * Copyright 2011, Lorand Jakab <lj@lispmon.net>
  *
- * $Id: packet-lisp.c 41724 2012-03-21 18:20:44Z wmeier $
+ * $Id: packet-lisp.c 44506 2012-08-14 21:39:49Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -266,7 +266,7 @@ dissect_lisp_mapping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree, g
             tir = proto_tree_add_text(lisp_tree, tvb, 0, 12 + INET_ADDRLEN,
                     "EID prefix: %s/%d, TTL: %s, %sAuthoritative, %s",
                     ip_to_str((guint8 *)&prefix_v4), prefix_mask,
-                    (ttl == 0xFFFFFFFF) ? "Unlimited" : g_strdup_printf("%d", ttl),
+                    (ttl == 0xFFFFFFFF) ? "Unlimited" : ep_strdup_printf("%d", ttl),
                     (flags&LISP_MAP_AUTH) ? "" : "Not ", lisp_actions[act]);
             offset += INET_ADDRLEN;
             /* Update the INFO column if there is only one record */
@@ -279,7 +279,7 @@ dissect_lisp_mapping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree, g
             tir = proto_tree_add_text(lisp_tree, tvb, 0, 12 + INET6_ADDRLEN,
                     "EID prefix: %s/%d, TTL: %s, %sAuthoritative, %s",
                     ip6_to_str(&prefix_v6), prefix_mask,
-                    (ttl == 0xFFFFFFFF) ? "Unlimited" : g_strdup_printf("%d", ttl),
+                    (ttl == 0xFFFFFFFF) ? "Unlimited" : ep_strdup_printf("%d", ttl),
                     (flags&LISP_MAP_AUTH) ? "" : "Not ", lisp_actions[act]);
             offset += INET6_ADDRLEN;
             /* Update the INFO column if there is only one record */
