@@ -1,7 +1,7 @@
 /* packet-lwres.c
  * Routines for light weight reslover (lwres, part of BIND9) packet disassembly
  *
- * $Id: packet-lwres.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-lwres.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Copyright (c) 2003 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -28,12 +28,10 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <time.h>
 #include <string.h>
 
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include "packet-dns.h"
