@@ -13,7 +13,7 @@
  * Updated to v1.1b of the Modbus Application Protocol specification
  *   Michael Mann * Copyright 2011
  *
- * $Id: packet-mbtcp.c 39288 2011-10-06 03:35:44Z wmeier $
+ * $Id: packet-mbtcp.c 40371 2012-01-04 13:29:48Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -150,7 +150,7 @@ static const value_string exception_code_vals[] = {
     { ILLEGAL_FUNCTION,    "Illegal function" },
     { ILLEGAL_ADDRESS,     "Illegal data address" },
     { ILLEGAL_VALUE,       "Illegal data value" },
-    { ILLEGAL_RESPONSE,    "Illegal response length" },
+    { SLAVE_FAILURE,       "Slave device failure" },
     { ACKNOWLEDGE,         "Acknowledge" },
     { SLAVE_BUSY,          "Slave device busy" },
     { MEMORY_ERR,          "Memory parity error" },
