@@ -1,5 +1,5 @@
 /* packet-mbtcp.h
- * $Id: packet-mbtcp.h 37565 2011-06-06 09:40:30Z martinm $
+ * $Id: packet-mbtcp.h 40371 2012-01-04 13:29:48Z alagoutte $
  * Routines for Modbus/TCP dissection
  * By Riaan Swart <rswart@cs.sun.ac.za>
  * Copyright 2001, Institute for Applied Computer Science
@@ -11,7 +11,7 @@
  *
  * for information on Modbus/TCP.
  *
- * $Id: packet-mbtcp.h 37565 2011-06-06 09:40:30Z martinm $
+ * $Id: packet-mbtcp.h 40371 2012-01-04 13:29:48Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,7 +58,7 @@
 #define ILLEGAL_FUNCTION	0x01
 #define ILLEGAL_ADDRESS		0x02
 #define ILLEGAL_VALUE		0x03
-#define ILLEGAL_RESPONSE	0x04
+#define SLAVE_FAILURE	0x04
 #define ACKNOWLEDGE		0x05
 #define SLAVE_BUSY		0x06
 #define MEMORY_ERR		0x08
