@@ -1,6 +1,6 @@
 /* Routines for 'Metadata' disassembly
  *
- * $Id: packet-meta.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-meta.c 40835 2012-02-04 12:13:59Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,9 +31,62 @@
 #include <epan/packet.h>
 #include <epan/expert.h>
 
-#include "packet-meta.h"
 #include "packet-sscop.h"
-#include "wiretap/erf.h"
+#include "packet-gsm_a_common.h"
+
+/* schemas */
+#define META_SCHEMA_PCAP        1
+#define META_SCHEMA_DXT         2
+
+/* protocols */
+#define META_PROTO_DXT_ETHERNET        1
+#define META_PROTO_DXT_ETHERNET_CRC   36
+#define META_PROTO_DXT_ATM            41
+#define META_PROTO_DXT_ERF_AAL5       49
+#define META_PROTO_DXT_M3UA           61
+#define META_PROTO_DXT_NBAP           69
+#define META_PROTO_DXT_ATM_AAL2       76
+#define META_PROTO_DXT_FP_HINT        82
+#define META_PROTO_DXT_HDLC          106
+#define META_PROTO_DXT_CONTAINER     127
+#define META_PROTO_DXT_FP_CAPTURE    193
+#define META_PROTO_DXT_UTRAN_CAPSULE 194
+
+/* data types */
+#define META_TYPE_NONE             0
+#define META_TYPE_BOOLEAN          1
+#define META_TYPE_UINT8            2
+#define META_TYPE_UINT16           3
+#define META_TYPE_UINT32           4
+#define META_TYPE_UINT64           5
+#define META_TYPE_STRING          16
+/* item ids */
+#define META_ID_NULL               0
+#define META_ID_DIRECTION          1
+#define META_ID_SIGNALING          2
+#define META_ID_INCOMPLETE         3
+#define META_ID_DECIPHERED         4
+#define META_ID_PAYLOADCUT         5
+#define META_ID_TIMESTAMP64        6
+#define META_ID_AAL5PROTO          7
+#define META_ID_PHYLINKID        256
+#define META_ID_LOCALDEVID       257
+#define META_ID_REMOTEDEVID      258
+#define META_ID_TAPGROUPID       259
+#define META_ID_IMSI            1024
+#define META_ID_IMEI            1025
+#define META_ID_CELL            1026
+#define META_ID_TLLI            1027
+#define META_ID_NSAPI           1028
+#define META_ID_APN             1029
+#define META_ID_RAT             1030
+#define META_ID_CALLING         1031
+#define META_ID_CALLED          1032
+
+enum meta_direction {
+    META_DIR_UP,
+    META_DIR_DOWN
+};
 
 static int proto_meta = -1;
 extern int proto_sscop;
@@ -54,8 +107,10 @@ static int hf_meta_item_direction = -1;
 static int hf_meta_item_ts = -1;
 static int hf_meta_item_phylinkid = -1;
 static int hf_meta_item_nsapi = -1;
-static int hf_meta_item_imsi = -1;
-static int hf_meta_item_imei = -1;
+static int hf_meta_item_imsi_value = -1;
+static int hf_meta_item_imsi_digits = -1;
+static int hf_meta_item_imei_value = -1;
+static int hf_meta_item_imei_digits = -1;
 static int hf_meta_item_signaling = -1;
 static int hf_meta_item_incomplete = -1;
 static int hf_meta_item_deciphered = -1;
@@ -73,6 +128,9 @@ static int hf_meta_item_called = -1;
 /* subtrees */
 static gint ett_meta = -1;
 static gint ett_meta_item = -1;
+static gint ett_meta_cell = -1;
+static gint ett_meta_imsi = -1;
+static gint ett_meta_imei = -1;
 
 /* default handle */
 static dissector_handle_t data_handle;
@@ -83,7 +141,9 @@ static dissector_handle_t nbap_handle;
 static dissector_handle_t ethwithfcs_handle;
 static dissector_handle_t ethwithoutfcs_handle;
 static dissector_handle_t fphint_handle;
-static dissector_handle_t erf_handle;
+static dissector_handle_t mtp2_handle;
+
+static dissector_table_t meta_dissector_table;
 
 static const value_string meta_schema_vals[] = {
     { META_SCHEMA_PCAP,     "PCAP" },
@@ -95,9 +155,13 @@ static const value_string meta_proto_vals[] = {
     { META_PROTO_DXT_ETHERNET,      "Ethernet without FCS" },
     { META_PROTO_DXT_ETHERNET_CRC,  "Ethernet with FCS" },
     { META_PROTO_DXT_FP_HINT,       "FP Hint" },
+    { META_PROTO_DXT_HDLC,          "HDLC" },
     { META_PROTO_DXT_ERF_AAL5,      "ERF AAL5" },
     { META_PROTO_DXT_ATM_AAL2,      "ATM AAL2" },
     { META_PROTO_DXT_ATM,           "ATM" },
+    { META_PROTO_DXT_CONTAINER,     "DXT CONTAINER" },
+    { META_PROTO_DXT_FP_CAPTURE,    "FP CAPTURE" },
+    { META_PROTO_DXT_UTRAN_CAPSULE, "UTRAN CAPSULE" },
     { 0, NULL }
 };
 
@@ -128,7 +192,7 @@ static const value_string meta_id_vals[] = {
     { META_ID_TAPGROUPID,   "Tap Group ID" },
     { META_ID_IMSI,         "IMSI" },
     { META_ID_IMEI,         "IMEI" },
-    { META_ID_CELL,         "Cell" },
+    { META_ID_CELL,         "Mobile Cell" },
     { META_ID_TLLI,         "TLLI" },
     { META_ID_NSAPI,        "NSAPI" },
     { META_ID_APN,          "APN" },
@@ -158,16 +222,16 @@ static const value_string meta_direction_vals[] = {
 
 static guint16 skip_item(proto_tree *meta_tree, tvbuff_t *tvb, packet_info *pinfo _U_, guint16 offs)
 {
-    guint16 id;
-    guint8 type, len, aligned_len, total_len;
+    guint16     id;
+    guint8      type, len, aligned_len, total_len;
     proto_tree *item_tree;
     proto_item *subti;
 
-    id = tvb_get_letohs(tvb, offs); offs += 2;
-    type = tvb_get_guint8(tvb, offs); offs++;
-    len = tvb_get_guint8(tvb, offs); offs++;
+    id          = tvb_get_letohs(tvb, offs); offs += 2;
+    type        = tvb_get_guint8(tvb, offs); offs++;
+    len         = tvb_get_guint8(tvb, offs); offs++;
     aligned_len = (len + 3) & 0xfffc;
-    total_len = aligned_len + 4; /* 4: id, type, len fields */
+    total_len   = aligned_len + 4; /* 4: id, type, len fields */
 
     subti = proto_tree_add_item(meta_tree, hf_meta_item, tvb, offs - 4,
         aligned_len + 4, ENC_NA);
@@ -188,13 +252,13 @@ static guint16 skip_item(proto_tree *meta_tree, tvbuff_t *tvb, packet_info *pinf
 */
 static guint16 evaluate_meta_item_pcap(proto_tree *meta_tree, tvbuff_t *tvb, packet_info *pinfo, guint16 offs)
 {
-    guint16 id;
-    guint8 type, len, aligned_len, total_len;
+    guint16     id;
+    guint8      type, len, aligned_len, total_len;
     proto_tree *item_tree;
     proto_item *subti;
     /* field values */
-    guint8 dir;
-    guint64 ts;
+    guint8      dir;
+    guint64     ts;
 
     id = tvb_get_letohs(tvb, offs); offs += 2;
     type = tvb_get_guint8(tvb, offs); offs++;
@@ -240,16 +304,19 @@ static guint16 evaluate_meta_item_pcap(proto_tree *meta_tree, tvbuff_t *tvb, pac
 */
 static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, packet_info *pinfo, guint16 offs)
 {
-    guint16 id;
-    guint8 type, len, aligned_len, total_len;
-    proto_tree *item_tree;
-    proto_item *subti;
+    guint16             id;
+    guint8              type, len, aligned_len, total_len;
+    proto_tree         *item_tree;
+    proto_item         *subti;
     /* field values */
-    guint8 dir, nsapi, rat, aal5proto, *apn, *calling, *called;
-    guint16 phylinkid, localdevid, remotedevid, tapgroupid;
-    guint32 tlli;
-    guint64 ts, imsi, imei, cell;
+    guint8              dir, nsapi, rat, aal5proto, *apn, *calling, *called;
+    guint16             phylinkid, localdevid, remotedevid, tapgroupid;
+    guint32             tlli;
+    guint64             ts, imsi, imei, cell;
     sscop_payload_info *p_sscop_info;
+    const gchar        *imsi_str, *imei_str;
+    proto_item         *cell_item, *imsi_item, *imei_item;
+    proto_tree         *cell_tree = NULL, *imsi_tree = NULL, *imei_tree = NULL;
 
     id = tvb_get_letohs(tvb, offs); offs += 2;
     type = tvb_get_guint8(tvb, offs); offs++;
@@ -260,7 +327,7 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
     switch (id) {
         case META_ID_DIRECTION:
             dir = tvb_get_guint8(tvb, offs);
-            pinfo->p2p_dir = dir == META_DIR_UP ? P2P_DIR_RECV : P2P_DIR_SENT;
+            pinfo->p2p_dir = (dir == META_DIR_UP ? P2P_DIR_RECV : P2P_DIR_SENT);
             proto_tree_add_uint(meta_tree, hf_meta_item_direction, tvb, offs, 1, dir);
             break;
         case META_ID_TIMESTAMP64:
@@ -279,19 +346,28 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
                 offs, 1, nsapi);
             break;
         case META_ID_IMSI:
-            imsi = tvb_get_letoh64(tvb, offs);
-            proto_tree_add_uint64(meta_tree, hf_meta_item_imsi, tvb,
-                offs, 8, imsi);
+            imsi     = tvb_get_letoh64(tvb, offs);
+            imsi_str = tvb_bcd_dig_to_ep_str(tvb, offs, 8, NULL, FALSE);
+            imsi_item = proto_tree_add_string(meta_tree, hf_meta_item_imsi_digits, tvb,
+                offs, 8, imsi_str);
+            imsi_tree = proto_item_add_subtree(imsi_item, ett_meta_imsi);
+            proto_tree_add_uint64(imsi_tree, hf_meta_item_imsi_value,
+                tvb, offs, 8, imsi);
             break;
         case META_ID_IMEI:
-            imei = tvb_get_letoh64(tvb, offs);
-            proto_tree_add_uint64(meta_tree, hf_meta_item_imei, tvb,
-                offs, 8, imei);
+            imei     = tvb_get_letoh64(tvb, offs);
+            imei_str = tvb_bcd_dig_to_ep_str(tvb, offs, 8, NULL, FALSE);
+            imei_item = proto_tree_add_string(meta_tree, hf_meta_item_imei_digits, tvb,
+                offs, 8, imei_str);
+            imei_tree = proto_item_add_subtree(imei_item, ett_meta_imei);
+            proto_tree_add_uint64(imei_tree, hf_meta_item_imei_value,
+                tvb, offs, 8, imei);
             break;
         case META_ID_APN:
             apn = tvb_get_string(tvb, offs, len);
             proto_tree_add_string(meta_tree, hf_meta_item_apn, tvb,
                 offs, len, apn);
+            g_free(apn);
             break;
         case META_ID_RAT:
             rat = tvb_get_guint8(tvb, offs);
@@ -300,12 +376,15 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
             break;
         case META_ID_CELL:
             cell = tvb_get_ntoh64(tvb, offs);
-            proto_tree_add_uint64(meta_tree, hf_meta_item_cell, tvb,
-                offs, 8, cell);
+            cell_item = proto_tree_add_uint64_format(meta_tree, hf_meta_item_cell,
+                                                     tvb, offs, 8, cell, "Mobile Cell");
+            cell_tree = proto_item_add_subtree(cell_item, ett_meta_cell);
+            de_gmm_rai(tvb, cell_tree, pinfo, offs, 8, NULL, 0);
+            de_cell_id(tvb, cell_tree, pinfo, offs + 6, 2, NULL, 0);
             break;
         case META_ID_SIGNALING:
             proto_tree_add_boolean(meta_tree, hf_meta_item_signaling, tvb,
-                offs, 0, 1);
+                                   offs, 0, 1);
             break;
         case META_ID_INCOMPLETE:
             proto_tree_add_boolean(meta_tree, hf_meta_item_incomplete, tvb,
@@ -316,7 +395,7 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
                 offs, 0, 1);
             break;
         case META_ID_AAL5PROTO:
-            aal5proto = tvb_get_guint8(tvb, offs);
+            aal5proto    = tvb_get_guint8(tvb, offs);
             p_sscop_info = p_get_proto_data(pinfo->fd, proto_sscop);
             if (!p_sscop_info) {
                 p_sscop_info = se_alloc0(sizeof(sscop_payload_info));
@@ -325,6 +404,9 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
             switch (aal5proto) {
                 case META_AAL5PROTO_MTP3:
                     p_sscop_info->subdissector = sscf_nni_handle;
+                    /* hint for ATM dissector that this frame contains SSCOP */
+                    memset(&pinfo->pseudo_header->atm, 0, sizeof(pinfo->pseudo_header->atm));
+                    pinfo->pseudo_header->atm.type = TRAF_SSCOP;
                     break;
                 case META_AAL5PROTO_ALCAP:
                     p_sscop_info->subdissector = alcap_handle;
@@ -369,11 +451,13 @@ static guint16 evaluate_meta_item_dxt(proto_tree *meta_tree, tvbuff_t *tvb, pack
             calling = tvb_get_string(tvb, offs, len);
             proto_tree_add_string(meta_tree, hf_meta_item_calling, tvb,
                 offs, len, calling);
+            g_free(calling);
             break;
         case META_ID_CALLED:
             called = tvb_get_string(tvb, offs, len);
             proto_tree_add_string(meta_tree, hf_meta_item_called, tvb,
                 offs, len, called);
+            g_free(called);
             break;
         default:
             subti = proto_tree_add_item(meta_tree, hf_meta_item, tvb, offs - 4,
@@ -427,20 +511,19 @@ static void
 dissect_meta(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 #define META_HEADER_SIZE 8
-    guint16 schema, proto, hdrlen, reserved;
-    gint32 item_len;
-    guint32 aal2_ext, atm_hdr;
-    proto_tree *meta_tree = NULL;
-    proto_item *ti = NULL;
-    tvbuff_t *next_tvb;
-    dissector_handle_t next_dissector = data_handle;
+    guint16             schema, proto, hdrlen, reserved;
+    gint32              item_len;
+    guint32             aal2_ext, atm_hdr;
+    proto_tree         *meta_tree      = NULL;
+    proto_item         *ti             = NULL;
+    tvbuff_t           *next_tvb       = NULL;
+    dissector_handle_t  next_dissector = NULL;
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "META");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "META");
 
-    schema = tvb_get_letohs(tvb, 0);
-    hdrlen = tvb_get_letohs(tvb, 2);
-    proto = tvb_get_letohs(tvb, 4);
+    schema   = tvb_get_letohs(tvb, 0);
+    hdrlen   = tvb_get_letohs(tvb, 2);
+    proto    = tvb_get_letohs(tvb, 4);
     reserved = tvb_get_letohs(tvb, 6);
 
     if (tree) {
@@ -482,17 +565,17 @@ dissect_meta(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     break;
                 case META_PROTO_DXT_ATM:
                     next_dissector = atm_untrunc_handle;
-                    pinfo->pseudo_header->atm.aal = AAL_OAMCELL;
+                    pinfo->pseudo_header->atm.aal  = AAL_OAMCELL;
                     pinfo->pseudo_header->atm.type = TRAF_UNKNOWN;
                     break;
                 case META_PROTO_DXT_ATM_AAL2:
                     aal2_ext = tvb_get_ntohl(tvb, item_len + META_HEADER_SIZE); item_len += 4;
-                    atm_hdr = tvb_get_ntohl(tvb, item_len + META_HEADER_SIZE); item_len += 4;
+                    atm_hdr  = tvb_get_ntohl(tvb, item_len + META_HEADER_SIZE); item_len += 4;
                     memset(&pinfo->pseudo_header->atm, 0, sizeof(pinfo->pseudo_header->atm));
                     pinfo->pseudo_header->atm.aal = AAL_2;
                     /* pinfo->pseudo_header->atm.flags = pinfo->p2p_dir; */
-                    pinfo->pseudo_header->atm.vpi = ((atm_hdr & 0x0ff00000) >> 20);
-                    pinfo->pseudo_header->atm.vci = ((atm_hdr & 0x000ffff0) >>  4);
+                    pinfo->pseudo_header->atm.vpi  = ((atm_hdr & 0x0ff00000) >> 20);
+                    pinfo->pseudo_header->atm.vci  = ((atm_hdr & 0x000ffff0) >>  4);
                     pinfo->pseudo_header->atm.aal2_cid = aal2_ext & 0x000000ff;
                     pinfo->pseudo_header->atm.type = TRAF_UMTS_FP;
                     next_dissector = atm_untrunc_handle;
@@ -504,10 +587,21 @@ dissect_meta(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     pinfo->pseudo_header->atm.aal = AAL_5;
                     next_dissector = atm_untrunc_handle;
                     break;
+                case META_PROTO_DXT_HDLC:
+                    next_dissector = mtp2_handle;
+                    next_tvb = tvb_new_subset(tvb, item_len + META_HEADER_SIZE,
+                        tvb_reported_length(tvb)-item_len-META_HEADER_SIZE-2, -1);
+                    break;
+                default:
+                    next_dissector =
+                        dissector_get_uint_handle(meta_dissector_table, proto);
             }
     }
-    next_tvb = tvb_new_subset(tvb, item_len + META_HEADER_SIZE, -1, -1);
-    call_dissector(next_dissector, next_tvb, pinfo, tree);
+    if (!next_tvb)
+        next_tvb = tvb_new_subset_remaining(tvb, item_len + META_HEADER_SIZE);
+
+    call_dissector(next_dissector ? next_dissector : data_handle,
+        next_tvb, pinfo, tree);
 }
 
 void
@@ -532,15 +626,17 @@ proto_register_meta(void)
         { &hf_meta_item_ts, { "Timestamp", "meta.timestamp", FT_UINT64, BASE_DEC, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_phylinkid, { "Physical Link ID", "meta.phylinkid", FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_nsapi, { "NSAPI", "meta.nsapi", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL } },
-        { &hf_meta_item_imsi, { "IMSI", "meta.imsi", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
-        { &hf_meta_item_imei, { "IMEI", "meta.imei", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_meta_item_imsi_digits, { "IMSI digits", "meta.imsi_digits", FT_STRINGZ, BASE_NONE, NULL, 0, NULL, HFILL } },
+        { &hf_meta_item_imsi_value, { "IMSI value", "meta.imsi_value", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_meta_item_imei_digits, { "IMEI digits", "meta.imei_digits", FT_STRINGZ, BASE_NONE, NULL, 0, NULL, HFILL } },
+        { &hf_meta_item_imei_value, { "IMEI value", "meta.imei_value", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_signaling, { "Signaling", "meta.signaling", FT_BOOLEAN, BASE_NONE, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_incomplete, { "Incomplete", "meta.incomplete", FT_BOOLEAN, BASE_NONE, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_deciphered, { "Deciphered", "meta.deciphered", FT_BOOLEAN, BASE_NONE, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_apn, { "APN", "meta.apn", FT_STRINGZ, BASE_NONE, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_rat, { "RAT", "meta.rat", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_aal5proto, { "AAL5 Protocol Type", "meta.aal5proto", FT_UINT8, BASE_DEC, VALS(meta_aal5proto_vals), 0, NULL, HFILL } },
-        { &hf_meta_item_cell, { "Cell", "meta.cell", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_meta_item_cell, { "Mobile Cell", "meta.cell", FT_UINT64, BASE_HEX, NULL, 0, NULL, HFILL } },
 
         { &hf_meta_item_localdevid, { "Local Device ID", "meta.localdevid", FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL } },
         { &hf_meta_item_remotedevid, { "Remote Device ID", "meta.remotedevid", FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL } },
@@ -552,7 +648,10 @@ proto_register_meta(void)
 
     static gint *ett[] = {
         &ett_meta,
-        &ett_meta_item
+        &ett_meta_item,
+        &ett_meta_cell,
+        &ett_meta_imsi,
+        &ett_meta_imei
     };
 
     proto_meta = proto_register_protocol("Metadata", "META", "meta");
@@ -560,6 +659,9 @@ proto_register_meta(void)
 
     proto_register_field_array(proto_meta, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    meta_dissector_table = register_dissector_table("meta.proto",
+            "META protocol", FT_UINT16, BASE_DEC);
 }
 
 void
@@ -579,5 +681,5 @@ proto_reg_handoff_meta(void)
     ethwithfcs_handle = find_dissector("eth_withfcs");
     ethwithoutfcs_handle = find_dissector("eth_withoutfcs");
     fphint_handle = find_dissector("fp_hint");
-    erf_handle = find_dissector("erf");
+    mtp2_handle = find_dissector("mtp2");
 }
