@@ -9,7 +9,7 @@
  *          Laboratories, Inc., http://www.PacketCable.com/
  * www.iana.org/assignments/mgcp-localconnectionoptions
  *
- * $Id: packet-mgcp.c 36698 2011-04-18 15:29:25Z stig $
+ * $Id: packet-mgcp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  * Copyright (c) 2004 by Thomas Anders <thomas.anders [AT] blue-cable.de>
@@ -40,9 +40,9 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+
 #include <epan/packet.h>
 #include <epan/emem.h>
-#include <epan/proto.h>
 #include <epan/prefs.h>
 #include <epan/conversation.h>
 #include <epan/tap.h>
@@ -332,7 +332,7 @@ static int dissect_mgcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	gint sectionlen;
 	guint32 num_messages;
-	gint tvb_sectionend,tvb_sectionbegin, tvb_len, tvb_current_len;
+	gint tvb_sectionend,tvb_sectionbegin, tvb_len;
 	proto_tree *mgcp_tree, *ti;
 	const gchar *verb_name = "";
 
@@ -341,7 +341,6 @@ static int dissect_mgcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	tvb_sectionbegin = tvb_sectionend;
 	sectionlen = 0;
 	tvb_len = tvb_length(tvb);
-	tvb_current_len  = tvb_len;
 	num_messages = 0;
 	mgcp_tree = NULL;
 	ti = NULL;
@@ -370,7 +369,7 @@ static int dissect_mgcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			if (tree)
 			{
 				/* Create our mgcp subtree */
-				ti = proto_tree_add_item(tree,proto_mgcp,tvb,0,0, FALSE);
+				ti = proto_tree_add_item(tree,proto_mgcp,tvb,0,0, ENC_NA);
 				mgcp_tree = proto_item_add_subtree(ti, ett_mgcp);
 			}
 
@@ -467,7 +466,7 @@ static void dissect_mgcp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 {
 	/* Declare variables */
 	gint sectionlen;
-	gint tvb_sectionend,tvb_sectionbegin, tvb_len, tvb_current_len;
+	gint tvb_sectionend,tvb_sectionbegin, tvb_len;
 	tvbuff_t *next_tvb;
 	const gchar *verb_name = "";
 
@@ -500,7 +499,6 @@ static void dissect_mgcp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 	tvb_sectionbegin = tvb_sectionend;
 	sectionlen = 0;
 	tvb_len = tvb_length(tvb);
-	tvb_current_len  = tvb_len;
 
 	/*
 	 * Check to see whether we're really dealing with MGCP by looking
@@ -511,7 +509,6 @@ static void dissect_mgcp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 	{
 		/* dissect first line */
 		tvb_sectionbegin = 0;
-		tvb_current_len = tvb_len;
 		tvb_sectionend = tvb_sectionbegin;
 		sectionlen = tvb_find_line_end(tvb,0,-1,&tvb_sectionend,FALSE);
 		if (sectionlen > 0)
@@ -1773,19 +1770,18 @@ static void dissect_mgcp_firstline(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 static void dissect_mgcp_params(tvbuff_t *tvb, proto_tree *tree)
 {
 	int linelen, tokenlen, *my_param;
-	gint tvb_lineend,tvb_current_len, tvb_linebegin,tvb_len,old_lineend;
+	gint tvb_lineend, tvb_linebegin, tvb_len, old_lineend;
 	gint tvb_tokenbegin;
 	proto_tree *mgcp_param_ti, *mgcp_param_tree;
 
 	tvb_len = tvb_length(tvb);
 	tvb_linebegin = 0;
-	tvb_current_len = tvb_length_remaining(tvb,tvb_linebegin);
 	tvb_lineend = tvb_linebegin;
 
 	if (tree)
 	{
 		mgcp_param_ti = proto_tree_add_item(tree, hf_mgcp_params, tvb,
-		                                    tvb_linebegin, tvb_len, FALSE);
+		                                    tvb_linebegin, tvb_len, ENC_NA);
 		proto_item_set_text(mgcp_param_ti, "Parameters");
 		mgcp_param_tree = proto_item_add_subtree(mgcp_param_ti, ett_mgcp_param);
 
@@ -1847,7 +1843,7 @@ dissect_mgcp_connectionparams(proto_tree *parent_tree, tvbuff_t *tvb, gint offse
 
 	if (parent_tree)
 	{
-		item = proto_tree_add_item(parent_tree, hf_mgcp_param_connectionparam, tvb, offset, param_type_len+param_val_len, FALSE);
+		item = proto_tree_add_item(parent_tree, hf_mgcp_param_connectionparam, tvb, offset, param_type_len+param_val_len, ENC_ASCII|ENC_NA);
 		tree = proto_item_add_subtree(item, ett_mgcp_param_connectionparam);
 	}
 
@@ -1959,7 +1955,7 @@ dissect_mgcp_localconnectionoptions(proto_tree *parent_tree, tvbuff_t *tvb, gint
 
 	if (parent_tree)
 	{
-		item = proto_tree_add_item(parent_tree, hf_mgcp_param_localconnoptions, tvb, offset, param_type_len+param_val_len, FALSE);
+		item = proto_tree_add_item(parent_tree, hf_mgcp_param_localconnoptions, tvb, offset, param_type_len+param_val_len, ENC_ASCII|ENC_NA);
 		tree = proto_item_add_subtree(item, ett_mgcp_param_localconnectionoptions);
 	}
 
