@@ -2,7 +2,7 @@
  * Routines for analyzing Cisco FabricPath MiM packets
  * Copyright 2011, Leonard Tracy <letracy@cisco.com>
  *
- * $Id: packet-mim.c 40585 2012-01-19 17:42:28Z wmeier $
+ * $Id: packet-mim.c 42296 2012-04-27 18:31:19Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -380,7 +380,7 @@ proto_reg_handoff_fabricpath(void)
   /*
     dissector_handle_t fp_handle;
     fp_handle = new_create_dissector_handle(dissect_fp, proto_fp);
-    dissector_add("ethertype", ETHERTYPE_DCE, fp_handle);
+    dissector_add_uint("ethertype", ETHERTYPE_DCE, fp_handle);
   */
   static gboolean prefs_initialized = FALSE;
 
