@@ -1,6 +1,6 @@
 /* packet-mime-encap.c
  *
- * $Id: packet-mime-encap.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-mime-encap.c 40308 2011-12-28 15:01:17Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,21 +25,14 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/expert.h>
-#include <epan/prefs.h>
-#include <epan/uat.h>
-#include <epan/emem.h>
 
 static int proto_mime_encap = -1;
 
 static heur_dissector_list_t heur_subdissector_list;
 static dissector_handle_t data_handle;
 
-/* XXX, orginal version was using composite tvb, sorry I can't force it to work */
 static GString *whole_file;
 
 static void
