@@ -5,7 +5,7 @@
  * Copyright 2009, Ohuchi Munenori <ohuchi_at_iij.ad.jp>
  * Copyright 2010, Yi Ren          <yi_ren1@agilent.com>
  *
- * $Id: packet-mip.c 41177 2012-02-24 14:40:31Z etxrab $
+ * $Id: packet-mip.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,10 +30,7 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
 #include <glib.h>
-#include <time.h>
 
 #include <epan/packet.h>
 #include <epan/sminmpec.h>
@@ -263,7 +260,6 @@ static const value_string mip_ext_types[]= {
   {128,                 "Deprecated (2001 Aug 31)"},
   {129,                 "SKIP Firewall Traversal Extension"},                  /*[RFC2356]*/
   {130,                 "Encapsulating Delivery Style Extension"},             /*[RFC3024]*/
-  {131,                 "Mobile Node NAI"},                                    /*[RFC2794]*/
   {MN_NAI_EXT,          "Mobile Node NAI Extension"},
   {MF_CHALLENGE_EXT,    "MN-FA Challenge Extension"},
   {OLD_NVSE_EXT,        "Normal Vendor/Organization Specific Extension"},
