@@ -1,7 +1,7 @@
 /* packet-mndp.c
  * Routines for the disassembly of the Mikrotik Neighbor Discovery Protocol
  *
- * $Id: packet-mndp.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-mndp.c 43219 2012-06-11 23:22:50Z gerald $
  *
  * Copyright 2011 Joerg Mayer (see AUTHORS file)
  *
@@ -340,7 +340,7 @@ proto_register_mndp(void)
 				0x0, NULL, HFILL }},
 
 		{ &hf_mndp_unpack,
-		{ "Unpack", "mndp.unpack", FT_UINT8, BASE_NONE, VALS(mndp_unpack_vals),
+		{ "Unpack", "mndp.unpack", FT_UINT8, BASE_DEC, VALS(mndp_unpack_vals),
 				0x0, NULL, HFILL }},
 
 		{ &hf_mndp_ipv6address,
