@@ -3,7 +3,7 @@
  * Copyright 2010, Alexis La Goutte <alexis.lagoutte at gmail dot com>
  * BSON dissection added 2011, Thomas Buchanan <tom at thomasbuchanan dot com>
  *
- * $Id: packet-mongo.c 39499 2011-10-20 20:45:34Z alagoutte $
+ * $Id: packet-mongo.c 44342 2012-08-08 15:56:25Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -239,8 +239,12 @@ dissect_fullcollectionname(tvbuff_t *tvb, guint offset, proto_tree *tree)
   return fcn_length;
 }
 
+/* http://docs.mongodb.org/manual/reference/limits/ */
+/* http://www.mongodb.org/display/DOCS/Documents */
+#define BSON_MAX_NESTING 100
+#define BSON_MAX_DOC_SIZE (16 * 1000 * 1000)
 static int
-dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mongo_doc)
+dissect_bson_document(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree, int hf_mongo_doc, int nest_level)
 {
   gint32 document_length;
   guint final_offset;
@@ -248,6 +252,27 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
   proto_tree *doc_tree, *elements_tree, *element_sub_tree, *objectid_sub_tree, *js_code_sub_tree, *js_scope_sub_tree;
 
   document_length = tvb_get_letohl(tvb, offset);
+
+  ti = proto_tree_add_item(tree, hf_mongo_doc, tvb, offset, document_length, ENC_NA);
+  doc_tree = proto_item_add_subtree(ti, ett_mongo_doc);
+
+  proto_tree_add_item(doc_tree, hf_mongo_document_length, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+
+  if (nest_level > BSON_MAX_NESTING) {
+      expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR, "BSON document recursion exceeds %u", BSON_MAX_NESTING);
+      THROW(ReportedBoundsError);
+  }
+
+  if (document_length < 5) {
+      expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR, "BSON document length too short: %u", document_length);
+      THROW(ReportedBoundsError);
+  }
+
+  if (document_length > BSON_MAX_DOC_SIZE) {
+      expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR, "BSON document length too long: %u", document_length);
+      THROW(ReportedBoundsError);
+  }
+
   if (document_length == 5) {
     /* document with length 5 is an empty document */
     /* don't display the element subtree */
@@ -255,11 +280,6 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
     return document_length;
   }
 
-  ti = proto_tree_add_item(tree, hf_mongo_doc, tvb, offset, document_length, ENC_NA);
-  doc_tree = proto_item_add_subtree(ti, ett_mongo_doc);
-
-  proto_tree_add_item(doc_tree, hf_mongo_document_length, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-
   final_offset = offset + document_length;
   offset += 4;
 
@@ -275,13 +295,13 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
 
     e_type = tvb_get_guint8(tvb, offset);
     tvb_get_ephemeral_stringz(tvb, offset+1, &str_len);
-    
+
     element = proto_tree_add_item(elements_tree, hf_mongo_element_name, tvb, offset+1, str_len-1, ENC_UTF_8|ENC_NA);
     element_sub_tree = proto_item_add_subtree(element, ett_mongo_element);
     proto_tree_add_item(element_sub_tree, hf_mongo_element_type, tvb, offset, 1, ENC_LITTLE_ENDIAN);
 
     offset += str_len+1;
-    
+
     switch(e_type) {
       case BSON_ELEMENT_TYPE_DOUBLE:
         proto_tree_add_item(element_sub_tree, hf_mongo_element_value_double, tvb, offset, 8, ENC_LITTLE_ENDIAN);
@@ -297,7 +317,7 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
         break;
       case BSON_ELEMENT_TYPE_DOC:
       case BSON_ELEMENT_TYPE_ARRAY:
-        offset += dissect_bson_document(tvb, offset, element_sub_tree, hf_mongo_document);
+        offset += dissect_bson_document(tvb, pinfo, offset, element_sub_tree, hf_mongo_document, nest_level+1);
         break;
       case BSON_ELEMENT_TYPE_BINARY:
         e_len = tvb_get_letohl(tvb, offset);
@@ -358,7 +378,7 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
         doc_len = e_len - (str_len + 8);
         js_scope = proto_tree_add_item(element_sub_tree, hf_mongo_element_value_js_scope, tvb, offset, doc_len, ENC_NA);
         js_scope_sub_tree = proto_item_add_subtree(js_scope, ett_mongo_code);
-        offset += dissect_bson_document(tvb, offset, js_scope_sub_tree, hf_mongo_document);
+        offset += dissect_bson_document(tvb, pinfo, offset, js_scope_sub_tree, hf_mongo_document, nest_level+1);
         break;
       case BSON_ELEMENT_TYPE_INT32:
         proto_tree_add_item(element_sub_tree, hf_mongo_element_value_int32, tvb, offset, 4, ENC_LITTLE_ENDIAN);
@@ -380,7 +400,7 @@ dissect_bson_document(tvbuff_t *tvb, guint offset, proto_tree *tree, int hf_mong
   return document_length;
 }
 static int
-dissect_mongo_reply(tvbuff_t *tvb, guint offset, proto_tree *tree)
+dissect_mongo_reply(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree)
 {
   proto_item *ti;
   proto_tree *flags_tree;
@@ -406,7 +426,7 @@ dissect_mongo_reply(tvbuff_t *tvb, guint offset, proto_tree *tree)
 
   for (i=1; i <= number_returned; i++)
   {
-    offset += dissect_bson_document(tvb, offset, tree, hf_mongo_document);
+    offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_document, 1);
   }
   return offset;
 }
@@ -423,7 +443,7 @@ dissect_mongo_msg(tvbuff_t *tvb, guint offset, proto_tree *tree)
 }
 
 static int
-dissect_mongo_update(tvbuff_t *tvb, guint offset, proto_tree *tree)
+dissect_mongo_update(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree)
 {
   proto_item *ti;
   proto_tree *flags_tree;
@@ -439,15 +459,15 @@ dissect_mongo_update(tvbuff_t *tvb, guint offset, proto_tree *tree)
   proto_tree_add_item(flags_tree, hf_mongo_update_flags_multiupdate, tvb, offset, 4, ENC_LITTLE_ENDIAN);
   offset += 4;
 
-  offset += dissect_bson_document(tvb, offset, tree, hf_mongo_selector);
+  offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_selector, 1);
 
-  offset += dissect_bson_document(tvb, offset, tree, hf_mongo_update);
+  offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_update, 1);
 
   return offset;
 }
 
 static int
-dissect_mongo_insert(tvbuff_t *tvb, guint offset, proto_tree *tree)
+dissect_mongo_insert(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree)
 {
   proto_item *ti;
   proto_tree *flags_tree;
@@ -460,14 +480,14 @@ dissect_mongo_insert(tvbuff_t *tvb, guint offset, proto_tree *tree)
   offset += dissect_fullcollectionname(tvb, offset, tree);
 
   while(offset < tvb_reported_length(tvb)) {
-    offset += dissect_bson_document(tvb, offset, tree, hf_mongo_document);
+    offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_document, 1);
   }
 
   return offset;
 }
 
 static int
-dissect_mongo_query(tvbuff_t *tvb, guint offset, proto_tree *tree)
+dissect_mongo_query(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree)
 {
   proto_item *ti;
   proto_tree *flags_tree;
@@ -491,10 +511,10 @@ dissect_mongo_query(tvbuff_t *tvb, guint offset, proto_tree *tree)
   proto_tree_add_item(tree, hf_mongo_number_to_return, tvb, offset, 4, ENC_LITTLE_ENDIAN);
   offset +=4;
 
-  offset += dissect_bson_document(tvb, offset, tree, hf_mongo_query);
+  offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_query, 1);
 
   while(offset < tvb_reported_length(tvb)) {
-    offset += dissect_bson_document(tvb, offset, tree, hf_mongo_return_field_selector);
+    offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_return_field_selector, 1);
   }
   return offset;
 }
@@ -518,7 +538,7 @@ dissect_mongo_getmore(tvbuff_t *tvb, guint offset, proto_tree *tree)
 }
 
 static int
-dissect_mongo_delete(tvbuff_t *tvb, guint offset, proto_tree *tree)
+dissect_mongo_delete(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree *tree)
 {
   proto_item *ti;
   proto_tree *flags_tree;
@@ -533,7 +553,7 @@ dissect_mongo_delete(tvbuff_t *tvb, guint offset, proto_tree *tree)
   proto_tree_add_item(flags_tree, hf_mongo_delete_flags_singleremove, tvb, offset, 4, ENC_LITTLE_ENDIAN);
   offset += 4;
 
-  offset += dissect_bson_document(tvb, offset, tree, hf_mongo_selector);
+  offset += dissect_bson_document(tvb, pinfo, offset, tree, hf_mongo_selector, 1);
 
   return offset;
 }
@@ -596,37 +616,37 @@ dissect_mongo_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     switch(opcode){
     case OP_REPLY:
-      offset = dissect_mongo_reply(tvb, offset, mongo_tree);
-    break;
+      offset = dissect_mongo_reply(tvb, pinfo, offset, mongo_tree);
+      break;
     case OP_MSG:
       offset = dissect_mongo_msg(tvb, offset, mongo_tree);
-    break;
+      break;
     case OP_UPDATE:
-      offset = dissect_mongo_update(tvb, offset, mongo_tree);
-    break;
+      offset = dissect_mongo_update(tvb, pinfo, offset, mongo_tree);
+      break;
     case OP_INSERT:
-      offset = dissect_mongo_insert(tvb, offset, mongo_tree);
-    break;
+      offset = dissect_mongo_insert(tvb, pinfo, offset, mongo_tree);
+      break;
     case OP_QUERY:
-      offset = dissect_mongo_query(tvb, offset, mongo_tree);
-    break;
+      offset = dissect_mongo_query(tvb, pinfo, offset, mongo_tree);
+      break;
     case OP_GET_MORE:
       offset = dissect_mongo_getmore(tvb, offset, mongo_tree);
-    break;
+      break;
     case OP_DELETE:
-      offset = dissect_mongo_delete(tvb, offset, mongo_tree);
-    break;
+      offset = dissect_mongo_delete(tvb, pinfo, offset, mongo_tree);
+      break;
     case OP_KILL_CURSORS:
       offset = dissect_mongo_kill_cursors(tvb, offset, mongo_tree);
-    break;
+      break;
     default:
       /* No default Action */
-    break;
+      break;
     }
     if(offset < tvb_reported_length(tvb))
     {
       ti = proto_tree_add_item(mongo_tree, hf_mongo_unknown, tvb, offset, -1, ENC_NA);
-      expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, " Unknown Data (not interpreted)");
+      expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "Unknown Data (not interpreted)");
     }
   }
 
@@ -684,7 +704,8 @@ proto_register_mongo(void)
     { &hf_mongo_fullcollectionname,
       { "fullCollectionName", "mongo.full_collection_name",
       FT_STRINGZ, BASE_NONE, NULL, 0x0,
-      "The full collection name is the concatenation of the database name with the collection name, using a dot for the concatenation", HFILL }
+      "The full collection name is the concatenation of the database name with the"
+        " collection name, using a dot for the concatenation", HFILL }
     },
     { &hf_mongo_database_name,
       { "Database Name", "mongo.database_name",
@@ -709,7 +730,8 @@ proto_register_mongo(void)
     { &hf_mongo_reply_flags_queryfailure,
       { "Query Failure", "mongo.reply.flags.queryfailure",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000002,
-      "Set when query failed. Results consist of one document containing an $err field describing the failure.", HFILL }
+      "Set when query failed. Results consist of one document containing an $err"
+        " field describing the failure.", HFILL }
     },
     { &hf_mongo_reply_flags_sharedconfigstale,
       { "Shared Config Stale", "mongo.reply.flags.sharedconfigstale",
@@ -769,12 +791,14 @@ proto_register_mongo(void)
     { &hf_mongo_update_flags_upsert,
       { "Upsert", "mongo.update.flags.upsert",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000001,
-      "If set, the database will insert the supplied object into the collection if no matching document is found", HFILL }
+      "If set, the database will insert the supplied object into the collection if no"
+        " matching document is found", HFILL }
     },
     { &hf_mongo_update_flags_multiupdate,
       { "Multi Update", "mongo.update.flags.multiupdate",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000002,
-      "If set, the database will update all matching objects in the collection. Otherwise only updates first matching doc.", HFILL }
+      "If set, the database will update all matching objects in the collection."
+        " Otherwise only updates first matching doc.", HFILL }
     },
     { &hf_mongo_selector,
       { "Selector", "mongo.selector",
@@ -794,7 +818,8 @@ proto_register_mongo(void)
     { &hf_mongo_insert_flags_continueonerror,
       { "ContinueOnError", "mongo.insert.flags.continueonerror",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000001,
-      "If set, the database will not stop processing a bulk insert if one fails (eg due to duplicate IDs)", HFILL }
+      "If set, the database will not stop processing a bulk insert if one fails"
+        " (eg due to duplicate IDs)", HFILL }
     },
     { &hf_mongo_query_flags_tailablecursor,
       { "Tailable Cursor", "mongo.query.flags.tailable_cursor",
@@ -814,17 +839,20 @@ proto_register_mongo(void)
     { &hf_mongo_query_flags_nocursortimeout,
       { "No Cursor Timeout", "mongo.query.flags.no_cursor_timeout",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000010,
-      "The server normally times out idle cursors after an inactivity period (10 minutes) to prevent excess memory use. Set this option to prevent that", HFILL }
+      "The server normally times out idle cursors after an inactivity period (10 minutes)"
+        " to prevent excess memory use. Set this option to prevent that", HFILL }
     },
     { &hf_mongo_query_flags_awaitdata,
       { "AwaitData", "mongo.query.flags.awaitdata",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000020,
-      "If we are at the end of the data, block for a while rather than returning no data. After a timeout period, we do return as normal", HFILL }
+      "If we are at the end of the data, block for a while rather than returning no data."
+        " After a timeout period, we do return as normal", HFILL }
     },
     { &hf_mongo_query_flags_exhaust,
       { "Exhaust", "mongo.query.flags.exhaust",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000040,
-      "Stream the data down full blast in multiple more packages, on the assumption that the client will fully read all data queried", HFILL }
+      "Stream the data down full blast in multiple more packages, on the assumption"
+        " that the client will fully read all data queried", HFILL }
     },
     { &hf_mongo_query_flags_partial,
       { "Partial", "mongo.query.flags.partial",
@@ -859,7 +887,8 @@ proto_register_mongo(void)
     { &hf_mongo_delete_flags_singleremove,
       { "Single Remove", "mongo.delete.flags.singleremove",
       FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000001,
-      "If set, the database will remove only the first matching document in the collection. Otherwise all matching documents will be removed", HFILL }
+      "If set, the database will remove only the first matching document in the"
+        " collection. Otherwise all matching documents will be removed", HFILL }
     },
     { &hf_mongo_number_of_cursor_ids,
       { "Number of Cursor IDS", "mongo.number_to_cursor_ids",
@@ -1020,8 +1049,6 @@ proto_reg_handoff_mongo(void)
     mongo_handle = create_dissector_handle(dissect_mongo, proto_mongo);
     initialized = TRUE;
   } else {
-
-
     dissector_delete_uint("tcp.port", currentPort, mongo_handle);
   }
 
