@@ -1,7 +1,7 @@
 /* packet-mount.c
  * Routines for mount dissection
  *
- * $Id: packet-mount.c 48079 2013-03-05 01:11:26Z gerald $
+ * $Id: packet-mount.c 39288 2011-10-06 03:35:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -169,7 +169,7 @@ dissect_mount_dirpath_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		if(civ->request && (civ->proc==1)){
 			const gchar *host;
 			unsigned char *name;
-			guint32 len;
+			int len;
 			unsigned char *ptr;
 
 			host=ip_to_str(pinfo->dst.data);
@@ -224,7 +224,7 @@ dissect_mountlist(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree
 
 	if (tree) {
 		lock_item = proto_tree_add_item(tree, hf_mount_mountlist, tvb,
-					offset, -1, FALSE);
+					offset, -1, ENC_NA);
 		if (lock_item)
 			lock_tree = proto_item_add_subtree(lock_item, ett_mount_mountlist);
 	}
@@ -302,7 +302,7 @@ dissect_exportlist(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tr
 	group_names_len=0;
 	if (tree) {
 		exportlist_item = proto_tree_add_item(tree, hf_mount_exportlist, tvb,
-					offset, -1, FALSE);
+					offset, -1, ENC_NA);
 		if (exportlist_item)
 			exportlist_tree = proto_item_add_subtree(exportlist_item, ett_mount_exportlist);
 	}
@@ -313,7 +313,7 @@ dissect_exportlist(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tr
 
 	if (tree) {
 		groups_item = proto_tree_add_item(exportlist_tree, hf_mount_groups, tvb,
-					offset, -1, FALSE);
+					offset, -1, ENC_NA);
 		if (groups_item)
 			groups_tree = proto_item_add_subtree(groups_item, ett_mount_groups);
 	}
@@ -493,7 +493,7 @@ dissect_mount_pathconf_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 
 	if (tree) {
 		lock_item = proto_tree_add_item(tree, hf_mount_pathconf_mask, tvb,
-					offset+2, 2, FALSE);
+					offset+2, 2, ENC_BIG_ENDIAN);
 
 		lock_tree = proto_item_add_subtree(lock_item, ett_mount_pathconf_mask);
 		proto_tree_add_boolean(lock_tree, hf_mount_pathconf_error_all, tvb,
@@ -589,7 +589,7 @@ dissect_sgi_exportlist(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_
 
 	if (tree) {
 		exportlist_item = proto_tree_add_item(tree, hf_mount_exportlist,
-					tvb, offset, -1, FALSE);
+					tvb, offset, -1, ENC_NA);
 		if (exportlist_item)
 			exportlist_tree = proto_item_add_subtree(exportlist_item,
 						ett_mount_exportlist);
@@ -718,7 +718,7 @@ dissect_mount_statvfs_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, p
 
 	if (tree) {
 		flag_item = proto_tree_add_item(tree, hf_mount_statvfs_flag,
-				tvb, offset, 4, FALSE);
+				tvb, offset, 4, ENC_BIG_ENDIAN);
 		if (flag_item) {
 			flag_tree = proto_item_add_subtree(flag_item,
 					ett_mount_statvfs_flag);
