@@ -3,7 +3,7 @@
  * Routines for MPEG4 dissection
  * Copyright 2007-2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-mp4ves.c 39539 2011-10-24 19:57:53Z wmeier $
+ * $Id: packet-mp4ves.c 42720 2012-05-19 19:05:36Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -361,7 +361,6 @@ dissect_mp4ves_visual_object_type(tvbuff_t *tvb, packet_info *pinfo _U_, proto_t
  */
 
 static const value_string mp4ves_aspect_ratio_info_vals[] = {
-	{ 0x0,	"reserved" },
 	{ 0x0,	"Forbidden" },
 	{ 0x1,	"1:1 (Square)" },
 	{ 0x2,	"12:11 (625-type for 4:3 picture)" },
@@ -903,7 +902,7 @@ proto_register_mp4ves(void)
 		},
 		{ &hf_mp4ves_start_code,
 		  { "Start code",		"mp4ves.start_code",
-		    FT_UINT8, BASE_RANGE_STRING|BASE_HEX, RVALS(&mp4ves_startcode_vals), 0x0,
+		    FT_UINT8, BASE_RANGE_STRING|BASE_HEX, RVALS(mp4ves_startcode_vals), 0x0,
 		    NULL, HFILL }
 		},
 		{ &hf_mp4ves_vop_coding_type,
