@@ -2,7 +2,7 @@
  *
  * Routines for RFC 2250 MPEG-1 dissection
  *
- * $Id: packet-mpeg1.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-mpeg1.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2001,
  * Francisco Javier Cabello Torres, <fjcabello@vtools.es>
@@ -152,7 +152,7 @@ dissect_mpeg1( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 
 	if ( tree )
 	  {
-	    ti = proto_tree_add_item( tree, proto_mpg, tvb, offset, -1, FALSE );
+	    ti = proto_tree_add_item( tree, proto_mpg, tvb, offset, -1, ENC_NA );
 	    mpg_tree = proto_item_add_subtree( ti, ett_mpg );
 
 	    proto_tree_add_uint( mpg_tree, hf_rtp_mpg_mbz, tvb, offset, 1, mpg_mbz );
@@ -175,7 +175,7 @@ dissect_mpeg1( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	    offset += 1;
 
 	    /* The rest of the packet is the MPEG-1 stream */
-	    proto_tree_add_item( mpg_tree, hf_rtp_mpg_data, tvb, offset, -1, FALSE );
+	    proto_tree_add_item( mpg_tree, hf_rtp_mpg_data, tvb, offset, -1, ENC_NA );
 
 	  }
 }
