@@ -24,7 +24,10 @@
  *     - Identification of BFD CC, BFD CV and ON-Demand CV ACH types as per RFC 6428, RFC 6426
  *       respectively and the corresponding decoding of messages
  *
- * $Id: packet-mpls.c 41828 2012-03-29 18:08:16Z alagoutte $
+ * (c) Copyright 2012, Aditya Ambadkar and Diana Chris <arambadk,dvchris@ncsu.edu>
+ *   -  Added preference to select BOS label as flowlabel as per RFC 6391
+ *
+ * $Id: packet-mpls.c 42894 2012-05-29 07:45:40Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -87,16 +90,6 @@ const value_string special_labels[] = {
     {0, NULL }
 };
 
-/* MPLS filter values */
-enum mpls_filter_keys {
-    /* MPLS encap properties */
-    MPLSF_LABEL,
-    MPLSF_EXP,
-    MPLSF_BOTTOM_OF_STACK,
-    MPLSF_TTL,
-    MPLSF_MAX
-};
-
 static dissector_handle_t dissector_data;
 static dissector_handle_t dissector_ipv6;
 static dissector_handle_t dissector_ip;
@@ -221,7 +214,14 @@ static enum_val_t mpls_default_payload_defs[] = {
     }
 };
 
-static int mpls_filter[MPLSF_MAX];
+/* For RFC6391 - Flow aware transport of pseudowire over a mpls PSN*/
+static gboolean mpls_bos_flowlabel = FALSE;
+
+static int hf_mpls_label;
+static int hf_mpls_label_special;
+static int hf_mpls_exp;
+static int hf_mpls_bos;
+static int hf_mpls_ttl;
 
 static gint mpls_default_payload = 0;
 
@@ -544,6 +544,8 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item *ti;
     tvbuff_t *next_tvb;
     struct mplsinfo mplsinfo;
+    int found = 0;
+    guint8 first_nibble;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "MPLS");
 
@@ -554,8 +556,11 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         decode_mpls_label(tvb, offset, &label, &exp, &bos, &ttl);
 
-        /* FF: export (last shim in stack) info to subdissectors */
-        mplsinfo.label = label;
+        /*
+         * FF: export (last shim in stack) info to subdissectors and
+         * update pinfo
+         */
+        mplsinfo.label = pinfo->mpls_label = label;
         mplsinfo.exp = exp;
         mplsinfo.bos = bos;
         mplsinfo.ttl = ttl;
@@ -566,29 +571,31 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             ti = proto_tree_add_item(tree, proto_mpls, tvb, offset, 4, ENC_NA);
             mpls_tree = proto_item_add_subtree(ti, ett_mpls);
 
-            proto_item_append_text(ti, ", Label: %u", label);
-            if (label <= LABEL_MAX_RESERVED){
-                proto_tree_add_uint_format(mpls_tree, mpls_filter[MPLSF_LABEL], tvb,
-                                    offset, 3, label, "MPLS Label: %u (%s)",
-                                    label, val_to_str(label, special_labels,
-                                                      "Reserved - Unknown"));
-                proto_item_append_text(ti, " (%s)", val_to_str(label, special_labels,
-                                        "Reserved - Unknown"));
+            if (mpls_bos_flowlabel) {
+                proto_item_append_text(ti, ", Label: %u (Flow Label)", label);
             } else {
-                proto_tree_add_uint_format(mpls_tree, mpls_filter[MPLSF_LABEL], tvb,
-                                    offset, 3, label, "MPLS Label: %u", label);
+                proto_item_append_text(ti, ", Label: %u", label);
+            }
+            if (label <= LABEL_MAX_RESERVED){
+                proto_tree_add_item(mpls_tree, hf_mpls_label_special, tvb,
+                                    offset, 4, ENC_BIG_ENDIAN);
+                proto_item_append_text(ti, " (%s)", val_to_str(label, 
+                                    special_labels, "Reserved - Unknown"));
+            } else {
+                proto_tree_add_item(mpls_tree, hf_mpls_label, tvb, offset, 4,
+                                    ENC_BIG_ENDIAN);
             }
 
-            proto_tree_add_uint(mpls_tree,mpls_filter[MPLSF_EXP], tvb,
-                                offset+2,1, exp);
+            proto_tree_add_item(mpls_tree, hf_mpls_exp, tvb, offset, 4,
+                                ENC_BIG_ENDIAN);
             proto_item_append_text(ti, ", Exp: %u", exp);
 
-            proto_tree_add_uint(mpls_tree,mpls_filter[MPLSF_BOTTOM_OF_STACK], tvb,
-                                offset+2,1, bos);
+            proto_tree_add_item(mpls_tree, hf_mpls_bos , tvb, offset, 4,
+                                ENC_BIG_ENDIAN);
             proto_item_append_text(ti, ", S: %u", bos);
 
-            proto_tree_add_uint(mpls_tree,mpls_filter[MPLSF_TTL], tvb,
-                                offset+3,1, ttl);
+            proto_tree_add_item(mpls_tree, hf_mpls_ttl, tvb, offset, 4,
+                                ENC_BIG_ENDIAN);
             proto_item_append_text(ti, ", TTL: %u", ttl);
         }
 
@@ -606,61 +613,85 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             return;
         }
         else
-        g_strlcpy(PW_ACH,"PW Associated Channel Header",50);
+            g_strlcpy(PW_ACH,"PW Associated Channel Header",50);
 
         if (bos) break;
     }
 
+    first_nibble = (tvb_get_guint8(tvb, offset) >> 4) & 0x0F;
+
     next_tvb = tvb_new_subset_remaining(tvb, offset);
 
-    if ( !dissector_try_uint(mpls_subdissector_table, label, next_tvb, pinfo, tree))
-    {
-        switch ( mpls_default_payload )
-        {
-        case MDD_PW_SATOP:
-               call_dissector(dissector_pw_satop, next_tvb, pinfo, tree);
-               break;
-        case MDD_PW_CESOPSN:
-               call_dissector(dissector_pw_cesopsn, next_tvb, pinfo, tree);
-               break;
-        case MDD_PW_ETH_HEUR:
-               call_dissector(dissector_pw_eth_heuristic, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_FR_DLCI:
-               call_dissector(dissector_pw_fr, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_HDLC_NOCW_FRPORT:
-               call_dissector(dissector_pw_hdlc_nocw_fr, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_HDLC_NOCW_HDLC_PPP:
-               call_dissector(dissector_pw_hdlc_nocw_hdlc_ppp,next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ETH_CW:
-               call_dissector(dissector_pw_eth_cw, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ETH_NOCW:
-               call_dissector(dissector_pw_eth_nocw, next_tvb, pinfo, tree);
-               break;
-        case MDD_ITDM:
-               call_dissector(dissector_itdm, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ATM_N1_CW:
-               call_dissector(dissector_mpls_pw_atm_n1_cw, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ATM_N1_NOCW:
-               call_dissector(dissector_mpls_pw_atm_n1_nocw, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ATM_11_OR_AAL5_PDU:
-               call_dissector(dissector_mpls_pw_atm_11_aal5pdu, next_tvb, pinfo, tree);
-               break;
-        case MDD_MPLS_PW_ATM_AAL5_SDU:
-               call_dissector(dissector_mpls_pw_atm_aal5_sdu, next_tvb, pinfo, tree);
-               break;
-        default: /*fallthrough*/
-        case MDD_MPLS_PW_GENERIC:
-               dissect_pw_mcw(next_tvb, pinfo, tree);
-               break;
-        }
+    /* 1) explicit label-to-dissector binding ? */
+    found = dissector_try_uint(mpls_subdissector_table, label, 
+                               next_tvb, pinfo, tree);
+    if (found)
+        return;
+
+    /* 2) use the 1st nibble logic (see BCP 4928, RFC 4385 and 5586) */
+    if (first_nibble == 4) {
+        call_dissector(dissector_ip, next_tvb, pinfo, tree);
+        return;
+    } else if (first_nibble == 6) {
+        call_dissector(dissector_ipv6, next_tvb, pinfo, tree);
+        return;
+    } else if (first_nibble == 1) {
+        dissect_pw_ach(next_tvb, pinfo, tree);
+        return;
+    } else if (first_nibble == 0) {
+        /* 
+         * FF: it should be a PW with a CW but... it's not
+         * guaranteed (e.g. an Ethernet PW w/o CW and a DA MAC 
+         * address like 00:xx:xx:xx:xx:xx).  So, let the user and
+         * eventually any further PW heuristics decide.
+         */
+    }
+
+    /* 3) use the mpls_default_payload info from user */
+    switch (mpls_default_payload) {
+    case MDD_PW_SATOP:
+        call_dissector(dissector_pw_satop, next_tvb, pinfo, tree);
+        break;
+    case MDD_PW_CESOPSN:
+        call_dissector(dissector_pw_cesopsn, next_tvb, pinfo, tree);
+        break;
+    case MDD_PW_ETH_HEUR:
+        call_dissector(dissector_pw_eth_heuristic, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_FR_DLCI:
+        call_dissector(dissector_pw_fr, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_HDLC_NOCW_FRPORT:
+        call_dissector(dissector_pw_hdlc_nocw_fr, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_HDLC_NOCW_HDLC_PPP:
+        call_dissector(dissector_pw_hdlc_nocw_hdlc_ppp,next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ETH_CW:
+        call_dissector(dissector_pw_eth_cw, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ETH_NOCW:
+        call_dissector(dissector_pw_eth_nocw, next_tvb, pinfo, tree);
+        break;
+    case MDD_ITDM:
+        call_dissector(dissector_itdm, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ATM_N1_CW:
+        call_dissector(dissector_mpls_pw_atm_n1_cw, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ATM_N1_NOCW:
+        call_dissector(dissector_mpls_pw_atm_n1_nocw, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ATM_11_OR_AAL5_PDU:
+        call_dissector(dissector_mpls_pw_atm_11_aal5pdu, next_tvb, pinfo, tree);
+        break;
+    case MDD_MPLS_PW_ATM_AAL5_SDU:
+        call_dissector(dissector_mpls_pw_atm_aal5_sdu, next_tvb, pinfo, tree);
+        break;
+    default: /* fallthrough */
+    case MDD_MPLS_PW_GENERIC:
+        dissect_pw_mcw(next_tvb, pinfo, tree);
+        break;
     }
 }
 
@@ -670,20 +701,24 @@ proto_register_mpls(void)
     static hf_register_info mplsf_info[] = {
 
         /* MPLS header fields */
-        {&mpls_filter[MPLSF_LABEL],
-         {"MPLS Label", "mpls.label", FT_UINT32, BASE_DEC, VALS(special_labels), 0x0,
+        {&hf_mpls_label,
+         {"MPLS Label", "mpls.label", FT_UINT32, BASE_DEC, NULL, 0xFFFFF000,
           NULL, HFILL }},
 
-        {&mpls_filter[MPLSF_EXP],
-         {"MPLS Experimental Bits", "mpls.exp", FT_UINT8, BASE_DEC, NULL, 0x0,
+        {&hf_mpls_label_special,
+         {"MPLS Label", "mpls.label", FT_UINT32, BASE_DEC, VALS(special_labels), 0xFFFFF000,
           NULL, HFILL }},
 
-        {&mpls_filter[MPLSF_BOTTOM_OF_STACK],
-         {"MPLS Bottom Of Label Stack", "mpls.bottom", FT_UINT8, BASE_DEC, NULL, 0x0,
+        {&hf_mpls_exp,
+         {"MPLS Experimental Bits", "mpls.exp", FT_UINT32, BASE_DEC, NULL, 0x00000E00,
           NULL, HFILL }},
 
-        {&mpls_filter[MPLSF_TTL],
-         {"MPLS TTL", "mpls.ttl", FT_UINT8, BASE_DEC, NULL, 0x0,
+        {&hf_mpls_bos,
+         {"MPLS Bottom Of Label Stack", "mpls.bottom", FT_UINT32, BASE_DEC, NULL, 0x00000100,
+          NULL, HFILL }},
+
+        {&hf_mpls_ttl,
+         {"MPLS TTL", "mpls.ttl", FT_UINT32, BASE_DEC, NULL, 0x0000000FF,
           NULL, HFILL }},
 
         /* PW Associated Channel Header fields */
@@ -748,6 +783,13 @@ proto_register_mpls(void)
                                    &mpls_default_payload,
                                    mpls_default_payload_defs,
                                    FALSE );
+
+    /* RFC6391: Flow aware transport of pseudowire*/
+    prefs_register_bool_preference(module_mpls,
+                                    "flowlabel_in_mpls_header",
+                                    "Assume bottom of stack label as Flow label",
+                                    "Lowest label is used to segregate flows inside a pseudowire",
+                                    &mpls_bos_flowlabel);
     }
 
 void
