@@ -5,8 +5,10 @@
  *
  * (c) Copyright 2006, _FF_ Francesco Fondelli <francesco.fondelli@gmail.com>  
  *                     added MPLS OAM support, ITU-T Y.1711
+ * (c) Copyright 2011, Shobhank Sharma <ssharma5@ncsu.edu>
+ *                     added MPLS Generic Associated Channel as per RFC 5586
  *
- * $Id: packet-mpls.h 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-mpls.h 41486 2012-03-11 19:05:32Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,8 +29,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef __PACKET_MPLS_H_
-#define __PACKET_MPLS_H__
+#ifndef PACKET_MPLS_H
+#define PACKET_MPLS_H
 
 /* Special labels in MPLS */
 enum {
@@ -36,8 +38,21 @@ enum {
     LABEL_ROUTER_ALERT,
     LABEL_IP6_EXPLICIT_NULL,
     LABEL_IMPLICIT_NULL,
+    LABEL_GACH = 13, /* aka GAL */
     LABEL_OAM_ALERT = 14,
-    LABEL_MAX_RESERVED = 15
+    LABEL_MAX_RESERVED = 15,
+    LABEL_INVALID = 0xffffffff  
+};
+
+/*
+ * FF: private data passed from the MPLS dissector to subdissectors 
+ * (pinfo->private_data).
+ */
+struct mplsinfo {
+    guint32 label; /* last mpls label in label stack */
+    guint8 exp;    /* former EXP bits of last mpls shim in stack */
+    guint8 bos;    /* BOS bit of last mpls shim in stack */
+    guint8 ttl;    /* TTL bits of last mpls shim in stack */
 };
 
 extern const value_string special_labels[];
@@ -45,4 +60,8 @@ extern void decode_mpls_label(tvbuff_t *tvb, int offset,
                               guint32 *label, guint8 *exp,
                               guint8 *bos, guint8 *ttl);
 
+extern gboolean dissect_try_cw_first_nibble(tvbuff_t *tvb, packet_info *pinfo, 
+                                            proto_tree *tree );
+void dissect_mpls_echo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+
 #endif
