@@ -6,7 +6,7 @@
  * Based on the code from packet-mmrp.c (MMRP) from
  * Markus Seehofer <mseehofe@nt.hirschmann.de> Copyright 2001
  *
- * $Id: packet-mrp-msrp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-mrp-msrp.c 39539 2011-10-24 19:57:53Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -167,6 +167,9 @@ static const value_string failure_vals[] = {
     { 14, "MaxFrameSize (35.2.2.8.4(a)) is too large for media" },
     { 15, "msrpMaxFanInPorts (35.2.1.4(f)) limit has been reached" },
     { 16, "Changes in FirstValue for a registered StreamID" },
+    { 17, "VLAN is blocked on this egress port (Registration Forbidden)" },
+    { 18, "VLAN tagging is disabled on this egress port (untagged set)" },
+    { 19, "SR class priority mismatch" },
     { 0, NULL }
 };
 
@@ -288,11 +291,11 @@ static void
 dissect_msrp_common1(proto_tree *msg_tree, tvbuff_t *tvb, int msg_offset)
 {
     proto_tree_add_item(msg_tree, hf_msrp_attribute_type, tvb,
-                        MSRP_ATTRIBUTE_TYPE_OFFSET + msg_offset, 1, FALSE);
+                        MSRP_ATTRIBUTE_TYPE_OFFSET + msg_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(msg_tree, hf_msrp_attribute_length, tvb,
-                        MSRP_ATTRIBUTE_LENGTH_OFFSET + msg_offset, 1, FALSE);
+                        MSRP_ATTRIBUTE_LENGTH_OFFSET + msg_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(msg_tree, hf_msrp_attribute_list_length, tvb,
-                        MSRP_ATTRIBUTE_LIST_LENGTH_OFFSET + msg_offset, 2, FALSE);
+                        MSRP_ATTRIBUTE_LIST_LENGTH_OFFSET + msg_offset, 2, ENC_BIG_ENDIAN);
 }
 
 
@@ -306,7 +309,7 @@ static void
 dissect_msrp_common2(proto_tree *vect_attr_tree, tvbuff_t *tvb, int msg_offset)
 {
     proto_tree_add_bitmask(vect_attr_tree, tvb, MSRP_VECTOR_HEADER_OFFSET + msg_offset,
-                           hf_msrp_vector_header, ett_vector_header, vector_header_fields, FALSE);
+                           hf_msrp_vector_header, ett_vector_header, vector_header_fields, ENC_BIG_ENDIAN);
 }
 
 
@@ -326,17 +329,17 @@ dissect_msrp_talker_common(proto_tree *first_value_tree, tvbuff_t *tvb, int msg_
 {
 
     proto_tree_add_item(first_value_tree, hf_msrp_stream_da, tvb,
-                        MSRP_STREAM_DA_OFFSET + msg_offset, 6, FALSE);
+                        MSRP_STREAM_DA_OFFSET + msg_offset, 6, ENC_NA);
     proto_tree_add_item(first_value_tree, hf_msrp_vlan_id, tvb,
-                        MSRP_VLAN_ID_OFFSET + msg_offset, 2, FALSE);
+                        MSRP_VLAN_ID_OFFSET + msg_offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item(first_value_tree, hf_msrp_tspec_max_frame_size, tvb,
-                        MSRP_TSPEC_MAX_FRAME_SIZE_OFFSET + msg_offset, 2, FALSE);
+                        MSRP_TSPEC_MAX_FRAME_SIZE_OFFSET + msg_offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item(first_value_tree, hf_msrp_tspec_max_interval_frames, tvb,
-                        MSRP_TSPEC_MAX_INTERVAL_FRAMES_OFFSET + msg_offset, 2, FALSE);
+                        MSRP_TSPEC_MAX_INTERVAL_FRAMES_OFFSET + msg_offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_bitmask(first_value_tree, tvb, MSRP_PRIORITY_AND_RANK_OFFSET + msg_offset,
-                           hf_msrp_priority_and_rank, ett_priority_and_rank, priority_and_rank_fields, FALSE);
+                           hf_msrp_priority_and_rank, ett_priority_and_rank, priority_and_rank_fields, ENC_BIG_ENDIAN);
     proto_tree_add_item(first_value_tree, hf_msrp_accumulated_latency, tvb,
-                        MSRP_ACCUMULATED_LATENCY_OFFSET + msg_offset, 4, FALSE);
+                        MSRP_ACCUMULATED_LATENCY_OFFSET + msg_offset, 4, ENC_BIG_ENDIAN);
 }
 
 
@@ -351,9 +354,9 @@ dissect_msrp_talker_failed(proto_tree *first_value_tree, tvbuff_t *tvb, int msg_
 {
 
     proto_tree_add_item(first_value_tree, hf_msrp_failure_bridge_id, tvb,
-                        MSRP_FAILURE_BRIDGE_ID_OFFSET + msg_offset, 8, FALSE);
+                        MSRP_FAILURE_BRIDGE_ID_OFFSET + msg_offset, 8, ENC_BIG_ENDIAN);
     proto_tree_add_item(first_value_tree, hf_msrp_failure_code, tvb,
-                        MSRP_FAILURE_CODE_OFFSET + msg_offset, 1, FALSE);
+                        MSRP_FAILURE_CODE_OFFSET + msg_offset, 1, ENC_BIG_ENDIAN);
 }
 
 
@@ -468,10 +471,10 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         int msg_offset;  /* Use when handling multiple messages.  This points to current msg being decoded. */
         int vect_offset; /* Use when handling multiple vector attributes.  This points to the current vector attribute being decoded. */
 
-        ti = proto_tree_add_item(tree, proto_msrp, tvb, 0, -1, FALSE);
+        ti = proto_tree_add_item(tree, proto_msrp, tvb, 0, -1, ENC_NA);
         msrp_tree = proto_item_add_subtree(ti, ett_msrp);
 
-        proto_tree_add_item(msrp_tree, hf_msrp_proto_id, tvb, MSRP_PROTOCOL_VERSION_OFFSET, 1, FALSE);
+        proto_tree_add_item(msrp_tree, hf_msrp_proto_id, tvb, MSRP_PROTOCOL_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
 
         /* MSRP supports multiple MRP Messages per frame.  Handle those Messages in
          * the following while() loop. You will know you are at the end of the list
@@ -496,7 +499,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             msg_length = 1 + 1 + 2 + attribute_list_length;
             msg_ti = proto_tree_add_item(msrp_tree, hf_msrp_message, tvb,
                                          MSRP_MESSAGE_GROUP_OFFSET + msg_offset,
-                                         msg_length, FALSE);
+                                         msg_length, ENC_NA);
             msg_tree = proto_item_add_subtree(msg_ti, ett_msg);
 
             /* Append AttributeType description to the end of the "Message" heading */
@@ -511,7 +514,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
              */
             attr_list_ti = proto_tree_add_item(msg_tree, hf_msrp_attribute_list, tvb,
                                                MSRP_ATTRIBUTE_LIST_GROUP_OFFSET + msg_offset,
-                                               attribute_list_length, FALSE);
+                                               attribute_list_length, ENC_NA);
             attr_list_tree = proto_item_add_subtree(attr_list_ti, ett_attr_list);
 
 
@@ -539,8 +542,8 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
                 vect_attr_ti = proto_tree_add_item(attr_list_tree, hf_msrp_vector_attribute, tvb,
                                                    MSRP_VECTOR_ATTRIBUTE_GROUP_OFFSET + msg_offset + vect_offset,
-                                                   vect_attr_len, FALSE);
- 
+                                                   vect_attr_len, ENC_NA);
+
                 vect_attr_tree = proto_item_add_subtree(vect_attr_ti, ett_vect_attr);
 
                 dissect_msrp_common2(vect_attr_tree, tvb, msg_offset + vect_offset);
@@ -555,16 +558,16 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                      */
                     first_value_ti = proto_tree_add_item(vect_attr_tree, hf_msrp_first_value, tvb,
                                                          MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + vect_offset,
-                                                         attribute_length, FALSE);
+                                                         attribute_length, ENC_NA);
                     first_value_tree = proto_item_add_subtree(first_value_ti, ett_first_value);
 
                     /* Add Domain components to First Value tree */
                     proto_tree_add_item(first_value_tree, hf_msrp_sr_class_id, tvb,
-                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset, 1, FALSE);
+                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset, 1, ENC_BIG_ENDIAN);
                     proto_tree_add_item(first_value_tree, hf_msrp_sr_class_priority, tvb,
-                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + 1, 1, FALSE);
+                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + 1, 1, ENC_BIG_ENDIAN);
                     proto_tree_add_item(first_value_tree, hf_msrp_sr_class_vid, tvb,
-                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + 2, 2, FALSE);
+                                        MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + 2, 2, ENC_BIG_ENDIAN);
 
                     /* Decode three packed events. */
                     offset = dissect_msrp_three_packed_event(vect_attr_tree, tvb,
@@ -585,12 +588,12 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                      */
                     first_value_ti = proto_tree_add_item(vect_attr_tree, hf_msrp_first_value, tvb,
                                                          MSRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + vect_offset,
-                                                         attribute_length, FALSE);
+                                                         attribute_length, ENC_NA);
                     first_value_tree = proto_item_add_subtree(first_value_ti, ett_first_value);
 
                     /* Decode StreamID */
                     proto_tree_add_item(first_value_tree, hf_msrp_stream_id, tvb,
-                                        MSRP_STREAM_ID_OFFSET + msg_offset + vect_offset, 8, FALSE);
+                                        MSRP_STREAM_ID_OFFSET + msg_offset + vect_offset, 8, ENC_BIG_ENDIAN);
 
                     switch ( attribute_type ) {
                     case MSRP_ATTRIBUTE_TYPE_LISTENER:
@@ -620,11 +623,11 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 vect_offset += vect_attr_len; /* Move to next Vector Attribute, if there is one */
             } /* Multiple VectorAttribute while() */
 
-            proto_tree_add_item(attr_list_tree, hf_msrp_end_mark, tvb, offset, 2, FALSE); /* VectorAttribute EndMark */
+            proto_tree_add_item(attr_list_tree, hf_msrp_end_mark, tvb, offset, 2, ENC_BIG_ENDIAN); /* VectorAttribute EndMark */
 
             msg_offset += msg_length; /* Move to next Message, if there is one */
         } /* Multiple Message while() */
-        proto_tree_add_item(msrp_tree, hf_msrp_end_mark, tvb, offset+2, 2, FALSE); /* Message EndMark */
+        proto_tree_add_item(msrp_tree, hf_msrp_end_mark, tvb, offset+2, 2, ENC_BIG_ENDIAN); /* Message EndMark */
     }
 }
 
