@@ -1,7 +1,7 @@
 /* packet-msnip.c   2001 Ronnie Sahlberg <See AUTHORS for email>
  * Routines for IGMP/MSNIP packet disassembly
  *
- * $Id: packet-msnip.c 32410 2010-04-06 21:14:01Z wmeier $
+ * $Id: packet-msnip.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -103,7 +103,7 @@ dissect_msnip_rmr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, in
 		int old_offset = offset;
 
 		item = proto_tree_add_item(parent_tree, hf_groups,
-				tvb, offset, -1, FALSE);
+				tvb, offset, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_groups);
 
 		/* record type */
@@ -182,7 +182,7 @@ dissect_msnip_gm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int
 		int old_offset = offset;
 
 		item = proto_tree_add_item(parent_tree, hf_groups,
-				tvb, offset, -1, FALSE);
+				tvb, offset, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_groups);
 
 		/* multicast group */
@@ -227,7 +227,7 @@ dissect_msnip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int of
 		return offset+tvb_length_remaining(tvb, offset);
 	}
 
-	item = proto_tree_add_item(parent_tree, proto_msnip, tvb, offset, -1, FALSE);
+	item = proto_tree_add_item(parent_tree, proto_msnip, tvb, offset, -1, ENC_NA);
 	tree = proto_item_add_subtree(item, ett_msnip);
 
 
