@@ -2,7 +2,7 @@
  * Routines for BACnet MS/TP datalink dissection
  * Copyright 2008 Steve Karg <skarg@users.sourceforge.net> Alabama
  *
- * $Id: packet-mstp.h 34767 2010-11-04 06:36:33Z jake $
+ * $Id: packet-mstp.h 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,15 +26,6 @@
 #ifndef __MSTP_H__
 #define __MSTP_H__
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <glib.h>
-
-#include <epan/packet.h>
-
-
 /**
  * Returns a value string for the BACnet MS/TP Frame Type.
  * @param val
