@@ -5,7 +5,7 @@
  *
  * Copyright 2001, 2004 Michael Tuexen <tuexen [AT] fh-muenster.de>
  *
- * $Id: packet-mtp2.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-mtp2.c 39153 2011-09-26 17:50:54Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/crc16.h>
+#include <epan/crc16-tvb.h>
 #include <epan/expert.h>
 
 /* Initialize the protocol and registered fields */
@@ -266,8 +266,7 @@ dissect_mtp2_lssu(tvbuff_t *su_tvb, packet_info *pinfo, proto_item *mtp2_tree)
   if ((tvb_get_guint8(su_tvb, LI_OFFSET) & LI_MASK) == 2)
     proto_tree_add_item(mtp2_tree, hf_mtp2_sf_extra, su_tvb, sf_extra_offset, SF_EXTRA_LENGTH, ENC_LITTLE_ENDIAN);
 
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_set_str(pinfo->cinfo, COL_INFO, val_to_str_const(sf, status_field_acro_vals, "Unknown"));
+  col_set_str(pinfo->cinfo, COL_INFO, val_to_str_const(sf, status_field_acro_vals, "Unknown"));
 }
 
 static void
