@@ -3,7 +3,7 @@
  * Copyright 2004, Anders Broman.
  * Copyright 2004, Olivier Biot.
  *
- * $Id: packet-multipart.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-multipart.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -60,15 +60,15 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
 #include <string.h>
-#include <epan/prefs.h>
-#include <glib.h>
 #include <ctype.h>
-#include <epan/base64.h>
-#include <epan/emem.h>
+
+#include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/prefs.h>
+#include <epan/base64.h>
+#include <epan/emem.h>
 
 #include "packet-imf.h"
 
@@ -796,6 +796,9 @@ process_body_part(proto_tree *tree, tvbuff_t *tvb, const guint8 *boundary,
 		return boundary_start + boundary_line_len;
 	}
 
+	g_free(filename);
+	g_free(typename);
+
 	return -1;
 }
 
