@@ -2,7 +2,7 @@
  * Dissects a variant of 3GPP TS 27.010 multiplexing protocol
  * Copyright 2011, Hans-Christoph Schemmel <hans-christoph.schemmel[AT]cinterion.com>
  *
- * $Id: packet-mux27010.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-mux27010.c 41374 2012-03-06 16:58:09Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -248,8 +248,6 @@ static char colDestText[256];
 static char colSourceText[256];
 static char frameTypeText[64];
 
-static char information_field_content[256];
-static char *information_field;
 static char dlci_char[3];
 
 static guint8 i = 0;
@@ -741,7 +739,7 @@ getControlChannelValues(tvbuff_t *tvb, proto_tree *field_tree_ctr){
         if (controlchannel_iei == MUX27010_VALUE_CONTROLCHANNEL_TEST_IEI_MS){
             proto_tree_add_uint_format(field_tree_ctr, hf_mux27010_controlchannelvalue, tvb, offset, 1, controlchannel_value, "IEI coding: MSMUX_VERSION");
         }
-        proto_tree_add_uint_format(field_tree_ctr, hf_mux27010_controlchannelvalue, tvb, offset+1, controlchannel_length_value-1, controlchannel_value, "Value (ASCII): %s", tvb_get_string(tvb, offset+1,controlchannel_length_value-1));
+        proto_tree_add_uint_format(field_tree_ctr, hf_mux27010_controlchannelvalue, tvb, offset+1, controlchannel_length_value-1, controlchannel_value, "Value (ASCII): %s", tvb_get_ephemeral_string(tvb, offset+1,controlchannel_length_value-1));
     }
 
     /*Command pattern for Power saving control (C/R is set to 1)*/
@@ -798,14 +796,17 @@ getControlChannelValues(tvbuff_t *tvb, proto_tree *field_tree_ctr){
 /*Get values information field*/
 static void
 getFrameInformation(tvbuff_t *tvb, proto_tree *field_tree){
+    char  information_field_content[52];
+    char *information_field, *save_information_field_ptr;
 
     /*Get the data from information field as string*/
     information_field = tvb_get_string(tvb,offset,length_info);
+    save_information_field_ptr = information_field;
     tmp = 0;
 
     /*Copy data from buffer to local array information_field_content*/
     /*and delete unneeded signs out of info field -> for info column: CR (0x0d) and LF (0x0a)*/
-    for (i = 0; i<length_info && i<=50; i++) {
+    for (i = 0; i<length_info && i<(sizeof(information_field_content)-1); i++) {
         /*Check every sign in information field for CR and LF*/
         if (*information_field != 0x0a && *information_field != 0x0d){
             /*Copy char to array*/
@@ -826,10 +827,11 @@ getFrameInformation(tvbuff_t *tvb, proto_tree *field_tree){
     g_snprintf(colInfoText,sizeof(colInfoText),"%s %s", colInfoText, information_field_content);
 
     /*Get pointer to begin of buffer again*/
-    information_field = tvb_get_string(tvb,offset,length_info);
+    information_field = save_information_field_ptr;
 
     /*Add info to subtree*/
     proto_tree_add_uint_format(field_tree, hf_mux27010_information, tvb, offset, length_info, controlchannel_type_command, "Information: %s",information_field);
+    g_free(information_field);
 
     /*Increment offset by the length of chars in info field*/
     offset +=length_info;
@@ -841,8 +843,8 @@ getFrameInformation(tvbuff_t *tvb, proto_tree *field_tree){
 static void
 dissect_mux27010(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    proto_item *ti = NULL;
-    proto_item *tf = NULL, *tf_extended_header, *tf_addr, *tf_ctr;
+    proto_item *ti            = NULL;
+    proto_item *tf            = NULL, *tf_extended_header, *tf_addr, *tf_ctr;
     proto_tree *mux27010_tree = NULL;
     proto_tree *field_tree, *field_tree_extended_header, *field_tree_addr, *field_tree_ctr;
 
@@ -1043,11 +1045,11 @@ dissect_mux27010(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 msg_flag  = tvb_get_guint8(tvb, tmpOffset); tmpOffset += 1;
 
                 if (msg_end <= msg_start) {
-		    proto_item *pi;
+                    proto_item *pi;
                     pi = proto_tree_add_text(field_tree, tvb, tmpOffset-3, 2,
                         "Message start and end are illogical, aborting dissection");
                     expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
-		        "Message start and end are illogical");
+                                           "Message start and end are illogical");
                     continue;
                 }
 
@@ -1077,7 +1079,7 @@ dissect_mux27010(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 }
 
                 if (new_tvb) { /* take it all */
-                    next_tvb2 = tvb_new_subset(new_tvb, 1, -1, -1);
+                    next_tvb2 = tvb_new_subset_remaining(new_tvb, 1);
                     call_dissector(ppp_handle, next_tvb2, pinfo, tree);
                 }
 
@@ -1177,7 +1179,7 @@ proto_register_mux27010 (void)
            FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_pos_I,
-         { "End Position I", "mux27010.ext_header.end_byte_I",
+         { "End Position I", "mux27010.ext_header.end_pos_I",
            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_byte_I,
@@ -1205,7 +1207,7 @@ proto_register_mux27010 (void)
            FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_pos_II,
-         { "End Position II", "mux27010.ext_header.end_byte_II",
+         { "End Position II", "mux27010.ext_header.end_pos_II",
            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_byte_II,
@@ -1233,7 +1235,7 @@ proto_register_mux27010 (void)
            FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_pos_III,
-         { "End Position III", "mux27010.ext_header.end_byte_III",
+         { "End Position III", "mux27010.ext_header.end_pos_III",
            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 
         {&hf_mux27010_extended_header_end_byte_III,
