@@ -5,7 +5,7 @@
  *
  * MySQL 4.1+ protocol by Axel Schwenke <axel@mysql.com>
  *
- * $Id: packet-mysql.c 39483 2011-10-20 01:55:04Z morriss $
+ * $Id: packet-mysql.c 39873 2011-11-16 01:56:58Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1447,6 +1447,7 @@ mysql_dissect_response(tvbuff_t *tvb, packet_info *pinfo, int offset,
 	gint response_code;
 	gint strlen;
 	gint server_status = 0;
+	proto_item *ti;
 
 	response_code = tvb_get_guint8(tvb, offset);
 
@@ -1530,8 +1531,8 @@ mysql_dissect_response(tvbuff_t *tvb, packet_info *pinfo, int offset,
 			break;
 
 		default:
-			proto_tree_add_string(tree, hf_mysql_payload, tvb, offset, -1,
-					      "unknown/invalid response");
+			ti = proto_tree_add_item(tree, hf_mysql_payload, tvb, offset, -1, ENC_NA);
+			expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "unknown/invalid response");
 			offset += tvb_reported_length_remaining(tvb, offset);
 			conn_data->state = UNDEFINED;
 		}
