@@ -2,7 +2,7 @@
  * Routines for NASDAQ SOUP 2.0 Protocol dissection
  * Copyright 2007,2008 Didier Gautheron <dgautheron@magic.fr>
  *
- * $Id: packet-nasdaq-soup.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-nasdaq-soup.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,15 +69,15 @@ static range_t *nasdaq_soup_tcp_range = NULL;
 /* Initialize the subtree pointers */
 static gint ett_nasdaq_soup = -1;
 
-static int hf_nasdaq_soup_packet_type = -1; 
-static int hf_nasdaq_soup_message = -1; 
-static int hf_nasdaq_soup_text = -1; 
-static int hf_nasdaq_soup_packet_eol = -1; 
-static int hf_nasdaq_soup_username = -1; 
-static int hf_nasdaq_soup_password = -1; 
-static int hf_nasdaq_soup_session = -1; 
-static int hf_nasdaq_soup_seq_number = -1; 
-static int hf_nasdaq_soup_reject_code = -1; 
+static int hf_nasdaq_soup_packet_type = -1;
+static int hf_nasdaq_soup_message = -1;
+static int hf_nasdaq_soup_text = -1;
+static int hf_nasdaq_soup_packet_eol = -1;
+static int hf_nasdaq_soup_username = -1;
+static int hf_nasdaq_soup_password = -1;
+static int hf_nasdaq_soup_session = -1;
+static int hf_nasdaq_soup_seq_number = -1;
+static int hf_nasdaq_soup_reject_code = -1;
 
 static void
 dissect_nasdaq_soup_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, proto_tree *tree, int offset, int linelen)
@@ -86,23 +86,23 @@ dissect_nasdaq_soup_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent
     tvbuff_t *new_tvb = NULL;
 
     nasdaq_soup_type = tvb_get_guint8(tvb, offset);
-    proto_tree_add_item(tree, hf_nasdaq_soup_packet_type, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_nasdaq_soup_packet_type, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset++;
 
     switch (nasdaq_soup_type) {
     case '+': /* debug msg */
-        proto_tree_add_item(tree, hf_nasdaq_soup_text, tvb, offset, linelen -1, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_text, tvb, offset, linelen -1, ENC_ASCII|ENC_NA);
         offset += linelen -1;
         break;
     case 'A': /* login accept */
-        proto_tree_add_item(tree, hf_nasdaq_soup_session, tvb, offset, 10, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_session, tvb, offset, 10, ENC_ASCII|ENC_NA);
         offset += 10;
 
-        proto_tree_add_item(tree, hf_nasdaq_soup_seq_number, tvb, offset, 10, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_seq_number, tvb, offset, 10, ENC_ASCII|ENC_NA);
         offset += 10;
         break;
     case 'J': /* login reject */
-        proto_tree_add_item(tree, hf_nasdaq_soup_reject_code, tvb, offset, 1, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_reject_code, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset++;
         break;
 
@@ -111,22 +111,22 @@ dissect_nasdaq_soup_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent
         if (linelen > 1 && nasdaq_itch_handle) {
             new_tvb = tvb_new_subset(tvb, offset,linelen -1,linelen -1);
         } else {
-            proto_tree_add_item(tree, hf_nasdaq_soup_message, tvb, offset, linelen -1, FALSE);
+            proto_tree_add_item(tree, hf_nasdaq_soup_message, tvb, offset, linelen -1, ENC_ASCII|ENC_NA);
         }
         offset += linelen -1;
         break;
 
     case 'L': /* login request */
-        proto_tree_add_item(tree, hf_nasdaq_soup_username, tvb, offset, 6, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_username, tvb, offset, 6, ENC_ASCII|ENC_NA);
         offset += 6;
 
-        proto_tree_add_item(tree, hf_nasdaq_soup_password, tvb, offset, 10, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_password, tvb, offset, 10, ENC_ASCII|ENC_NA);
         offset += 10;
 
-        proto_tree_add_item(tree, hf_nasdaq_soup_session, tvb, offset, 10, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_session, tvb, offset, 10, ENC_ASCII|ENC_NA);
         offset += 10;
 
-        proto_tree_add_item(tree, hf_nasdaq_soup_seq_number, tvb, offset, 10, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_seq_number, tvb, offset, 10, ENC_ASCII|ENC_NA);
         offset += 10;
         break;
 
@@ -137,12 +137,12 @@ dissect_nasdaq_soup_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent
         break;
     default:
         /* unknown */
-        proto_tree_add_item(tree, hf_nasdaq_soup_message, tvb, offset, linelen -1, FALSE);
+        proto_tree_add_item(tree, hf_nasdaq_soup_message, tvb, offset, linelen -1, ENC_ASCII|ENC_NA);
         offset += linelen -1;
         break;
     }
 
-    proto_tree_add_item(tree, hf_nasdaq_soup_packet_eol, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_nasdaq_soup_packet_eol, tvb, offset, 1, ENC_ASCII|ENC_NA);
     if (new_tvb) {
         call_dissector(nasdaq_itch_handle, new_tvb, pinfo, parent_tree);
     }
@@ -194,7 +194,7 @@ dissect_nasdaq_soup(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       }
       counter++;
       if (tree) {
-          ti = proto_tree_add_item(tree, proto_nasdaq_soup, tvb, offset, linelen +1, FALSE);
+          ti = proto_tree_add_item(tree, proto_nasdaq_soup, tvb, offset, linelen +1, ENC_NA);
           nasdaq_soup_tree = proto_item_add_subtree(ti, ett_nasdaq_soup);
       }
       dissect_nasdaq_soup_packet(tvb, pinfo, tree, nasdaq_soup_tree, offset, linelen);
@@ -211,7 +211,7 @@ static void range_add_nasdaq_soup_tcp_callback(guint32 port) {
     dissector_add_uint("tcp.port", port, nasdaq_soup_handle);
 }
 
-static void nasdaq_soup_prefs(void) 
+static void nasdaq_soup_prefs(void)
 {
     range_foreach(nasdaq_soup_tcp_range, range_delete_nasdaq_soup_tcp_callback);
     g_free(nasdaq_soup_tcp_range);
@@ -226,7 +226,7 @@ proto_register_nasdaq_soup(void)
 /* Setup list of header fields  See Section 1.6.1 for details*/
     static hf_register_info hf[] = {
 
-    { &hf_nasdaq_soup_packet_type, 
+    { &hf_nasdaq_soup_packet_type,
       { "Packet Type",       "nasdaq-soup.packet_type",
         FT_UINT8, BASE_DEC, VALS(message_types_val), 0x0,
         NULL, HFILL }},
