@@ -2,7 +2,7 @@
  * Routines for 3GPP RTP Multiplex dissection, 3GPP TS 29.414
  * Copyright 2009, ip.access ltd <amp@ipaccess.com>
  *
- * $Id: packet-nb_rtpmux.c 34946 2010-11-18 16:01:39Z etxrab $
+ * $Id: packet-nb_rtpmux.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -105,38 +105,38 @@ dissect_nb_rtpmux(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         length = tvb_get_guint8(tvb, offset+2);
         ti = proto_tree_add_item(tree, proto_nb_rtpmux, tvb, offset,
-            length+5, FALSE);
+            length+5, ENC_NA);
         nb_rtpmux_tree = proto_item_add_subtree(ti, ett_nb_rtpmux);
 
         /* XXX - what if the T bit is set? */
         proto_tree_add_item(nb_rtpmux_tree,
-            hf_nb_rtpmux_compressed, tvb, offset, 1, FALSE);
+            hf_nb_rtpmux_compressed, tvb, offset, 1, ENC_BIG_ENDIAN);
 		tbit = tvb_get_guint8(tvb,offset)>>7;
 		if(tbit == 1){
 			/* 6.4.2.4 Transport Format for multiplexing with RTP header compression */
 			dstport = (tvb_get_ntohs(tvb, offset) & 0x7fff) << 1;
 			proto_tree_add_uint(nb_rtpmux_tree, hf_nb_rtpmux_dstport, tvb, offset, 2, dstport );
 			proto_tree_add_item(nb_rtpmux_tree,
-				hf_nb_rtpmux_length, tvb, offset+2, 1, FALSE);
-            proto_tree_add_item(nb_rtpmux_tree, hf_nb_r_bit, tvb, offset, 1, FALSE);			
+				hf_nb_rtpmux_length, tvb, offset+2, 1, ENC_BIG_ENDIAN);
+            proto_tree_add_item(nb_rtpmux_tree, hf_nb_r_bit, tvb, offset, 1, ENC_BIG_ENDIAN);
 			srcport = (tvb_get_ntohs(tvb, offset+3) & 0x7fff) << 1;
 			proto_tree_add_uint(nb_rtpmux_tree, hf_nb_rtpmux_srcport, tvb, offset+3, 2, srcport );
 			cmp_rtp_item = proto_tree_add_text( nb_rtpmux_tree, tvb, offset+5, 3, "Compressed RTP header" );
 			nb_rtpmux_cmp_rtp_tree = proto_item_add_subtree(cmp_rtp_item, ett_nb_rtpmux_cmp_rtp_hdr);
 			/* Sequence Number (SN) */
-			proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_sequence_no, tvb, offset+5, 1, FALSE);
+			proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_sequence_no, tvb, offset+5, 1, ENC_BIG_ENDIAN);
 			/* Timestamp (TS) */
-			proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_timestamp, tvb, offset+6, 2, FALSE);
+			proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_timestamp, tvb, offset+6, 2, ENC_BIG_ENDIAN);
 			if (length != 0)
-				proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_data,tvb, offset+8, length-3, FALSE);
+				proto_tree_add_item(nb_rtpmux_cmp_rtp_tree, hf_nb_rtpmux_cmp_rtp_data,tvb, offset+8, length-3, ENC_NA);
 
 		}else{
 			/* 6.4.2.3 Transport Format for multiplexing without RTP Header Compression */
 			dstport = (tvb_get_ntohs(tvb, offset) & 0x7fff) << 1;
 			proto_tree_add_uint(nb_rtpmux_tree, hf_nb_rtpmux_dstport, tvb, offset, 2, dstport );
 			proto_tree_add_item(nb_rtpmux_tree,
-				hf_nb_rtpmux_length, tvb, offset+2, 1, FALSE);
-            proto_tree_add_item(nb_rtpmux_tree, hf_nb_r_bit, tvb, offset, 1, FALSE);			
+				hf_nb_rtpmux_length, tvb, offset+2, 1, ENC_BIG_ENDIAN);
+            proto_tree_add_item(nb_rtpmux_tree, hf_nb_r_bit, tvb, offset, 1, ENC_BIG_ENDIAN);
 			srcport = (tvb_get_ntohs(tvb, offset+3) & 0x7fff) << 1;
 			proto_tree_add_uint(nb_rtpmux_tree, hf_nb_rtpmux_srcport, tvb, offset+3, 2, srcport );
 
@@ -156,7 +156,7 @@ dissect_nb_rtpmux(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				else
 				{
 					proto_tree_add_item(nb_rtpmux_tree,
-						hf_nb_rtpmux_data, tvb, offset+5, length, FALSE);
+						hf_nb_rtpmux_data, tvb, offset+5, length, ENC_NA);
 				}
 			}
 		} /* if tbit */
@@ -212,11 +212,11 @@ proto_register_nb_rtpmux(void)
             { "Sequence Number", "nb_rtpmux.cmp_rtp.sequence_no",
              FT_UINT16, BASE_DEC, NULL, 0x00,
             NULL, HFILL }
-       }, 
+       },
        { &hf_nb_rtpmux_cmp_rtp_timestamp,
             { "Timestamp", "nb_rtpmux.cmp_rtp.timestamp",
              FT_UINT16, BASE_DEC, NULL, 0x00,
-            NULL, HFILL } 
+            NULL, HFILL }
        },
        { &hf_nb_rtpmux_cmp_rtp_data,
             { "RTP Data", "nb_rtpmux.cmp_rtp.data",
