@@ -2,7 +2,7 @@
  * Routines for NetBIOS over IPX packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-nbipx.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-nbipx.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -260,7 +260,7 @@ dissect_nbipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_nbipx, tvb, 0,
-		    -1, FALSE);
+		    -1, ENC_NA);
 		nbipx_tree = proto_item_add_subtree(ti, ett_nbipx);
 	}
 
@@ -404,7 +404,7 @@ dissect_nbipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	case NBIPX_DIRECTED_DATAGRAM:
 		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_add_str(pinfo->cinfo, COL_INFO, 
+			col_add_str(pinfo->cinfo, COL_INFO,
 				val_to_str(packet_type, nbipx_data_stream_type_vals, "Unknown"));
 		}
 		dissect_conn_control(tvb, offset, nbipx_tree);
@@ -431,7 +431,7 @@ dissect_nbipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	default:
 		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_add_str(pinfo->cinfo, COL_INFO, 
+			col_add_str(pinfo->cinfo, COL_INFO,
 				val_to_str(packet_type, nbipx_data_stream_type_vals, "Unknown"));
 		}
 
@@ -668,7 +668,7 @@ dissect_nmpi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	char		name[(NETBIOS_NAME_LEN - 1)*4 + 1];
 	int		name_type;
 	char		node_name[(NETBIOS_NAME_LEN - 1)*4 + 1];
-	int		node_name_type = 0;
+	/*int		node_name_type = 0;*/
 	tvbuff_t	*next_tvb;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "NMPI");
@@ -676,7 +676,7 @@ dissect_nmpi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_nmpi, tvb, offset, 68,
-		    FALSE);
+		    ENC_NA);
 		nmpi_tree = proto_item_add_subtree(ti, ett_nmpi);
 
 		add_routers(nmpi_tree, tvb, offset);
@@ -689,7 +689,7 @@ dissect_nmpi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	opcode = tvb_get_guint8(tvb, offset);
 	nmpi_name_type = tvb_get_guint8(tvb, offset+1);
 	name_type = get_netbios_name(tvb, offset+4, name, (NETBIOS_NAME_LEN - 1)*4 + 1);
-	node_name_type = get_netbios_name(tvb, offset+20, node_name, (NETBIOS_NAME_LEN - 1)*4 + 1);
+	/*node_name_type = */get_netbios_name(tvb, offset+20, node_name, (NETBIOS_NAME_LEN - 1)*4 + 1);
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		switch (opcode) {
