@@ -3,7 +3,7 @@
  * Greg Morris <gmorris@novell.com>
  * Copyright (c) Novell, Inc. 2002-2004
  *
- * $Id: packet-ncp-nmas.c 32410 2010-04-06 21:14:01Z wmeier $
+ * $Id: packet-ncp-nmas.c 39288 2011-10-06 03:35:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -206,7 +206,7 @@ nmas_string(tvbuff_t* tvb, int hfinfo, proto_tree *nmas_tree, int offset, gboole
         guint16 c_char;
         guint32 length_remaining = 0;
 
-	buffer=ep_alloc(ITEM_LABEL_LENGTH+1);
+        buffer=ep_alloc(ITEM_LABEL_LENGTH+1);
         if (little) {
             str_length = tvb_get_letohl(tvb, foffset);
         }
@@ -224,18 +224,18 @@ nmas_string(tvbuff_t* tvb, int hfinfo, proto_tree *nmas_tree, int offset, gboole
         }
         if(str_length == 0)
         {
-       	    proto_tree_add_string(nmas_tree, hfinfo, tvb, offset,
+            proto_tree_add_string(nmas_tree, hfinfo, tvb, offset,
                 4, "<Not Specified>");
             return foffset;
         }
-	/*
-	 * XXX - other than the special-casing of null bytes,
-	 * we could just use "proto_tree_add_item()", as for
-	 * FT_STRING, FT_STRINGZ, and FT_UINT_STRING fields,
-	 * the display representation of an item is generated
-	 * using "format_text()", so it handles non-printable
-	 * characters.
-	 */
+        /*
+         * XXX - other than the special-casing of null bytes,
+         * we could just use "proto_tree_add_item()", as for
+         * FT_STRING, FT_STRINGZ, and FT_UINT_STRING fields,
+         * the display representation of an item is generated
+         * using "format_text()", so it handles non-printable
+         * characters.
+         */
         for ( i = 0; i < str_length; i++ )
         {
                 c_char = tvb_get_guint8(tvb, foffset );
@@ -261,8 +261,8 @@ nmas_string(tvbuff_t* tvb, int hfinfo, proto_tree *nmas_tree, int offset, gboole
 
                 if(length_remaining==1)
                 {
-                	i++;
-                	break;
+                        i++;
+                        break;
                 }
         }
         buffer[i] = '\0';
@@ -282,7 +282,7 @@ nmas_string(tvbuff_t* tvb, int hfinfo, proto_tree *nmas_tree, int offset, gboole
 void
 dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp_req_hash_value *request_value)
 {
-    guint8              func, subfunc = 0;
+    guint8              /*func,*/ subfunc;
     guint32             msg_length=0, cur_string_len=0;
     guint32             foffset;
     guint32             subverb=0;
@@ -292,7 +292,7 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
     proto_item          *aitem;
 
     foffset = 6;
-    func = tvb_get_guint8(tvb, foffset);
+    /*func = tvb_get_guint8(tvb, foffset);*/
     foffset += 1;
     subfunc = tvb_get_guint8(tvb, foffset);
     foffset += 1;
@@ -308,25 +308,25 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
     atree = proto_item_add_subtree(aitem, ett_nmas);
     switch (subfunc) {
     case 1:
-        proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
-        proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
         break;
     case 2:
-        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         /* Check for Fragment packet */
         if (tvb_get_letohl(tvb, foffset)!=0xffffffff) {
             break;
         }
         foffset += 4;
         foffset += 4; /* Dont know what this is */
-        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         msg_length = tvb_get_letohl(tvb, foffset);
         foffset += 4;
         foffset += 12;
         msg_length -= 16;
-        proto_tree_add_item(atree, hf_subverb, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_subverb, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         subverb = tvb_get_letohl(tvb, foffset);
         if (request_value) {
             request_value->req_nds_flags=subverb; /* Store the NMAS fragment verb */
@@ -339,13 +339,13 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
         }
         switch (subverb) {
         case 0:             /* Fragmented Ping */
-            proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, TRUE);
+            proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
             foffset += 4;
-            proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, TRUE);
+            proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
             foffset += 4;
             break;
         case 2:             /* Client Put Data */
-            proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, FALSE);
+            proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, ENC_NA);
             foffset += msg_length;
             break;
         case 4:             /* Client Get Data */
@@ -353,13 +353,13 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
             /* No Op */
             break;
         case 8:             /* Login Store Management */
-            proto_tree_add_item(atree, hf_reply_buffer_size, tvb, foffset, 1, TRUE);
+            proto_tree_add_item(atree, hf_reply_buffer_size, tvb, foffset, 1, ENC_LITTLE_ENDIAN);
             foffset += 4;
             msgverb = tvb_get_guint8(tvb, foffset);
             if (request_value) {
                 request_value->nds_request_verb=msgverb; /* Use nds_request_verb for passed subverb */
             }
-            proto_tree_add_item(atree, hf_lsm_verb, tvb, foffset, 1, TRUE);
+            proto_tree_add_item(atree, hf_lsm_verb, tvb, foffset, 1, ENC_LITTLE_ENDIAN);
             foffset += 4;
             if (check_col(pinfo->cinfo, COL_INFO)) {
                 col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
@@ -391,16 +391,16 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
             break;
         case 1242:          /* Message Handler */
             foffset += 4;
-            proto_tree_add_item(atree, hf_msg_version, tvb, foffset, 4, FALSE);
+            proto_tree_add_item(atree, hf_msg_version, tvb, foffset, 4, ENC_BIG_ENDIAN);
             foffset += 4;
-            proto_tree_add_item(atree, hf_session_ident, tvb, foffset, 4, FALSE);
+            proto_tree_add_item(atree, hf_session_ident, tvb, foffset, 4, ENC_BIG_ENDIAN);
             foffset += 4;
             foffset += 3;
             msgverb = tvb_get_guint8(tvb, foffset);
             if (request_value) {
                 request_value->nds_request_verb=msgverb; /* Use nds_request_verb for passed verb */
             }
-            proto_tree_add_item(atree, hf_msg_verb, tvb, foffset, 1, FALSE);
+            proto_tree_add_item(atree, hf_msg_verb, tvb, foffset, 1, ENC_BIG_ENDIAN);
             foffset += 1;
             msg_length -= 12;
             if (check_col(pinfo->cinfo, COL_INFO)) {
@@ -411,15 +411,15 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
             {
             case 1:
                 msg_length = tvb_get_ntohl(tvb, foffset);
-                proto_tree_add_item(atree, hf_length, tvb, foffset, 4, FALSE);
+                proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_BIG_ENDIAN);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_data, tvb, foffset, msg_length, FALSE);
+                proto_tree_add_item(atree, hf_data, tvb, foffset, msg_length, ENC_NA);
                 foffset += msg_length;
                 break;
             case 3:
                 msg_length = tvb_get_ntohl(tvb, foffset);
                 msg_length -= 4;
-                proto_tree_add_item(atree, hf_length, tvb, foffset, 4, FALSE);
+                proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_BIG_ENDIAN);
                 foffset += 4;
                 while (msg_length > 0)
                 {
@@ -450,7 +450,7 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
                 }
                 break;
             case 5:
-                proto_tree_add_item(atree, hf_opaque, tvb, foffset, tvb_reported_length_remaining(tvb, foffset), FALSE);
+                proto_tree_add_item(atree, hf_opaque, tvb, foffset, tvb_reported_length_remaining(tvb, foffset), ENC_NA);
                 foffset += msg_length;
                 break;
             case 7:
@@ -474,7 +474,7 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
 }
 
 void
-dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint8 func _U_, guint8 subfunc, ncp_req_hash_value	*request_value)
+dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint8 func _U_, guint8 subfunc, ncp_req_hash_value *request_value)
 {
     guint32             foffset=0, roffset=0;
     guint32             subverb=0;
@@ -484,6 +484,7 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
     proto_tree          *atree;
     proto_item          *aitem;
     proto_item          *expert_item;
+    const gchar         *str;
 
 
     foffset = 8;
@@ -501,18 +502,18 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
     atree = proto_item_add_subtree(aitem, ett_nmas);
     switch (subfunc) {
     case 1:
-        proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
-        proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
         break;
     case 2:
         proto_tree_add_text(atree, tvb, foffset, -1, "Verb: %s",
                             val_to_str(subverb, nmas_subverb_enum, "Unknown (%u)"));
-        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         msg_length = tvb_get_letohl(tvb, foffset);
         foffset +=4;
-        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         /* Check for a fragment packet */
         if (tvb_get_letohl(tvb, foffset)!=0xffffffff) {
             break;
@@ -526,30 +527,30 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
         {
             switch (subverb) {
             case 0:             /* Fragmented Ping */
-                proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_ping_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
                 break;
             case 2:             /* Client Put Data */
-                proto_tree_add_item(atree, hf_squeue_bytes, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_squeue_bytes, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_cqueue_bytes, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_cqueue_bytes, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
                 break;
             case 4:             /* Client Get Data */
-                proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, TRUE);
+                proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, ENC_NA);
                 foffset += msg_length;
                 break;
             case 6:             /* Client Get User NDS Credentials */
-                proto_tree_add_item(atree, hf_num_creds, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_num_creds, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_cred_type, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_cred_type, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_login_state, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_login_state, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
                 msg_length -= 12;
-                proto_tree_add_item(atree, hf_enc_cred, tvb, foffset, msg_length, TRUE);
+                proto_tree_add_item(atree, hf_enc_cred, tvb, foffset, msg_length, ENC_NA);
                 foffset += msg_length;
                 break;
             case 8:             /* Login Store Management */
@@ -563,7 +564,7 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
                 case 5:
                 case 7:
                 case 9:
-                    proto_tree_add_item(atree, hf_enc_data, tvb, foffset, msg_length, TRUE);
+                    proto_tree_add_item(atree, hf_enc_data, tvb, foffset, msg_length, ENC_NA);
                     foffset += msg_length;
                     break;
                 default:
@@ -571,7 +572,7 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
                 }
                 break;
             case 10:            /* Writable Object Check */
-                proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, TRUE);
+                proto_tree_add_item(atree, hf_nmas_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
                 foffset += 4;
                 break;
             case 1242:          /* Message Handler */
@@ -581,13 +582,13 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
                 {
                 case 1:
                     msg_length = tvb_get_ntohl(tvb, foffset);
-                    proto_tree_add_item(atree, hf_length, tvb, foffset, 4, FALSE);
+                    proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_BIG_ENDIAN);
                     foffset += 4;
-                    proto_tree_add_item(atree, hf_data, tvb, foffset, msg_length, FALSE);
+                    proto_tree_add_item(atree, hf_data, tvb, foffset, msg_length, ENC_NA);
                     foffset += msg_length;
                     break;
                 case 3:
-                    proto_tree_add_item(atree, hf_session_ident, tvb, foffset, 4, FALSE);
+                    proto_tree_add_item(atree, hf_session_ident, tvb, foffset, 4, ENC_BIG_ENDIAN);
                     foffset += 4;
                     break;
                 case 5:
@@ -595,17 +596,16 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
                     break;
                 case 7:
                     encrypt_error = tvb_get_ntohl(tvb, foffset);
-                    if (match_strval(encrypt_error, nmas_errors_enum)!=NULL)
+                    str = match_strval(encrypt_error, nmas_errors_enum);
+                    if (str)
                     {
-                        if (check_col(pinfo->cinfo, COL_INFO)) {
-                           col_add_fstr(pinfo->cinfo, COL_INFO, "R Payload Error - %s", match_strval(encrypt_error, nmas_errors_enum));
-                        }
-                        expert_item = proto_tree_add_item(atree, hf_encrypt_error, tvb, foffset, 4, FALSE);
-                        expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "NMAS Payload Error: %s", match_strval(encrypt_error, nmas_errors_enum));
+                        col_add_fstr(pinfo->cinfo, COL_INFO, "R Payload Error - %s", str);
+                        expert_item = proto_tree_add_item(atree, hf_encrypt_error, tvb, foffset, 4, ENC_BIG_ENDIAN);
+                        expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "NMAS Payload Error: %s", str);
                     }
                     else
                     {
-                        proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, FALSE);
+                        proto_tree_add_item(atree, hf_opaque, tvb, foffset, msg_length, ENC_NA);
                     }
                     foffset += msg_length;
                     break;
@@ -620,19 +620,18 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
                 break;
             }
         }
-        if (match_strval(return_code, nmas_errors_enum)!=NULL)
+        str = match_strval(return_code, nmas_errors_enum);
+        if (str)
         {
-            expert_item = proto_tree_add_item(atree, hf_return_code, tvb, roffset, 4, TRUE);
-            expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "NMAS Error: 0x%08x %s", return_code, match_strval(return_code, nmas_errors_enum));
-            if (check_col(pinfo->cinfo, COL_INFO)) {
-               col_add_fstr(pinfo->cinfo, COL_INFO, "R Error - %s", match_strval(return_code, nmas_errors_enum));
-            }
+            expert_item = proto_tree_add_item(atree, hf_return_code, tvb, roffset, 4, ENC_LITTLE_ENDIAN);
+            expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "NMAS Error: 0x%08x %s", return_code, str);
+            col_add_fstr(pinfo->cinfo, COL_INFO, "R Error - %s", str);
         }
         else
         {
             if (return_code!=0)
             {
-                expert_item = proto_tree_add_item(atree, hf_return_code, tvb, roffset, 4, TRUE);
+                expert_item = proto_tree_add_item(atree, hf_return_code, tvb, roffset, 4, ENC_LITTLE_ENDIAN);
                 expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "NMAS Error: 0x%08x is unknown", return_code);
                 if (check_col(pinfo->cinfo, COL_INFO)) {
                    col_add_fstr(pinfo->cinfo, COL_INFO, "R Unknown NMAS Error - 0x%08x", return_code);
@@ -656,27 +655,27 @@ proto_register_nmas(void)
 {
     static hf_register_info hf_nmas[] = {
         { &hf_func,
-        { "Function",		"nmas.func", FT_UINT8, BASE_HEX, NULL, 0x0,
+        { "Function", "nmas.func", FT_UINT8, BASE_HEX, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_subfunc,
-        { "Subfunction",		"nmas.subfunc", FT_UINT8, BASE_HEX, NULL, 0x0,
+        { "Subfunction", "nmas.subfunc", FT_UINT8, BASE_HEX, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_ping_version,
-        { "Ping Version",		"nmas.ping_version", FT_UINT32, BASE_HEX, NULL, 0x0,
+        { "Ping Version", "nmas.ping_version", FT_UINT32, BASE_HEX, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_ping_flags,
-        { "Flags",		"nmas.ping_flags", FT_UINT32, BASE_HEX, NULL, 0x0,
+        { "Flags", "nmas.ping_flags", FT_UINT32, BASE_HEX, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_frag_handle,
-        { "Fragment Handle",        "nmas.frag_handle", FT_UINT32, BASE_HEX, NULL, 0x0,
+        { "Fragment Handle", "nmas.frag_handle", FT_UINT32, BASE_HEX, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_length,
-        { "Length",        "nmas.length", FT_UINT32, BASE_DEC, NULL, 0x0,
+        { "Length", "nmas.length", FT_UINT32, BASE_DEC, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_subverb,
