@@ -3,7 +3,7 @@
  * Greg Morris <gmorris@novell.com>
  * Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id: packet-ncp-sss.c 33198 2010-06-09 18:12:17Z wmeier $
+ * $Id: packet-ncp-sss.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -171,8 +171,8 @@ process_flags(proto_tree *sss_tree, tvbuff_t *tvb, guint32 foffset)
 {
     gchar                   flags_str[1024];
     const gchar            *sep;
-    proto_item		   *tinew;
-    proto_tree		   *flags_tree;
+    proto_item             *tinew;
+    proto_tree             *flags_tree;
     guint32                 i;
     guint32                 bvalue = 0;
     guint32                 flags = 0;
@@ -293,7 +293,7 @@ process_flags(proto_tree *sss_tree, tvbuff_t *tvb, guint32 foffset)
     }
 
     tinew = proto_tree_add_uint_format(sss_tree, hf_flags, tvb, foffset, 4, flags, "%s 0x%08x", "Flags:", flags);
-	flags_tree = proto_item_add_subtree(tinew, ett_nds);
+    flags_tree = proto_item_add_subtree(tinew, ett_nds);
 
     bvalue = 0x00000001;
 
@@ -304,100 +304,100 @@ process_flags(proto_tree *sss_tree, tvbuff_t *tvb, guint32 foffset)
             switch(bvalue)
             {
                 case 0x00000001:
-                        proto_tree_add_item(flags_tree, hfbit1, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit1, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000002:
-                    proto_tree_add_item(flags_tree, hfbit2, tvb, foffset, 4, FALSE);
+                    proto_tree_add_item(flags_tree, hfbit2, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000004:
-                    proto_tree_add_item(flags_tree, hfbit3, tvb, foffset, 4, FALSE);
+                    proto_tree_add_item(flags_tree, hfbit3, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000008:
-                        proto_tree_add_item(flags_tree, hfbit4, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit4, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000010:
-                        proto_tree_add_item(flags_tree, hfbit5, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit5, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000020:
-                        proto_tree_add_item(flags_tree, hfbit6, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit6, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000040:
-                        proto_tree_add_item(flags_tree, hfbit7, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit7, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000080:
-                        proto_tree_add_item(flags_tree, hfbit8, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit8, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000100:
-                        proto_tree_add_item(flags_tree, hfbit9, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit9, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000200:
-                        proto_tree_add_item(flags_tree, hfbit10, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit10, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000400:
-                        proto_tree_add_item(flags_tree, hfbit11, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit11, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00000800:
-                        proto_tree_add_item(flags_tree, hfbit12, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit12, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00001000:
-                        proto_tree_add_item(flags_tree, hfbit13, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit13, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00002000:
-                        proto_tree_add_item(flags_tree, hfbit14, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit14, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00004000:
-                        proto_tree_add_item(flags_tree, hfbit15, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit15, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00008000:
-                        proto_tree_add_item(flags_tree, hfbit16, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit16, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00010000:
-                        proto_tree_add_item(flags_tree, hfbit17, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit17, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00020000:
-                        proto_tree_add_item(flags_tree, hfbit18, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit18, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00040000:
-                        proto_tree_add_item(flags_tree, hfbit19, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit19, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00080000:
-                        proto_tree_add_item(flags_tree, hfbit20, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit20, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00100000:
-                        proto_tree_add_item(flags_tree, hfbit21, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit21, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00200000:
-                        proto_tree_add_item(flags_tree, hfbit22, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit22, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00400000:
-                        proto_tree_add_item(flags_tree, hfbit23, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit23, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x00800000:
-                        proto_tree_add_item(flags_tree, hfbit24, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit24, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x01000000:
-                        proto_tree_add_item(flags_tree, hfbit25, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit25, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x02000000:
-                        proto_tree_add_item(flags_tree, hfbit26, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit26, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x04000000:
-                        proto_tree_add_item(flags_tree, hfbit27, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit27, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x08000000:
-                        proto_tree_add_item(flags_tree, hfbit28, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit28, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x10000000:
-                        proto_tree_add_item(flags_tree, hfbit29, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit29, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x20000000:
-                        proto_tree_add_item(flags_tree, hfbit30, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit30, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x40000000:
-                        proto_tree_add_item(flags_tree, hfbit31, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit31, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 case 0x80000000:
-                        proto_tree_add_item(flags_tree, hfbit32, tvb, foffset, 4, FALSE);
+                        proto_tree_add_item(flags_tree, hfbit32, tvb, foffset, 4, ENC_BIG_ENDIAN);
                         break;
                 default:
                         break;
@@ -463,7 +463,7 @@ sss_string(tvbuff_t* tvb, int hfinfo, proto_tree *sss_tree, int offset, gboolean
         }
         if(str_length == 0)
         {
-       	    proto_tree_add_string(sss_tree, hfinfo, tvb, offset,
+            proto_tree_add_string(sss_tree, hfinfo, tvb, offset,
                 4, "<Not Specified>");
             return foffset;
         }
@@ -492,8 +492,8 @@ sss_string(tvbuff_t* tvb, int hfinfo, proto_tree *sss_tree, int offset, gboolean
 
                 if(length_remaining==1)
                 {
-                	i++;
-                	break;
+                        i++;
+                        break;
                 }
         }
         buffer[i] = '\0';
@@ -521,7 +521,7 @@ sss_string(tvbuff_t* tvb, int hfinfo, proto_tree *sss_tree, int offset, gboolean
 void
 dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp_req_hash_value *request_value)
 {
-    guint8              func, subfunc = 0;
+    guint8              /*func,*/ subfunc = 0;
     guint32             subverb=0;
     guint32             msg_length=0;
     guint32             foffset= 0;
@@ -533,7 +533,7 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
         return;
     }
     foffset = 6;
-    func = tvb_get_guint8(tvb, foffset);
+    /*func = tvb_get_guint8(tvb, foffset);*/
     foffset += 1;
     subfunc = tvb_get_guint8(tvb, foffset);
     foffset += 1;
@@ -547,26 +547,26 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
     case 1:
         aitem = proto_tree_add_text(ncp_tree, tvb, foffset, tvb_length_remaining(tvb, foffset), "Packet Type: %s", val_to_str(subfunc, sss_func_enum, "Unknown (%d)"));
         atree = proto_item_add_subtree(aitem, ett_sss);
-        proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_ping_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
-        proto_tree_add_item(atree, hf_flags, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
         break;
     case 2:
-        proto_tree_add_item(ncp_tree, hf_frag_handle, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(ncp_tree, hf_frag_handle, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         if (tvb_get_letohl(tvb, foffset)==0xffffffff) /* Fragment handle of -1 means no fragment. So process packet */
         {
             foffset += 4;
-            proto_tree_add_item(ncp_tree, hf_buffer_size, tvb, foffset, 4, TRUE);
+            proto_tree_add_item(ncp_tree, hf_buffer_size, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
             foffset += 4;
-            proto_tree_add_item(ncp_tree, hf_length, tvb, foffset, 4, TRUE);
+            proto_tree_add_item(ncp_tree, hf_length, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
             foffset += 4;
             foffset += 12; /* Blank Context */
             subverb = tvb_get_letohl(tvb, foffset);
             if (check_col(pinfo->cinfo, COL_INFO)) {
                 col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", val_to_str(subverb, sss_verb_enum, "Unknown (%d)"));
             }
-            aitem = proto_tree_add_item(ncp_tree, hf_verb, tvb, foffset, 4, TRUE);
+            aitem = proto_tree_add_item(ncp_tree, hf_verb, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
             atree = proto_item_add_subtree(aitem, ett_sss);
             if (request_value) {
                 request_value->req_nds_flags=subverb;
@@ -574,7 +574,7 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
             foffset += 4;
             process_flags(atree, tvb, foffset);
             foffset += 4;
-            proto_tree_add_item(atree, hf_context, tvb, foffset, 4, FALSE);
+            proto_tree_add_item(atree, hf_context, tvb, foffset, 4, ENC_BIG_ENDIAN);
             foffset += 4;
             switch (subverb) {
             case 0:
@@ -603,11 +603,11 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
                     foffset += 4;
                     if (tvb_length_remaining(tvb, foffset) < (gint) msg_length)
                     {
-                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, -1, TRUE);
+                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, -1, ENC_NA);
                     }
                     else
                     {
-                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, msg_length, TRUE);
+                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, msg_length, ENC_NA);
                     }
                 }
                 break;
@@ -631,7 +631,7 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
             case 7:
                 msg_length = tvb_get_letohl(tvb, foffset);
                 foffset += 4;
-                proto_tree_add_item(atree, hf_enc_cred, tvb, foffset, msg_length, FALSE);
+                proto_tree_add_item(atree, hf_enc_cred, tvb, foffset, msg_length, ENC_NA);
                 break;
             case 8:
             case 9:
@@ -653,7 +653,7 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
             if (tvb_length_remaining(tvb, foffset) > 8)
             {
                 foffset += 4;
-                proto_tree_add_item(ncp_tree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), TRUE);
+                proto_tree_add_item(ncp_tree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), ENC_NA);
             }
         }
         break;
@@ -666,7 +666,7 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
 }
 
 void
-dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint8 subfunc, ncp_req_hash_value	*request_value)
+dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint8 subfunc, ncp_req_hash_value *request_value)
 {
     guint32             foffset=0;
     guint32             subverb=0;
@@ -675,6 +675,7 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
     guint32             number_of_items=0;
     gint32              length_of_string=0;
     guint32             i = 0;
+    const gchar		*str;
 
     proto_tree          *atree;
     proto_item          *aitem;
@@ -690,33 +691,35 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
     atree = proto_item_add_subtree(aitem, ett_sss);
     switch (subfunc) {
     case 1:
-        proto_tree_add_item(atree, hf_flags, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_flags, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
-        proto_tree_add_item(atree, hf_sss_version, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_sss_version, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
         break;
     case 2:
         if (request_value) {
             subverb = request_value->req_nds_flags;
-            if (match_strval(subverb, sss_verb_enum)) {
-                proto_tree_add_text(atree, tvb, foffset, tvb_length_remaining(tvb, foffset), "Verb: %s", match_strval(subverb, sss_verb_enum));
+            str = match_strval(subverb, sss_verb_enum);
+            if (str) {
+                proto_tree_add_text(atree, tvb, foffset, tvb_length_remaining(tvb, foffset), "Verb: %s", str);
             }
         }
-        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_length, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         msg_length = tvb_get_letohl(tvb, foffset);
         return_code = tvb_get_ntohl(tvb, foffset+msg_length);
         foffset += 4;
-        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, TRUE);
+        proto_tree_add_item(atree, hf_frag_handle, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
         foffset += 4;
         msg_length -= 4;
         if ((tvb_get_letohl(tvb, foffset-4)==0xffffffff) && (msg_length > 4))
         {
             foffset += 4;
             return_code = tvb_get_letohl(tvb, foffset);
-            if ( match_strval(return_code, sss_errors_enum) != NULL )
+            str = match_strval(return_code, sss_errors_enum);
+            if (str)
             {
-                expert_item = proto_tree_add_item(atree, hf_return_code, tvb, foffset, 4, TRUE);
-                expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "SSS Error: %s", match_strval(return_code, sss_errors_enum));
+                expert_item = proto_tree_add_item(atree, hf_return_code, tvb, foffset, 4, ENC_LITTLE_ENDIAN);
+                expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "SSS Error: %s", str);
                 if (check_col(pinfo->cinfo, COL_INFO)) {
                    col_add_fstr(pinfo->cinfo, COL_INFO, "R Error - %s", val_to_str(return_code, sss_errors_enum, "Unknown (%d)"));
                 }
@@ -750,7 +753,7 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
                     }
                     else
                     {
-                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), TRUE);
+                        proto_tree_add_item(atree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), ENC_NA);
                     }
                 }
             }
@@ -760,7 +763,7 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
             proto_tree_add_text(atree, tvb, foffset, 4, "Return Code: Success (0x00000000)");
             if (tvb_length_remaining(tvb, foffset) > 8) {
                 foffset += 4;
-                proto_tree_add_item(atree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), TRUE);
+                proto_tree_add_item(atree, hf_enc_data, tvb, foffset, tvb_length_remaining(tvb, foffset), ENC_NA);
             }
         }
         break;
@@ -774,30 +777,30 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
 void
 proto_register_sss(void)
 {
-	static hf_register_info hf_sss[] = {
-		{ &hf_buffer_size,
-		{ "Buffer Size",		"sss.buffer", FT_UINT32, BASE_DEC, NULL, 0x0,
-			NULL, HFILL }},
+    static hf_register_info hf_sss[] = {
+        { &hf_buffer_size,
+        { "Buffer Size", "sss.buffer", FT_UINT32, BASE_DEC, NULL, 0x0,
+          NULL, HFILL }},
 
-		{ &hf_ping_version,
-		{ "Ping Version",		"sss.ping_version", FT_UINT32, BASE_HEX, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_ping_version,
+        { "Ping Version", "sss.ping_version", FT_UINT32, BASE_HEX, NULL, 0x0,
+          NULL, HFILL }},
 
-		{ &hf_flags,
-		{ "Flags",		"sss.flags", FT_UINT32, BASE_HEX, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_flags,
+        { "Flags", "sss.flags", FT_UINT32, BASE_HEX, NULL, 0x0,
+          NULL, HFILL }},
 
-		{ &hf_context,
-		{ "Context",		"sss.context", FT_UINT32, BASE_HEX, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_context,
+        { "Context", "sss.context", FT_UINT32, BASE_HEX, NULL, 0x0,
+          NULL, HFILL }},
 
-		{ &hf_frag_handle,
-		{ "Fragment Handle",		"sss.frag_handle", FT_UINT32, BASE_HEX, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_frag_handle,
+        { "Fragment Handle", "sss.frag_handle", FT_UINT32, BASE_HEX, NULL, 0x0,
+          NULL, HFILL }},
 
-		{ &hf_length,
-		{ "Length",		"sss.length", FT_UINT32, BASE_DEC, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_length,
+        { "Length", "sss.length", FT_UINT32, BASE_DEC, NULL, 0x0,
+          NULL, HFILL }},
 
         { &hf_verb,
         { "Verb",    "sss.verb",
@@ -814,13 +817,13 @@ proto_register_sss(void)
           FT_STRING,    BASE_NONE,   NULL,   0x0,
           NULL, HFILL }},
 
-		{ &hf_sss_version,
-		{ "SecretStore Protocol Version",		"sss.version", FT_UINT32, BASE_HEX, NULL, 0x0,
-			NULL, HFILL }},
+        { &hf_sss_version,
+        { "SecretStore Protocol Version", "sss.version", FT_UINT32, BASE_HEX, NULL, 0x0,
+          NULL, HFILL }},
 
         { &hf_return_code,
-		{ "Return Code",		"sss.return_code", FT_UINT32, BASE_HEX, VALS(sss_errors_enum), 0x0,
-			NULL, HFILL }},
+        { "Return Code", "sss.return_code", FT_UINT32, BASE_HEX, VALS(sss_errors_enum), 0x0,
+          NULL, HFILL }},
 
         { &hf_enc_cred,
         { "Encrypted Credential",    "sss.enc_cred",
@@ -930,12 +933,12 @@ proto_register_sss(void)
 
     };
 
-	static gint *ett[] = {
-		&ett_sss,
-	};
-	/*module_t *sss_module;*/
+        static gint *ett[] = {
+            &ett_sss,
+        };
+        /*module_t *sss_module;*/
 
-	proto_sss = proto_register_protocol("Novell SecretStore Services", "SSS", "sss");
-	proto_register_field_array(proto_sss, hf_sss, array_length(hf_sss));
-	proto_register_subtree_array(ett, array_length(ett));
+        proto_sss = proto_register_protocol("Novell SecretStore Services", "SSS", "sss");
+        proto_register_field_array(proto_sss, hf_sss, array_length(hf_sss));
+        proto_register_subtree_array(ett, array_length(ett));
 }
