@@ -3,7 +3,7 @@
  * Greg Morris <gmorris@novell.com>
  * Copyright (c) Novell, Inc. 2002-2005
  *
- * $Id: packet-ncs.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-ncs.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,8 +23,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
- 
- 
+
+
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -44,9 +44,9 @@ dissect_ncs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     proto_tree	    *ncs_tree = NULL;
     proto_item	    *ti;
-    
+
     if (tree) {
-        ti = proto_tree_add_item(tree, proto_ncs, tvb, 0, -1, FALSE);
+        ti = proto_tree_add_item(tree, proto_ncs, tvb, 0, -1, ENC_NA);
         ncs_tree = proto_item_add_subtree(ti, ett_ncs);
     }
 
@@ -54,8 +54,8 @@ dissect_ncs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "NCS");
     col_set_str(pinfo->cinfo, COL_INFO, "Novell Cluster Services Heartbeat");
 
-    proto_tree_add_item(ncs_tree, hf_panning_id, tvb, 4, 4, FALSE);
-    proto_tree_add_item(ncs_tree, hf_incarnation, tvb, 8, 4, FALSE);
+    proto_tree_add_item(ncs_tree, hf_panning_id, tvb, 4, 4, ENC_BIG_ENDIAN);
+    proto_tree_add_item(ncs_tree, hf_incarnation, tvb, 8, 4, ENC_BIG_ENDIAN);
 }
 
 void
