@@ -4,7 +4,7 @@
  *
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-nfsacl.c 35466 2011-01-10 22:31:05Z sahlberg $
+ * $Id: packet-nfsacl.c 39260 2011-10-04 22:44:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -149,7 +149,7 @@ dissect_nfsacl_aclent(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	if (tree)
 	{
 		entry_item = proto_tree_add_item(tree, hf_nfsacl_aclent, tvb,
-						 offset + 0, -1, FALSE);
+						 offset + 0, -1, ENC_NA);
 		entry_tree = proto_item_add_subtree(entry_item, ett_nfsacl_aclent);
 	}
 
@@ -450,7 +450,7 @@ dissect_nfsacl3_getacl_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	if (tree)
 	{
 		entry_item = proto_tree_add_item(tree, hf_nfsacl_entry, tvb,
-				offset + 0, -1, FALSE);
+				offset + 0, -1, ENC_NA);
 		if (entry_item)
 			entry_tree = proto_item_add_subtree(entry_item, ett_nfsacl_entry);
 	}
@@ -480,7 +480,7 @@ dissect_nfsacl3_setacl_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	if (tree)
 	{
 		acl_item = proto_tree_add_item(tree, hf_nfsacl_entry, tvb, offset + 0,
-				-1, FALSE);
+				-1, ENC_NA);
 
 		if (acl_item)
 			acl_tree = proto_item_add_subtree(acl_item, ett_nfsacl_entry);
