@@ -2,7 +2,7 @@
  * ISC OMAPI (Object Management API) dissector
  * Copyright 2006, Jaap Keuter <jaap.keuter@xs4all.nl>
  *
- * $Id: packet-omapi.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-omapi.c 39566 2011-10-25 16:04:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -112,7 +112,7 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   col_clear(pinfo->cinfo, COL_INFO);
 
-  ti = proto_tree_add_item(tree, proto_omapi, tvb, 0, -1, FALSE);
+  ti = proto_tree_add_item(tree, proto_omapi, tvb, 0, -1, ENC_NA);
   omapi_tree = proto_item_add_subtree(ti, ett_omapi);
   cursor = ptvcursor_new(omapi_tree, tvb, 0);
 
@@ -124,51 +124,51 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   else if (tvb_reported_length_remaining(tvb, 0) < 24)
   {
     /* This is a startup message */
-    ptvcursor_add(cursor, hf_omapi_version, 4, FALSE);
-    ptvcursor_add(cursor, hf_omapi_hlength, 4, FALSE);
+    ptvcursor_add(cursor, hf_omapi_version, 4, ENC_BIG_ENDIAN);
+    ptvcursor_add(cursor, hf_omapi_hlength, 4, ENC_BIG_ENDIAN);
 
     col_set_str(pinfo->cinfo, COL_INFO, "Status message");
-    proto_item_append_text(ti, ", Status message"); 
+    proto_item_append_text(ti, ", Status message");
 
     return;
   }
   else if ( !(tvb_get_ntohl(tvb, 8) || tvb_get_ntohl(tvb, 12)) )
   {
     /* This is a startup message, and more */
-    ptvcursor_add(cursor, hf_omapi_version, 4, FALSE);
-    ptvcursor_add(cursor, hf_omapi_hlength, 4, FALSE);
+    ptvcursor_add(cursor, hf_omapi_version, 4, ENC_BIG_ENDIAN);
+    ptvcursor_add(cursor, hf_omapi_hlength, 4, ENC_BIG_ENDIAN);
 
     if (check_col(pinfo->cinfo, COL_INFO))
     {
       col_append_str(pinfo->cinfo, COL_INFO, "Status message");
     }
-    proto_item_append_text(ti, ", Status message"); 
+    proto_item_append_text(ti, ", Status message");
   }
 
-  ptvcursor_add(cursor, hf_omapi_auth_id, 4, FALSE);
+  ptvcursor_add(cursor, hf_omapi_auth_id, 4, ENC_BIG_ENDIAN);
   authlength = tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor));
-  ptvcursor_add(cursor, hf_omapi_auth_len, 4, FALSE);
+  ptvcursor_add(cursor, hf_omapi_auth_len, 4, ENC_BIG_ENDIAN);
 
-  if (check_col(pinfo->cinfo, COL_INFO)) 
+  if (check_col(pinfo->cinfo, COL_INFO))
   {
     col_append_sep_str(pinfo->cinfo, COL_INFO, NULL,
       val_to_str(tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor)), omapi_opcode_vals, "Unknown opcode (0x%04x)"));
   }
-  proto_item_append_text(ti, ", Opcode: %s", 
+  proto_item_append_text(ti, ", Opcode: %s",
     val_to_str(tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor)), omapi_opcode_vals, "Unknown opcode (0x%04x)"));
 
-  ptvcursor_add(cursor, hf_omapi_opcode, 4, FALSE);
-  ptvcursor_add(cursor, hf_omapi_handle, 4, FALSE);
-  ptvcursor_add(cursor, hf_omapi_id, 4, FALSE);
-  ptvcursor_add(cursor, hf_omapi_rid, 4, FALSE);
+  ptvcursor_add(cursor, hf_omapi_opcode, 4, ENC_BIG_ENDIAN);
+  ptvcursor_add(cursor, hf_omapi_handle, 4, ENC_BIG_ENDIAN);
+  ptvcursor_add(cursor, hf_omapi_id, 4, ENC_BIG_ENDIAN);
+  ptvcursor_add(cursor, hf_omapi_rid, 4, ENC_BIG_ENDIAN);
 
   msglength = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
   while (msglength)
   {
-    ptvcursor_add(cursor, hf_omapi_msg_name_len, 2, FALSE);
-    ptvcursor_add(cursor, hf_omapi_msg_name, msglength, FALSE);
+    ptvcursor_add(cursor, hf_omapi_msg_name_len, 2, ENC_BIG_ENDIAN);
+    ptvcursor_add(cursor, hf_omapi_msg_name, msglength, ENC_ASCII|ENC_NA);
     msglength = tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor));
-    ptvcursor_add(cursor, hf_omapi_msg_value_len, 4, FALSE);
+    ptvcursor_add(cursor, hf_omapi_msg_value_len, 4, ENC_BIG_ENDIAN);
 
     if (msglength == 0)
     {
@@ -177,10 +177,10 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     else if (msglength == (guint32)~0)
     {
       proto_tree_add_text(omapi_tree, tvb, 0, 0, "No value");
-    }        
+    }
     else
     {
-      ptvcursor_add(cursor, hf_omapi_msg_value, msglength, FALSE);
+      ptvcursor_add(cursor, hf_omapi_msg_value, msglength, ENC_ASCII|ENC_NA);
     }
 
     msglength = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
@@ -192,10 +192,10 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   objlength = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
   while (objlength)
   {
-    ptvcursor_add(cursor, hf_omapi_obj_name_len, 2, FALSE);
-    ptvcursor_add(cursor, hf_omapi_obj_name, objlength, FALSE);
+    ptvcursor_add(cursor, hf_omapi_obj_name_len, 2, ENC_BIG_ENDIAN);
+    ptvcursor_add(cursor, hf_omapi_obj_name, objlength, ENC_ASCII|ENC_NA);
     objlength = tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor));
-    ptvcursor_add(cursor, hf_omapi_obj_value_len, 4, FALSE);
+    ptvcursor_add(cursor, hf_omapi_obj_value_len, 4, ENC_BIG_ENDIAN);
 
     if (objlength == 0)
     {
@@ -204,10 +204,10 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     else if (objlength == (guint32)~0)
     {
       proto_tree_add_text(omapi_tree, tvb, 0, 0, "No value");
-    }        
+    }
     else
     {
-      ptvcursor_add(cursor, hf_omapi_obj_value, objlength, FALSE);
+      ptvcursor_add(cursor, hf_omapi_obj_value, objlength, ENC_NA);
     }
 
     objlength = tvb_get_ntohs(tvb, ptvcursor_current_offset(cursor));
@@ -217,7 +217,7 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   ptvcursor_advance(cursor, 2);
 
   if (authlength > 0) {
-    ptvcursor_add(cursor, hf_omapi_signature, authlength, FALSE);
+    ptvcursor_add(cursor, hf_omapi_signature, authlength, ENC_NA);
   }
 }
 
