@@ -4,7 +4,7 @@
  * http://www.cablelabs.com/specifications/archives/PKT-SP-ESP-I01-991229.pdf
  * Chapter 4 ( Call Content Connection Interface )
  *
- * $Id: packet-pcli.c 41581 2012-03-15 23:21:05Z cmaynard $
+ * $Id: packet-pcli.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  *
@@ -33,11 +33,8 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <time.h>
-
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
