@@ -1,7 +1,7 @@
 /* packet-pcnfsd.c
  * Routines for PCNFSD dissection
  *
- * $Id: packet-pcnfsd.c 28770 2009-06-18 21:30:42Z stig $
+ * $Id: packet-pcnfsd.c 39288 2011-10-06 03:35:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -284,7 +284,7 @@ dissect_pcnfsd2_auth_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 		gtree = proto_item_add_subtree(gitem, ett_pcnfsd_gids);
 	}
 	if (gtree) {
-		proto_tree_add_item(gtree, hf_pcnfsd_gids_count, tvb, offset, 4, FALSE);
+		proto_tree_add_item(gtree, hf_pcnfsd_gids_count, tvb, offset, 4, ENC_BIG_ENDIAN);
 	}
 	offset += 4;
 	for (gids_i = 0 ; gids_i < gids_count ; gids_i++) {
