@@ -1,7 +1,7 @@
 /* packet-pdcp-lte.h
  *
  * Martin Mathieson
- * $Id: packet-pdcp-lte.h 37941 2011-07-08 16:10:25Z martinm $
+ * $Id: packet-pdcp-lte.h 40656 2012-01-23 02:36:46Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,6 +23,8 @@
  */
 
 
+#include "packet-rohc.h"
+
 /* Direction */
 #define DIRECTION_UPLINK   0
 #define DIRECTION_DOWNLINK 1
@@ -33,13 +35,6 @@ enum pdcp_plane
   USER_PLANE = 2
 };
 
-enum rohc_mode
-{
-  UNIDIRECTIONAL = 1,
-  OPTIMISTIC_BIDIRECTIONAL = 2,
-  RELIABLE_BIDIRECTIONAL = 3
-};
-
 typedef enum LogicalChannelType
 {
     Channel_DCCH=1,
@@ -88,6 +83,8 @@ typedef struct pdcp_lte_info
     gboolean           rnd;
     gboolean           udp_checkum_present;
     unsigned short     profile;
+
+    guint8             is_retx;
 } pdcp_lte_info;
 
 
