@@ -9,7 +9,7 @@
  * Ronnie Sahlberg 2004
  * Thomas Anders 2004
  *
- * $Id: packet-pktc.c 35558 2011-01-16 20:51:21Z morriss $
+ * $Id: packet-pktc.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -179,7 +179,7 @@ dissect_pktc_app_specific_data(packet_info *pinfo _U_, proto_tree *parent_tree,
     guint8 len;
 
     if (parent_tree) {
-        item = proto_tree_add_item(parent_tree, hf_pktc_app_spec_data, tvb, offset, -1, FALSE);
+        item = proto_tree_add_item(parent_tree, hf_pktc_app_spec_data, tvb, offset, -1, ENC_NA);
         tree = proto_item_add_subtree(item, ett_pktc_app_spec_data);
     }
 
@@ -197,17 +197,17 @@ dissect_pktc_app_specific_data(packet_info *pinfo _U_, proto_tree *parent_tree,
             offset+=1;
 
             /* snmpEngineID */
-            engineid_item = proto_tree_add_item(tree, hf_pktc_snmpEngineID, tvb, offset, len, FALSE);
+            engineid_item = proto_tree_add_item(tree, hf_pktc_snmpEngineID, tvb, offset, len, ENC_NA);
 	    engineid_tree = proto_item_add_subtree(engineid_item, ett_pktc_engineid);
 	    dissect_snmp_engineid(engineid_tree, tvb, offset, len);
             offset+=len;
 
             /* boots */
-            proto_tree_add_item(tree, hf_pktc_snmpEngineBoots, tvb, offset, 4, FALSE);
+            proto_tree_add_item(tree, hf_pktc_snmpEngineBoots, tvb, offset, 4, ENC_BIG_ENDIAN);
             offset+=4;
 
             /* time */
-            proto_tree_add_item(tree, hf_pktc_snmpEngineTime, tvb, offset, 4, FALSE);
+            proto_tree_add_item(tree, hf_pktc_snmpEngineTime, tvb, offset, 4, ENC_BIG_ENDIAN);
             offset+=4;
 
             /* usmUserName Length */
@@ -216,7 +216,7 @@ dissect_pktc_app_specific_data(packet_info *pinfo _U_, proto_tree *parent_tree,
             offset+=1;
 
             /* usmUserName */
-            proto_tree_add_item(tree, hf_pktc_usmUserName, tvb, offset, len, FALSE);
+            proto_tree_add_item(tree, hf_pktc_usmUserName, tvb, offset, len, ENC_ASCII|ENC_NA);
             offset+=len;
 
             break;
@@ -234,7 +234,7 @@ dissect_pktc_app_specific_data(packet_info *pinfo _U_, proto_tree *parent_tree,
         case KMMID_AP_REPLY:
         case KMMID_REKEY:
             /* Security Parameter Index (SPI) */
-            proto_tree_add_item(tree, hf_pktc_ipsec_spi, tvb, offset, 4, FALSE);
+            proto_tree_add_item(tree, hf_pktc_ipsec_spi, tvb, offset, 4, ENC_BIG_ENDIAN);
             offset+=4;
 
 	    break;
@@ -261,7 +261,7 @@ dissect_pktc_list_of_ciphersuites(packet_info *pinfo _U_, proto_tree *parent_tre
     guint8 len, i;
 
     if (parent_tree) {
-        item = proto_tree_add_item(parent_tree, hf_pktc_list_of_ciphersuites, tvb, offset, -1, FALSE);
+        item = proto_tree_add_item(parent_tree, hf_pktc_list_of_ciphersuites, tvb, offset, -1, ENC_NA);
         tree = proto_item_add_subtree(item, ett_pktc_list_of_ciphersuites);
     }
 
@@ -279,12 +279,12 @@ dissect_pktc_list_of_ciphersuites(packet_info *pinfo _U_, proto_tree *parent_tre
     case DOI_SNMPv3:
         for(i=0;i<len;i++){
             /* SNMPv3 authentication algorithm */
-            proto_tree_add_item(tree, hf_pktc_snmpAuthenticationAlgorithm, tvb, offset, 1, FALSE);
+            proto_tree_add_item(tree, hf_pktc_snmpAuthenticationAlgorithm, tvb, offset, 1, ENC_BIG_ENDIAN);
             proto_item_append_text(tree, " %s", val_to_str(tvb_get_guint8(tvb, offset), snmp_authentication_algorithm_vals, "%0x"));
             offset+=1;
 
             /* SNMPv3 encryption transform id */
-            proto_tree_add_item(tree, hf_pktc_snmpEncryptionTransformID, tvb, offset, 1, FALSE);
+            proto_tree_add_item(tree, hf_pktc_snmpEncryptionTransformID, tvb, offset, 1, ENC_BIG_ENDIAN);
             proto_item_append_text(tree, "/%s", val_to_str(tvb_get_guint8(tvb, offset), snmp_transform_id_vals, "%0x"));
             offset+=1;
 	}
@@ -292,12 +292,12 @@ dissect_pktc_list_of_ciphersuites(packet_info *pinfo _U_, proto_tree *parent_tre
     case DOI_IPSEC:
         for(i=0;i<len;i++){
             /* IPsec authentication algorithm */
-            proto_tree_add_item(tree, hf_pktc_ipsecAuthenticationAlgorithm, tvb, offset, 1, FALSE);
+            proto_tree_add_item(tree, hf_pktc_ipsecAuthenticationAlgorithm, tvb, offset, 1, ENC_BIG_ENDIAN);
             proto_item_append_text(tree, " %s", val_to_str(tvb_get_guint8(tvb, offset), ipsec_authentication_algorithm_vals, "%0x"));
             offset+=1;
 
             /* IPsec encryption transform id */
-            proto_tree_add_item(tree, hf_pktc_ipsecEncryptionTransformID, tvb, offset, 1, FALSE);
+            proto_tree_add_item(tree, hf_pktc_ipsecEncryptionTransformID, tvb, offset, 1, ENC_BIG_ENDIAN);
             proto_item_append_text(tree, "/%s", val_to_str(tvb_get_guint8(tvb, offset), ipsec_transform_id_vals, "%0x"));
             offset+=1;
 	}
@@ -324,7 +324,7 @@ dissect_pktc_wakeup(proto_tree *tree, tvbuff_t *tvb, int offset)
 
     /* Server Kerberos Principal Identifier */
     string_len=tvb_strsize(tvb, offset);
-    proto_tree_add_item(tree, hf_pktc_server_principal, tvb, offset, string_len, FALSE);
+    proto_tree_add_item(tree, hf_pktc_server_principal, tvb, offset, string_len, ENC_ASCII|ENC_NA);
     offset+=string_len;
 
     return offset;
@@ -352,11 +352,11 @@ dissect_pktc_ap_request(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int
     offset=dissect_pktc_list_of_ciphersuites(pinfo, tree, tvb, offset, doi);
 
     /* re-establish flag */
-    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset+=1;
 
     /* sha-1 hmac */
-    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, FALSE);
+    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, ENC_NA);
     offset+=20;
 
     return offset;
@@ -385,19 +385,19 @@ dissect_pktc_ap_reply(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int o
     offset+=4;
 
     /* grace period */
-    proto_tree_add_item(tree, hf_pktc_grace_period, tvb, offset, 4, FALSE);
+    proto_tree_add_item(tree, hf_pktc_grace_period, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset+=4;
 
     /* re-establish flag */
-    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset+=1;
 
     /* ack required flag */
-    proto_tree_add_item(tree, hf_pktc_ack_required_flag, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_pktc_ack_required_flag, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset+=1;
 
     /* sha-1 hmac */
-    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, FALSE);
+    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, ENC_NA);
     offset+=20;
 
     return offset;
@@ -407,7 +407,7 @@ static int
 dissect_pktc_sec_param_rec(proto_tree *tree, tvbuff_t *tvb, int offset)
 {
     /* sha-1 hmac of the subkey of the preceding AP-REP */
-    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, FALSE);
+    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, ENC_NA);
     offset+=20;
 
     return offset;
@@ -427,7 +427,7 @@ dissect_pktc_rekey(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offs
 
     /* Server Kerberos Principal Identifier */
     string_len=tvb_strsize(tvb, offset);
-    proto_tree_add_item(tree, hf_pktc_server_principal, tvb, offset, string_len, FALSE);
+    proto_tree_add_item(tree, hf_pktc_server_principal, tvb, offset, string_len, ENC_ASCII|ENC_NA);
     offset+=string_len;
 
     /* Timestamp: YYMMDDhhmmssZ */
@@ -446,19 +446,19 @@ dissect_pktc_rekey(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offs
     offset=dissect_pktc_list_of_ciphersuites(pinfo, tree, tvb, offset, doi);
 
     /* sec param lifetime */
-    proto_tree_add_item(tree, hf_pktc_sec_param_lifetime, tvb, offset, 4, FALSE);
+    proto_tree_add_item(tree, hf_pktc_sec_param_lifetime, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset+=4;
 
     /* grace period */
-    proto_tree_add_item(tree, hf_pktc_grace_period, tvb, offset, 4, FALSE);
+    proto_tree_add_item(tree, hf_pktc_grace_period, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset+=4;
 
     /* re-establish flag */
-    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tree, hf_pktc_reestablish_flag, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset+=1;
 
     /* sha-1 hmac */
-    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, FALSE);
+    proto_tree_add_item(tree, hf_pktc_sha1_hmac, tvb, offset, 20, ENC_NA);
     offset+=20;
 
     return offset;
@@ -508,7 +508,7 @@ dissect_pktc_mtafqdn_krbsafeuserdata(packet_info *pinfo, tvbuff_t *tvb, proto_tr
        offset+=6;
 
        /* MTA pub key hash */
-       proto_tree_add_item(tree, hf_pktc_mtafqdn_pub_key_hash, tvb, offset, 20, FALSE);
+       proto_tree_add_item(tree, hf_pktc_mtafqdn_pub_key_hash, tvb, offset, 20, ENC_NA);
        offset+=20;
 
        /* manufacturer cert revocation time */
@@ -525,7 +525,7 @@ dissect_pktc_mtafqdn_krbsafeuserdata(packet_info *pinfo, tvbuff_t *tvb, proto_tr
         string_len = tvb_length_remaining(tvb, offset) - 4;
         if (string_len <= 0)
                 THROW(ReportedBoundsError);
-        proto_tree_add_item(tree, hf_pktc_mtafqdn_fqdn, tvb, offset, string_len, FALSE);
+        proto_tree_add_item(tree, hf_pktc_mtafqdn_fqdn, tvb, offset, string_len, ENC_ASCII|ENC_NA);
         offset+=string_len;
 
         /* MTA IP address */
@@ -554,7 +554,7 @@ dissect_pktc_mtafqdn(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKTC");
 
     if (tree) {
-        item = proto_tree_add_item(tree, proto_pktc, tvb, 0, 0, FALSE);
+        item = proto_tree_add_item(tree, proto_pktc, tvb, 0, 0, ENC_NA);
         pktc_mtafqdn_tree = proto_item_add_subtree(item, ett_pktc_mtafqdn);
     }
 
@@ -587,7 +587,7 @@ dissect_pktc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKTC");
 
     if (tree) {
-        item = proto_tree_add_item(tree, proto_pktc, tvb, 0, 3, FALSE);
+        item = proto_tree_add_item(tree, proto_pktc, tvb, 0, 3, ENC_NA);
         pktc_tree = proto_item_add_subtree(item, ett_pktc);
     }
 
