@@ -3,7 +3,7 @@
  *
  *  Copyright 2010, Jan Gerbecks <jan.gerbecks@stud.uni-due.de>
  *
- * $Id: packet-pnrp.c 39539 2011-10-24 19:57:53Z wmeier $
+ * $Id: packet-pnrp.c 41873 2012-03-31 20:57:15Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -685,7 +685,7 @@ static int dissect_pnrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                         /* Entry Length: Must be 0x0002 */
                         proto_tree_add_item(pnrp_message_tree, hf_pnrp_message_classifier_entryLength, tvb, offset + 10, 2, ENC_BIG_ENDIAN);
                         /* The actual classifier String */
-                        proto_tree_add_text(pnrp_message_tree, tvb, offset + 12, tvb_get_ntohs(tvb,offset+6)-8, "Classifier: %s",tvb_get_ephemeral_unicode_string(tvb, offset + 12, (tvb_get_ntohs(tvb,offset+6)-8)/2, ENC_BIG_ENDIAN));
+                        proto_tree_add_text(pnrp_message_tree, tvb, offset + 12, tvb_get_ntohs(tvb,offset+6)-8, "Classifier: %s",tvb_get_ephemeral_unicode_string(tvb, offset + 12, tvb_get_ntohs(tvb,offset+6)-8, ENC_BIG_ENDIAN));
                     }
 
                     /* There might be padding, so fill up to the next byte */
@@ -1009,7 +1009,7 @@ static void dissect_payload_structure(tvbuff_t *tvb, gint offset, gint length, p
         dissect_ipv6_address(tvb, offset, 16, pnrp_payload_tree);
         offset += 16;
         proto_tree_add_text(pnrp_payload_tree, tvb, offset,2, "Port Number : %d",tvb_get_letohs(tvb,offset));
-        /* proto_tree_add_item(pnrp_payload_tree, hf_pnrp_payload_port, tvb, offset, 2, FALSE); */
+        /* proto_tree_add_item(pnrp_payload_tree, hf_pnrp_payload_port, tvb, offset, 2, ENC_BIG_ENDIAN); */
         offset += 2;
         proto_tree_add_text(pnrp_payload_tree, tvb, offset,2, "IANA Protocol Number : %d",tvb_get_letohs(tvb,offset));
         offset += 2;
@@ -1155,10 +1155,10 @@ void proto_register_pnrp(void)
                 NULL, HFILL }},
         /* Ack Flags */
         { &hf_pnrp_message_ack_flags_reserved,
-            { "Reserved", "pnrp.segment.ack.flags.reserved", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+            { "Reserved", "pnrp.segment.ack.flags.reserved", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
                 NULL, HFILL }},
         { &hf_pnrp_message_ack_flags_Nbit,
-            { "(N)ot found Bit", "pnrp.segment.ack.flags.Nbit", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+            { "(N)ot found Bit", "pnrp.segment.ack.flags.Nbit", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
                 NULL, HFILL }},
         /* Authority Flags */
         { &hf_pnrp_message_authority_flags,
@@ -1184,10 +1184,10 @@ void proto_register_pnrp(void)
                 NULL, HFILL }},
         /* Flood Control Flags */
         { &hf_pnrp_message_flood_flags_reserved1,
-            { "Reserved", "pnrp.segment.flood.flags.reserved", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+            { "Reserved", "pnrp.segment.flood.flags.reserved", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
                 NULL, HFILL }},
         { &hf_pnrp_message_flood_flags_Dbit,
-            { "(D)on't send ACK", "pnrp.segment.flood.flags.Dbit", FT_BOOLEAN, BASE_DEC, NULL, 0x0,
+            { "(D)on't send ACK", "pnrp.segment.flood.flags.Dbit", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
                 NULL, HFILL }},
         /* Split Controls */
         { &hf_pnrp_message_splitControls_authorityBuffer,
@@ -1249,7 +1249,7 @@ void proto_register_pnrp(void)
             { "Service Location", "pnrp.encodedCPA.serviceLocation", FT_BYTES,BASE_NONE, NULL, 0x0,
                 NULL, HFILL }},
         { &hf_pnrp_encodedCPA_binaryAuthority,
-            { "Binary Authoriy", "pnrp.encodedCPA.binaryAuthority", FT_BYTES,BASE_NONE, NULL, 0x0,
+            { "Binary Authority", "pnrp.encodedCPA.binaryAuthority", FT_BYTES,BASE_NONE, NULL, 0x0,
                 "SHA-1 Hash of PublicKey Data field", HFILL }},
         { &hf_pnrp_encodedCPA_classifiertHash,
             { "Classifiert Hash", "pnrp.encodedCPA.classifierHash", FT_BYTES,BASE_NONE, NULL, 0x0,
