@@ -2,7 +2,7 @@
  * Routines for PPI-GEOLOCATION-ANNTENNA  dissection
  * Copyright 2010, Harris Corp, jellch@harris.com
  *
- * $Id: packet-ppi-antenna.c 39426 2011-10-15 18:46:26Z wmeier $
+ * $Id: packet-ppi-antenna.c 41645 2012-03-18 22:24:24Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -465,7 +465,7 @@ proto_register_ppi_antenna(void) {
         { &hf_ppi_antennaflags_mimo,
           { "mimo", "ppi_antenna.antennaflags.mimo",
             FT_BOOLEAN, 32, NULL, PPI_ANTENNAFLAGS_MASK_MIMO,
-            "Antena is part of MIMO system", HFILL } },
+            "Antenna is part of MIMO system", HFILL } },
         { &hf_ppi_antennaflags_horizpol,
           { "horizontally polarized", "ppi_antenna.antennaflags.horizpol",
             FT_BOOLEAN, 32, NULL, PPI_ANTENNAFLAGS_MASK_HPOL,
