@@ -2,7 +2,7 @@
  * packet-ppi.c
  * Routines for PPI Packet Header dissection
  *
- * $Id: packet-ppi.c 40346 2011-12-30 15:30:32Z wmeier $
+ * $Id: packet-ppi.c 42505 2012-05-08 06:43:15Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -727,7 +727,7 @@ dissect_8023_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
 #define PADDING4(x) ((((x + 3) >> 2) << 2) - x)
 #define ADD_BASIC_TAG(hf_tag) \
     if (tree)   \
-        proto_tree_add_item(ppi_tree, hf_tag, tvb, offset, data_len, FALSE)
+        proto_tree_add_item(ppi_tree, hf_tag, tvb, offset, data_len, ENC_NA)
 
 static void
 dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
