@@ -1,6 +1,6 @@
 /* packet-ppp.h
  *
- * $Id: packet-ppp.h 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-ppp.h 34745 2010-11-01 18:26:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,7 @@ tvbuff_t *decode_fcs(tvbuff_t *tvb, proto_tree *fh_tree, int fcs_decode, int pro
 /*
  * Used by the GTP dissector as well.
  */
-extern const value_string ppp_vals[];
+extern value_string_ext ppp_vals_ext;
 
 /*
  * Used by CHDLC dissector as well.
