@@ -4,7 +4,7 @@
  * Copyright 2011, Martin Renold <reld[AT]zhaw.ch>
  * Copyright 2011, Florian Reichert <refl [AT] zhaw.ch>
  *
- * $Id: packet-prp.c 39692 2011-10-31 18:37:58Z alagoutte $
+ * $Id: packet-prp.c 40585 2012-01-19 17:42:28Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald[AT]wireshark.org>
@@ -49,7 +49,6 @@ static const value_string prp_lan_vals[] = {
 
 void proto_reg_handoff_prp(void);
 static int proto_prp = -1;
-static module_t *prp_module;
 
 
 /* Initialize trailer fields */
@@ -81,14 +80,14 @@ dissect_prp_redundancy_control_trailer(tvbuff_t *tvb, packet_info *pinfo _U_, pr
 {
     proto_item *ti;
     proto_tree *prp_tree;
-    guint i;
-    guint length;
-    guint offset;
-    guint16 lan_id;
-    guint16 lsdu_size;
-    guint16 prp1_suffix;
-    guint trailer_start;
-    guint trailer_length;
+    guint       i;
+    guint       length;
+    guint       offset;
+    guint16     lan_id;
+    guint16     lsdu_size;
+    guint16     prp1_suffix;
+    guint       trailer_start;
+    guint       trailer_length;
 
     if (!tree)
         return;
@@ -120,7 +119,7 @@ dissect_prp_redundancy_control_trailer(tvbuff_t *tvb, packet_info *pinfo _U_, pr
         lsdu_size = tvb_get_ntohs(tvb, (i+2)) & 0x0fff;
         if(lsdu_size == i+4-offset && (lan_id == 0xa || lan_id == 0xb))
         {
-            trailer_start = i;
+            trailer_start  = i;
             trailer_length = 4;
             break;
         }
@@ -142,7 +141,7 @@ dissect_prp_redundancy_control_trailer(tvbuff_t *tvb, packet_info *pinfo _U_, pr
             /* We don't check the lsdu_size, we just display whether
                it's correct. Helpful for testing, because different
                definitions of the lsdu_size did exist. */
-            trailer_start = length-6;
+            trailer_start  = length-6;
             trailer_length = 6;
         }
     }
@@ -196,7 +195,6 @@ dissect_prp_redundancy_control_trailer(tvbuff_t *tvb, packet_info *pinfo _U_, pr
 /* Register the protocol with Wireshark */
 void proto_register_prp(void)
 {
-
     static hf_register_info hf[] = {
         /*trailer*/
         { &hf_prp_redundancy_control_trailer_sequence_nr,
@@ -234,6 +232,7 @@ void proto_register_prp(void)
         &ett_prp_redundancy_control_trailer,
     };
 
+    module_t *prp_module;
 
     /* Register the protocol name and description */
     proto_prp = proto_register_protocol("Parallel Redundancy Protocol (IEC62439 Part 3)",
@@ -263,5 +262,5 @@ void proto_reg_handoff_prp(void)
         prefs_initialized = TRUE;
     }
 
-      proto_set_decoding(proto_prp, prp_enable_dissector);
+    proto_set_decoding(proto_prp, prp_enable_dissector);
 }
