@@ -3,7 +3,7 @@
  * By Mike Frisch <mfrisch@platform.com>
  * Joint and Several Copyright 2005, Mike Frisch and Platform Computing Inc.
  *
- * $Id: packet-pvfs2.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-pvfs2.c 43091 2012-06-04 22:26:40Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
@@ -1577,7 +1576,7 @@ dissect_pvfs2_io_request(tvbuff_t *tvb, proto_tree *tree, int offset,
 	/* */
 	offset += 4;
 
-	offset = dissect_pvfs_pint_request(tvb, tree, offset);
+	/*offset = */dissect_pvfs_pint_request(tvb, tree, offset);
 
 	/* TODO: remove this!!! */
 	offset = tvb_length(tvb) - 16;
@@ -3206,7 +3205,7 @@ dissect_pvfs_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 	if (mode == TCP_MODE_UNEXP)
 	{
 		/* Request */
-		offset = dissect_pvfs2_request(tvb, pvfs_tree, offset, pinfo, server_op);
+		/*offset = */dissect_pvfs2_request(tvb, pvfs_tree, offset, pinfo, server_op);
 	}
 	else
 	{
@@ -3225,7 +3224,7 @@ dissect_pvfs_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 #endif
 		{
 			/* Response */
-			offset = dissect_pvfs2_response(tvb, pvfs_tree, offset, pinfo,
+			/*offset = */dissect_pvfs2_response(tvb, pvfs_tree, offset, pinfo,
 					server_op);
 		}
 	}
