@@ -2,7 +2,7 @@
  * Routine and tables for analyzing an ISPC according to Q.708
  * Copyright 2010, Gerasimos Dimitriadis <dimeg [AT] intracom.gr>
  *
- * $Id: packet-q708.h 32331 2010-03-30 23:44:25Z jmayer $
+ * $Id: packet-q708.h 35140 2010-12-06 23:20:21Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,12 +26,6 @@
 #ifndef __PACKET_Q708_H__
 #define __PACKET_Q708_H__
 
-#include <epan/value_string.h>
-
-extern const value_string q708_sanc_areas[];
-extern const value_string q708_ispc_point_name[];
-extern const value_string q708_ispc_operator_name[];
-
 void analyze_q708_ispc(tvbuff_t *tvb, proto_tree *tree, int offset, int length, guint16 ispc);
 
 #endif /* __PACKET_Q708_H__ */
