@@ -2,7 +2,7 @@
  * Routines for Q.933 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q933.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-q933.c 39774 2011-11-09 17:33:18Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1682,7 +1682,7 @@ dissect_q933_number_ie(tvbuff_t *tvb, int offset, int len,
 
 	if (len == 0)
 		return;
-	proto_tree_add_item(tree, hfindex, tvb, offset, len, FALSE);
+	proto_tree_add_item(tree, hfindex, tvb, offset, len, ENC_ASCII|ENC_NA);
 }
 
 /*
