@@ -2,7 +2,7 @@
  * Routines for QLLC protocol - Qualified? LLC
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-qllc.c 31580 2010-01-19 23:51:27Z wmeier $
+ * $Id: packet-qllc.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -95,7 +95,7 @@ dissect_qllc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_clear(pinfo->cinfo, COL_INFO);
 
     if (tree) {
-	qllc_ti = proto_tree_add_item(tree, proto_qllc, tvb, 0, -1, FALSE);
+	qllc_ti = proto_tree_add_item(tree, proto_qllc, tvb, 0, -1, ENC_NA);
 	qllc_tree = proto_item_add_subtree(qllc_ti, ett_qllc);
     }
 
@@ -103,7 +103,7 @@ dissect_qllc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      * COMMAND or a RESPONSE */
     addr = tvb_get_guint8(tvb, 0);
     if (tree) {
-	proto_tree_add_item(qllc_tree, hf_qllc_address, tvb, 0, 1, FALSE);
+	proto_tree_add_item(qllc_tree, hf_qllc_address, tvb, 0, 1, ENC_BIG_ENDIAN);
     }
 
     /* The address field equals X'FF' in commands (except QRR)
