@@ -4,7 +4,7 @@
  * Uwe Girlich <uwe@planetquake.com>
  *	http://www.idsoftware.com/q1source/q1source.zip
  *
- * $Id: packet-quake.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-quake.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -162,11 +162,11 @@ dissect_quake_CCREQ_CONNECT
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, hf_quake_CCREQ_CONNECT_game,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		proto_tree_add_item(tree, hf_quake_CCREQ_CONNECT_version,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 	}
 }
 
@@ -182,10 +182,10 @@ dissect_quake_CCREQ_SERVER_INFO
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, hf_quake_CCREQ_SERVER_INFO_game,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 		proto_tree_add_item(tree, hf_quake_CCREQ_SERVER_INFO_version,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 	}
 }
 
@@ -196,7 +196,7 @@ dissect_quake_CCREQ_PLAYER_INFO
 {
 	if (tree) {
 		 proto_tree_add_item(tree, hf_quake_CCREQ_PLAYER_INFO_player,
-			tvb, 0, 1, TRUE);
+			tvb, 0, 1, ENC_LITTLE_ENDIAN);
 	}
 }
 
@@ -207,7 +207,7 @@ dissect_quake_CCREQ_RULE_INFO
 {
 	if (tree) {
 		proto_tree_add_item(tree, hf_quake_CCREQ_RULE_INFO_lastrule,
-			tvb, 0, -1, TRUE);
+			tvb, 0, -1, ENC_ASCII|ENC_NA);
 	}
 }
 
@@ -236,7 +236,7 @@ dissect_quake_CCREP_REJECT
 {
 	if (tree) {
 		proto_tree_add_item(tree, hf_quake_CCREP_REJECT_reason,
-			tvb, 0, -1, TRUE);
+			tvb, 0, -1, ENC_ASCII|ENC_NA);
 	}
 }
 
@@ -253,26 +253,26 @@ dissect_quake_CCREP_SERVER_INFO
 	if (tree) {
 		ti = proto_tree_add_item(tree,
 			hf_quake_CCREP_SERVER_INFO_address, tvb, offset, -1,
-			TRUE);
+			ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		ti = proto_tree_add_item(tree,
 			hf_quake_CCREP_SERVER_INFO_server, tvb, offset, -1,
-			TRUE);
+			ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		ti = proto_tree_add_item(tree, hf_quake_CCREP_SERVER_INFO_map,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		proto_tree_add_item(tree, hf_quake_CCREP_SERVER_INFO_num_player,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 		offset += 1;
 		proto_tree_add_item(tree, hf_quake_CCREP_SERVER_INFO_max_player,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 		offset += 1;
 		proto_tree_add_item(tree, hf_quake_CCREQ_SERVER_INFO_version,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 	}
 }
 
@@ -293,11 +293,11 @@ dissect_quake_CCREP_PLAYER_INFO
 
 	if (tree) {
 		proto_tree_add_item(tree, hf_quake_CCREQ_PLAYER_INFO_player,
-			tvb, offset, 1, TRUE);
+			tvb, offset, 1, ENC_LITTLE_ENDIAN);
 		offset += 1;
 
 		ti = proto_tree_add_item(tree, hf_quake_CCREP_PLAYER_INFO_name,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		colors       = tvb_get_letohl(tvb, offset + 0);
@@ -317,14 +317,14 @@ dissect_quake_CCREP_PLAYER_INFO
 			tvb, offset, 1, color_pants);
 		offset += 4;
 		proto_tree_add_item(tree, hf_quake_CCREP_PLAYER_INFO_frags,
-			tvb, offset, 4, TRUE);
+			tvb, offset, 4, ENC_LITTLE_ENDIAN);
 		offset += 4;
 		proto_tree_add_item(tree, hf_quake_CCREP_PLAYER_INFO_connect_time,
-			tvb, offset, 4, TRUE);
+			tvb, offset, 4, ENC_LITTLE_ENDIAN);
 		offset += 4;
 
 		proto_tree_add_item(tree, hf_quake_CCREP_PLAYER_INFO_address,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 	}
 }
 
@@ -342,11 +342,11 @@ dissect_quake_CCREP_RULE_INFO
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, hf_quake_CCREP_RULE_INFO_rule,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 		offset += proto_item_get_len(ti);
 
 		proto_tree_add_item(tree, hf_quake_CCREP_RULE_INFO_value,
-			tvb, offset, -1, TRUE);
+			tvb, offset, -1, ENC_ASCII|ENC_NA);
 	}
 }
 
@@ -446,7 +446,7 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 		proto_item *quake_item;
 		quake_item = proto_tree_add_item(tree, proto_quake,
-				tvb, 0, -1, FALSE);
+				tvb, 0, -1, ENC_NA);
 		quake_tree = proto_item_add_subtree(quake_item, ett_quake);
 	}
 
