@@ -7,7 +7,7 @@
  *	http://www.dgs.monash.edu.au/~timf/bottim/
  *	http://www.opt-sci.Arizona.EDU/Pandora/default.asp
  *
- * $Id: packet-quake2.c 35558 2011-01-16 20:51:21Z morriss $
+ * $Id: packet-quake2.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -341,13 +341,12 @@ dissect_quake2_client_commands_uinfo(tvbuff_t *tvb, packet_info *pinfo _U_,
 	proto_tree *tree)
 {
 	guint len;
-	proto_item *userinfo_item;
 
 	len = tvb_strsize(tvb, 0);
 
 	if (tree) {
-		userinfo_item = proto_tree_add_text(tree, tvb, 0, len, "Userinfo: %s",
-			tvb_get_ephemeral_string(tvb, 0, len));
+		proto_tree_add_text(tree, tvb, 0, len, "Userinfo: %s",
+				    tvb_get_ephemeral_string(tvb, 0, len));
 	}
 
 	return len;
@@ -358,13 +357,12 @@ dissect_quake2_client_commands_stringcmd(tvbuff_t *tvb, packet_info *pinfo _U_,
 	proto_tree *tree)
 {
 	guint len;
-	proto_item *stringcmd_item;
 
 	len = tvb_strsize(tvb, 0);
 
 	if (tree) {
-		stringcmd_item = proto_tree_add_text(tree, tvb, 0, len, "Command: %s",
-			tvb_get_ephemeral_string(tvb, 0, len));
+		proto_tree_add_text(tree, tvb, 0, len, "Command: %s",
+				    tvb_get_ephemeral_string(tvb, 0, len));
 	}
 
 	return len;
@@ -696,7 +694,7 @@ dissect_quake2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 		proto_item *quake2_item;
 		quake2_item = proto_tree_add_item(tree, proto_quake2,
-						  tvb, 0, -1, FALSE);
+						  tvb, 0, -1, ENC_NA);
 		quake2_tree = proto_item_add_subtree(quake2_item, ett_quake2);
 		proto_tree_add_uint_format(quake2_tree,
 					   direction == DIR_S2C ?
