@@ -3,7 +3,7 @@
  *
  * Routines for Packetcable's RADIUS AVPs dissection
  *
- * $Id: packet-radius_packetcable.c 36443 2011-04-04 14:37:25Z etxrab $
+ * $Id: packet-radius_packetcable.c 39640 2011-10-27 20:30:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -251,7 +251,7 @@ static void decode_packetcable_bcid (tvbuff_t *tvb, proto_tree *tree, int offset
 	guint8 packetcable_buf[64];
 
 	proto_tree_add_item(tree, hf_packetcable_bcid_timestamp,
-						tvb, offset, 4, FALSE);
+						tvb, offset, 4, ENC_BIG_ENDIAN);
 	tvb_memcpy(tvb, packetcable_buf, offset + 4, 8); packetcable_buf[8] = '\0';
 	proto_tree_add_text(tree, tvb, offset + 4, 8,
 						"Element ID: %s", packetcable_buf);
@@ -260,7 +260,7 @@ static void decode_packetcable_bcid (tvbuff_t *tvb, proto_tree *tree, int offset
 						"Time Zone: DST: %c, Offset: %s", tvb_get_guint8(tvb, offset + 12),
 						packetcable_buf);
 	proto_tree_add_item(tree, hf_packetcable_bcid_event_counter,
-						tvb, offset + 20, 4, FALSE);
+						tvb, offset + 20, 4, ENC_BIG_ENDIAN);
 }
 
 static const gchar* dissect_packetcable_em_hdr(proto_tree* tree, tvbuff_t* tvb, packet_info *pinfo _U_) {
@@ -268,38 +268,38 @@ static const gchar* dissect_packetcable_em_hdr(proto_tree* tree, tvbuff_t* tvb,
 	proto_item *ti;
 	proto_tree *obj_tree;
 
-	proto_tree_add_item(tree, hf_packetcable_em_header_version_id, tvb,  0, 2, FALSE);
+	proto_tree_add_item(tree, hf_packetcable_em_header_version_id, tvb,  0, 2, ENC_BIG_ENDIAN);
 	ti = proto_tree_add_text(tree, tvb,  2, 24, "BCID");
 	obj_tree = proto_item_add_subtree(ti, ett_radius_vendor_packetcable_bcid);
 	decode_packetcable_bcid(tvb, obj_tree,  2);
 
-	proto_tree_add_item(tree, hf_packetcable_em_header_event_message_type, tvb,  26, 2, FALSE);
-	proto_tree_add_item(tree, hf_packetcable_em_header_element_type, tvb,  28, 2, FALSE);
+	proto_tree_add_item(tree, hf_packetcable_em_header_event_message_type, tvb,  26, 2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_packetcable_em_header_element_type, tvb,  28, 2, ENC_BIG_ENDIAN);
 	tvb_memcpy(tvb, packetcable_buf,  30, 8); packetcable_buf[8] = '\0';
 	proto_tree_add_text(tree, tvb,  30, 8, "Element ID: %s", packetcable_buf );
 	tvb_memcpy(tvb, packetcable_buf,  39, 7); packetcable_buf[7] = '\0';
 	proto_tree_add_text(tree, tvb,  38, 8, "Time Zone: DST: %c, Offset: %s", tvb_get_guint8(tvb,  38), packetcable_buf);
-	proto_tree_add_item(tree, hf_packetcable_em_header_sequence_number, tvb,  46, 4, FALSE);
+	proto_tree_add_item(tree, hf_packetcable_em_header_sequence_number, tvb,  46, 4, ENC_BIG_ENDIAN);
 	tvb_memcpy(tvb, packetcable_buf,  50, 18); packetcable_buf[18] = '\0';
 	proto_tree_add_text(tree, tvb,  50, 18, "Event Time: %s", packetcable_buf);
 
-	ti = proto_tree_add_item(tree, hf_packetcable_em_header_status, tvb,  68, 4, FALSE);
+	ti = proto_tree_add_item(tree, hf_packetcable_em_header_status, tvb,  68, 4, ENC_BIG_ENDIAN);
 	obj_tree = proto_item_add_subtree(ti, ett_radius_vendor_packetcable_status);
-	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_error_indicator, tvb,  68, 4, FALSE);
-	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_event_origin, tvb,  68, 4, FALSE);
-	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_event_message_proxied, tvb,  68, 4, FALSE);
+	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_error_indicator, tvb,  68, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_event_origin, tvb,  68, 4, ENC_BIG_ENDIAN);
+	proto_tree_add_item(obj_tree, hf_packetcable_em_header_status_event_message_proxied, tvb,  68, 4, ENC_BIG_ENDIAN);
 
-	proto_tree_add_item(tree, hf_packetcable_em_header_priority, tvb,  72, 1, FALSE);
-	proto_tree_add_item(tree, hf_packetcable_em_header_attribute_count, tvb,  73, 2, FALSE);
-	proto_tree_add_item(tree, hf_packetcable_em_header_event_object, tvb,  75, 1, FALSE);
+	proto_tree_add_item(tree, hf_packetcable_em_header_priority, tvb,  72, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_packetcable_em_header_attribute_count, tvb,  73, 2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_packetcable_em_header_event_object, tvb,  75, 1, ENC_BIG_ENDIAN);
 	return "";
 }
 
 static const gchar* dissect_packetcable_call_term_cause(proto_tree* tree, tvbuff_t* tvb, packet_info *pinfo _U_) {
 	proto_tree_add_item(tree, hf_packetcable_call_termination_cause_source_document,
-						tvb, 0, 2, FALSE);
+						tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(tree, hf_packetcable_call_termination_cause_code,
-						tvb, 2, 4, FALSE);
+						tvb, 2, 4, ENC_BIG_ENDIAN);
 
 	return "";
 }
@@ -311,9 +311,9 @@ static const gchar* dissect_packetcable_rel_call_billing_correlation(proto_tree*
 
 static const gchar* dissect_packetcable_trunk_group_id(proto_tree* tree, tvbuff_t* tvb, packet_info *pinfo _U_) {
 	proto_tree_add_item(tree, hf_packetcable_trunk_group_id_trunk_type,
-						tvb, 0, 2, FALSE);
+						tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(tree, hf_packetcable_trunk_group_id_trunk_number,
-						tvb, 2, 4, FALSE);
+						tvb, 2, 4, ENC_BIG_ENDIAN);
 	return "";
 }
 
@@ -321,15 +321,15 @@ static const gchar* dissect_packetcable_qos_descriptor(proto_tree* tree, tvbuff_
 	guint8 packetcable_buf[64];
 	guint32 intval;
 	guint32 packetcable_qos_flags = tvb_get_ntohl(tvb, 0);
-	proto_item* ti = proto_tree_add_item(tree, hf_packetcable_qos_status, tvb, 0, 4, FALSE);
+	proto_item* ti = proto_tree_add_item(tree, hf_packetcable_qos_status, tvb, 0, 4, ENC_BIG_ENDIAN);
 	proto_tree* obj_tree = proto_item_add_subtree(ti, ett_radius_vendor_packetcable_qos_status);
 
 	guint packetcable_qos_off = 20;
 
-	proto_tree_add_item(obj_tree, hf_packetcable_qos_status_indication, tvb, 0, 4, FALSE);
+	proto_tree_add_item(obj_tree, hf_packetcable_qos_status_indication, tvb, 0, 4, ENC_BIG_ENDIAN);
 
 	for (intval = 0; intval < PACKETCABLE_QOS_DESC_BITFIELDS; intval++) {
-		proto_tree_add_item(obj_tree, hf_packetcable_qos_desc_flags[intval], tvb, 0, 4, FALSE);
+		proto_tree_add_item(obj_tree, hf_packetcable_qos_desc_flags[intval], tvb, 0, 4, ENC_BIG_ENDIAN);
 	}
 
 	tvb_memcpy(tvb, packetcable_buf, 4, 16);
@@ -340,7 +340,7 @@ static const gchar* dissect_packetcable_qos_descriptor(proto_tree* tree, tvbuff_
 	for (intval = 0; intval < PACKETCABLE_QOS_DESC_BITFIELDS; intval++) {
 		if (packetcable_qos_flags & packetcable_qos_desc_mask[intval]) {
 			proto_tree_add_item(tree, hf_packetcable_qos_desc_fields[intval],
-								tvb, packetcable_qos_off, 4, FALSE);
+								tvb, packetcable_qos_off, 4, ENC_BIG_ENDIAN);
 			packetcable_qos_off += 4;
 		}
 	}
@@ -349,7 +349,7 @@ static const gchar* dissect_packetcable_qos_descriptor(proto_tree* tree, tvbuff_
 }
 
 static const gchar* dissect_packetcable_time_adjustment(proto_tree* tree, tvbuff_t* tvb, packet_info *pinfo _U_) {
-	proto_tree_add_item(tree, hf_packetcable_time_adjustment, tvb, 0, 8, FALSE);
+	proto_tree_add_item(tree, hf_packetcable_time_adjustment, tvb, 0, 8, ENC_BIG_ENDIAN);
 
 	return "";
 }
@@ -366,7 +366,7 @@ static const gchar* dissect_packetcable_redirected_from_info(proto_tree* tree, t
 						"Original-Called-Party: %s", packetcable_buf);
 
 	proto_tree_add_item(tree, hf_packetcable_redirected_from_info_number_of_redirections,
-						tvb, 40, 2, FALSE);
+						tvb, 40, 2, ENC_BIG_ENDIAN);
 
 	return "";
 }
@@ -377,13 +377,13 @@ static const gchar* dissect_packetcable_time_electr_surv_ind(proto_tree* tree, t
 		return "None";
 
 	proto_tree_add_item(tree, hf_packetcable_electronic_surveillance_indication_df_cdc_address,
-						tvb, 0, 4, FALSE);
+						tvb, 0, 4, ENC_BIG_ENDIAN);
 	proto_tree_add_item(tree, hf_packetcable_electronic_surveillance_indication_df_ccc_address,
-						tvb, 4, 4, FALSE);
+						tvb, 4, 4, ENC_BIG_ENDIAN);
 	proto_tree_add_item(tree, hf_packetcable_electronic_surveillance_indication_cdc_port,
-						tvb, 8, 2, FALSE);
+						tvb, 8, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(tree, hf_packetcable_electronic_surveillance_indication_ccc_port,
-						tvb, 10, 2, FALSE);
+						tvb, 10, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_text(tree, tvb, 12, tvb_length(tvb) - 12, "DF-DF-Key");
 
 	return "";
@@ -402,39 +402,39 @@ static const gchar* dissect_packetcable_term_dsply_info(proto_tree* tree, tvbuff
 	guint8 bitmask = tvb_get_guint8(tvb, 2);
 	guint intval = 1;
 	proto_item* ti = proto_tree_add_item(tree, hf_packetcable_terminal_display_info_terminal_display_status_bitmask,
-							 tvb, 0, 1, FALSE);
+							 tvb, 0, 1, ENC_BIG_ENDIAN);
 	proto_tree* obj_tree = proto_item_add_subtree(ti, ett_packetcable_term_dsply);
 
-	proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_sbm_general_display,
+	proto_tree_add_boolean(obj_tree, hf_packetcable_terminal_display_info_sbm_general_display,
 						tvb, 0, 1, bitmask);
-	proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_sbm_calling_number,
+	proto_tree_add_boolean(obj_tree, hf_packetcable_terminal_display_info_sbm_calling_number,
 						tvb, 0, 1, bitmask);
-	proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_sbm_calling_name,
+	proto_tree_add_boolean(obj_tree, hf_packetcable_terminal_display_info_sbm_calling_name,
 						tvb, 0, 1, bitmask);
-	proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_sbm_message_waiting,
+	proto_tree_add_boolean(obj_tree, hf_packetcable_terminal_display_info_sbm_message_waiting,
 						tvb, 0, 1, bitmask);
 
 	if (bitmask & PACKETCABLE_GENERAL_DISPLAY) {
 		proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_general_display,
-							tvb, intval, 80, FALSE);
+							tvb, intval, 80, ENC_ASCII|ENC_NA);
 		intval += 80;
 	}
 
 	if (bitmask & PACKETCABLE_CALLING_NUMBER) {
 		proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_calling_number,
-							tvb, intval, 40, FALSE);
+							tvb, intval, 40, ENC_ASCII|ENC_NA);
 		intval += 40;
 	}
 
 	if (bitmask & PACKETCABLE_CALLING_NAME) {
 		proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_calling_name,
-							tvb, intval, 40, FALSE);
+							tvb, intval, 40, ENC_ASCII|ENC_NA);
 		intval += 40;
 	}
 
 	if (bitmask & PACKETCABLE_MESSAGE_WAITING) {
 		proto_tree_add_item(obj_tree, hf_packetcable_terminal_display_info_message_waiting,
-							tvb, intval, 40, FALSE);
+							tvb, intval, 40, ENC_ASCII|ENC_NA);
 	}
 
 	return "";
