@@ -1,6 +1,6 @@
 /* packet-redback.c
  *
- * $Id: packet-redback.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-redback.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,7 +28,6 @@
 #endif
 
 #include <glib.h>
-#include <epan/proto.h>
 #include <epan/packet.h>
 #include "packet-ip.h"
 
@@ -70,19 +69,19 @@ dissect_redback(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	l3off = tvb_get_ntohs(tvb, 22);
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_redback, tvb, 0, -1, FALSE);
+		ti = proto_tree_add_item(tree, proto_redback, tvb, 0, -1, ENC_NA);
 		rbtree = proto_item_add_subtree(ti, ett_redback);
 
-		proto_tree_add_item(rbtree, hf_redback_context, tvb, 0, 4, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_flags, tvb, 4, 4, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_circuit, tvb, 8, 8, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_length, tvb, 16, 2, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_protocol, tvb, 18, 2, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_dataoffset, tvb, 20, 2, FALSE);
-		proto_tree_add_item(rbtree, hf_redback_l3offset, tvb, 22, 2, FALSE);
+		proto_tree_add_item(rbtree, hf_redback_context, tvb, 0, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_flags, tvb, 4, 4, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_circuit, tvb, 8, 8, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_length, tvb, 16, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_protocol, tvb, 18, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_dataoffset, tvb, 20, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(rbtree, hf_redback_l3offset, tvb, 22, 2, ENC_BIG_ENDIAN);
 
 		if (dataoff > 24) {
-			proto_tree_add_item(rbtree, hf_redback_padding, tvb, 24, dataoff-24, FALSE);
+			proto_tree_add_item(rbtree, hf_redback_padding, tvb, 24, dataoff-24, ENC_NA);
 		}
 	}
 
@@ -106,7 +105,7 @@ dissect_redback(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		case 0x02:
 			/*
 			 * This is ISIS - Either incoming with ethernet FCS
-			 * and CLNP - passed to the eth dissector or in case 
+			 * and CLNP - passed to the eth dissector or in case
 			 * of outgoing its pure ISIS and the linecard attaches
 			 * the ethernet and CLNP headers ...
 			 *
@@ -137,7 +136,7 @@ dissect_redback(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				next_tvb = tvb_new_subset_remaining(tvb, dataoff);
 			} else {
 				if (tree)
-					proto_tree_add_item(rbtree, hf_redback_unknown, tvb, dataoff, 4, FALSE);
+					proto_tree_add_item(rbtree, hf_redback_unknown, tvb, dataoff, 4, ENC_NA);
 				next_tvb = tvb_new_subset_remaining(tvb, dataoff+4);
 			}
 
