@@ -1,6 +1,6 @@
 /* packet-redbackli.c
  *
- * $Id: packet-redbackli.c 39774 2011-11-09 17:33:18Z wmeier $
+ * $Id: packet-redbackli.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Redback Lawful Intercept Packet dissector
  *
@@ -29,11 +29,8 @@
 #include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <time.h>
-
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/strutil.h>
