@@ -6,7 +6,7 @@
  * RFC2082 ( Keyed Message Digest Algorithm )
  *   Emanuele Caratti  <wiz@iol.it>
  *
- * $Id: packet-rip.c 35892 2011-02-09 22:43:06Z morriss $
+ * $Id: packet-rip.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -132,7 +132,7 @@ dissect_rip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		    val_to_str(command, command_vals, "Unknown command (%u)"));
 
     if (tree) {
-	ti = proto_tree_add_item(tree, proto_rip, tvb, 0, -1, FALSE);
+	ti = proto_tree_add_item(tree, proto_rip, tvb, 0, -1, ENC_NA);
 	rip_tree = proto_item_add_subtree(ti, ett_rip);
 
 	proto_tree_add_uint(rip_tree, hf_rip_command, tvb, 0, 1, command);
@@ -193,14 +193,14 @@ dissect_unspec_rip_vektor(tvbuff_t *tvb, int offset, guint8 version,
 			     metric);
     rip_vektor_tree = proto_item_add_subtree(ti, ett_rip_vec);
 
-    proto_tree_add_item(rip_vektor_tree, hf_rip_family, tvb, offset, 2, FALSE);
+    proto_tree_add_item(rip_vektor_tree, hf_rip_family, tvb, offset, 2, ENC_BIG_ENDIAN);
     if (version == RIPv2) {
 	proto_tree_add_item(rip_vektor_tree, hf_rip_route_tag, tvb, offset+2, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 	proto_tree_add_item(rip_vektor_tree, hf_rip_netmask, tvb, offset+8, 4,
-			    FALSE);
+			    ENC_BIG_ENDIAN);
 	proto_tree_add_item(rip_vektor_tree, hf_rip_next_hop, tvb, offset+12, 4,
-			    FALSE);
+			    ENC_BIG_ENDIAN);
     }
     proto_tree_add_uint(rip_vektor_tree, hf_rip_metric, tvb,
 			offset+16, 4, metric);
@@ -220,19 +220,19 @@ dissect_ip_rip_vektor(tvbuff_t *tvb, int offset, guint8 version,
 			     tvb_ip_to_str(tvb, offset+4), metric);
     rip_vektor_tree = proto_item_add_subtree(ti, ett_rip_vec);
 
-    proto_tree_add_item(rip_vektor_tree, hf_rip_family, tvb, offset, 2, FALSE);
+    proto_tree_add_item(rip_vektor_tree, hf_rip_family, tvb, offset, 2, ENC_BIG_ENDIAN);
     if (version == RIPv2) {
 	proto_tree_add_item(rip_vektor_tree, hf_rip_route_tag, tvb, offset+2, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
     }
 
-    proto_tree_add_item(rip_vektor_tree, hf_rip_ip, tvb, offset+4, 4, FALSE);
+    proto_tree_add_item(rip_vektor_tree, hf_rip_ip, tvb, offset+4, 4, ENC_BIG_ENDIAN);
 
     if (version == RIPv2) {
 	proto_tree_add_item(rip_vektor_tree, hf_rip_netmask, tvb, offset+8, 4,
-			    FALSE);
+			    ENC_BIG_ENDIAN);
 	proto_tree_add_item(rip_vektor_tree, hf_rip_next_hop, tvb, offset+12, 4,
-			    FALSE);
+			    ENC_BIG_ENDIAN);
     }
     proto_tree_add_uint(rip_vektor_tree, hf_rip_metric, tvb,
 			offset+16, 4, metric);
@@ -260,7 +260,7 @@ dissect_rip_authentication(tvbuff_t *tvb, int offset, proto_tree *tree)
 
     case AUTH_PASSWORD: /* Plain text password */
 	proto_tree_add_item(rip_authentication_tree, hf_rip_auth_passwd,
-			tvb, offset+4, 16, FALSE);
+			tvb, offset+4, 16, ENC_ASCII|ENC_NA);
 	break;
 
     case AUTH_KEYED_MSG_DIGEST: /* Keyed MD5 rfc 2082 */
