@@ -3,7 +3,7 @@
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  * derived from packet-rip.c
  *
- * $Id: packet-ripng.c 36033 2011-02-23 17:31:03Z morriss $
+ * $Id: packet-ripng.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -74,43 +74,43 @@ dissect_ripng(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     }
 
     if (tree) {
-	ti = proto_tree_add_item(tree, proto_ripng, tvb, offset, -1, FALSE);
+	ti = proto_tree_add_item(tree, proto_ripng, tvb, offset, -1, ENC_NA);
 	ripng_tree = proto_item_add_subtree(ti, ett_ripng);
 
 	/* Command */
-	proto_tree_add_item(ripng_tree, hf_ripng_cmd, tvb, offset, 1, FALSE);
+	proto_tree_add_item(ripng_tree, hf_ripng_cmd, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset += 1;
 
 	/* Version */
-	proto_tree_add_item(ripng_tree, hf_ripng_version, tvb, offset, 1, FALSE);
+	proto_tree_add_item(ripng_tree, hf_ripng_version, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset += 1;
 
 	/* Reserved */
-	proto_tree_add_item(ripng_tree, hf_ripng_reserved, tvb, offset, 2, FALSE);
+	proto_tree_add_item(ripng_tree, hf_ripng_reserved, tvb, offset, 2, ENC_NA);
 	offset += 2;
 
 	/* Route Table Entry */
 	while (tvb_reported_length_remaining(tvb, offset) > 0) {
 
-		rte_ti = proto_tree_add_item(ripng_tree, hf_ripng_rte, tvb, offset, 16 + 2 + 1 + 1, FALSE);
+		rte_ti = proto_tree_add_item(ripng_tree, hf_ripng_rte, tvb, offset, 16 + 2 + 1 + 1, ENC_NA);
 		rte_tree = proto_item_add_subtree(rte_ti, ett_ripng_rte);
 
 		/* IPv6 Prefix */
-		proto_tree_add_item(rte_tree, hf_ripng_rte_ipv6_prefix, tvb, offset, 16, FALSE);
+		proto_tree_add_item(rte_tree, hf_ripng_rte_ipv6_prefix, tvb, offset, 16, ENC_NA);
 		proto_item_append_text(rte_ti, ": IPv6 Prefix: %s", tvb_ip6_to_str(tvb, offset));
 		offset += 16;
 
 		/* Route Tag */
-		proto_tree_add_item(rte_tree, hf_ripng_rte_route_tag, tvb, offset, 2, FALSE);
+		proto_tree_add_item(rte_tree, hf_ripng_rte_route_tag, tvb, offset, 2, ENC_BIG_ENDIAN);
 		offset += 2;
 
 		/* Prefix Length */
-		proto_tree_add_item(rte_tree, hf_ripng_rte_prefix_length, tvb, offset, 1, FALSE);
+		proto_tree_add_item(rte_tree, hf_ripng_rte_prefix_length, tvb, offset, 1, ENC_BIG_ENDIAN);
 		proto_item_append_text(rte_ti, "/%u", tvb_get_guint8(tvb, offset));
 		offset += 1;
 
 		/* Metric */
-		proto_tree_add_item(rte_tree, hf_ripng_rte_metric, tvb, offset, 1, FALSE);
+		proto_tree_add_item(rte_tree, hf_ripng_rte_metric, tvb, offset, 1, ENC_BIG_ENDIAN);
 		proto_item_append_text(rte_ti, " Metric: %u", tvb_get_guint8(tvb, offset));
 		offset += 1;
 	}
