@@ -1,7 +1,7 @@
 /* Routines for UMTS RLC (Radio Link Control) disassembly
  * http://www.3gpp.org/ftp/Specs/archive/25_series/25.322/
  *
- * $Id: packet-rlc.c 41585 2012-03-16 00:05:36Z wmeier $
+ * $Id: packet-rlc.c 42889 2012-05-28 20:34:27Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,13 +27,14 @@
 #endif
 
 #include <string.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/conversation.h>
 #include <epan/asn1.h>
 #include <epan/expert.h>
 #include <epan/prefs.h>
+
 #include "packet-umts_fp.h"
 #include "packet-umts_mac.h"
 #include "packet-rlc.h"
@@ -1046,9 +1047,17 @@ rlc_decode_li(enum rlc_mode mode, tvbuff_t *tvb, packet_info *pinfo, proto_tree
 	guint16     total_len;
 
 	switch (mode) {
-		case RLC_AM: offs = 1; break;
-		case RLC_UM: offs = 0; break;
-		case RLC_TM: return -1;
+		case RLC_AM:
+			offs = 1; 
+			break;
+		case RLC_UM:
+			offs = 0; 
+			break;
+		case RLC_TM:
+			/* fall trough */
+		case RLC_UNKNOWN_MODE:
+		default:
+			return -1;
 	}
 	hdr_len = offs;
 	/* calculate header length */
@@ -1481,7 +1490,6 @@ dissect_rlc_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_bits_ret_val(tree, hf_rlc_rsn, tvb, 4, 1, &rsn, ENC_BIG_ENDIAN);
 			proto_tree_add_bits_ret_val(tree, hf_rlc_r1, tvb, 5, 3, &r1, ENC_BIG_ENDIAN);
 			if (r1) {
-				proto_item *malformed;
 				malformed = proto_tree_add_protocol_format(tree,
 				proto_malformed, tvb, 0, 0, "[Malformed Packet: %s]", pinfo->current_proto);
 				expert_add_info_format(pinfo, malformed, PI_MALFORMED, PI_ERROR,
@@ -1799,7 +1807,12 @@ dissect_rlc_ps_dtch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	fpi  = p_get_proto_data(pinfo->fd, proto_fp);
 	rlci = p_get_proto_data(pinfo->fd, proto_rlc);
 
-	if (!fpi || !rlci) return;
+	if (!fpi || !rlci) {
+		ti = proto_tree_add_text(tree, tvb, 0, -1,
+					 "Can't dissect RLC frame because no per-frame info was attached!");
+		PROTO_ITEM_SET_GENERATED(ti);
+		return;
+	}
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_rlc, tvb, 0, -1, ENC_NA);
