@@ -1,6 +1,6 @@
 /* Routines for UMTS RLC disassembly
  *
- * $Id: packet-rlc.h 39656 2011-10-28 18:36:20Z martinm $
+ * $Id: packet-rlc.h 42889 2012-05-28 20:34:27Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -21,12 +21,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+/* Do not change enum order and append only to keep
+   backward compatibility with UDP framing format */
 enum rlc_mode {
 	RLC_TM,
 	RLC_UM,
-	RLC_AM
+	RLC_AM,
+	RLC_UNKNOWN_MODE
 };
 
+/* Do not change enum order and append only to keep
+   backward compatibility with UDP framing format */
 enum rlc_li_size {
 	RLC_LI_VARIABLE,
 	RLC_LI_7BITS,
