@@ -2,7 +2,7 @@
  * Routines for RLM dissection
  * Copyright 2004, Duncan Sargeant <dunc-ethereal@rcpt.to>
  *
- * $Id: packet-rlm.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-rlm.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,9 +51,8 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/xdlc.h>
 
@@ -140,23 +139,23 @@ dissect_rlm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	switch (rlm_type) {
 		case RLM_START_REQUEST:
 			type_str = "Start request";
-			break;;
+			break;
 
 		case RLM_START_ACK:
 			type_str = "Start acknowledgement";
-			break;;
+			break;
 
 		case RLM_ECHO_REQUEST:
 			type_str = "Echo request";
-			break;;
+			break;
 
 		case RLM_ECHO_REPLY:
 			type_str = "Echo reply";
-			break;;
+			break;
 
 		default:
 			type_str = "Unknown type";
-			break;;
+			break;
 	}
 
 	col_set_str(pinfo->cinfo, COL_INFO, type_str);
