@@ -2,7 +2,7 @@
  * Routines for roofnet dissection
  * Copyright 2006, Sebastien Tandel (sebastien@tandel.be)
  *
- * $Id: packet-roofnet.c 39566 2011-10-25 16:04:31Z wmeier $
+ * $Id: packet-roofnet.c 42131 2012-04-18 12:35:36Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -147,8 +147,8 @@ static void dissect_roofnet_link(proto_tree *tree, tvbuff_t *tvb, guint *offset,
   it = proto_tree_add_text(tree, tvb, *offset, ROOFNET_LINK_LEN,
 			    "link: %u, src: %s, dst: %s",
 			    link,
-			    (char*)get_hostname(addr_src),
-			    (char*)get_hostname(addr_dst));
+			    get_hostname(addr_src),
+			    get_hostname(addr_dst));
   subtree= proto_item_add_subtree(it, ett_roofnet_link);
 
   proto_tree_add_ipv4(subtree, hf_roofnet_link_src, tvb, *offset, 4, addr_src);
