@@ -2,7 +2,7 @@
  * Routines for rquota dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id: packet-rquota.c 34322 2010-10-02 01:33:02Z morriss $
+ * $Id: packet-rquota.c 39260 2011-10-04 22:44:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,7 +77,7 @@ dissect_rquota(tvbuff_t *tvb, int offset, proto_tree *tree)
 	proto_tree *lock_tree = NULL;
 
 	lock_item = proto_tree_add_item(tree, hf_rquota_rquota, tvb,
-			offset, -1, FALSE);
+			offset, -1, ENC_NA);
 
 	lock_tree = proto_item_add_subtree(lock_item, ett_rquota_rquota);
 
