@@ -2,7 +2,7 @@
  * Routines for rsh (Remote Shell) dissection
  * Copyright 2012, Stephen Fisher (see AUTHORS file)
  *
- * $Id: packet-rsh.c 41056 2012-02-17 18:28:07Z sfisher $
+ * $Id: packet-rsh.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,15 +32,13 @@
 # include "config.h"
 #endif
 
-#include <glib.h>
-
-#include <stdio.h>
-#include <stdlib.h>
 #include <ctype.h>
 
+#include <glib.h>
+
+#include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/emem.h>
-#include <epan/packet.h>
 #include <epan/prefs.h>
 #include <wsutil/str_util.h>
 
