@@ -3,7 +3,7 @@
  * [ very rough, but mininally functional ]
  * Copyright 2003, Brad Hards <bradh@frogmouth.net>
  *
- * $Id: packet-rsync.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-rsync.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,10 +28,8 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-
 #include <string.h>
-#include <time.h>
+
 #include <glib.h>
 
 #include <epan/packet.h>
