@@ -8,7 +8,7 @@
  * 385 Moffett Park Drive
  * Sunnyvale, CA 94089
  *
- * $Id: packet-rtps2.h 31026 2009-11-19 21:30:25Z jake $
+ * $Id: packet-rtps2.h 32473 2010-04-15 17:49:15Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -330,6 +330,8 @@ typedef enum {
 #define RTPS_VENDOR_UNKNOWN_STRING      "VENDOR_ID_UNKNOWN (0x0000)"
 #define RTPS_VENDOR_RTI                 (0x0101)
 #define RTPS_VENDOR_RTI_STRING          "Real-Time Innovations, Inc."
+#define RTPS_VENDOR_TOC                 (0x0106)
+#define RTPS_VENDOR_TOC_STRING          "Twin Oaks Computing, Inc."
 
 /* Parameter Liveliness */
 #define LIVELINESS_AUTOMATIC            (0)
