@@ -4,7 +4,7 @@
  *
  * Heikki Vatiainen <hessu@cs.tut.fi>
  *
- * $Id: packet-sap.c 36031 2011-02-23 13:51:49Z etxrab $
+ * $Id: packet-sap.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -145,7 +145,7 @@ dissect_sap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
 
 	if (tree) {
-	  si = proto_tree_add_item(tree, proto_sap, tvb, offset, -1, FALSE);
+	  si = proto_tree_add_item(tree, proto_sap, tvb, offset, -1, ENC_NA);
 	  sap_tree = proto_item_add_subtree(si, ett_sap);
 
 	  sif = proto_tree_add_uint(sap_tree, hf_sap_flags, tvb, offset, 1, vers_flags);
@@ -180,7 +180,7 @@ dissect_sap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
                   auth_data_len = auth_len * sizeof(guint32);
 
-                  sdi = proto_tree_add_item(sap_tree, hf_auth_data, tvb, offset, auth_data_len, FALSE);
+                  sdi = proto_tree_add_item(sap_tree, hf_auth_data, tvb, offset, auth_data_len, ENC_NA);
                   sa_tree = proto_item_add_subtree(sdi, ett_sap_auth);
 
                   auth_flags = tvb_get_guint8(tvb, offset);
