@@ -4,7 +4,7 @@
  * Ronnie sahlberg 2006
  * Joe Breher 2006
  *
- * $Id: packet-scsi-osd.c 32410 2010-04-06 21:14:01Z wmeier $
+ * $Id: packet-scsi-osd.c 39507 2011-10-21 14:33:43Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -190,7 +190,7 @@ static void
 dissect_osd_user_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* user object id */
-	proto_tree_add_item(tree, hf_scsi_osd_user_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_user_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -202,7 +202,7 @@ attribute_1_82(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	int offset=0;
 
 	/* user object id */
-	proto_tree_add_item(tree, hf_scsi_osd_user_object_logical_length, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_user_object_logical_length, tvb, offset, 8, ENC_BIG_ENDIAN);
 	offset+=8;
 }
 
@@ -257,7 +257,7 @@ dissect_osd_attributes_list(packet_info *pinfo, tvbuff_t *tvb, int offset, proto
 
 	/* list type */
 	type=tvb_get_guint8(tvb, offset)&0x0f;
-	proto_tree_add_item(tree, hf_scsi_osd_attributes_list_type, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_attributes_list_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* a reserved byte */
@@ -265,11 +265,11 @@ dissect_osd_attributes_list(packet_info *pinfo, tvbuff_t *tvb, int offset, proto
 
 	/* length */
 	length=tvb_get_ntohs(tvb, offset);
-	proto_tree_add_item(tree, hf_scsi_osd_attributes_list_length, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_attributes_list_length, tvb, offset, 2, ENC_BIG_ENDIAN);
 	offset+=2;
 
 	/* if type is 1 length will be zero and we have to cycle over
-	 * all remaining bytes.   7.1.3.1 
+	 * all remaining bytes.   7.1.3.1
 	 */
 	if(type==1){
 		length=tvb_length_remaining(tvb, offset);
@@ -280,12 +280,12 @@ dissect_osd_attributes_list(packet_info *pinfo, tvbuff_t *tvb, int offset, proto
 		case 0x01: /* retrieving attributes 7.1.3.2 */
 			/* attributes page */
 			page=tvb_get_ntohl(tvb, offset);
-			proto_tree_add_item(tree, hf_scsi_osd_attributes_page, tvb, offset, 4, 0);
+			proto_tree_add_item(tree, hf_scsi_osd_attributes_page, tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset+=4;
 
 			/* attribute number */
 			number=tvb_get_ntohl(tvb, offset);
-			item=proto_tree_add_item(tree, hf_scsi_osd_attribute_number, tvb, offset, 4, 0);
+			item=proto_tree_add_item(tree, hf_scsi_osd_attribute_number, tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset+=4;
 
 			/* find the proper attributes page */
@@ -323,17 +323,17 @@ dissect_osd_attributes_list(packet_info *pinfo, tvbuff_t *tvb, int offset, proto
 		case 0x09: /* retrieved/set attributes 7.1.3.3 */
 			/* attributes page */
 			page=tvb_get_ntohl(tvb, offset);
-			proto_tree_add_item(tree, hf_scsi_osd_attributes_page, tvb, offset, 4, 0);
+			proto_tree_add_item(tree, hf_scsi_osd_attributes_page, tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset+=4;
 
 			/* attribute number */
 			number=tvb_get_ntohl(tvb, offset);
-			item=proto_tree_add_item(tree, hf_scsi_osd_attribute_number, tvb, offset, 4, 0);
+			item=proto_tree_add_item(tree, hf_scsi_osd_attribute_number, tvb, offset, 4, ENC_BIG_ENDIAN);
 			offset+=4;
 
 			/* attribute length */
 			attribute_length=tvb_get_ntohs(tvb, offset);
-			proto_tree_add_item(tree, hf_scsi_osd_attribute_length, tvb, offset, 2, 0);
+			proto_tree_add_item(tree, hf_scsi_osd_attribute_length, tvb, offset, 2, ENC_BIG_ENDIAN);
 			offset+=2;
 
 			/* find the proper attributes page */
@@ -399,16 +399,16 @@ dissect_osd_option(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 	option=tvb_get_guint8(tvb, offset);
 
 	if(parent_tree){
-		it=proto_tree_add_item(parent_tree, hf_scsi_osd_option, tvb, offset, 1, 0);
+		it=proto_tree_add_item(parent_tree, hf_scsi_osd_option, tvb, offset, 1, ENC_BIG_ENDIAN);
 		tree = proto_item_add_subtree(it, ett_osd_option);
 	}
 
-	proto_tree_add_item(tree, hf_scsi_osd_option_dpo, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_option_dpo, tvb, offset, 1, ENC_BIG_ENDIAN);
 	if(option&0x10){
 		proto_item_append_text(tree, " DPO");
 	}
 
-	proto_tree_add_item(tree, hf_scsi_osd_option_fua, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_option_fua, tvb, offset, 1, ENC_BIG_ENDIAN);
 	if(option&0x08){
 		proto_item_append_text(tree, " FUA");
 	}
@@ -428,7 +428,7 @@ dissect_osd_getsetattrib(tvbuff_t *tvb, int offset, proto_tree *tree, scsi_task_
 		scsi_osd_extra_data_t *extra_data=cdata->itlq->extra_data;
 		extra_data->gsatype=(tvb_get_guint8(tvb, offset)>>4)&0x03;
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_getsetattrib, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_getsetattrib, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 
@@ -441,14 +441,14 @@ static const value_string scsi_osd_timestamps_control_vals[] = {
 static void
 dissect_osd_timestamps_control(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_timestamps_control, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_timestamps_control, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 
 static void
 dissect_osd_formatted_capacity(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_formatted_capacity, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_formatted_capacity, tvb, offset, 8, ENC_BIG_ENDIAN);
 }
 
 
@@ -465,7 +465,7 @@ dissect_osd_attribute_parameters(tvbuff_t *tvb, int offset, proto_tree *parent_t
 		    "Attribute Parameters");
 		tree = proto_item_add_subtree(item, ett_osd_attribute_parameters);
 	}
-		
+
 	if(cdata && cdata->itlq && cdata->itlq->extra_data){
 		extra_data=cdata->itlq->extra_data;
 		gsatype=extra_data->gsatype;
@@ -475,23 +475,23 @@ dissect_osd_attribute_parameters(tvbuff_t *tvb, int offset, proto_tree *parent_t
 
 	switch(gsatype){
 	case 2: /* 5.2.2.2  attribute page */
-		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_page, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_page, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_allocation_length, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_allocation_length, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_retrieved_attributes_offset, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_retrieved_attributes_offset, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_page, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_page, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_set_attribute_number, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attribute_number, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_set_attribute_length, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attribute_length, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
-		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_offset, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_offset, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
 		break;
 	case 3: /* 5.2.2.3  attribute list */
-		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_list_length, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_list_length, tvb, offset, 4, ENC_BIG_ENDIAN);
 		extra_data->u.al.get_list_length=tvb_get_ntohl(tvb, offset);
 		offset+=4;
 
@@ -502,7 +502,7 @@ dissect_osd_attribute_parameters(tvbuff_t *tvb, int offset, proto_tree *parent_t
 		proto_tree_add_uint(tree, hf_scsi_osd_get_attributes_list_offset, tvb, offset, 4, extra_data->u.al.get_list_offset);
 		offset+=4;
 
-		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_allocation_length, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_get_attributes_allocation_length, tvb, offset, 4, ENC_BIG_ENDIAN);
 		extra_data->u.al.get_list_allocation_length=tvb_get_ntohl(tvb, offset);
 		offset+=4;
 
@@ -513,11 +513,11 @@ dissect_osd_attribute_parameters(tvbuff_t *tvb, int offset, proto_tree *parent_t
 		proto_tree_add_uint(tree, hf_scsi_osd_retrieved_attributes_offset, tvb, offset, 4, extra_data->u.al.retrieved_list_offset);
 		offset+=4;
 
-		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_list_length, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_list_length, tvb, offset, 4, ENC_BIG_ENDIAN);
 		extra_data->u.al.set_list_length=tvb_get_ntohl(tvb, offset);
 		offset+=4;
 
-		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_list_offset, tvb, offset, 4, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_set_attributes_list_offset, tvb, offset, 4, ENC_BIG_ENDIAN);
 		extra_data->u.al.set_list_offset=tvb_get_ntohl(tvb, offset);
 		offset+=4;
 
@@ -655,54 +655,54 @@ dissect_osd_permissions(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 	proto_item *it=NULL;
 	guint16 permissions;
 
-	permissions=tvb_get_ntohs(tvb, offset); 
+	permissions=tvb_get_ntohs(tvb, offset);
 
 	if(parent_tree){
-		it=proto_tree_add_item(parent_tree, hf_scsi_osd_permissions, tvb, offset, 2, 0);
+		it=proto_tree_add_item(parent_tree, hf_scsi_osd_permissions, tvb, offset, 2, ENC_BIG_ENDIAN);
 		tree = proto_item_add_subtree(it, ett_osd_permission_bitmask);
 	}
 
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_read, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_read, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x8000){
 		proto_item_append_text(tree, " READ");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_write, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_write, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x4000){
 		proto_item_append_text(tree, " WRITE");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_get_attr, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_get_attr, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x2000){
 		proto_item_append_text(tree, " GET_ATTR");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_set_attr, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_set_attr, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x1000){
 		proto_item_append_text(tree, " SET_ATTR");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_create, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_create, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0800){
 		proto_item_append_text(tree, " CREATE");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_remove, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_remove, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0400){
 		proto_item_append_text(tree, " REMOVE");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_obj_mgmt, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_obj_mgmt, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0200){
 		proto_item_append_text(tree, " OBJ_MGMT");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_append, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_append, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0100){
 		proto_item_append_text(tree, " APPEND");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_dev_mgmt, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_dev_mgmt, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0080){
 		proto_item_append_text(tree, " DEV_MGMT");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_global, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_global, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0040){
 		proto_item_append_text(tree, " GLOBAL");
 	}
-	proto_tree_add_item(tree, hf_scsi_osd_permissions_pol_sec, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_permissions_pol_sec, tvb, offset, 2, ENC_BIG_ENDIAN);
 	if(permissions&0x0020){
 		proto_item_append_text(tree, " POL/SEC");
 	}
@@ -720,41 +720,41 @@ dissect_osd_capability(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 		    "Capability");
 		tree = proto_item_add_subtree(item, ett_osd_capability);
 	}
-		
+
 	/* capability format */
-	proto_tree_add_item(tree, hf_scsi_osd_capability_format, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_capability_format, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* key version and icva */
-	proto_tree_add_item(tree, hf_scsi_osd_key_version, tvb, offset, 1, 0);
-	proto_tree_add_item(tree, hf_scsi_osd_icva, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_key_version, tvb, offset, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(tree, hf_scsi_osd_icva, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* security method */
-	proto_tree_add_item(tree, hf_scsi_osd_security_method, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_security_method, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* a reserved byte */
 	offset++;
 
 	/* capability expiration time */
-	proto_tree_add_item(tree, hf_scsi_osd_capability_expiration_time, tvb, offset, 6, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_capability_expiration_time, tvb, offset, 6, ENC_NA);
 	offset+=6;
 
 	/* audit */
-	proto_tree_add_item(tree, hf_scsi_osd_audit, tvb, offset, 20, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_audit, tvb, offset, 20, ENC_NA);
 	offset+=20;
 
 	/* capability discriminator */
-	proto_tree_add_item(tree, hf_scsi_osd_capability_discriminator, tvb, offset, 12, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_capability_discriminator, tvb, offset, 12, ENC_NA);
 	offset+=12;
 
 	/* object created time */
-	proto_tree_add_item(tree, hf_scsi_osd_object_created_time, tvb, offset, 6, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_object_created_time, tvb, offset, 6, ENC_NA);
 	offset+=6;
 
 	/* object type */
-	proto_tree_add_item(tree, hf_scsi_osd_object_type, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_object_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* permission bitmask */
@@ -765,11 +765,11 @@ dissect_osd_capability(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 	offset++;
 
 	/* object descriptor type */
-	proto_tree_add_item(tree, hf_scsi_osd_object_descriptor_type, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_object_descriptor_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 
 	/* object descriptor */
-	proto_tree_add_item(tree, hf_scsi_osd_object_descriptor, tvb, offset, 24, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_object_descriptor, tvb, offset, 24, ENC_NA);
 	offset+=24;
 }
 
@@ -787,21 +787,21 @@ dissect_osd_security_parameters(tvbuff_t *tvb, int offset, proto_tree *parent_tr
 		    "Security Parameters");
 		tree = proto_item_add_subtree(item, ett_osd_security_parameters);
 	}
-		
+
 	/* request integrity check value */
-	proto_tree_add_item(tree, hf_scsi_osd_ricv, tvb, offset, 20, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_ricv, tvb, offset, 20, ENC_NA);
 	offset+=20;
 
 	/* request nonce */
-	proto_tree_add_item(tree, hf_scsi_osd_request_nonce, tvb, offset, 12, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_request_nonce, tvb, offset, 12, ENC_NA);
 	offset+=12;
 
 	/* data in integrity check value offset */
-	proto_tree_add_item(tree, hf_scsi_osd_diicvo, tvb, offset, 4, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_diicvo, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset+=4;
 
 	/* data out integrity check value offset */
-	proto_tree_add_item(tree, hf_scsi_osd_doicvo, tvb, offset, 4, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_doicvo, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset+=4;
 }
 
@@ -864,7 +864,7 @@ dissect_osd_format_osd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for format osd */
 	}
-	
+
 }
 
 
@@ -875,7 +875,7 @@ dissect_osd_partition_id(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tr
 	guint32 partition_id[2];
 
 	/* partition id */
-	item=proto_tree_add_item(tree, hf_index, tvb, offset, 8, 0);
+	item=proto_tree_add_item(tree, hf_index, tvb, offset, 8, ENC_BIG_ENDIAN);
 	partition_id[0]=tvb_get_ntohl(tvb, offset);
 	partition_id[1]=tvb_get_ntohl(tvb, offset+4);
 	if(!partition_id[0] && !partition_id[1]){
@@ -983,7 +983,7 @@ dissect_osd_create_partition(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
 		/* no data in for create partition */
 	}
-	
+
 }
 
 static const value_string scsi_osd_sort_order_vals[] = {
@@ -994,7 +994,7 @@ static void
 dissect_osd_sortorder(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* sort order */
-	proto_tree_add_item(tree, hf_scsi_osd_sortorder, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_sortorder, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 }
 
@@ -1002,7 +1002,7 @@ static void
 dissect_osd_list_identifier(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* list identifier */
-	proto_tree_add_item(tree, hf_scsi_osd_list_identifier, tvb, offset, 4, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_list_identifier, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset+=4;
 }
 
@@ -1010,7 +1010,7 @@ static void
 dissect_osd_allocation_length(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* allocation length */
-	proto_tree_add_item(tree, hf_scsi_osd_allocation_length, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_allocation_length, tvb, offset, 8, ENC_BIG_ENDIAN);
 	offset+=8;
 }
 
@@ -1018,7 +1018,7 @@ static void
 dissect_osd_initial_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* initial object id */
-	proto_tree_add_item(tree, hf_scsi_osd_initial_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_initial_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -1026,7 +1026,7 @@ static void
 dissect_osd_additional_length(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* additional length */
-	proto_tree_add_item(tree, hf_scsi_osd_additional_length, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_additional_length, tvb, offset, 8, ENC_BIG_ENDIAN);
 	offset+=8;
 }
 
@@ -1035,7 +1035,7 @@ static void
 dissect_osd_continuation_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* continuation object id */
-	proto_tree_add_item(tree, hf_scsi_osd_continuation_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_continuation_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -1140,8 +1140,8 @@ dissect_osd_list(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		offset+=3;
 
 		/* LSTCHG and ROOT flags */
-		proto_tree_add_item(tree, hf_scsi_osd_list_flags_lstchg, tvb, offset, 1, 0);
-		proto_tree_add_item(tree, hf_scsi_osd_list_flags_root, tvb, offset, 1, 0);
+		proto_tree_add_item(tree, hf_scsi_osd_list_flags_lstchg, tvb, offset, 1, ENC_BIG_ENDIAN);
+		proto_tree_add_item(tree, hf_scsi_osd_list_flags_root, tvb, offset, 1, ENC_BIG_ENDIAN);
 		is_root=tvb_get_guint8(tvb, offset)&0x01;
 		offset++;
 
@@ -1156,14 +1156,14 @@ dissect_osd_list(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			offset+=8;
 		}
 	}
-	
+
 }
 
 static void
 dissect_osd_requested_user_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* request user object id */
-	proto_tree_add_item(tree, hf_scsi_osd_requested_user_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_requested_user_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -1171,7 +1171,7 @@ static void
 dissect_osd_number_of_user_objects(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* number_of_user_objects */
-	proto_tree_add_item(tree, hf_scsi_osd_number_of_user_objects, tvb, offset, 2, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_number_of_user_objects, tvb, offset, 2, ENC_BIG_ENDIAN);
 	offset+=2;
 }
 
@@ -1245,7 +1245,7 @@ dissect_osd_create(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for create */
 	}
-	
+
 }
 
 
@@ -1308,7 +1308,7 @@ dissect_osd_remove_partition(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
 		/* no data in for remove partition */
 	}
-	
+
 }
 
 static const value_string key_to_set_vals[] = {
@@ -1320,25 +1320,25 @@ static const value_string key_to_set_vals[] = {
 static void
 dissect_osd_key_to_set(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_key_to_set, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_key_to_set, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 static void
 dissect_osd_set_key_version(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_set_key_version, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_set_key_version, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 static void
 dissect_osd_key_identifier(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_key_identifier, tvb, offset, 7, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_key_identifier, tvb, offset, 7, ENC_NA);
 }
 
 static void
 dissect_osd_seed(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_seed, tvb, offset, 20, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_seed, tvb, offset, 20, ENC_NA);
 }
 
 static void
@@ -1409,7 +1409,7 @@ dissect_osd_set_key(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for set key */
 	}
-	
+
 }
 
 static void
@@ -1475,7 +1475,7 @@ dissect_osd_remove(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for remove */
 	}
-	
+
 }
 
 static const true_false_string collection_fcr_tfs = {
@@ -1485,14 +1485,14 @@ static const true_false_string collection_fcr_tfs = {
 static void
 dissect_osd_collection_fcr(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	proto_tree_add_item(tree, hf_scsi_osd_collection_fcr, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_collection_fcr, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 static void
 dissect_osd_collection_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* collection object id */
-	proto_tree_add_item(tree, hf_scsi_osd_collection_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_collection_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -1561,7 +1561,7 @@ dissect_osd_remove_collection(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
 		/* no data in for remove collection */
 	}
-	
+
 }
 
 
@@ -1569,7 +1569,7 @@ static void
 dissect_osd_length(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* length */
-	proto_tree_add_item(tree, hf_scsi_osd_length, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_length, tvb, offset, 8, ENC_BIG_ENDIAN);
 	offset+=8;
 }
 
@@ -1577,7 +1577,7 @@ static void
 dissect_osd_starting_byte_address(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* starting_byte_address */
-	proto_tree_add_item(tree, hf_scsi_osd_starting_byte_address, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_starting_byte_address, tvb, offset, 8, ENC_BIG_ENDIAN);
 	offset+=8;
 }
 
@@ -1653,7 +1653,7 @@ dissect_osd_write(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for WRITE */
 	}
-	
+
 }
 
 
@@ -1661,7 +1661,7 @@ static void
 dissect_osd_requested_collection_object_id(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* requested collection object id */
-	proto_tree_add_item(tree, hf_scsi_osd_requested_collection_object_id, tvb, offset, 8, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_requested_collection_object_id, tvb, offset, 8, ENC_NA);
 	offset+=8;
 }
 
@@ -1730,7 +1730,7 @@ dissect_osd_create_collection(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
 		/* no data in for create collection */
 	}
-	
+
 }
 
 
@@ -1744,7 +1744,7 @@ static void
 dissect_osd_flush_scope(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* flush scope */
-	proto_tree_add_item(tree, hf_scsi_osd_flush_scope, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_flush_scope, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 }
 
@@ -1811,7 +1811,7 @@ dissect_osd_flush(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for flush */
 	}
-	
+
 }
 
 
@@ -1826,7 +1826,7 @@ static void
 dissect_osd_flush_collection_scope(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* flush collection scope */
-	proto_tree_add_item(tree, hf_scsi_osd_flush_collection_scope, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_flush_collection_scope, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 }
 
@@ -1894,7 +1894,7 @@ dissect_osd_flush_collection(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
 		/* no data in for flush collection */
 	}
-	
+
 }
 
 
@@ -1968,7 +1968,7 @@ dissect_osd_append(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for append */
 	}
-	
+
 }
 
 static void
@@ -2042,7 +2042,7 @@ dissect_osd_create_and_write(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
 		/* no data in for create and write*/
 	}
-	
+
 }
 
 
@@ -2057,7 +2057,7 @@ static void
 dissect_osd_flush_osd_scope(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* flush osd scope */
-	proto_tree_add_item(tree, hf_scsi_osd_flush_osd_scope, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_flush_osd_scope, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 }
 
@@ -2113,7 +2113,7 @@ dissect_osd_flush_osd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for flush osd */
 	}
-	
+
 }
 
 
@@ -2128,7 +2128,7 @@ static void
 dissect_osd_flush_partition_scope(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	/* flush partition scope */
-	proto_tree_add_item(tree, hf_scsi_osd_flush_partition_scope, tvb, offset, 1, 0);
+	proto_tree_add_item(tree, hf_scsi_osd_flush_partition_scope, tvb, offset, 1, ENC_BIG_ENDIAN);
 	offset++;
 }
 
@@ -2192,7 +2192,7 @@ dissect_osd_flush_partition(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for flush partition */
 	}
-	
+
 }
 
 
@@ -2259,7 +2259,7 @@ dissect_osd_get_attributes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for get attributes */
 	}
-	
+
 }
 
 
@@ -2334,7 +2334,7 @@ dissect_osd_list_collection(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 /* XXX dissect the data */
 	}
-	
+
 }
 
 
@@ -2410,7 +2410,7 @@ dissect_osd_read(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 /* xxx should dissect the data ? */
 	}
-	
+
 }
 
 
@@ -2477,7 +2477,7 @@ dissect_osd_set_attributes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		/* no data in for set attributes */
 	}
-	
+
 }
 
 /* OSD Service Actions */
@@ -2605,13 +2605,13 @@ dissect_osd_opcode(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	/* dissecting the CDB */
 	if (isreq && iscdb) {
-		proto_tree_add_item (tree, hf_scsi_control, tvb, offset, 1, 0);
+		proto_tree_add_item (tree, hf_scsi_control, tvb, offset, 1, ENC_BIG_ENDIAN);
 		offset++;
 
 		/* 5 reserved bytes */
 		offset+=5;
 
-		proto_tree_add_item (tree, hf_scsi_osd_add_cdblen, tvb, offset, 1, 0);
+		proto_tree_add_item (tree, hf_scsi_osd_add_cdblen, tvb, offset, 1, ENC_BIG_ENDIAN);
 		offset++;
 
 		svcaction=tvb_get_ntohs(tvb, offset);
@@ -2628,12 +2628,12 @@ dissect_osd_opcode(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 				cdata->itlq->extra_data=extra_data;
 			}
 		}
-		proto_tree_add_item (tree, hf_scsi_osd_svcaction, tvb, offset, 2, 0);
+		proto_tree_add_item (tree, hf_scsi_osd_svcaction, tvb, offset, 2, ENC_BIG_ENDIAN);
 		offset+=2;
 
 
 		if(check_col(pinfo->cinfo, COL_INFO)){
-			col_append_str(pinfo->cinfo, COL_INFO, 
+			col_append_str(pinfo->cinfo, COL_INFO,
 				val_to_str(svcaction, scsi_osd_svcaction_vals, "Unknown OSD Serviceaction"));
 		}
 		dissector=find_svcaction_dissector(svcaction);
@@ -2651,7 +2651,7 @@ dissect_osd_opcode(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		svcaction=extra_data->svcaction;
 	}
 	if(check_col(pinfo->cinfo, COL_INFO)){
-		col_append_str(pinfo->cinfo, COL_INFO, 
+		col_append_str(pinfo->cinfo, COL_INFO,
 			val_to_str(svcaction, scsi_osd_svcaction_vals, "Unknown OSD Serviceaction"));
 	}
 	if(svcaction){
