@@ -10,7 +10,7 @@
  * Convert to built-in dissector
  *   Michael Mann * Copyright 2011
  *
- * $Id: packet-sercosiii.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-sercosiii.c 41993 2012-04-09 17:53:04Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1178,8 +1178,8 @@ dissect_siii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   proto_item*  ti;
   proto_tree*  siii_tree;
   guint    type;
-  char* tel_ch="?";
-  char* tel_type="?";
+  const char* tel_ch="?";
+  const char* tel_type="?";
   guint tel_no = 0;
 
   /* setup columns */
