@@ -2,7 +2,7 @@
 *
 * Routine to dissect ITU-T Rec. X.225 (1995 E)/ISO 8327-1 OSI Session Protocol packets
 *
-* $Id: packet-ses.c 41395 2012-03-07 15:18:22Z etxrab $
+* $Id: packet-ses.c 43842 2012-07-20 00:45:59Z gerald $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -1997,7 +1997,7 @@ dissect_ses_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		return FALSE;	/* no */
 
 	/* final check to see if the next SPDU, if present, is also valid */
-	if (tvb_length(tvb) > len) {
+	if (tvb_length(tvb) > 1+(guint) len) {
 	  type = tvb_get_guint8(tvb, offset + len + 1);
 	  /* check SPDU type */
 	  if (match_strval(type, ses_vals) == NULL) {
