@@ -3,7 +3,7 @@
  *
  * Copyright 2010 - 2011, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-sgsap.c 40669 2012-01-23 20:14:37Z cmaynard $
+ * $Id: packet-sgsap.c 42755 2012-05-21 19:27:38Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1456,7 +1456,7 @@ void proto_register_sgsap(void) {
     },
     { &hf_sgsap_elem_id,
         { "Element ID",    "sgsap.elem_id",
-        FT_UINT8, BASE_DEC, NULL, 0x0,
+        FT_UINT8, BASE_HEX, NULL, 0x0,
         NULL, HFILL }
     },
     { &hf_sgsap_eps_location_update_type,
