@@ -3,7 +3,7 @@
  * Martin Mathieson
  * Based on packet-sdp.c
  *
- * $Id: packet-sipfrag.c 34124 2010-09-15 16:16:23Z martinm $
+ * $Id: packet-sipfrag.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,7 +64,7 @@ static void dissect_sipfrag(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_append_str(pinfo->cinfo, COL_INFO, ", with Sipfrag");
 
     /* Create sipfrag tree. */
-    ti = proto_tree_add_item(tree, proto_sipfrag, tvb, offset, -1, FALSE);
+    ti = proto_tree_add_item(tree, proto_sipfrag, tvb, offset, -1, ENC_NA);
     sipfrag_tree = proto_item_add_subtree(ti, ett_sipfrag);
 
     /* Show the sipfrag message a line at a time. */
