@@ -6,7 +6,7 @@
  * Adds support for the data packet protocol for the SliMP3
  * See www.slimdevices.com for details.
  *
- * $Id: packet-slimp3.c 35540 2011-01-15 03:25:43Z morriss $
+ * $Id: packet-slimp3.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -260,7 +260,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     if (tree) {
 
-	ti = proto_tree_add_item(tree, proto_slimp3, tvb, offset, -1, FALSE);
+	ti = proto_tree_add_item(tree, proto_slimp3, tvb, offset, -1, ENC_NA);
 	slimp3_tree = proto_item_add_subtree(ti, ett_slimp3);
 
 	proto_tree_add_uint(slimp3_tree, hf_slimp3_opcode, tvb,
@@ -306,7 +306,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	* [12..17]   reserved
 	*/
 	if (tree) {
-	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_ir, tvb, offset+8, 4, FALSE);
+	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_ir, tvb, offset+8, 4, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 
 	    i1 = tvb_get_ntohl(tvb, offset+2);
@@ -360,7 +360,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_display,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 
 	    /* Loop through the commands */
@@ -461,7 +461,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case SLIMP3_CONTROL:
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_control,
-				       tvb, offset+1, 1, FALSE);
+				       tvb, offset+1, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    proto_tree_add_text(slimp3_tree, tvb, offset+1, 1, "Command: %s",
 				val_to_str(tvb_get_guint8(tvb, offset+1),
@@ -478,7 +478,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case SLIMP3_HELLO:
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_hello,
-				       tvb, offset+1, 1, FALSE);
+				       tvb, offset+1, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    if (to_server) {
 		guint8 fw_ver = 0;
@@ -499,7 +499,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case SLIMP3_I2C:
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_i2c,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    if (to_server) {
 		/* Hello response; client->server */
@@ -524,7 +524,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case SLIMP3_DATA_REQ:
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_data_request,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    proto_tree_add_text(slimp3_tree, tvb, offset+2, 2,
 				"Requested offset: %d bytes.",
@@ -550,7 +550,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	*/
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_data,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    if (old_protocol) {
 	        proto_tree_add_text(slimp3_tree, tvb, offset, -1,
@@ -599,7 +599,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tree) {
 	    guint8 fw_ver;
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_discover_request,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    proto_tree_add_text(slimp3_tree, tvb, offset+1, 1,
 				"Device ID: %d.", tvb_get_guint8(tvb, offset+1));
@@ -618,7 +618,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case SLIMP3_DISC_RSP:
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_discover_response,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    proto_tree_add_text(slimp3_tree, tvb, offset+2, 4,
 				"Server Address: %s.",
@@ -646,7 +646,7 @@ dissect_slimp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	*/
 	if (tree) {
 	    hidden_item = proto_tree_add_item(slimp3_tree, hf_slimp3_data_ack,
-				       tvb, offset, 1, FALSE);
+				       tvb, offset, 1, ENC_BIG_ENDIAN);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	    proto_tree_add_text(slimp3_tree, tvb, offset+6, 2,
 				"Write Pointer: %d",
