@@ -2,7 +2,7 @@
  * Routines for SMB mailslot packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-smb-mailslot.c 29346 2009-08-09 08:14:59Z krj $
+ * $Id: packet-smb-mailslot.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -147,7 +147,7 @@ dissect_mailslot_smb(tvbuff_t *mshdr_tvb, tvbuff_t *setup_tvb,
 	if(mshdr_tvb && setup_tvb){
 		if (parent_tree) {
 			item = proto_tree_add_item(parent_tree, proto_smb_msp,
-						   mshdr_tvb, 0, -1, FALSE);
+						   mshdr_tvb, 0, -1, ENC_NA);
 			tree = proto_item_add_subtree(item, ett_smb_msp);
 		}
 
@@ -169,11 +169,11 @@ dissect_mailslot_smb(tvbuff_t *mshdr_tvb, tvbuff_t *setup_tvb,
 
 		/* priority */
 		proto_tree_add_item(tree, hf_priority, setup_tvb, offset, 2,
-		    TRUE);
+		    ENC_LITTLE_ENDIAN);
 		offset += 2;
 
 		/* class */
-		proto_tree_add_item(tree, hf_class, setup_tvb, offset, 2, TRUE);
+		proto_tree_add_item(tree, hf_class, setup_tvb, offset, 2, ENC_LITTLE_ENDIAN);
 		offset += 2;
 
 		/* These are in the rest of the data; use "mshdr_tvb", which
@@ -181,12 +181,12 @@ dissect_mailslot_smb(tvbuff_t *mshdr_tvb, tvbuff_t *setup_tvb,
 
 		/* size */
 		/* this is actually bytecount in the SMB Transaction command */
-		proto_tree_add_item(tree, hf_size, mshdr_tvb, offset, 2, TRUE);
+		proto_tree_add_item(tree, hf_size, mshdr_tvb, offset, 2, ENC_LITTLE_ENDIAN);
 		offset += 2;
 
 		/* mailslot name */
 		len = tvb_strsize(mshdr_tvb, offset);
-		proto_tree_add_item(tree, hf_name, mshdr_tvb, offset, len, TRUE);
+		proto_tree_add_item(tree, hf_name, mshdr_tvb, offset, len, ENC_ASCII|ENC_NA);
 		offset += len;
 		proto_item_set_len(item, offset);
 	}
