@@ -2,7 +2,7 @@
  * Routines for snooping SID to name mappings
  * Copyright 2003, Ronnie Sahlberg
  *
- * $Id: packet-smb-sidsnooping.c 29499 2009-08-21 20:25:24Z krj $
+ * $Id: packet-smb-sidsnooping.c 31623 2010-01-22 17:41:47Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -116,7 +116,7 @@ samr_query_dispinfo(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt, co
 	field_info *fi;
 	field_info *fi_rid;
 	field_info *fi_name;
-	char sid_name[256];
+	char sid_name_str[256];
 	int info_level;
 
 	gp=proto_get_finfo_ptr_array(edt->tree, hf_samr_level);
@@ -148,8 +148,7 @@ samr_query_dispinfo(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt, co
 			g_hash_table_remove(ctx_handle_table, GINT_TO_POINTER(pinfo->fd->num));
 		}
 		if(!old_ctx){
-			old_ctx=se_alloc(20);
-			memcpy(old_ctx, fi->value.value.bytes->data, 20);
+			old_ctx=se_memdup(fi->value.value.bytes->data, 20);
 		}
 		g_hash_table_insert(ctx_handle_table, GINT_TO_POINTER(pinfo->fd->num), old_ctx);
 
@@ -204,13 +203,15 @@ samr_query_dispinfo(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt, co
 
 	for(;num_rids;num_rids--){
 		int len=sid_len;
+		if (len > 247)
+			len = 247;
 
 		fi_rid=gp_rids->pdata[num_rids-1];
 		fi_name=gp_names->pdata[num_rids-1];
-		g_strlcpy(sid_name, sid, 256);
-		sid_name[len++]='-';
-		g_snprintf(sid_name+len, 256-len, "%d",fi_rid->value.value.sinteger);
-		add_sid_name_mapping(sid_name, fi_name->value.value.string);
+		g_strlcpy(sid_name_str, sid, 256);
+		sid_name_str[len++]='-';
+		g_snprintf(sid_name_str+len, 256-len, "%d",fi_rid->value.value.sinteger);
+		add_sid_name_mapping(sid_name_str, fi_name->value.value.string);
 	}
 	return 1;
 }
