@@ -1,7 +1,7 @@
 /* packet-smb2.h
  * Defines for SMB2 packet dissection
  *
- * $Id: packet-smb2.h 34692 2010-10-29 20:22:02Z wmeier $
+ * $Id: packet-smb2.h 42768 2012-05-22 05:48:55Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -107,6 +107,15 @@ typedef struct _smb2_info_t {
 	proto_tree *top_tree;	
 } smb2_info_t;
 
+/* for transform content information */
+
+typedef struct _smb2_transform_info_t {
+	guint8  nonce[16];
+	guint32 size;
+	guint16 alg;
+	guint8  session_id[8];
+} smb2_transform_info_t;
+
 
 int dissect_smb2_FILE_OBJECTID_BUFFER(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int offset);
 int dissect_smb2_ioctl_function(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int offset, guint32 *ioctl_function);
