@@ -1,7 +1,7 @@
 /* packet-smtp.c
  * Routines for SMTP packet disassembly
  *
- * $Id: packet-smtp.c 36763 2011-04-21 13:42:15Z alagoutte $
+ * $Id: packet-smtp.c 39550 2011-10-25 01:13:21Z morriss $
  *
  * Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
  *
@@ -28,8 +28,11 @@
 #include "config.h"
 #endif
 
+#include <stdlib.h>
 #include <ctype.h>
+
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/prefs.h>
@@ -49,8 +52,11 @@ static int proto_smtp = -1;
 
 static int hf_smtp_req = -1;
 static int hf_smtp_rsp = -1;
+static int hf_smtp_message = -1;
+static int hf_smtp_command_line = -1;
 static int hf_smtp_req_command = -1;
 static int hf_smtp_req_parameter = -1;
+static int hf_smtp_response = -1;
 static int hf_smtp_rsp_code = -1;
 static int hf_smtp_rsp_parameter = -1;
 
@@ -231,9 +237,8 @@ dissect_smtp_data(tvbuff_t *tvb, int offset, proto_tree *smtp_tree)
       /*
        * Put this line.
        */
-      proto_tree_add_text(smtp_tree, tvb, offset, next_offset - offset,
-                          "Message: %s",
-                          tvb_format_text(tvb, offset, next_offset - offset));
+      proto_tree_add_item(smtp_tree, hf_smtp_message, tvb,
+                          offset, next_offset - offset, ENC_ASCII|ENC_NA);
 
       /*
        * Step to the next line.
@@ -628,7 +633,7 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   }
 
   if (tree) { /* Build the tree info ... */
-    ti = proto_tree_add_item(tree, proto_smtp, tvb, offset, -1, FALSE);
+    ti = proto_tree_add_item(tree, proto_smtp, tvb, offset, -1, ENC_NA);
     smtp_tree = proto_item_add_subtree(ti, ett_smtp);
   }
 
@@ -713,16 +718,15 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         /*
          * Put the command line into the protocol tree.
          */
-        ti = proto_tree_add_text(smtp_tree, tvb, loffset, next_offset - loffset,
-                                 "Command: %s",
-                                 tvb_format_text(tvb, loffset, next_offset - loffset));
+        ti =  proto_tree_add_item(smtp_tree, hf_smtp_command_line, tvb,
+                          loffset, next_offset - loffset, ENC_ASCII|ENC_NA);
         cmdresp_tree = proto_item_add_subtree(ti, ett_smtp_cmdresp);
 
         proto_tree_add_item(cmdresp_tree, hf_smtp_req_command, tvb,
-                            loffset, cmdlen, FALSE);
+                            loffset, cmdlen, ENC_ASCII|ENC_NA);
         if (linelen > 5) {
           proto_tree_add_item(cmdresp_tree, hf_smtp_req_parameter, tvb,
-                              loffset + 5, linelen - 5, FALSE);
+                              loffset + 5, linelen - 5, ENC_ASCII|ENC_NA);
         }
 
         if (smtp_data_desegment && !spd_frame_data->more_frags) {
@@ -739,7 +743,7 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
     if (smtp_data_desegment) {
-      next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled DATA",
+      next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled SMTP",
                                           frag_msg, &smtp_data_frag_items, NULL, smtp_tree);
       if (next_tvb) {
         /* XXX: this is presumptious - we may have negotiated something else */
@@ -779,10 +783,8 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         /*
          * Put it into the protocol tree.
          */
-        ti = proto_tree_add_text(smtp_tree, tvb, offset,
-                                 next_offset - offset, "Response: %s",
-                                 tvb_format_text(tvb, offset,
-                                                 next_offset - offset));
+        ti =  proto_tree_add_item(smtp_tree, hf_smtp_response, tvb,
+                          offset, next_offset - offset, ENC_ASCII|ENC_NA);
         cmdresp_tree = proto_item_add_subtree(ti, ett_smtp_cmdresp);
       } else
         cmdresp_tree = NULL;
@@ -817,7 +819,7 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
           if (linelen >= 4) {
             proto_tree_add_item(cmdresp_tree, hf_smtp_rsp_parameter, tvb,
-                                offset + 4, linelen - 4, FALSE);
+                                offset + 4, linelen - 4, ENC_ASCII|ENC_NA);
           }
         }
       }
@@ -852,6 +854,14 @@ proto_register_smtp(void)
       { "Response", "smtp.rsp",
         FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 
+    { &hf_smtp_message,
+      { "Message", "smtp.message",
+        FT_STRING,  BASE_NONE, NULL, 0x0, NULL, HFILL }},
+
+    { &hf_smtp_command_line,
+      { "Command Line", "smtp.command_line",
+        FT_STRING,  BASE_NONE, NULL, 0x0, NULL, HFILL }},
+
     { &hf_smtp_req_command,
       { "Command", "smtp.req.command",
         FT_STRING,  BASE_NONE, NULL, 0x0, NULL, HFILL }},
@@ -860,6 +870,10 @@ proto_register_smtp(void)
       { "Request parameter", "smtp.req.parameter",
         FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 
+    { &hf_smtp_response,
+      { "Response", "smtp.response",
+        FT_STRING,  BASE_NONE, NULL, 0x0, NULL, HFILL }},
+
     { &hf_smtp_rsp_code,
       { "Response code", "smtp.response.code",
         FT_UINT32, BASE_DEC, VALS(response_codes_vs), 0x0, NULL, HFILL }},
