@@ -2,7 +2,7 @@
  * Routines for XNS SPP
  * Based on the Netware SPX dissector by Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-spp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-spp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,8 +69,6 @@ static dissector_table_t spp_socket_dissector_table;
 static const char*
 spp_conn_ctrl(guint8 ctrl)
 {
-	const char *p;
-
 	static const value_string conn_vals[] = {
 		{ 0x00,                        "Data, No Ack Required" },
 		{ SPP_EOM,                     "End-of-Message" },
@@ -82,14 +80,7 @@ spp_conn_ctrl(guint8 ctrl)
 		{ 0x00,                        NULL }
 	};
 
-	p = match_strval((ctrl & 0xf0), conn_vals );
-
-	if (p) {
-		return p;
-	}
-	else {
-		return "Unknown";
-	}
+	return val_to_str_const((ctrl & 0xf0), conn_vals, "Unknown");
 }
 
 static const char*
@@ -131,7 +122,7 @@ dissect_spp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	col_set_str(pinfo->cinfo, COL_INFO, "SPP");
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_spp, tvb, 0, SPP_HEADER_LEN, FALSE);
+		ti = proto_tree_add_item(tree, proto_spp, tvb, 0, SPP_HEADER_LEN, ENC_NA);
 		spp_tree = proto_item_add_subtree(ti, ett_spp);
 	}
 
@@ -175,14 +166,14 @@ dissect_spp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						   "Datastream Type: 0x%02X",
 						   datastream_type);
 		}
-		proto_tree_add_item(spp_tree, hf_spp_src_id, tvb,  2, 2, FALSE);
-		proto_tree_add_item(spp_tree, hf_spp_dst_id, tvb,  4, 2, FALSE);
+		proto_tree_add_item(spp_tree, hf_spp_src_id, tvb,  2, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(spp_tree, hf_spp_dst_id, tvb,  4, 2, ENC_BIG_ENDIAN);
 	}
 	spp_seq = tvb_get_ntohs(tvb, 6);
 	if (tree) {
 		proto_tree_add_uint(spp_tree, hf_spp_seq_nr, tvb,  6, 2, spp_seq);
-		proto_tree_add_item(spp_tree, hf_spp_ack_nr, tvb,  8, 2, FALSE);
-		proto_tree_add_item(spp_tree, hf_spp_all_nr, tvb, 10, 2, FALSE);
+		proto_tree_add_item(spp_tree, hf_spp_ack_nr, tvb,  8, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(spp_tree, hf_spp_all_nr, tvb, 10, 2, ENC_BIG_ENDIAN);
 	}
 
 	if (tvb_reported_length_remaining(tvb, SPP_HEADER_LEN) > 0) {
