@@ -2,7 +2,7 @@
  * Routines for H.324/SRP dissection
  * 2004 Richard van der Hoff <richardv@mxtelecom.com>
  *
- * $Id: packet-srp.c 29446 2009-08-16 12:36:22Z krj $
+ * $Id: packet-srp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,14 +27,12 @@
 # include "config.h"
 #endif
 
-#include <gmodule.h>
 #include <glib.h>
+#include <epan/packet.h>
 #include <epan/bitswap.h>
 #include <epan/circuit.h>
-#include <epan/packet.h>
 #include <epan/stream.h>
-/* #include <epan/reassemble.h> */
-#include <epan/crc16.h>
+#include <epan/crc16-tvb.h>
 
 /* Wireshark ID of the protocols */
 static int proto_srp = -1;
@@ -86,13 +84,13 @@ static void dissect_ccsrl(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree
 
     /* add the 'ccsrl' tree to the main tree */
     if (tree) {
-	ccsrl_item = proto_tree_add_item (tree, proto_ccsrl, tvb, 0, -1, FALSE);
+	ccsrl_item = proto_tree_add_item (tree, proto_ccsrl, tvb, 0, -1, ENC_NA);
 	ccsrl_tree = proto_item_add_subtree (ccsrl_item, ett_ccsrl);
 	proto_tree_add_uint(ccsrl_tree,hf_ccsrl_ls,tvb,0,1,lastseg);
     }
 
     /* XXX add support for reassembly of fragments */
-    
+
     /* XXX currently, we always dissect as H245. It's not necessarily
         that though.
     */
@@ -106,7 +104,7 @@ static void dissect_srp_command(tvbuff_t * tvb, packet_info * pinfo, proto_tree
     guint payload_len;
 
     if( srp_tree )
-	proto_tree_add_item(srp_tree,hf_srp_seqno,tvb,1,1,FALSE);
+	proto_tree_add_item(srp_tree,hf_srp_seqno,tvb,1,1,ENC_BIG_ENDIAN);
 
     payload_len = tvb_reported_length_remaining(tvb,4);
     next_tvb = tvb_new_subset(tvb, 2, payload_len, payload_len );
@@ -124,10 +122,10 @@ static void dissect_srp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
     proto_item *hidden_item;
 
     guint8 header = tvb_get_guint8(tvb,0);
-    
+
     /* add the 'srp' tree to the main tree */
     if (tree) {
-	srp_item = proto_tree_add_item (tree, proto_srp, tvb, 0, -1, FALSE);
+	srp_item = proto_tree_add_item (tree, proto_srp, tvb, 0, -1, ENC_NA);
 	srp_tree = proto_item_add_subtree (srp_item, ett_srp);
 	proto_tree_add_uint(srp_tree,hf_srp_header,tvb,0,1,header);
     }
@@ -142,7 +140,7 @@ static void dissect_srp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 
 	case SRP_NSRP_RESPONSE:
 	    if( srp_tree )
-		proto_tree_add_item(srp_tree,hf_srp_seqno,tvb,1,1,FALSE);
+		proto_tree_add_item(srp_tree,hf_srp_seqno,tvb,1,1,ENC_BIG_ENDIAN);
 	    break;
 
 	default:
@@ -156,7 +154,7 @@ static void dissect_srp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 
 	/* crc includes the header */
 	calc_crc = crc16_ccitt_tvb(tvb,crc_offset);
-	
+
 	if( crc == calc_crc ) {
 	    proto_tree_add_uint_format(srp_tree, hf_srp_crc, tvb,
 				       crc_offset, 2, crc,
