@@ -4,7 +4,7 @@
  * Huagang XIE <huagang@intruvert.com>
  * Kees Cook <kees@outflux.net>
  *
- * $Id: packet-ssh.c 41556 2012-03-15 08:23:26Z tuexen $
+ * $Id: packet-ssh.c 42996 2012-06-02 13:25:02Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -457,7 +457,7 @@ ssh_dissect_ssh2(tvbuff_t *tvb, packet_info *pinfo,
 
 		ti=proto_tree_add_text(tree,tvb,offset,-1, "%s", title->str);
 		ssh2_tree = proto_item_add_subtree(ti ,ett_ssh2);
-		if (title) g_string_free(title,TRUE);
+		g_string_free(title,TRUE);
 	}
 
 	if((is_response && this_number > 3) || (!is_response && this_number>4)) {
@@ -946,7 +946,7 @@ ssh_gslist_compare_strings(gconstpointer a, gconstpointer b)
 		return -1;
 	if (b == NULL)
 		return 1;
-	return strcmp((char*)a,(char*)b);
+	return strcmp((const char*)a,(const char*)b);
 }
 
 /* expects that *result is NULL */
