@@ -5,7 +5,7 @@
  * Copyright 2007-2008, 8x8 Inc. <petithug@8x8.com>
  * Copyright 2008, Gael Breard <gael@breard.org>
  *
- * $Id: packet-stun.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-stun.c 44367 2012-08-09 00:26:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -469,6 +469,12 @@ dissect_stun_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		if ((stun_trans =
 		     se_tree_lookup32_array(stun_info->transaction_pdus,
 					    transaction_id_key)) == NULL) {
+
+			transaction_id_key[0].length = 3;
+			transaction_id_key[0].key =  transaction_id;
+			transaction_id_key[1].length = 0;
+			transaction_id_key[1].key = NULL;
+
 			stun_trans=se_alloc(sizeof(stun_transaction_t));
 			stun_trans->req_frame=0;
 			stun_trans->rep_frame=0;
@@ -798,15 +804,14 @@ dissect_stun_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					XOR (host order) transid with (host order) xor-address.
 					Add in network order tree. */
 					ti = proto_tree_add_ipv4(att_tree, stun_att_ipv4, tvb, offset+4, 4,
-						g_htonl(tvb_get_ntohl(tvb, offset+4) ^
-						magic_cookie_first_word));
+								 tvb_get_ipv4(tvb, offset+4) ^ g_htonl(magic_cookie_first_word));
 					PROTO_ITEM_SET_GENERATED(ti);
 
 					{
 						const gchar *ipstr;
 						guint32 ip;
 						guint16 port;
-						ip = g_htonl(tvb_get_ntohl(tvb, offset+4) ^ magic_cookie_first_word);
+						ip = tvb_get_ipv4(tvb, offset+4) ^ g_htonl(magic_cookie_first_word);
 						ipstr = ip_to_str((guint8*)&ip);
 						port = tvb_get_ntohs(tvb, offset+2) ^ (magic_cookie_first_word >> 16);
 						proto_item_append_text(att_tree, ": %s:%d", ipstr, port);
@@ -826,10 +831,11 @@ dissect_stun_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					proto_tree_add_item(att_tree, stun_att_xor_ipv6, tvb, offset+4, 16, ENC_NA);
 					{
 						guint32 IPv6[4];
-						IPv6[0] = g_htonl(tvb_get_ntohl(tvb, offset+4)  ^ magic_cookie_first_word);
-						IPv6[1] = g_htonl(tvb_get_ntohl(tvb, offset+8)  ^ transaction_id[0]);
-						IPv6[2] = g_htonl(tvb_get_ntohl(tvb, offset+12) ^ transaction_id[1]);
-						IPv6[3] = g_htonl(tvb_get_ntohl(tvb, offset+16) ^ transaction_id[2]);
+						tvb_get_ipv6(tvb, offset+4, (struct e_in6_addr *)IPv6);
+						IPv6[0] = IPv6[0] ^ g_htonl(magic_cookie_first_word);
+						IPv6[1] = IPv6[1] ^ g_htonl(transaction_id[0]);
+						IPv6[2] = IPv6[2] ^ g_htonl(transaction_id[1]);
+						IPv6[3] = IPv6[3] ^ g_htonl(transaction_id[2]);
 						ti = proto_tree_add_ipv6(att_tree, stun_att_ipv6, tvb, offset+4, 16,
 									 (const guint8 *)IPv6);
 						PROTO_ITEM_SET_GENERATED(ti);
