@@ -3,7 +3,7 @@
  * Symantec Enterprise Firewall/Symantec Gateway Security appliance
  * v2/Symantec Gateway Security appliance v3.
  *
- * $Id: packet-symantec.c 29446 2009-08-16 12:36:22Z krj $
+ * $Id: packet-symantec.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -89,12 +89,12 @@ dissect_symantec(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 		if (tree) {
 			proto_tree_add_item(symantec_tree, hf_symantec_if, tvb,
-				0, 4, FALSE);
+				0, 4, ENC_BIG_ENDIAN);
 			proto_tree_add_uint(symantec_tree, hf_symantec_etype, tvb,
 				6, 2, etypev2);
 		}
 		next_tvb = tvb_new_subset_remaining(tvb, 44);
-		dissector_try_port(ethertype_dissector_table, etypev2, next_tvb, pinfo,
+		dissector_try_uint(ethertype_dissector_table, etypev2, next_tvb, pinfo,
 			tree);
 	}
 
@@ -107,7 +107,7 @@ dissect_symantec(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 		if (tree) {
 			proto_tree_add_item(symantec_tree, hf_symantec_if, tvb,
-				0, 4, FALSE);
+				0, 4, ENC_BIG_ENDIAN);
 			proto_tree_add_uint(symantec_tree, hf_symantec_etype, tvb,
 				10, 2, etypev3);
 		}
@@ -117,7 +117,7 @@ dissect_symantec(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * tagging.
 		 */
 		next_tvb = tvb_new_subset_remaining(tvb, 56);
-		dissector_try_port(ethertype_dissector_table, etypev3, next_tvb, pinfo,
+		dissector_try_uint(ethertype_dissector_table, etypev3, next_tvb, pinfo,
 			tree);
 	}
 }
@@ -152,5 +152,5 @@ proto_reg_handoff_symantec(void)
 
 	symantec_handle = create_dissector_handle(dissect_symantec,
 	    proto_symantec);
-	dissector_add("wtap_encap", WTAP_ENCAP_SYMANTEC, symantec_handle);
+	dissector_add_uint("wtap_encap", WTAP_ENCAP_SYMANTEC, symantec_handle);
 }
