@@ -7,7 +7,7 @@
  * facility) to the MTP3 dissector by Abhik Sarkar <sarkar.abhik[AT]gmail.com>
  * with some rework by Jeff Morriss <jeff.morriss.ws [AT] gmail.com>
  *
- * $Id: packet-syslog.c 40186 2011-12-13 21:51:33Z wmeier $
+ * $Id: packet-syslog.c 43219 2012-06-11 23:22:50Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald[AT]wireshark.org>
@@ -32,11 +32,11 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 
-#include <string.h>
 #include <glib.h>
+
 #include <epan/packet.h>
 #include <epan/strutil.h>
 
@@ -357,6 +357,7 @@ proto_reg_handoff_syslog(void)
 
   syslog_handle = create_dissector_handle(dissect_syslog, proto_syslog);
   dissector_add_uint("udp.port", UDP_PORT_SYSLOG, syslog_handle);
+  dissector_add_handle("tcp.port", syslog_handle);
 
   /* Find the mtp3 dissector */
   mtp_handle = find_dissector("mtp3");
