@@ -5,7 +5,7 @@
  * Full Tacacs+ parsing with decryption by
  *   Emanuele Caratti <wiz@iol.it>
  *
- * $Id: packet-tacacs.c 39328 2011-10-10 00:39:31Z wmeier $
+ * $Id: packet-tacacs.c 40511 2012-01-15 12:29:44Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,7 +66,7 @@
 #include <epan/packet.h>
 
 #include <epan/prefs.h>
-#include <epan/crypt/crypt-md5.h>
+#include <epan/crypt/md5.h>
 #include <epan/emem.h>
 #include "packet-tacacs.h"
 
