@@ -1,7 +1,7 @@
-/* packet-3com-tapa.c
+/* packet-tapa.c
  * Routines for the disassembly of the Trapeze TAPA protocol
  *
- * $Id: packet-tapa.c 35540 2011-01-15 03:25:43Z morriss $
+ * $Id: packet-tapa.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright 2007 Joerg Mayer (see AUTHORS file)
  *
@@ -127,19 +127,25 @@ static const value_string tapa_discover_request_vals[] = {
 	{ 0,	NULL }
 };
 
+#if 0
 static const value_string tapa_discover_unknown_vals[] = {
 
 	{ 0,	NULL }
 };
+#endif
 
 static gboolean
-check_ascii(const guint8 *buffer, gint length)
+check_ascii(tvbuff_t *tvb, gint offset, gint length)
 {
 	gint i;
+	guint8 buf;
 
-	for (i = 0; i < length; i++)
-		if (buffer[i] < 0x20 || buffer[i] >= 0x80)
+	for (i = 0; i < length; i++) {
+		buf = tvb_get_guint8(tvb, offset+i);
+		if (buf < 0x20 || buf >= 0x80) {
 			return FALSE;
+		}
+	}
 	return TRUE;
 }
 
@@ -147,7 +153,7 @@ static int
 dissect_tapa_discover_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tapa_discover_tree, guint32 offset, gint remaining)
 {
 	proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_reply_switchip, tvb, offset, 4,
-		FALSE);
+		ENC_BIG_ENDIAN);
 
 	if (check_col(pinfo->cinfo, COL_INFO))
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", Switch: %s",
@@ -156,16 +162,16 @@ dissect_tapa_discover_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tapa_
 	offset += 4;
 
 	proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_reply_unused, tvb, offset, 1,
-		FALSE);
+		ENC_BIG_ENDIAN);
 	offset += 1;
 
 	proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_reply_bias, tvb, offset, 1,
-		FALSE);
+		ENC_BIG_ENDIAN);
 	offset += 1;
 
 	remaining -= 6;
 	proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_reply_pad, tvb, offset, remaining,
-		FALSE);
+		ENC_NA);
 	offset += remaining;
 
 	return offset;
@@ -200,18 +206,18 @@ dissect_tapa_discover_req(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tapa_di
 		tapa_discover_item_tree = proto_item_add_subtree(item, ett_tapa_discover_req);
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_req_type, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_req_pad, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_req_length, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 2;
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_req_value, tvb, offset, item_length,
-			FALSE);
+			ENC_NA);
 		offset += item_length;
 
 		remaining -= (item_length + 4);
@@ -227,18 +233,17 @@ dissect_tapa_discover_unknown_new_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_t
 	guint8		 item_type;
 	gint		 item_length;
 	const gchar	*item_text;
-	const gchar	*item_type_text;
+	/*const gchar	*item_type_text;*/
 	gboolean	 is_ascii;
 
 	while (remaining > 0) {
 		item_type = tvb_get_guint8(tvb, offset);
-		item_type_text = val_to_str(item_type, tapa_discover_unknown_vals, "%d");
+		/*item_type_text = val_to_str(item_type, tapa_discover_unknown_vals, "%d");*/
 		item_length = tvb_get_ntohs(tvb, offset + 2) - 4;
 
 		DISSECTOR_ASSERT(item_length > 0);
 
-		is_ascii = check_ascii(tvb_get_ptr(tvb, offset + 4, item_length),
-				item_length);
+		is_ascii = check_ascii(tvb, offset + 4, item_length);
 		if (is_ascii)
 			item_text = tvb_format_text(tvb, offset + 4, item_length);
 		else
@@ -255,23 +260,23 @@ dissect_tapa_discover_unknown_new_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_t
 		tapa_discover_item_tree = proto_item_add_subtree(item, ett_tapa_discover_req);
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_type, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_pad, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_length, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 2;
 
 		if (is_ascii)
 			proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_valuetext,
-				tvb, offset, item_length, FALSE);
+				tvb, offset, item_length, ENC_ASCII|ENC_NA);
 		else
 			proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_valuehex,
-				tvb, offset, item_length, FALSE);
+				tvb, offset, item_length, ENC_NA);
 		offset += item_length;
 
 		remaining -= (item_length + 4);
@@ -300,19 +305,19 @@ dissect_tapa_discover(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_tapa, tvb, offset, -1,
-			FALSE);
+			ENC_NA);
 		tapa_discover_tree = proto_item_add_subtree(ti, ett_tapa_discover);
 
 		proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_type, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_flags, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_length, tvb, offset, 2,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 2;
 
 		switch (packet_type) {
@@ -329,7 +334,7 @@ dissect_tapa_discover(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		default:
 			proto_tree_add_item(tapa_discover_tree, hf_tapa_discover_unknown, tvb, offset,
-					remaining, FALSE);
+					remaining, ENC_NA);
 		offset += 1;
 
 			break;
@@ -359,49 +364,49 @@ dissect_tapa_tunnel(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_tapa, tvb, offset, -1,
-			FALSE);
+			ENC_NA);
 		tapa_tunnel_tree = proto_item_add_subtree(ti, ett_tapa_tunnel);
 
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_version, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_five, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_type, tvb, offset, 1,
-			FALSE);
+			ENC_BIG_ENDIAN);
 		offset += 1;
 
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_zero, tvb, offset, 8,
-			FALSE);
+			ENC_NA);
 		offset += 8;
 
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_dmac, tvb, offset, 6,
-			FALSE);
+			ENC_NA);
 		offset += 6;
 
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_smac, tvb, offset, 6,
-			FALSE);
+			ENC_NA);
 		offset += 6;
 
 		switch (type) {
 		case TAPA_TUNNEL_TYPE_0:
 			proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_0804, tvb, offset, 2,
-				FALSE);
+				ENC_BIG_ENDIAN);
 			offset += 2;
 
 			proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_tagsetc, tvb, offset, 6,
-				FALSE);
+				ENC_NA);
 			offset += 6;
 
 			break;
 		case TAPA_TUNNEL_TYPE_1:
 			proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_seqno, tvb, offset, 2,
-				FALSE);
+				ENC_BIG_ENDIAN);
 			offset += 2;
 
 			proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_length, tvb, offset, 2,
-				FALSE);
+				ENC_BIG_ENDIAN);
 			offset += 2;
 			break;
 		default:
@@ -411,7 +416,7 @@ dissect_tapa_tunnel(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		/* FIXME: This is just to help figuring out what the bytes mean */
 		proto_tree_add_item(tapa_tunnel_tree, hf_tapa_tunnel_remaining, tvb,
-			offset, remaining - offset, FALSE);
+			offset, remaining - offset, ENC_NA);
 		offset = remaining;
 
 	}
