@@ -1,7 +1,7 @@
 /* packet-tns.c
  * Routines for Oracle TNS packet dissection
  *
- * $Id: packet-tns.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-tns.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -201,27 +201,27 @@ static void dissect_tns_service_options(tvbuff_t *tvb, int offset,
 {
 
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_bconn, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_pc, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_hc, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_fd, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_hd, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dc1, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dc2, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dio, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_ap, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_ra, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_sa, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 
 }
 
@@ -229,11 +229,11 @@ static void dissect_tns_connect_flag(tvbuff_t *tvb, int offset,
 	proto_tree *cflag_tree)
 {
 
-	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nareq, tvb, offset, 1, FALSE);
-	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nalink, tvb, offset, 1, FALSE);
-	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_enablena, tvb, offset, 1, FALSE);
-	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_ichg, tvb, offset, 1, FALSE);
-	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_wantna, tvb, offset, 1, FALSE);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nareq, tvb, offset, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nalink, tvb, offset, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_enablena, tvb, offset, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_ichg, tvb, offset, 1, ENC_BIG_ENDIAN);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_wantna, tvb, offset, 1, ENC_BIG_ENDIAN);
 }
 
 static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
@@ -277,18 +277,18 @@ static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	{
 		proto_tree *df_tree = NULL;
 
-		ti = proto_tree_add_item(data_tree, hf_tns_data_flag, tvb, offset, 2, FALSE);
+		ti = proto_tree_add_item(data_tree, hf_tns_data_flag, tvb, offset, 2, ENC_BIG_ENDIAN);
 
 		df_tree = proto_item_add_subtree(ti, ett_tns_data_flag);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_send, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_rc, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_c, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_reserved, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_more, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_eof, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_dic, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_rts, tvb, offset, 2, FALSE);
-		proto_tree_add_item(df_tree, hf_tns_data_flag_sntt, tvb, offset, 2, FALSE);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_send, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_rc, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_c, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_reserved, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_more, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_eof, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_dic, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_rts, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(df_tree, hf_tns_data_flag_sntt, tvb, offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
@@ -338,14 +338,14 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_version, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_compat_version, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
@@ -354,7 +354,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *sopt_tree = NULL;
 
 		ti = proto_tree_add_item(connect_tree, hf_tns_service_options, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 
 		sopt_tree = proto_item_add_subtree(ti, ett_tns_sopt_flag);
 
@@ -367,14 +367,14 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_sdu_size, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_max_tdu_size, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
@@ -383,40 +383,40 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *ntp_tree = NULL;
 
 		ti = proto_tree_add_item(connect_tree, hf_tns_nt_proto_characteristics, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 
 		ntp_tree = proto_item_add_subtree(ti, ett_tns_ntp_flag);
 
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_hangon, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_crel, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_tduio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_srun, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_dtest, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_cbio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_asio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_pio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_grant, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_handoff, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigpipe, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigurg, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_urgentio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_fdio, tvb, offset, 2, FALSE);
-		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_testop, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_hangon, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_crel, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_tduio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_srun, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_dtest, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_cbio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_asio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_pio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_grant, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_handoff, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigpipe, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigurg, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_urgentio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_fdio, tvb, offset, 2, ENC_BIG_ENDIAN);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_testop, tvb, offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_line_turnaround, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_value_of_one, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_NA);
 	}
 	offset += 2;
 
@@ -439,7 +439,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_connect_data_max, tvb,
-			offset, 4, FALSE);
+			offset, 4, ENC_BIG_ENDIAN);
 	}
 	offset += 4;
 
@@ -448,7 +448,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *cflag_tree = NULL;
 
 		ti = proto_tree_add_item(connect_tree, hf_tns_connect_flags0, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 
 		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
 
@@ -461,7 +461,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *cflag_tree = NULL;
 
 		ti = proto_tree_add_item(connect_tree, hf_tns_connect_flags1, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 
 		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
 
@@ -478,21 +478,21 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		if ( connect_tree )
 		{
 			proto_tree_add_item(connect_tree, hf_tns_trace_cf1, tvb,
-				offset, 4, FALSE);
+				offset, 4, ENC_BIG_ENDIAN);
 		}
 		offset += 4;
 
 		if ( connect_tree )
 		{
 			proto_tree_add_item(connect_tree, hf_tns_trace_cf2, tvb,
-				offset, 4, FALSE);
+				offset, 4, ENC_BIG_ENDIAN);
 		}
 		offset += 4;
 
 		if ( connect_tree )
 		{
 			proto_tree_add_item(connect_tree, hf_tns_trace_cid, tvb,
-				offset, 8, FALSE);
+				offset, 8, ENC_BIG_ENDIAN);
 		}
 		offset += 8;
 	}
@@ -500,7 +500,7 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( connect_tree && cd_len > 0)
 	{
 		proto_tree_add_item(connect_tree, hf_tns_connect_data, tvb,
-			tns_offset+cd_offset, -1, FALSE);
+			tns_offset+cd_offset, -1, ENC_ASCII|ENC_NA);
 	}
 	return;
 }
@@ -530,7 +530,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( accept_tree )
 	{
 		proto_tree_add_item(accept_tree, hf_tns_version, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
@@ -539,7 +539,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *sopt_tree = NULL;
 
 		ti = proto_tree_add_item(accept_tree, hf_tns_service_options,
-			tvb, offset, 2, FALSE);
+			tvb, offset, 2, ENC_BIG_ENDIAN);
 
 		sopt_tree = proto_item_add_subtree(ti, ett_tns_sopt_flag);
 
@@ -551,21 +551,21 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( accept_tree )
 	{
 		proto_tree_add_item(accept_tree, hf_tns_sdu_size, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( accept_tree )
 	{
 		proto_tree_add_item(accept_tree, hf_tns_max_tdu_size, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( accept_tree )
 	{
 		proto_tree_add_item(accept_tree, hf_tns_value_of_one, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_NA);
 	}
 	offset += 2;
 
@@ -590,7 +590,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *cflag_tree = NULL;
 
 		ti = proto_tree_add_item(accept_tree, hf_tns_connect_flags0, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 
 		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
 
@@ -604,7 +604,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		proto_tree *cflag_tree = NULL;
 
 		ti = proto_tree_add_item(accept_tree, hf_tns_connect_flags1, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 
 		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
 
@@ -616,7 +616,7 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( accept_tree && accept_len > 0)
 	{
 		proto_tree_add_item(accept_tree, hf_tns_accept_data, tvb,
-			tns_offset+accept_offset, -1, FALSE);
+			tns_offset+accept_offset, -1, ENC_ASCII|ENC_NA);
 	}
 	return;
 }
@@ -644,28 +644,28 @@ static void dissect_tns_refuse(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( refuse_tree )
 	{
 		proto_tree_add_item(refuse_tree, hf_tns_refuse_reason_user, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( refuse_tree )
 	{
 		proto_tree_add_item(refuse_tree, hf_tns_refuse_reason_system, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( refuse_tree )
 	{
 		proto_tree_add_item(refuse_tree, hf_tns_refuse_data_length, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( refuse_tree )
 	{
 		proto_tree_add_item(refuse_tree, hf_tns_refuse_data, tvb,
-			offset, -1, FALSE);
+			offset, -1, ENC_ASCII|ENC_NA);
 	}
 	return;
 }
@@ -693,21 +693,21 @@ static void dissect_tns_abort(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( abort_tree )
 	{
 		proto_tree_add_item(abort_tree, hf_tns_abort_reason_user, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( abort_tree )
 	{
 		proto_tree_add_item(abort_tree, hf_tns_abort_reason_system, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( abort_tree )
 	{
 		proto_tree_add_item(abort_tree, hf_tns_abort_data, tvb,
-			offset, -1, FALSE);
+			offset, -1, ENC_ASCII|ENC_NA);
 	}
 	return;
 }
@@ -753,21 +753,21 @@ static void dissect_tns_marker(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( marker_tree )
 	{
 		proto_tree_add_item(marker_tree, hf_tns_marker_type, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( marker_tree )
 	{
 		proto_tree_add_item(marker_tree, hf_tns_marker_data_byte, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
 	if ( marker_tree )
 	{
 		proto_tree_add_item(marker_tree, hf_tns_marker_data_byte, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_BIG_ENDIAN);
 	}
 	offset += 1;
 
@@ -796,14 +796,14 @@ static void dissect_tns_redirect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( redirect_tree )
 	{
 		proto_tree_add_item(redirect_tree, hf_tns_redirect_data_length, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( redirect_tree )
 	{
 		proto_tree_add_item(redirect_tree, hf_tns_redirect_data, tvb,
-			offset, -1, FALSE);
+			offset, -1, ENC_ASCII|ENC_NA);
 	}
 	return;
 }
@@ -830,14 +830,14 @@ static void dissect_tns_control(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if ( control_tree )
 	{
 		proto_tree_add_item(control_tree, hf_tns_control_cmd, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
 	if ( control_tree )
 	{
 		proto_tree_add_item(control_tree, hf_tns_control_data, tvb,
-			offset, -1, FALSE);
+			offset, -1, ENC_NA);
 	}
 	return;
 }
@@ -894,7 +894,7 @@ dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (tree)
 	{
-		ti = proto_tree_add_item(tree, proto_tns, tvb, 0, -1, FALSE);
+		ti = proto_tree_add_item(tree, proto_tns, tvb, 0, -1, ENC_NA);
 		tns_tree = proto_item_add_subtree(ti, ett_tns);
 
 		if (pinfo->match_uint == pinfo->destport)
@@ -921,7 +921,7 @@ dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if ( tree )
 	{
 		proto_tree_add_item(tns_tree, hf_tns_packet_checksum, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
@@ -942,14 +942,14 @@ dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if ( tree )
 	{
 		proto_tree_add_item(tns_tree, hf_tns_reserved_byte, tvb,
-			offset, 1, FALSE);
+			offset, 1, ENC_NA);
 	}
 	offset += 1;
 
 	if ( tree )
 	{
 		proto_tree_add_item(tns_tree, hf_tns_header_checksum, tvb,
-			offset, 2, FALSE);
+			offset, 2, ENC_BIG_ENDIAN);
 	}
 	offset += 2;
 
