@@ -7,7 +7,7 @@
  * TTTech Computertechnik AG, Austria.
  * http://www.tttech.com/solutions/ttethernet/
  *
- * $Id: packet-tte.c 37048 2011-05-10 17:28:46Z wmeier $
+ * $Id: packet-tte.c 39635 2011-10-27 15:59:12Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,7 +38,6 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/etypes.h>
-#include <epan/proto.h>
 
 #include "packet-tte.h"
 
@@ -94,30 +93,29 @@ dissect_tte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         /* create display subtree for the protocol */
         tte_root_item = proto_tree_add_item(tree, proto_tte, tvb, 0,
-            TTE_HEADER_LENGTH, FALSE);
+            TTE_HEADER_LENGTH, ENC_NA);
 
         tte_tree = proto_item_add_subtree(tte_root_item, ett_tte);
 
         tte_macdest_item = proto_tree_add_item(tte_tree,
-            hf_eth_dst, tvb, 0, TTE_MAC_LENGTH, FALSE);
+            hf_eth_dst, tvb, 0, TTE_MAC_LENGTH, ENC_NA);
 
         proto_tree_add_item(tte_tree,
-            hf_eth_src, tvb, TTE_MAC_LENGTH, TTE_MAC_LENGTH, FALSE);
+            hf_eth_src, tvb, TTE_MAC_LENGTH, TTE_MAC_LENGTH, ENC_NA);
 
         proto_tree_add_item(tte_tree,
             hf_eth_type, tvb, TTE_MAC_LENGTH*2, TTE_ETHERTYPE_LENGTH,
-
-            FALSE);
+            ENC_BIG_ENDIAN);
 
         tte_macdest_tree = proto_item_add_subtree(tte_macdest_item,
             ett_tte_macdest);
 
         proto_tree_add_item(tte_macdest_tree,
-            hf_tte_dst_cf, tvb, 0, TTE_MACDEST_CF_LENGTH, FALSE);
+            hf_tte_dst_cf, tvb, 0, TTE_MACDEST_CF_LENGTH, ENC_BIG_ENDIAN);
 
         proto_tree_add_item(tte_macdest_tree,
             hf_tte_ctid, tvb, TTE_MACDEST_CF_LENGTH,
-            TTE_MACDEST_CTID_LENGTH, FALSE);
+            TTE_MACDEST_CTID_LENGTH, ENC_BIG_ENDIAN);
     }
 
     /* prevent clearing the Columns...appending cannot be prevented */
