@@ -1,6 +1,6 @@
 /* packet-tzsp.c
  *
- * $Id: packet-tzsp.c 39288 2011-10-06 03:35:44Z wmeier $
+ * $Id: packet-tzsp.c 42429 2012-05-04 21:29:00Z wmeier $
  *
  * Copyright 2002, Tazmen Technologies Inc
  *
@@ -30,10 +30,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <glib.h>
 
 #include <epan/packet.h>
@@ -87,8 +83,8 @@ static int hf_sensormac = -1;
 
 #define TZSP_ENCAP_ETHERNET			1
 #define TZSP_ENCAP_IEEE_802_11			18
-#define TZSP_ENCAP_PRISM_HEADER			119
-#define TZSP_ENCAP_WLAN_AVS			127
+#define TZSP_ENCAP_IEEE_802_11_PRISM		119
+#define TZSP_ENCAP_IEEE_802_11_AVS		127
 
 /* ************************************************************************* */
 /*                          Generic header options                           */
@@ -117,11 +113,11 @@ static int hf_sensormac = -1;
 /*                Add option information to the display                      */
 /* ************************************************************************* */
 
-static int 
+static int
 add_option_info(tvbuff_t *tvb, int pos, proto_tree *tree, proto_item *ti)
 {
 	guint8 tag, length, fcs_err = 0, encr = 0, seen_fcs_err = 0;
-	
+
 	/*
 	 * Read all option tags in an endless loop. If the packet is malformed this
 	 * loop might be a problem.
@@ -254,8 +250,8 @@ struct encap_map {
 
 static const struct encap_map map_table[] = {
 	{ TZSP_ENCAP_ETHERNET,		WTAP_ENCAP_ETHERNET },
-	{ TZSP_ENCAP_PRISM_HEADER,	WTAP_ENCAP_PRISM_HEADER },
-	{ TZSP_ENCAP_WLAN_AVS,		WTAP_ENCAP_IEEE_802_11_WLAN_AVS },
+	{ TZSP_ENCAP_IEEE_802_11_PRISM,	WTAP_ENCAP_IEEE_802_11_PRISM },
+	{ TZSP_ENCAP_IEEE_802_11_AVS,	WTAP_ENCAP_IEEE_802_11_AVS },
 	{ TZSP_ENCAP_IEEE_802_11,	WTAP_ENCAP_IEEE_802_11 },
 	{ 0,				-1 }
 };
