@@ -1,6 +1,6 @@
 /* Routines for UMTS MAC (3GPP TS 25.321) disassembly
  *
- * $Id: packet-umts_mac.c 41375 2012-03-06 17:11:01Z wmeier $
+ * $Id: packet-umts_mac.c 43113 2012-06-05 15:05:17Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,12 +28,15 @@
 #include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/conversation.h>
 
 #include "packet-umts_fp.h"
+#include "packet-rlc.h"
 #include "packet-umts_mac.h"
 
 int proto_umts_mac = -1;
 extern int proto_fp;
+extern int proto_rlc;
 
 /* dissector fields */
 static int hf_mac_fach_fdd_tctf = -1;
@@ -138,7 +141,7 @@ static guint8 fach_fdd_tctf(guint8 hdr, guint16 *bit_offs)
 }
 
 static guint16 tree_add_common_dcch_dtch_fields(tvbuff_t *tvb, packet_info *pinfo _U_,
-    proto_tree *tree, guint16 bitoffs, fp_info *fpinf, umts_mac_info *macinf)
+    proto_tree *tree, guint16 bitoffs, fp_info *fpinf, umts_mac_info *macinf, rlc_info  *rlcinf)
 {
     guint8 ueid_type;
 
@@ -154,6 +157,9 @@ static guint16 tree_add_common_dcch_dtch_fields(tvbuff_t *tvb, packet_info *pinf
     }
 
     if (macinf->ctmux[fpinf->cur_tb]) {
+        if(rlcinf){
+            rlcinf->rbid[fpinf->cur_tb] = tvb_get_bits8(tvb, bitoffs, 4);
+        }
         proto_tree_add_bits_item(tree, hf_mac_ct, tvb, bitoffs, 4, ENC_BIG_ENDIAN);
         bitoffs += 4;
     }
@@ -189,6 +195,7 @@ static void dissect_mac_fdd_rach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     proto_item    *channel_type;
     umts_mac_info *macinf;
     fp_info       *fpinf;
+    rlc_info      *rlcinf;
     proto_item    *ti        = NULL;
 
     /* RACH TCTF is always 2 bit */
@@ -203,8 +210,9 @@ static void dissect_mac_fdd_rach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     ti = proto_tree_add_item(tree, proto_umts_mac, tvb, 0, -1, ENC_NA);
     rach_tree = proto_item_add_subtree(ti, ett_mac_rach);
 
-    macinf = p_get_proto_data(pinfo->fd, proto_umts_mac);
-    fpinf = p_get_proto_data(pinfo->fd, proto_fp);
+    macinf = (umts_mac_info *)p_get_proto_data(pinfo->fd, proto_umts_mac);
+    fpinf  = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp);
+    rlcinf = (rlc_info *)p_get_proto_data(pinfo->fd, proto_rlc);
     if (!macinf || !fpinf) {
         proto_tree_add_text(rach_tree, tvb, 0, -1,
             "Cannot dissect MAC frame because per-frame info is missing");
@@ -214,7 +222,7 @@ static void dissect_mac_fdd_rach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     proto_tree_add_bits_item(rach_tree, hf_mac_rach_fdd_tctf, tvb, 0, 2, ENC_BIG_ENDIAN);
     if (tctf == TCTF_DCCH_DTCH_RACH_FDD) {
         macinf->ctmux[fpinf->cur_tb] = 1; /* DCCH/DTCH on RACH *always* has a C/T */
-        bitoffs = tree_add_common_dcch_dtch_fields(tvb, pinfo, rach_tree, bitoffs, fpinf, macinf);
+        bitoffs = tree_add_common_dcch_dtch_fields(tvb, pinfo, rach_tree, bitoffs, fpinf, macinf, rlcinf);
     }
 
     chan = fpinf->cur_chan;
@@ -268,6 +276,7 @@ static void dissect_mac_fdd_fach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     proto_item    *channel_type;
     umts_mac_info *macinf;
     fp_info       *fpinf;
+    rlc_info      *rlcinf;
     proto_item    *ti        = NULL;
 
     hdr = tvb_get_guint8(tvb, 0);
@@ -284,8 +293,10 @@ static void dissect_mac_fdd_fach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     ti = proto_tree_add_item(tree, proto_umts_mac, tvb, 0, -1, ENC_NA);
     fach_tree = proto_item_add_subtree(ti, ett_mac_fach);
 
-    macinf = p_get_proto_data(pinfo->fd, proto_umts_mac);
-    fpinf = p_get_proto_data(pinfo->fd, proto_fp);
+    macinf = (umts_mac_info *)p_get_proto_data(pinfo->fd, proto_umts_mac);
+    fpinf  = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp);
+    rlcinf = (rlc_info *)p_get_proto_data(pinfo->fd, proto_rlc);
+
     if (!macinf || !fpinf) {
         proto_tree_add_text(fach_tree, tvb, 0, -1,
             "Cannot dissect MAC frame because per-frame info is missing");
@@ -295,7 +306,7 @@ static void dissect_mac_fdd_fach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     proto_tree_add_bits_item(fach_tree, hf_mac_fach_fdd_tctf, tvb, 0, tctf_len, ENC_BIG_ENDIAN);
     if (tctf == TCTF_DCCH_DTCH_FACH_FDD) {
         macinf->ctmux[fpinf->cur_tb] = 1; /* DCCH/DTCH on FACH *always* has a C/T */
-        bitoffs = tree_add_common_dcch_dtch_fields(tvb, pinfo, fach_tree, bitoffs, fpinf, macinf);
+        bitoffs = tree_add_common_dcch_dtch_fields(tvb, pinfo, fach_tree, bitoffs, fpinf, macinf, rlcinf);
     }
 
     chan = fpinf->cur_chan;
@@ -354,6 +365,7 @@ static void dissect_mac_fdd_dch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     guint8         bitoffs  = 0;
     umts_mac_info *macinf;
     fp_info       *fpinf;
+    rlc_info      *rlcinf;
     proto_tree    *dch_tree = NULL;
     proto_item    *channel_type;
     tvbuff_t      *next_tvb;
@@ -364,8 +376,9 @@ static void dissect_mac_fdd_dch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     ti = proto_tree_add_item(tree, proto_umts_mac, tvb, 0, -1, ENC_NA);
     dch_tree = proto_item_add_subtree(ti, ett_mac_dch);
 
-    macinf = p_get_proto_data(pinfo->fd, proto_umts_mac);
-    fpinf = p_get_proto_data(pinfo->fd, proto_fp);
+    macinf = (umts_mac_info *)p_get_proto_data(pinfo->fd, proto_umts_mac);
+    fpinf  = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp);
+    rlcinf = (rlc_info *)p_get_proto_data(pinfo->fd, proto_rlc);
     if (!macinf || !fpinf) {
         proto_tree_add_text(dch_tree, tvb, 0, -1,
             "Cannot dissect MAC frame because per-frame info is missing");
@@ -373,6 +386,9 @@ static void dissect_mac_fdd_dch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     }
     pos = fpinf->cur_tb;
     if (macinf->ctmux[pos]) {
+        if(rlcinf){
+            rlcinf->rbid[fpinf->cur_tb] = tvb_get_bits8(tvb, bitoffs, 4);
+        }
         proto_tree_add_bits_item(dch_tree, hf_mac_ct, tvb, 0, 4, ENC_BIG_ENDIAN);
         bitoffs = 4;
     }
@@ -419,15 +435,16 @@ static void dissect_mac_fdd_edch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
     ti = proto_tree_add_item(tree, proto_umts_mac, tvb, 0, -1, ENC_NA);
     edch_tree = proto_item_add_subtree(ti, ett_mac_edch);
 
-    fpinf = p_get_proto_data(pinfo->fd, proto_fp);
-    macinf = p_get_proto_data(pinfo->fd, proto_umts_mac);
-    pos = fpinf->cur_tb;
-    if (!macinf) {
+    fpinf  = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp);
+    macinf = (umts_mac_info *)p_get_proto_data(pinfo->fd, proto_umts_mac);
+    if (!macinf|| !fpinf) {
         proto_tree_add_text(edch_tree, tvb, 0, -1,
             "Cannot dissect MAC frame because per-frame info is missing");
         return;
     }
 
+    pos = fpinf->cur_tb;
+
     switch (macinf->content[pos]) {
         case MAC_CONTENT_DCCH:
             proto_item_append_text(ti, " (DCCH)");
@@ -472,8 +489,8 @@ static void dissect_mac_fdd_hsdsch(tvbuff_t *tvb, packet_info *pinfo, proto_tree
     ti = proto_tree_add_item(tree, proto_umts_mac, tvb, 0, -1, ENC_NA);
     hsdsch_tree = proto_item_add_subtree(ti, ett_mac_hsdsch);
 
-    fpinf = p_get_proto_data(pinfo->fd, proto_fp);
-    macinf = p_get_proto_data(pinfo->fd, proto_umts_mac);
+    fpinf  = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp);
+    macinf = (umts_mac_info *)p_get_proto_data(pinfo->fd, proto_umts_mac);
     pos = fpinf->cur_tb;
     bitoffs = fpinf->hsdsch_entity == ehs ? 0 : 4;
 
