@@ -1,6 +1,6 @@
 /* packet-usb-hid.c
  *
- * $Id: packet-usb-hid.c 41715 2012-03-21 08:40:19Z etxrab $
+ * $Id: packet-usb-hid.c 42823 2012-05-24 09:17:11Z etxrab $
  *
  * USB HID dissector
  * By Adam Nielsen <a.nielsen@shikadi.net> 2009
@@ -583,7 +583,7 @@ dissect_usb_hid_get_report(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *t
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -608,7 +608,7 @@ dissect_usb_hid_set_report(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *t
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -634,7 +634,7 @@ dissect_usb_hid_get_idle(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *tvb
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -660,7 +660,7 @@ dissect_usb_hid_set_idle(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *tvb
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -677,7 +677,7 @@ dissect_usb_hid_get_protocol(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -694,7 +694,7 @@ dissect_usb_hid_set_protocol(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_usb_hid_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-		offset += 2;
+		/*offset += 2;*/
 	} else {
 	}
 }
@@ -880,13 +880,13 @@ proto_register_usb_hid(void)
 				TFS(&tfs_mainitem_bit8), 1<<8, NULL, HFILL }},
 
 		{ &hf_usb_hid_mainitem_colltype,
-			{ "Collection type", "usbhid.item.main.colltype", FT_UINT8, BASE_HEX,
+			{ "Collection type", "usbhid.item.main.colltype", FT_UINT8, BASE_RANGE_STRING|BASE_HEX,
 				RVALS(usb_hid_mainitem_colltype_vals), 0, NULL, HFILL }},
 
 		/* Global-report item data */
 
 		{ &hf_usb_hid_globalitem_usage,
-			{ "Usage page", "usbhid.item.global.usage", FT_UINT8, BASE_HEX,
+			{ "Usage page", "usbhid.item.global.usage", FT_UINT8, BASE_RANGE_STRING|BASE_HEX,
 				RVALS(usb_hid_item_usage_vals), 0, NULL, HFILL }},
 
 		{ &hf_usb_hid_globalitem_log_min,
@@ -960,7 +960,7 @@ proto_register_usb_hid(void)
 		/* Local-report item data */
 
 		{ &hf_usb_hid_localitem_usage,
-			{ "Usage", "usbhid.item.local.usage", FT_UINT8, BASE_HEX,
+			{ "Usage", "usbhid.item.local.usage", FT_UINT8, BASE_RANGE_STRING|BASE_HEX,
 				RVALS(usb_hid_item_usage_vals), 0, NULL, HFILL }},
 
 		{ &hf_usb_hid_localitem_usage_min,
