@@ -1,6 +1,6 @@
 /* packet-usb.h
  *
- * $Id: packet-usb.h 41715 2012-03-21 08:40:19Z etxrab $
+ * $Id: packet-usb.h 42286 2012-04-27 08:44:36Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -155,6 +155,13 @@ typedef struct _usb_tap_data_t {
 #define RQT_SETUP_RECIPIENT_ENDPOINT    2
 #define RQT_SETUP_RECIPIENT_OTHER       3
 
+/* Endpoint descriptor bmAttributes  */
+#define ENDPOINT_TYPE(ep_attrib)        ((ep_attrib) & 0x03)
+#define ENDPOINT_TYPE_CONTROL           0
+#define ENDPOINT_TYPE_ISOCHRONOUS       1
+#define ENDPOINT_TYPE_BULK              2
+#define ENDPOINT_TYPE_INTERRUPT         3
+
 void dissect_usb_descriptor_header(proto_tree *tree, tvbuff_t *tvb, int offset);
 void dissect_usb_endpoint_address(proto_tree *tree, tvbuff_t *tvb, int offset);
 
