@@ -2,7 +2,7 @@
  * Routines for UTS WAN protocol dissection
  * Copyright 2007, Fulko Hew, SITA INC Canada, Inc.
  *
- * $Id: packet-uts.c 48713 2013-04-02 21:25:51Z cmaynard $
+ * $Id: packet-uts.c 40320 2011-12-28 23:39:14Z gerald $
  *
  * Copied from packet-ipars.c
  *
@@ -160,7 +160,7 @@ dissect_uts(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 					set_addr(pinfo, SRC, rid, sid, did);
 				} else {
 					col_add_str(pinfo->cinfo, COL_INFO, "Unknown Message Format");
-					if ((pinfo->pseudo_header->sita.flags & SITA_FRAME_DIR) == SITA_FRAME_DIR_TXED) {
+					if ((pinfo->pseudo_header->sita.sita_flags & SITA_FRAME_DIR) == SITA_FRAME_DIR_TXED) {
 						set_addr(pinfo, DST, rid, sid, did);	/* if the ACN sent it, the address is of the destination... the terminal */
 					} else {
 						set_addr(pinfo, SRC, rid, sid, did);	/* if the ACN received it, the address if of the source... the terminal */
@@ -192,7 +192,7 @@ dissect_uts(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 				header_length = offset+1;
 				stx_start = offset;
 				col_add_str(pinfo->cinfo, COL_INFO, "Text");
-				if ((pinfo->pseudo_header->sita.flags & SITA_FRAME_DIR) == SITA_FRAME_DIR_TXED) {
+				if ((pinfo->pseudo_header->sita.sita_flags & SITA_FRAME_DIR) == SITA_FRAME_DIR_TXED) {
 					set_addr(pinfo, DST, rid, sid, did);		/* if the ACN sent it, the address is of the destination... the terminal */
 				} else {
 					set_addr(pinfo, SRC, rid, sid, did);		/* if the ACN received it, the address if of the source... the terminal */
@@ -241,7 +241,7 @@ dissect_uts(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 		}
 	}
 
-	while (tvb_length_remaining(tvb, offset) > 0) {				/* now look for the ETX */
+	while (tvb_length_remaining(tvb, offset) > 0) {					/* now look for the ETX */
 		if ((tvb_get_guint8(tvb, offset) & 0x7f) == ETX) {
 			if (header_length == -1)
 				header_length = offset;	/* the header ends at an STX, or if not found, the ETX */
