@@ -15,7 +15,7 @@
  *
  * Routines for V5.2-User Adaptation Layer dissection
  *
- * $Id: packet-v5ua.c 41645 2012-03-18 22:24:24Z wmeier $
+ * $Id: packet-v5ua.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Extension of ISDN Q.921-User Adaptation Layer dissection
  * Copyright 2002, Michael Tuexen <Michael.Tuexen[AT]siemens.com>
@@ -45,9 +45,6 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
-#include <ctype.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
