@@ -1,7 +1,7 @@
 /* packet-vj.c
  * Routines for Van Jacobson header decompression.  (See RFC 1144.)
  *
- * $Id: packet-vj.c 31682 2010-01-26 15:54:12Z wmeier $
+ * $Id: packet-vj.c 35224 2010-12-20 05:35:29Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -878,10 +878,10 @@ proto_reg_handoff_vj(void)
   dissector_handle_t vjuc_handle;
 
   vjc_handle = create_dissector_handle(dissect_vjc, proto_vj);
-  dissector_add("ppp.protocol", PPP_VJC_COMP, vjc_handle);
+  dissector_add_uint("ppp.protocol", PPP_VJC_COMP, vjc_handle);
 
   vjuc_handle = create_dissector_handle(dissect_vjuc, proto_vj);
-  dissector_add("ppp.protocol", PPP_VJC_UNCOMP, vjuc_handle);
+  dissector_add_uint("ppp.protocol", PPP_VJC_UNCOMP, vjuc_handle);
 
   ip_handle = find_dissector("ip");
   data_handle = find_dissector("data");
