@@ -1,7 +1,7 @@
 /* packet-vxi11.c
  * Routines for VXI-11 (TCP/IP Instrument Protocol) dissection.
  *
- * $Id: packet-vxi11.c 32494 2010-04-16 16:12:29Z wmeier $
+ * $Id: packet-vxi11.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -231,16 +231,16 @@ dissect_flags(tvbuff_t *tvb, int offset, proto_tree *tree)
         guint32 flags =
             tvb_get_ntohl(tvb, offset);
         proto_item *flags_item =
-            proto_tree_add_item(tree, hf_vxi11_core_flags, tvb, offset, 4, FALSE);
+            proto_tree_add_item(tree, hf_vxi11_core_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
 
         if (flags_item)
         {
             proto_tree *flags_tree =
                 proto_item_add_subtree(flags_item, ett_vxi11_core_flags);
 
-            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_wait_lock, tvb, offset, 4, FALSE);
-            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_end, tvb, offset, 4, FALSE);
-            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_term_chr_set, tvb, offset, 4, FALSE);
+            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_wait_lock, tvb, offset, 4, ENC_BIG_ENDIAN);
+            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_end, tvb, offset, 4, ENC_BIG_ENDIAN);
+            proto_tree_add_item(flags_tree, hf_vxi11_core_flag_term_chr_set, tvb, offset, 4, ENC_BIG_ENDIAN);
 
             if (flags != 0)
             {
@@ -276,16 +276,16 @@ dissect_reason(tvbuff_t *tvb, int offset, proto_tree *tree)
         guint32 reason =
             tvb_get_ntohl(tvb, offset);
         proto_item *reason_item =
-            proto_tree_add_item(tree, hf_vxi11_core_reason, tvb, offset, 4, FALSE);
+            proto_tree_add_item(tree, hf_vxi11_core_reason, tvb, offset, 4, ENC_BIG_ENDIAN);
 
         if (reason_item)
         {
             proto_tree *reason_tree =
                 proto_item_add_subtree(reason_item, ett_vxi11_core_reason);
 
-            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_req_cnt, tvb, offset, 4, FALSE);
-            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_chr, tvb, offset, 4, FALSE);
-            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_end, tvb, offset, 4, FALSE);
+            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_req_cnt, tvb, offset, 4, ENC_BIG_ENDIAN);
+            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_chr, tvb, offset, 4, ENC_BIG_ENDIAN);
+            proto_tree_add_item(reason_tree, hf_vxi11_core_reason_end, tvb, offset, 4, ENC_BIG_ENDIAN);
 
             if (reason != 0)
             {
