@@ -2,7 +2,7 @@
  *
  * Declarations for WAP packet disassembly
  *
- * $Id: packet-wap.h 34763 2010-11-03 18:28:35Z wmeier $
+ * $Id: packet-wap.h 39276 2011-10-05 19:21:48Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -73,12 +73,6 @@
 #define HF_EMPTY	( -1 )
 #define ETT_EMPTY	( -1 )
 
-enum
-{
-	bo_big_endian		= 0,
-	bo_little_endian	= 1
-};
-
 /* Utility function for reading Uintvar encoded values */
 guint tvb_get_guintvar (tvbuff_t *, guint , guint *);
 
