@@ -2,7 +2,7 @@
  * Routines for Web Cache Communication Protocol dissection
  * Jerry Talkington <jtalkington@users.sourceforge.net>
  *
- * $Id: packet-wccp.c 35519 2011-01-13 15:53:30Z morriss $
+ * $Id: packet-wccp.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -221,7 +221,7 @@ dissect_wccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if(tree != NULL) {
 		wccp_tree_item = proto_tree_add_item(tree, proto_wccp, tvb, offset,
-		    -1, FALSE);
+		    -1, ENC_NA);
 		wccp_tree = proto_item_add_subtree(wccp_tree_item, ett_wccp);
 
 		proto_tree_add_uint(wccp_tree, hf_wccp_message_type, tvb, offset,
@@ -232,24 +232,24 @@ dissect_wccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		case WCCP_HERE_I_AM:
 			proto_tree_add_item(wccp_tree, hf_wccp_version, tvb,
-			    offset, 4, FALSE);
+			    offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 			dissect_hash_data(tvb, offset, wccp_tree);
 			offset += HASH_INFO_SIZE;
 			proto_tree_add_item(wccp_tree, hf_recvd_id, tvb, offset,
-			    4, FALSE);
+			    4, ENC_BIG_ENDIAN);
 			offset += 4;
 			break;
 
 		case WCCP_I_SEE_YOU:
 			proto_tree_add_item(wccp_tree, hf_wccp_version, tvb,
-			    offset, 4, FALSE);
+			    offset, 4, ENC_BIG_ENDIAN);
 			offset += 4;
 			proto_tree_add_item(wccp_tree, hf_change_num, tvb, offset,
-			    4, FALSE);
+			    4, ENC_BIG_ENDIAN);
 			offset += 4;
 			proto_tree_add_item(wccp_tree, hf_recvd_id, tvb, offset,
-			    4, FALSE);
+			    4, ENC_BIG_ENDIAN);
 			offset += 4;
 			cache_count = tvb_get_ntohl(tvb, offset);
 			proto_tree_add_text(wccp_tree, tvb, offset, 4,
@@ -272,7 +272,7 @@ dissect_wccp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			 * rather than a Version field.
 			 */
 			proto_tree_add_item(wccp_tree, hf_recvd_id, tvb, offset,
-			    4, FALSE);
+			    4, ENC_BIG_ENDIAN);
 			offset += 4;
 			cache_count = tvb_get_ntohl(tvb, offset);
 			proto_tree_add_text(wccp_tree, tvb, offset, 4,
@@ -327,7 +327,7 @@ dissect_hash_data(tvbuff_t *tvb, int offset, proto_tree *wccp_tree)
 	guint32 flags;
 
 	proto_tree_add_item(wccp_tree, hf_hash_revision, tvb, offset, 4,
-	    FALSE);
+	    ENC_BIG_ENDIAN);
 	offset += 4;
 
 	bucket_item = proto_tree_add_text(wccp_tree, tvb, offset, 32,
@@ -364,7 +364,7 @@ dissect_web_cache_list_entry(tvbuff_t *tvb, int offset, int idx,
 	    "Web-Cache List Entry(%d)", idx);
 	list_entry_tree = proto_item_add_subtree(tl, ett_cache_info);
 	proto_tree_add_item(list_entry_tree, hf_cache_ip, tvb, offset, 4,
-	    FALSE);
+	    ENC_BIG_ENDIAN);
 	dissect_hash_data(tvb, offset + 4, list_entry_tree);
 }
 
@@ -405,7 +405,7 @@ dissect_wccp2_header(tvbuff_t *tvb, int offset, proto_tree *wccp_tree)
 	guint16 length;
 
 	proto_tree_add_item(wccp_tree, hf_wccp_version, tvb, offset, 2,
-	    FALSE);
+	    ENC_BIG_ENDIAN);
 	offset += 2;
 	length = tvb_get_ntohs(tvb, offset);
 	proto_tree_add_text(wccp_tree, tvb, offset, 2, "Length: %u",
