@@ -4,7 +4,7 @@
  *
  * Copyright 2009-2010 Atheros Communications
  *
- * $Id: packet-wifi-p2p.c 35504 2011-01-12 07:46:46Z jake $
+ * $Id: packet-wifi-p2p.c 39700 2011-11-01 01:23:10Z morriss $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,7 +52,7 @@ enum {
   P2P_ATTR_OPERATING_CHANNEL = 17,
   P2P_ATTR_INVITATION_FLAGS = 18,
   /* 19-220 Reserved */
-  P2P_ATTR_VENDOR_SPECIFIC = 221,
+  P2P_ATTR_VENDOR_SPECIFIC = 221
   /* 222-255 Reserved */
 };
 
@@ -115,7 +115,7 @@ enum {
   P2P_ACT_DEV_DISC_REQ = 5,
   P2P_ACT_DEV_DISC_RESP = 6,
   P2P_ACT_PROV_DISC_REQ = 7,
-  P2P_ACT_PROV_DISC_RESP = 8,
+  P2P_ACT_PROV_DISC_RESP = 8
 };
 
 static const value_string p2p_public_action_subtypes[] = {
@@ -135,7 +135,7 @@ enum {
   P2P_ACT_NOA = 0,
   P2P_ACT_P2P_PRESENCE_REQ = 1,
   P2P_ACT_P2P_PRESENCE_RESP = 2,
-  P2P_ACT_GO_DISC_REQ = 3,
+  P2P_ACT_GO_DISC_REQ = 3
 };
 
 static const value_string p2p_action_subtypes[] = {
@@ -158,7 +158,7 @@ enum {
   P2P_FAIL_UNKNOWN_P2P_GROUP = 8,
   P2P_FAIL_BOTH_DEVICES_GO = 9,
   P2P_FAIL_INCOMPATIBLE_PROVISION_METHOD = 10,
-  P2P_FAIL_REJECTED_BY_USER = 11,
+  P2P_FAIL_REJECTED_BY_USER = 11
 };
 
 static const value_string p2p_status_codes[] = {
@@ -186,7 +186,7 @@ enum {
   P2P_MINOR_DISCONNECT_DUE_TO_CROSS_CONNECTION = 1,
   P2P_MINOR_DISCONNECT_DUE_TO_NOT_P2P_MANAGED = 2,
   P2P_MINOR_DISCONNECT_DUE_TO_NO_COEXISTENCE = 3,
-  P2P_MINOR_DISCONNECT_DUE_TO_OUTSIDE_POLICY = 4,
+  P2P_MINOR_DISCONNECT_DUE_TO_OUTSIDE_POLICY = 4
 };
 
 static const value_string p2p_minor_reason_codes[] = {
@@ -371,42 +371,42 @@ static void dissect_wifi_p2p_capability(proto_item *tlv_root,
                                         tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_device, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_device_service_discovery, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_device_client_discoverability,
-                      tvb, offset + 3, 1, FALSE);
+                      tvb, offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_device_concurrent_operation,
-                      tvb, offset + 3, 1, FALSE);
+                      tvb, offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_device_infrastructure_managed,
-                      tvb, offset + 3, 1, FALSE);
+                      tvb, offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_device_limit, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_invitation_procedure, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group_owner,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group_persistent,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group_limit,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_group_intra_bss_distribution,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group_cross_connection,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_capab_group_persistent_reconnect,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_capab_group_group_formation,
-                      tvb, offset + 4, 1, FALSE);
+                      tvb, offset + 4, 1, ENC_BIG_ENDIAN);
 
   proto_item_append_text(tlv_item, ": Device 0x%x  Group 0x%x",
                          tvb_get_guint8(tvb, offset + 3),
@@ -418,7 +418,7 @@ static void dissect_device_id(proto_item *tlv_root, proto_item *tlv_item,
 {
   guint8 addr[6];
   proto_tree_add_item(tlv_root, hf_p2p_attr_device_id, tvb,
-                      offset + 3, 6, FALSE);
+                      offset + 3, 6, ENC_NA);
   tvb_memcpy(tvb, addr, offset + 3, 6);
   proto_item_append_text(tlv_item, ": %s", ether_to_str(addr));
 }
@@ -428,9 +428,9 @@ static void dissect_group_owner_intent(proto_item *tlv_root,
                                        tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_go_intent, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_go_intent_tie_breaker, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": Intent %u  Tie breaker %u",
                          tvb_get_guint8(tvb, offset + 3) >> 1,
                          tvb_get_guint8(tvb, offset + 3) & 0x01);
@@ -440,7 +440,7 @@ static void dissect_status(proto_item *tlv_root, proto_item *tlv_item,
                            tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_status, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": %u (%s)",
                          tvb_get_guint8(tvb, offset + 3),
                          val_to_str(tvb_get_guint8(tvb, offset + 3),
@@ -452,11 +452,11 @@ static void dissect_listen_channel(proto_item *tlv_root, proto_item *tlv_item,
                                    tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_listen_channel_country, tvb,
-                      offset + 3, 3, FALSE);
+                      offset + 3, 3, ENC_ASCII|ENC_NA);
   proto_tree_add_item(tlv_root, hf_p2p_attr_listen_channel_oper_class, tvb,
-                      offset + 6, 1, FALSE);
+                      offset + 6, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_listen_channel_number, tvb,
-                      offset + 7, 1, FALSE);
+                      offset + 7, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": Operating Class %u  "
                          "Channel Number %u",
                          tvb_get_guint8(tvb, offset + 6),
@@ -468,11 +468,11 @@ static void dissect_operating_channel(proto_item *tlv_root,
                                       tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_operating_channel_country, tvb,
-                      offset + 3, 3, FALSE);
+                      offset + 3, 3, ENC_ASCII|ENC_NA);
   proto_tree_add_item(tlv_root, hf_p2p_attr_operating_channel_oper_class, tvb,
-                      offset + 6, 1, FALSE);
+                      offset + 6, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_operating_channel_number, tvb,
-                      offset + 7, 1, FALSE);
+                      offset + 7, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": Operating Class %u  "
                          "Channel Number %u",
                          tvb_get_guint8(tvb, offset + 6),
@@ -486,21 +486,21 @@ static void dissect_channel_list(proto_item *tlv_root, tvbuff_t *tvb,
   guint8 num_chan;
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_channel_list_country, tvb,
-                      s_offset, 3, FALSE);
+                      s_offset, 3, ENC_ASCII|ENC_NA);
   s_offset += 3;
 
   while (offset + 3 + slen > s_offset) {
     proto_tree_add_item(tlv_root, hf_p2p_attr_channel_list_oper_class, tvb,
-                        s_offset, 1, FALSE);
+                        s_offset, 1, ENC_BIG_ENDIAN);
     s_offset++;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_channel_list_num_chan, tvb,
-                        s_offset, 1, FALSE);
+                        s_offset, 1, ENC_BIG_ENDIAN);
     num_chan = tvb_get_guint8(tvb, s_offset);
     s_offset++;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_channel_list_chan, tvb,
-                        s_offset, num_chan, FALSE);
+                        s_offset, num_chan, ENC_NA);
     s_offset += num_chan;
   }
 }
@@ -517,65 +517,65 @@ static void dissect_wifi_p2p_device_info(packet_info *pinfo,
   s_offset = offset + 3;
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_p2p_dev_addr, tvb,
-                      s_offset, 6, FALSE);
+                      s_offset, 6, ENC_NA);
   s_offset += 6;
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_config_methods,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_usba,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_ethernet,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_label,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_display,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_ext_nfc_token,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_int_nfc_token,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_nfc_interface,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_pushbutton,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root,
                       hf_p2p_attr_dev_info_config_methods_keypad,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
 
   s_offset += 2;
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_pri_dev_type, tvb,
-                      s_offset, 8, FALSE);
+                      s_offset, 8, ENC_NA);
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_pri_dev_type_category,
-                      tvb, s_offset, 2, FALSE);
+                      tvb, s_offset, 2, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_pri_dev_type_oui,
-                      tvb, s_offset + 2, 4, FALSE);
+                      tvb, s_offset + 2, 4, ENC_NA);
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_pri_dev_type_subcategory,
-                      tvb, s_offset + 6, 2, FALSE);
+                      tvb, s_offset + 6, 2, ENC_BIG_ENDIAN);
   s_offset += 8;
 
   num_sec = tvb_get_guint8(tvb, s_offset);
   proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_num_sec, tvb,
-                      s_offset, 1, FALSE);
+                      s_offset, 1, ENC_BIG_ENDIAN);
   s_offset++;
 
   while (num_sec > 0) {
     proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_sec_dev_type,
-                        tvb, s_offset, 8, FALSE);
+                        tvb, s_offset, 8, ENC_NA);
     s_offset += 8;
     num_sec--;
   }
 
   item = proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_dev_name_type,
-                             tvb, s_offset, 2, FALSE);
+                             tvb, s_offset, 2, ENC_BIG_ENDIAN);
   attr_type = tvb_get_ntohs(tvb, s_offset);
   if (attr_type != 0x1011) {
     expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
@@ -583,7 +583,7 @@ static void dissect_wifi_p2p_device_info(packet_info *pinfo,
   }
   s_offset += 2;
   item = proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_dev_name_len,
-                             tvb, s_offset, 2, FALSE);
+                             tvb, s_offset, 2, ENC_BIG_ENDIAN);
   attr_len = tvb_get_ntohs(tvb, s_offset);
   s_offset += 2;
   if (attr_len > offset + 3 + slen - s_offset) {
@@ -596,7 +596,7 @@ static void dissect_wifi_p2p_device_info(packet_info *pinfo,
     item = proto_tree_add_item(tlv_root, hf_p2p_attr_dev_info_dev_name,
                                tvb, s_offset,
                                nlen > attr_len ? attr_len : nlen,
-                               FALSE);
+                               ENC_ASCII|ENC_NA);
   if (nlen != attr_len) {
     expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
                            "Invalid Device Name attribute");
@@ -608,9 +608,9 @@ static void dissect_configuration_timeout(proto_item *tlv_root,
                                           tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_config_timeout_go, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_config_timeout_client, tvb,
-                      offset + 4, 1, FALSE);
+                      offset + 4, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": GO %u msec, client %u msec",
                          tvb_get_guint8(tvb, offset + 3) * 10,
                          tvb_get_guint8(tvb, offset + 4) * 10);
@@ -622,7 +622,7 @@ static void dissect_intended_interface_addr(proto_item *tlv_root,
 {
   guint8 addr[6];
   proto_tree_add_item(tlv_root, hf_p2p_attr_intended_interface_addr, tvb,
-                      offset + 3, 6, FALSE);
+                      offset + 3, 6, ENC_NA);
   tvb_memcpy(tvb, addr, offset + 3, 6);
   proto_item_append_text(tlv_item, ": %s", ether_to_str(addr));
 }
@@ -651,18 +651,18 @@ static void dissect_wifi_p2p_group_id(proto_item *tlv_root,
 
   s_offset = offset + 3;
   proto_tree_add_item(tlv_root, hf_p2p_attr_p2p_group_id_dev_addr, tvb,
-                      s_offset, 6, FALSE);
+                      s_offset, 6, ENC_NA);
   tvb_memcpy(tvb, addr, offset + 3, 6);
   proto_item_append_text(tlv_item, ": %s", ether_to_str(addr));
   s_offset += 6;
   proto_tree_add_item(tlv_root, hf_p2p_attr_p2p_group_id_ssid, tvb,
-                      s_offset, offset + 3 + slen - s_offset, FALSE);
+                      s_offset, offset + 3 + slen - s_offset, ENC_ASCII|ENC_NA);
 }
 
 static void dissect_wifi_p2p_group_bssid(packet_info *pinfo,
-	                              proto_item *tlv_root,
-                                      proto_item *tlv_item, tvbuff_t *tvb,
-                                      int offset, guint16 slen)
+                                         proto_item *tlv_root,
+                                         proto_item *tlv_item, tvbuff_t *tvb,
+                                         int offset, guint16 slen)
 {
   int s_offset;
   guint8 addr[6];
@@ -675,7 +675,7 @@ static void dissect_wifi_p2p_group_bssid(packet_info *pinfo,
 
   s_offset = offset + 3;
   proto_tree_add_item(tlv_root, hf_p2p_attr_p2p_group_bssid, tvb,
-                      s_offset, 6, FALSE);
+                      s_offset, 6, ENC_NA);
   tvb_memcpy(tvb, addr, offset + 3, 6);
   proto_item_append_text(tlv_item, ": %s", ether_to_str(addr));
 }
@@ -693,27 +693,27 @@ static void dissect_notice_of_absence(packet_info *pinfo, proto_item *tlv_root,
   }
 
   proto_tree_add_item(tlv_root, hf_p2p_attr_noa_index, tvb, s_offset, 1,
-                      FALSE);
+                      ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_noa_params, tvb, s_offset + 1, 1,
-                      FALSE);
+                      ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_noa_params_opp_ps, tvb,
-                      s_offset + 1, 1, FALSE);
+                      s_offset + 1, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_noa_params_ctwindow, tvb,
-                      s_offset + 1, 1, FALSE);
+                      s_offset + 1, 1, ENC_BIG_ENDIAN);
 
   s_offset += 2;
   while (offset + 3 + slen >= s_offset + 13) {
     proto_tree_add_item(tlv_root, hf_p2p_attr_noa_count_type, tvb, s_offset, 1,
-                        FALSE);
+                        ENC_BIG_ENDIAN);
     s_offset++;
     proto_tree_add_item(tlv_root, hf_p2p_attr_noa_duration, tvb, s_offset, 4,
-                        TRUE);
+                        ENC_LITTLE_ENDIAN);
     s_offset += 4;
     proto_tree_add_item(tlv_root, hf_p2p_attr_noa_interval, tvb, s_offset, 4,
-                        TRUE);
+                        ENC_LITTLE_ENDIAN);
     s_offset += 4;
     proto_tree_add_item(tlv_root, hf_p2p_attr_noa_start_time, tvb, s_offset, 4,
-                        TRUE);
+                        ENC_LITTLE_ENDIAN);
     s_offset += 4;
   }
 }
@@ -737,7 +737,7 @@ static void dissect_wifi_p2p_group_info(packet_info *pinfo,
     }
 
     item = proto_tree_add_item(tlv_root, hf_p2p_attr_gi_length, tvb, s_offset,
-                               1, FALSE);
+                               1, ENC_BIG_ENDIAN);
     ci_len = tvb_get_guint8(tvb, s_offset);
     if (ci_len < 24 || s_offset + ci_len > offset + 3 + slen) {
       expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
@@ -748,49 +748,49 @@ static void dissect_wifi_p2p_group_info(packet_info *pinfo,
     next_offset = s_offset + ci_len;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_p2p_dev_addr, tvb, s_offset,
-                        6, FALSE);
+                        6, ENC_NA);
     s_offset += 6;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_p2p_iface_addr, tvb, s_offset,
-                        6, FALSE);
+                        6, ENC_NA);
     s_offset += 6;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_dev_capab, tvb, s_offset, 1,
-                        FALSE);
+                        ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root,
                         hf_p2p_attr_gi_dev_capab_service_discovery, tvb,
-                        s_offset, 1, FALSE);
+                        s_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root,
                         hf_p2p_attr_gi_dev_capab_client_discoverability,
-                        tvb, s_offset, 1, FALSE);
+                        tvb, s_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root,
                         hf_p2p_attr_gi_dev_capab_concurrent_operation,
-                        tvb, s_offset, 1, FALSE);
+                        tvb, s_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root,
                         hf_p2p_attr_gi_dev_capab_infrastructure_managed,
-                        tvb, s_offset, 1, FALSE);
+                        tvb, s_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_dev_capab_limit, tvb,
-                        s_offset, 1, FALSE);
+                        s_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root, hf_p2p_attr_capab_invitation_procedure, tvb,
-                        s_offset, 1, FALSE);
+                        s_offset, 1, ENC_BIG_ENDIAN);
     s_offset++;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_config_methods, tvb, s_offset,
-                        2, FALSE);
+                        2, ENC_BIG_ENDIAN);
     s_offset += 2;
 
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_pri_dev_type, tvb,
-                        s_offset, 8, FALSE);
+                        s_offset, 8, ENC_NA);
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_pri_dev_type_category,
-                        tvb, s_offset, 2, FALSE);
+                        tvb, s_offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_pri_dev_type_oui,
-                        tvb, s_offset + 2, 4, FALSE);
+                        tvb, s_offset + 2, 4, ENC_NA);
     proto_tree_add_item(tlv_root, hf_p2p_attr_gi_pri_dev_type_subcategory,
-                        tvb, s_offset + 6, 2, FALSE);
+                        tvb, s_offset + 6, 2, ENC_BIG_ENDIAN);
     s_offset += 8;
 
     item = proto_tree_add_item(tlv_root, hf_p2p_attr_gi_num_sec_dev_types, tvb,
-                               s_offset, 1, FALSE);
+                               s_offset, 1, ENC_BIG_ENDIAN);
     num_sec = tvb_get_guint8(tvb, s_offset);
     s_offset++;
     left = offset + 3 + slen - s_offset;
@@ -801,13 +801,13 @@ static void dissect_wifi_p2p_group_info(packet_info *pinfo,
     }
     while (num_sec > 0) {
       proto_tree_add_item(tlv_root, hf_p2p_attr_gi_sec_dev_type,
-                          tvb, s_offset, 8, FALSE);
+                          tvb, s_offset, 8, ENC_NA);
       s_offset += 8;
       num_sec--;
     }
 
     item = proto_tree_add_item(tlv_root, hf_p2p_attr_gi_dev_name_type,
-                               tvb, s_offset, 2, FALSE);
+                               tvb, s_offset, 2, ENC_BIG_ENDIAN);
     attr_type = tvb_get_ntohs(tvb, s_offset);
     if (attr_type != 0x1011) {
       expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
@@ -815,7 +815,7 @@ static void dissect_wifi_p2p_group_info(packet_info *pinfo,
     }
     s_offset += 2;
     item = proto_tree_add_item(tlv_root, hf_p2p_attr_gi_dev_name_len,
-                               tvb, s_offset, 2, FALSE);
+                               tvb, s_offset, 2, ENC_BIG_ENDIAN);
     attr_len = tvb_get_ntohs(tvb, s_offset);
     s_offset += 2;
     if (attr_len > offset + 3 + slen - s_offset) {
@@ -828,7 +828,7 @@ static void dissect_wifi_p2p_group_info(packet_info *pinfo,
       item = proto_tree_add_item(tlv_root, hf_p2p_attr_gi_dev_name,
                                  tvb, s_offset,
                                  nlen > attr_len ? attr_len : nlen,
-                                 FALSE);
+                                 ENC_ASCII|ENC_NA);
     if (nlen != attr_len) {
       expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
                              "Invalid Device Name attribute");
@@ -843,9 +843,9 @@ static void dissect_invitation_flags(proto_item *tlv_root,
                                      tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_invitation_flags, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_invitation_flags_type, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": Invitation Flags 0x%x",
                          tvb_get_guint8(tvb, offset + 3));
 }
@@ -855,13 +855,13 @@ static void dissect_manageability(proto_item *tlv_root,
                                   tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_manageability_bitmap, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_manageability_bitmap_mgmt, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_manageability_bitmap_cross_connect,
-                      tvb, offset + 3, 1, FALSE);
+                      tvb, offset + 3, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item(tlv_root, hf_p2p_attr_manageability_bitmap_coex_opt, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": Bitmap field 0x%x",
                          tvb_get_guint8(tvb, offset + 3));
 }
@@ -871,7 +871,7 @@ static void dissect_minor_reason_code(proto_item *tlv_root,
                                       tvbuff_t *tvb, int offset)
 {
   proto_tree_add_item(tlv_root, hf_p2p_attr_minor_reason_code, tvb,
-                      offset + 3, 1, FALSE);
+                      offset + 3, 1, ENC_BIG_ENDIAN);
   proto_item_append_text(tlv_item, ": %u (%s)",
                          tvb_get_guint8(tvb, offset + 3),
                          val_to_str(tvb_get_guint8(tvb, offset + 3),
@@ -901,7 +901,7 @@ void dissect_wifi_p2p_ie(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
                                               "Unknown attribute type (%u)"));
     tlv_root = proto_item_add_subtree(tlv_item, ett_p2p_tlv);
 
-    proto_tree_add_item(tlv_root, hf_p2p_attr_type, tvb, offset, 1, FALSE);
+    proto_tree_add_item(tlv_root, hf_p2p_attr_type, tvb, offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_uint(tlv_root, hf_p2p_attr_len, tvb, offset + 1, 2,
                         slen);
 
@@ -968,13 +968,19 @@ void dissect_wifi_p2p_ie(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
   }
 }
 
-int dissect_wifi_p2p_public_action(proto_tree *tree, tvbuff_t *tvb, int offset)
+int dissect_wifi_p2p_public_action(packet_info *pinfo, proto_tree *tree,
+                                   tvbuff_t *tvb, int offset)
 {
+  guint8 subtype;
   proto_tree_add_item(tree, hf_p2p_public_action_subtype, tvb, offset, 1,
-                      FALSE);
+                      ENC_BIG_ENDIAN);
+  subtype = tvb_get_guint8(tvb, offset);
+  col_append_fstr(pinfo->cinfo, COL_INFO, ", P2P - %s",
+                  val_to_str(subtype, p2p_public_action_subtypes,
+                             "Unknown (%u)"));
   offset++;
   proto_tree_add_item(tree, hf_p2p_public_action_dialog_token, tvb, offset, 1,
-                      FALSE);
+                      ENC_BIG_ENDIAN);
   offset++;
   /* Followed by variable length IEs dissected by packet-ieee80211.c */
   return offset;
@@ -982,9 +988,9 @@ int dissect_wifi_p2p_public_action(proto_tree *tree, tvbuff_t *tvb, int offset)
 
 int dissect_wifi_p2p_action(proto_tree *tree, tvbuff_t *tvb, int offset)
 {
-  proto_tree_add_item(tree, hf_p2p_action_subtype, tvb, offset, 1, FALSE);
+  proto_tree_add_item(tree, hf_p2p_action_subtype, tvb, offset, 1, ENC_BIG_ENDIAN);
   offset++;
-  proto_tree_add_item(tree, hf_p2p_action_dialog_token, tvb, offset, 1, FALSE);
+  proto_tree_add_item(tree, hf_p2p_action_dialog_token, tvb, offset, 1, ENC_BIG_ENDIAN);
   offset++;
   /* Followed by variable length IEs dissected by packet-ieee80211.c */
   return offset;
@@ -996,7 +1002,7 @@ void dissect_wifi_p2p_anqp(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
   proto_item *item;
 
   item = proto_tree_add_item(tree, hf_p2p_anqp_service_update_indicator, tvb,
-                             offset, 2, TRUE);
+                             offset, 2, ENC_LITTLE_ENDIAN);
   offset += 2;
 
   while (tvb_length_remaining(tvb, offset) >= (request ? 4 : 5)) {
@@ -1024,20 +1030,20 @@ void dissect_wifi_p2p_anqp(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
                                               "Unknown (%u)"));
     tlv = proto_item_add_subtree(item, ett_p2p_service_tlv);
 
-    proto_tree_add_item(tlv, hf_p2p_anqp_length, tvb, offset, 2, TRUE);
+    proto_tree_add_item(tlv, hf_p2p_anqp_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
     offset += 2;
     proto_tree_add_item(tlv, hf_p2p_anqp_service_protocol_type, tvb,
-                        offset, 1, FALSE);
+                        offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(tlv, hf_p2p_anqp_service_transaction_id, tvb,
-                        offset + 1, 1, FALSE);
+                        offset + 1, 1, ENC_BIG_ENDIAN);
     if (request) {
       proto_tree_add_item(tlv, hf_p2p_anqp_query_data, tvb,
-                          offset + 2, len - 2, FALSE);
+                          offset + 2, len - 2, ENC_NA);
     } else {
       proto_tree_add_item(tlv, hf_p2p_anqp_status_code, tvb,
-                          offset + 2, 1, FALSE);
+                          offset + 2, 1, ENC_BIG_ENDIAN);
       proto_tree_add_item(tlv, hf_p2p_anqp_response_data, tvb,
-                          offset + 3, len - 3, FALSE);
+                          offset + 3, len - 3, ENC_NA);
     }
     offset += len;
   }
@@ -1507,6 +1513,6 @@ proto_register_p2p(void)
  * indent-tabs-mode: nil
  * End:
  *
- * ex: set shiftwidth=2 tabstop=8 expandtab
+ * ex: set shiftwidth=2 tabstop=8 expandtab:
  * :indentSize=2:tabSize=8:noTabs=true:
  */
