@@ -4,7 +4,7 @@
  *
  * Copyright 2009-2010 Atheros Communications
  *
- * $Id: packet-wifi-p2p.h 34642 2010-10-25 16:40:45Z wmeier $
+ * $Id: packet-wifi-p2p.h 39367 2011-10-11 18:26:03Z etxrab $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,8 +27,8 @@
 
 void dissect_wifi_p2p_ie(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
 			 int offset, gint size);
-int dissect_wifi_p2p_public_action(proto_tree *tree, tvbuff_t *tvb,
-				   int offset);
+int dissect_wifi_p2p_public_action(packet_info *pinfo, proto_tree *tree,
+                                   tvbuff_t *tvb, int offset);
 int dissect_wifi_p2p_action(proto_tree *tree, tvbuff_t *tvb, int offset);
 void dissect_wifi_p2p_anqp(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb,
 			   int offset, gboolean request);
