@@ -2,7 +2,7 @@
  * Routines for WOL dissection
  * Copyright 2007, Christopher Maynard <Chris.Maynard[AT]gtech.com>
  *
- * $Id: packet-wol.c 41724 2012-03-21 18:20:44Z wmeier $
+ * $Id: packet-wol.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,13 +58,10 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include <glib.h>
 
-#include <epan/addr_resolv.h>
 #include <epan/packet.h>
+#include <epan/addr_resolv.h>
 #include <epan/etypes.h>
 
 /* IF PROTO exposes code to other dissectors, then it must be exported
