@@ -12,7 +12,7 @@
  *
  * Copyright 2007 Jens Braeuer <jensb@cs.tu-berlin.de>
  *
- * $Id: packet-wps.c 39774 2011-11-09 17:33:18Z wmeier $
+ * $Id: packet-wps.c 41993 2012-04-09 17:53:04Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1568,7 +1568,7 @@ dissect_wps_tlvs(proto_tree *eap_tree, tvbuff_t *tvb, int offset,
       guint32 value = -1;
       void* valuep = NULL;
       header_field_info* hf_info = NULL;
-      char* fmt = NULL;
+      const char* fmt = NULL;
 
       proto_item_set_text(tlv_item, "%s",
                           val_to_str(tlv_type, eapwps_tlv_types, "Unknown (0x%04x)"));
