@@ -2,7 +2,7 @@
  * Routines for WAVE Short Message  dissection (WSMP)
  * Copyright 2008, Arada Systems (http://www.aradasystems.com) (email: siva@aradasystems.com)
  *
- * $Id: packet-wsmp.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-wsmp.c 42632 2012-05-15 19:23:35Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,7 +29,7 @@
 # include "config.h"
 #endif
 
-#include <stdlib.h>
+#include <glib.h>
 
 #include <epan/packet.h>
 #include <epan/etypes.h>
