@@ -2,7 +2,7 @@
  * Routines for X.25 packet disassembly
  * Olivier Abad <oabad@noos.fr>
  *
- * $Id: packet-x25.c 42632 2012-05-15 19:23:35Z wmeier $
+ * $Id: packet-x25.c 44409 2012-08-09 23:44:52Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,7 @@
 #include <epan/emem.h>
 #include <epan/nlpid.h>
 #include <epan/x264_prt_id.h>
+#include <epan/lapd_sapi.h>
 
 /*
  * Direction of packet.
@@ -2768,4 +2769,5 @@ proto_reg_handoff_x25(void)
 
     x25_handle = find_dissector("x.25");
     dissector_add_uint("llc.dsap", SAP_X25, x25_handle);
+    dissector_add_uint("lapd.sapi", LAPD_SAPI_X25, x25_handle);
 }
