@@ -1,7 +1,7 @@
 /* packet-ypserv.c
  * Routines for ypserv dissection
  *
- * $Id: packet-ypserv.c 28770 2009-06-18 21:30:42Z stig $
+ * $Id: packet-ypserv.c 39328 2011-10-10 00:39:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -337,7 +337,7 @@ dissect_xfr_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *
 
 	if(tree){
 		sub_item = proto_tree_add_item(tree, hf_ypserv_map_parms, tvb,
-				offset, -1, FALSE);
+				offset, -1, ENC_NA);
 		if(sub_item)
 			sub_tree = proto_item_add_subtree(sub_item, ett_ypserv_map_parms);
 	}
@@ -350,7 +350,7 @@ dissect_xfr_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *
 
 	offset = dissect_rpc_string(tvb, sub_tree, hf_ypserv_peer, offset, NULL);
 
-	proto_tree_add_item(tree, hf_ypserv_transid, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_ypserv_transid, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset += 4;
 
 	offset = dissect_rpc_uint32(tvb, tree, hf_ypserv_prog, offset);
@@ -383,7 +383,7 @@ dissect_xfr_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree
 {
 	proto_item_append_text(tree, " XFR reply");
 
-	proto_tree_add_item(tree, hf_ypserv_transid, tvb, offset, 4, FALSE);
+	proto_tree_add_item(tree, hf_ypserv_transid, tvb, offset, 4, ENC_BIG_ENDIAN);
 	offset += 4;
 
 	offset = dissect_rpc_uint32(tvb, tree, hf_ypserv_xfrstat, offset);
