@@ -3,7 +3,7 @@
  * By Owen Kirby <osk@exegin.com>
  * Copyright 2009 Exegin Technologies Limited
  *
- * $Id: packet-zbee-zdp.h 28439 2009-05-21 20:03:03Z wmeier $
+ * $Id: packet-zbee-zdp.h 31657 2010-01-25 13:20:53Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -280,7 +280,7 @@ extern const gchar  *zdp_status_name    (guint8 status);
 extern void     zdp_dump_excess         (tvbuff_t *tvb, guint offset, packet_info *pinfo, proto_tree *tree);
 extern guint    zbee_parse_uint         (proto_tree *tree, int hfindex, tvbuff_t *tvb, guint *offset, guint length, proto_item **ti);
 extern guint64  zbee_parse_eui64        (proto_tree *tree, int hfindex, tvbuff_t *tvb, guint *offset, guint length, proto_item **ti);
-extern void     zbee_append_info        (proto_item *item, packet_info *pinfo, const gchar *format, ...) GNUC_FORMAT_CHECK(printf, 3, 4);
+extern void     zbee_append_info        (proto_item *item, packet_info *pinfo, const gchar *format, ...) G_GNUC_PRINTF(3, 4);
 
 extern void     zdp_parse_node_desc     (proto_tree *tree, gint ettindex, tvbuff_t *tvb, guint *offset, packet_info *pinfo);
 extern void     zdp_parse_power_desc    (proto_tree *tree, gint ettindex, tvbuff_t *tvb, guint *offset);
