@@ -3,7 +3,7 @@
  *
  * Jochen Friedrich <jochen@scram.de>
  *
- * $Id: packet-zebra.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-zebra.c 40237 2011-12-17 14:26:57Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -156,7 +156,7 @@ static const value_string families[] = {
 
 #define PSIZE(a) (((a) + 7) / (8))
 
-static void
+static int
 dissect_zebra_request(proto_tree *tree, gboolean request, tvbuff_t *tvb,
 	int offset, guint16 len, guint8 command)
 {
@@ -427,6 +427,7 @@ dissect_zebra_request(proto_tree *tree, gboolean request, tvbuff_t *tvb,
 			/* Not yet implemeted in ZEBRA */
 			break;
 	}
+return offset;
 }
 
 static void
