@@ -2,7 +2,7 @@
  * Extenal definitions for EAP Extensible Authentication Protocol dissection
  * RFC 2284, RFC 3748
  *
- * $Id: eap.h 31704 2010-01-27 18:16:07Z etxrab $
+ * $Id: eap.h 41955 2012-04-05 12:33:25Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,6 @@
 #define EAP_INITIATE    5 /* [RFC5296] */
 #define EAP_FINISH      6 /* [RFC5296] */
 
-
 WS_VAR_IMPORT const value_string eap_code_vals[];
 
 #define EAP_TYPE_ID     1
@@ -54,4 +53,30 @@ WS_VAR_IMPORT const value_string eap_code_vals[];
 
 WS_VAR_IMPORT const value_string eap_type_vals[];
 
+#define SIM_START 10
+#define SIM_CHALLENGE 11
+#define SIM_NOTIFICATION 12
+#define SIM_RE_AUTHENTICATION 13
+#define SIM_CLIENT_ERROR 14
+
+WS_VAR_IMPORT const value_string eap_sim_subtype_vals[];
+
+#define AKA_CHALLENGE 1
+#define AKA_AUTHENTICATION_REJECT 2
+#define AKA_SYNCHRONIZATION_FAILURE 4
+#define AKA_IDENTITY 5
+#define AKA_NOTIFICATION 12
+#define AKA_REAUTHENTICATION 13
+#define AKA_CLIENT_ERROR 14
+
+WS_VAR_IMPORT const value_string eap_aka_subtype_vals[];
+
+#define MS_CHAP_V2_CHALLENGE 1
+#define MS_CHAP_V2_RESPONSE 2
+#define MS_CHAP_V2_SUCCESS 3
+#define MS_CHAP_V2_FAILURE 4
+#define MS_CHAP_V2_CHANGE_PASSWORD 7
+
+WS_VAR_IMPORT const value_string eap_ms_chap_v2_opcode_vals[];
+
 #endif
