@@ -2,7 +2,7 @@
  * Wireshark memory management and garbage collection functions
  * Ronnie Sahlberg 2005
  *
- * $Id: emem.c 41656 2012-03-19 02:00:42Z morriss $
+ * $Id: emem.c 42431 2012-05-04 21:56:32Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -753,13 +753,14 @@ emem_alloc_chunk(size_t size, emem_header_t *mem)
 
 	/* Allocate room for at least 8 bytes of canary plus some padding
 	 * so the canary ends on an 8-byte boundary.
-	 * Then add the room needed for the pointer to the next canary.
+	 * But first add the room needed for the pointer to the next canary
+	 * (so the entire allocation will end on an 8-byte boundary).
 	 */
 	 if (use_canary) {
-		pad = emem_canary_pad(asize);
 		asize += sizeof(void *);
+		pad = emem_canary_pad(asize);
 	} else
-		pad = (G_MEM_ALIGN - (asize & (G_MEM_ALIGN-1))) & (G_MEM_ALIGN-1);
+		pad = (WS_MEM_ALIGN - (asize & (WS_MEM_ALIGN-1))) & (WS_MEM_ALIGN-1);
 
 	asize += pad;
 
