@@ -2,7 +2,7 @@
  * Definitions for Wireshark memory management and garbage collection
  * Ronnie Sahlberg 2005
  *
- * $Id: emem.h 39957 2011-11-20 12:43:04Z etxrab $
+ * $Id: emem.h 42431 2012-05-04 21:56:32Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -166,9 +166,21 @@ void se_free_all(void);
  **************************************************************/
 struct _emem_chunk_t;
 
+/* G_MEM_ALIGN is not always enough: http://mail.gnome.org/archives/gtk-devel-list/2004-December/msg00091.html
+ * So, we check (in configure) if we need 8-byte alignment.  (Windows
+ * shouldn't need such a check until someone trys running it 32-bit on a CPU
+ * with more stringent alignment requirements than i386.)
+ *
+ * Yes, this ignores the possibility of needing 16-byte alignment for long doubles.
+ */
+#if defined(NEED_8_BYTE_ALIGNMENT) && (G_MEM_ALIGN < 8)
+#define WS_MEM_ALIGN 8
+#else
+#define WS_MEM_ALIGN G_MEM_ALIGN
+#endif
+
 /* Macros to initialize ws_memory_slab */
-/* XXX, is G_MEM_ALIGN enough? http://mail.gnome.org/archives/gtk-devel-list/2004-December/msg00091.html */
-#define WS_MEMORY_SLAB_INIT(type, count) { ((sizeof(type) + (G_MEM_ALIGN - 1)) & ~(G_MEM_ALIGN - 1)), count, NULL, NULL }
+#define WS_MEMORY_SLAB_INIT(type, count) { ((sizeof(type) + (WS_MEM_ALIGN - 1)) & ~(WS_MEM_ALIGN - 1)), count, NULL, NULL }
 #define WS_MEMORY_SLAB_INIT_UNALIGNED(size, count) { size, count, NULL, NULL }
 
 struct ws_memory_slab {
