@@ -1,7 +1,7 @@
 /* etypes.h
  * Defines ethernet packet types, similar to tcpdump's ethertype.h
  *
- * $Id: etypes.h 39692 2011-10-31 18:37:58Z alagoutte $
+ * $Id: etypes.h 43932 2012-07-23 16:16:03Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -406,6 +406,10 @@
 #endif						/* Specification (IOS) for cdma2000 Access Network Interfaces (document numbers A.S0011-B */
 						/* through A.S0017-B v1.0). This document already uses the Ether type 8881 */
 
+#ifndef ETHERTYPE_CESOETH
+#define ETHERTYPE_CESOETH		0x88D8  /* Circuit Emulation Services over Ethernet (MEF 8) */
+#endif
+
 #ifndef ETHERTYPE_LLTD
 #define ETHERTYPE_LLTD			0x88D9  /* Link Layer Topology Discovery (LLTD) */
 #endif
@@ -430,6 +434,10 @@
 #define ETHERTYPE_IEEE_802_1AH  	0x88E7  /* IEEE 802.1ah Provider Backbone Bridge Mac-in-Mac */
 #endif
 
+#ifndef ETHERTYPE_ELMI
+#define ETHERTYPE_ELMI			0x88EE  /* Ethernet Local Management Interface (E-LMI) (MEF16) */
+#endif
+
 #ifndef ETHERTYPE_MVRP
 #define ETHERTYPE_MVRP			0x88F5  /* IEEE 802.1ak Multiple VLAN Registration Protocol */
 #endif
