@@ -3,7 +3,7 @@
  *
  * For further info, see: http://wiki.wireshark.org/Development/ExpertInfo
  *
- * $Id: expert.h 37391 2011-05-25 11:05:23Z etxrab $
+ * $Id: expert.h 40204 2011-12-14 21:13:06Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,6 +47,11 @@ typedef struct expert_info_s {
 WS_VAR_IMPORT const value_string expert_severity_vals[];
 WS_VAR_IMPORT const value_string expert_group_vals[];
 
+/* "proto_expert" is exported from libwireshark.dll.
+ * Thus we need a special declaration.
+ */
+WS_VAR_IMPORT int proto_expert;
+
 extern void
 expert_init(void);
 
