@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c 39949 2011-11-19 20:18:01Z guy $
+ * $Id: filesystem.c 43286 2012-06-16 19:00:58Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -305,7 +305,7 @@ init_progfile_dir(const char *arg0
          * Oh, well.  Return an indication of the error.
          */
         error = GetLastError();
-        if (FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER|FORMAT_MESSAGE_FROM_SYSTEM,
+        if (FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER|FORMAT_MESSAGE_FROM_SYSTEM|FORMAT_MESSAGE_IGNORE_INSERTS,
             NULL, error, 0, (LPTSTR) &msg_w, 0, NULL) == 0) {
             /*
              * Gak.  We can't format the message.
