@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-double.c 40306 2011-12-27 20:35:41Z gerald $
+ * $Id: ftype-double.c 43282 2012-06-16 17:54:07Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -55,7 +55,7 @@ val_from_unparsed(fvalue_t *fv, char *s, gboolean allow_partial_value _U_, LogFu
 {
 	char    *endptr = NULL;
 
-	fv->value.floating = strtod(s, &endptr);
+	fv->value.floating = g_ascii_strtod(s, &endptr);
 
 	if (endptr == s || *endptr != '\0') {
 		/* This isn't a valid number. */
