@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-guid.c 28117 2009-04-22 03:07:37Z guy $
+ * $Id: ftype-guid.c 32765 2010-05-11 21:46:17Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -130,7 +130,7 @@ ftype_register_guid(void)
 
     static ftype_t guid_type = {
         FT_GUID,              /* ftype */
-        "GUID",              /* name */
+        "FT_GUID",           /* name */
         "Globally Unique Identifier",            /* pretty_name */
         GUID_LEN,            /* wire_size */
         NULL,                /* new_value */
