@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-integer.c 40306 2011-12-27 20:35:41Z gerald $
+ * $Id: ftype-integer.c 43001 2012-06-02 15:32:54Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -636,7 +636,7 @@ eui64_repr_len(fvalue_t *fv _U_, ftrepr_t rtype _U_)
 static void
 eui64_to_repr(fvalue_t *fv, ftrepr_t rtype _U_, char *buf)
 {
-  	guint8 *p_eui64 = ep_alloc(8);
+  	guint8 *p_eui64 = (guint8 *)ep_alloc(8);
 
   	/* Copy and convert the address to network byte order. */
   	*(guint64 *)(void *)(p_eui64) = pntoh64(&(fv->value.integer64));
