@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-none.c 20472 2007-01-18 11:02:26Z martinm $
+ * $Id: ftype-none.c 40306 2011-12-27 20:35:41Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,7 @@ ftype_register_none(void)
 	static ftype_t none_type = {
 		FT_NONE,			/* ftype */
 		"FT_NONE",			/* name */
-		"label",			/* pretty_name */
+		"Label",			/* pretty_name */
 		0,				/* wire_size */
 		NULL,				/* new_value */
 		NULL,				/* free_value */
