@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-pcre.c 40867 2012-02-05 13:30:27Z etxrab $
+ * $Id: ftype-pcre.c 43001 2012-06-02 15:32:54Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -145,7 +145,7 @@ gregex_fvalue_set(fvalue_t *fv, gpointer value, gboolean already_copied)
     /* Free up the old value, if we have one */
     gregex_fvalue_free(fv);
     g_assert(! already_copied);
-    val_from_unparsed(fv, value, FALSE, NULL);
+    val_from_unparsed(fv, (char *)value, FALSE, NULL);
 }
 
 static gpointer
