@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-time.c 38233 2011-07-28 05:49:47Z etxrab $
+ * $Id: ftype-time.c 40306 2011-12-27 20:35:41Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -365,7 +365,7 @@ ftype_register_time(void)
 	static ftype_t abstime_type = {
 		FT_ABSOLUTE_TIME,		/* ftype */
 		"FT_ABSOLUTE_TIME",		/* name */
-		"date/time",			/* pretty_name */
+		"Date and time",		/* pretty_name */
 		0,				/* wire_size */
 		time_fvalue_new,		/* new_value */
 		NULL,				/* free_value */
@@ -402,7 +402,7 @@ ftype_register_time(void)
 	static ftype_t reltime_type = {
 		FT_RELATIVE_TIME,		/* ftype */
 		"FT_RELATIVE_TIME",		/* name */
-		"time offset",			/* pretty_name */
+		"Time offset",			/* pretty_name */
 		0,				/* wire_size */
 		time_fvalue_new,		/* new_value */
 		NULL,				/* free_value */
