@@ -1,5 +1,5 @@
 /*
- * $Id: ftypes-int.h 31302 2009-12-18 01:15:08Z gerald $
+ * $Id: ftypes-int.h 38916 2011-09-07 11:03:47Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,21 +26,6 @@
 #include <epan/packet.h>
 #include "ftypes.h"
 
-#ifdef HAVE_LIBPCRE
-#include <pcre.h>
-#endif /* HAVE_LIBPCRE */
-
-
-#ifdef HAVE_LIBPCRE
-struct _pcre_tuple_t {
-    char *string;
-    pcre *re;
-    pcre_extra *ex;
-    char *error;
-};
-#elif GLIB_CHECK_VERSION(2,14,0) /* No HAVE_LIBPCRE. Try falling back to GRegex. */
-
-#endif /* HAVE_LIBPCRE */
 
 void
 ftype_register(enum ftenum ftype, ftype_t *ft);
@@ -53,6 +38,7 @@ void ftype_register_bytes(void);
 void ftype_register_double(void);
 void ftype_register_integers(void);
 void ftype_register_ipv4(void);
+void ftype_register_ipv6(void);
 void ftype_register_guid(void);
 void ftype_register_none(void);
 void ftype_register_string(void);
