@@ -1,7 +1,7 @@
 /* ftypes.h
  * Definitions for field types
  *
- * $Id: ftypes.h 37030 2011-05-09 12:52:55Z darkjames $
+ * $Id: ftypes.h 38916 2011-09-07 11:03:47Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,7 +50,6 @@ enum ftenum {
 	FT_RELATIVE_TIME,
 	FT_STRING,
 	FT_STRINGZ,	/* for use with proto_tree_add_item() */
-	FT_EBCDIC,	/* for use with proto_tree_add_item() */
 	FT_UINT_STRING,	/* for use with proto_tree_add_item() */
 	/*FT_UCS2_LE, */    /* Unicode, 2 byte, Little Endian     */
 	FT_ETHER,
@@ -63,7 +62,7 @@ enum ftenum {
 	FT_PCRE,	/* a compiled Perl-Compatible Regular Expression object */
 	FT_GUID,	/* GUID, UUID */
 	FT_OID,		/* OBJECT IDENTIFIER */
-	FT_EUI64,	
+	FT_EUI64,
 	FT_NUM_TYPES /* last item number plus one */
 };
 
@@ -91,10 +90,6 @@ enum ftrepr {
 
 typedef enum ftrepr ftrepr_t;
 
-#ifdef HAVE_LIBPCRE
-typedef struct _pcre_tuple_t pcre_tuple_t;
-#endif /* HAVE_LIBPCRE */
-
 /* Initialize the ftypes subsytem. Called once. */
 void
 ftypes_initialize(void);
@@ -148,6 +143,7 @@ ftype_can_matches(enum ftenum ftype);
 /* ---------------- FVALUE ----------------- */
 
 #include <epan/ipv4.h>
+#include <epan/ipv6-utils.h>
 #include <epan/guid-utils.h>
 
 #include <epan/tvbuff.h>
@@ -166,14 +162,11 @@ typedef struct _fvalue_t {
 		guchar		*ustring;
 		GByteArray	*bytes;
 		ipv4_addr	ipv4;
+		ipv6_addr	ipv6;
 		e_guid_t	guid;
 		nstime_t	time;
 		tvbuff_t	*tvb;
-#ifdef HAVE_LIBPCRE
-		pcre_tuple_t	*re;
-#elif GLIB_CHECK_VERSION(2,14,0) /* Try falling back to GRegex. */
 		GRegex	        *re;
-#endif /* HAVE_LIBPCRE */
 	} value;
 
 	/* The following is provided for private use
