@@ -3,7 +3,7 @@
  * pointers/lengths giving the pieces to be checksummed.  Also using
  * Tahoe/CGI version of ADDCARRY(x) macro instead of from portable version.
  *
- * $Id: in_cksum.c 36796 2011-04-22 04:04:20Z guy $
+ * $Id: in_cksum.c 37677 2011-06-16 03:56:08Z guy $
  */
 
 /*
@@ -75,7 +75,7 @@ in_cksum(const vec_t *vec, int veclen)
 	for (; veclen != 0; vec++, veclen--) {
 		if (vec->len == 0)
 			continue;
-		w = (const guint16 *)(void *)vec->ptr;
+		w = (const guint16 *)(const void *)vec->ptr;
 		if (mlen == -1) {
 			/*
 			 * The first byte of this chunk is the continuation
@@ -87,7 +87,7 @@ in_cksum(const vec_t *vec, int veclen)
 			 */
 			s_util.c[1] = *(const guint8 *)w;
 			sum += s_util.s;
-			w = (const guint16 *)(void *)((const guint8 *)w + 1);
+			w = (const guint16 *)(const void *)((const guint8 *)w + 1);
 			mlen = vec->len - 1;
 		} else
 			mlen = vec->len;
@@ -98,7 +98,7 @@ in_cksum(const vec_t *vec, int veclen)
 			REDUCE;
 			sum <<= 8;
 			s_util.c[0] = *(const guint8 *)w;
-			w = (const guint16 *)(void *)((const guint8 *)w + 1);
+			w = (const guint16 *)(const void *)((const guint8 *)w + 1);
 			mlen--;
 			byte_swapped = 1;
 		}
