@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2005 MX Telecom Ltd. <richardv@mxtelecom.com>
  *
- * $Id: nstime.c 34660 2010-10-27 07:44:26Z stig $
+ * $Id: nstime.c 39082 2011-09-21 18:55:03Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,18 +36,18 @@
 /* set the given nstime_t to zero */
 void nstime_set_zero(nstime_t *nstime)
 {
-	nstime->secs  = 0;
-	nstime->nsecs = 0;
+    nstime->secs  = 0;
+    nstime->nsecs = 0;
 }
 
 /* is the given nstime_t currently zero? */
 gboolean nstime_is_zero(nstime_t *nstime)
 {
-	if(nstime->secs == 0 && nstime->nsecs == 0) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
+    if(nstime->secs == 0 && nstime->nsecs == 0) {
+        return TRUE;
+    } else {
+        return FALSE;
+    }
 }
 
 /* set the given nstime_t to (0,maxint) to mark it as "unset"
@@ -56,21 +56,31 @@ gboolean nstime_is_zero(nstime_t *nstime)
  */
 void nstime_set_unset(nstime_t *nstime)
 {
-	nstime->secs  = 0;
-	nstime->nsecs = G_MAXINT;
+    nstime->secs  = 0;
+    nstime->nsecs = G_MAXINT;
 }
 
 /* is the given nstime_t currently (0,maxint)? */
 gboolean nstime_is_unset(nstime_t *nstime)
 {
-	if(nstime->secs == 0 && nstime->nsecs == G_MAXINT) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
+    if(nstime->secs == 0 && nstime->nsecs == G_MAXINT) {
+        return TRUE;
+    } else {
+        return FALSE;
+    }
 }
 
 
+/** funcion: nstime_copy
+ *
+ * a = b
+ */
+void nstime_copy(nstime_t *a, const nstime_t *b)
+{
+    a->secs = b->secs;
+    a->nsecs = b->nsecs;
+}
+
 /*
  * function: nstime_delta
  * delta = b - a
@@ -130,24 +140,6 @@ void nstime_sum(nstime_t *sum, const nstime_t *a, const nstime_t *b)
     }
 }
 
-/*
- * function: nstime_diff
- * diff = a - b
- */
-
-void nstime_diff(nstime_t *diff, const nstime_t *a, const nstime_t *b)
-{
-    diff->secs = a->secs - b->secs;
-    diff->nsecs = a->nsecs - b->nsecs;
-    if(diff->nsecs>=NS_PER_S || (diff->nsecs>0 && diff->secs<0)){
-        diff->nsecs-=NS_PER_S;
-        diff->secs++;
-    } else if(diff->nsecs<=-NS_PER_S || (diff->nsecs<0 && diff->secs>0)) {
-        diff->nsecs+=NS_PER_S;
-        diff->secs--;
-    }
-}
-
 /*
  * function: nstime_cmp
  *
@@ -204,7 +196,7 @@ double wtap_nstime_to_sec(const struct wtap_nstime *nstime)
  * indent-tabs-mode: nil
  * End:
  *
- * ex: set shiftwidth=4 tabstop=8 expandtab
+ * ex: set shiftwidth=4 tabstop=8 expandtab:
  * :indentSize=4:tabSize=8:noTabs=true:
  */
 
