@@ -3,7 +3,7 @@
  *
  * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: oids.c 37398 2011-05-25 21:19:56Z gerald $
+ * $Id: oids.c 39081 2011-09-21 17:49:11Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -230,7 +230,7 @@ static uat_t* smi_modules_uat = NULL;
 
 static GString* smi_errors;
 
-UAT_CSTRING_CB_DEF(smi_mod,name,smi_module_t)
+UAT_DIRECTORYNAME_CB_DEF(smi_mod,name,smi_module_t)
 
 static void smi_error_handler(char *path, int line, int severity, char *msg, char *tag) {
 		g_string_append_printf(smi_errors,"%s:%d %d %s %s\n",
@@ -284,7 +284,7 @@ static const oid_value_type_t* get_typedata(SmiType* smiType) {
 	 * SNMP Types and our FT_s
 	 */
 	static const struct _type_mapping_t {
-		char* name;
+		const char* name;
 		SmiBasetype base;
 		const oid_value_type_t* type;
 	} types[] =  {
@@ -507,7 +507,7 @@ static void restart_needed_warning(void) {
 		report_failure("Wireshark needs to be restarted for these changes to take effect");
 }
 
-static void register_mibs() {
+static void register_mibs(void) {
 	SmiModule *smiModule;
 	SmiNode *smiNode;
 	guint i;
@@ -519,7 +519,7 @@ static void register_mibs() {
 		UAT_END_FIELDS
 	};
 	static uat_field_t smi_paths_fields[] = {
-		UAT_FLD_PATHNAME(smi_mod,name,"Directory path","The directory name"),
+		UAT_FLD_DIRECTORYNAME(smi_mod,name,"Directory path","The directory name"),
 		UAT_END_FIELDS
 	};
 	char* smi_load_error = NULL;
@@ -1230,7 +1230,7 @@ void add_oid_debug_subtree(oid_info_t* oid_info, proto_tree *tree) {
  * indent-tabs-mode: t
  * End:
  *
- * ex: set shiftwidth=8 tabstop=8 noexpandtab
+ * ex: set shiftwidth=8 tabstop=8 noexpandtab:
  * :indentSize=8:tabSize=8:noTabs=false:
  */
 
