@@ -1,7 +1,7 @@
 /* oids.h
  * Object IDentifier Support
  *
- * $Id: oids.h 32096 2010-03-03 17:19:30Z rbalint $
+ * $Id: oids.h 33990 2010-08-29 10:47:38Z etxrab $
  *
  * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
@@ -28,7 +28,9 @@
 #define __OIDS_H__
 
 #include <epan/ftypes/ftypes.h>
-
+/**
+ *@file
+ */
 #define BER_TAG_ANY -1
 
 struct _oid_bit_t {
@@ -94,7 +96,7 @@ typedef struct _oid_info_t {
 	guint32 subid;
 	char* name;
 	oid_kind_t kind;
-	void* children; /* an emem_tree_t* */
+	void* children; /**< an emem_tree_t* */
 	const oid_value_type_t* value_type;
 	int value_hfid;
 	oid_key_t* key;
@@ -102,10 +104,10 @@ typedef struct _oid_info_t {
 	struct _oid_info_t* parent;
 } oid_info_t;
 
-/* init funcion called from epan.h */
+/** init funcion called from epan.h */
 extern void oids_init(void);
 
-/* init funcion called from epan.h */
+/** init funcion called from epan.h */
 extern void oids_cleanup(void);
 
 /*
