@@ -1,7 +1,7 @@
 /* plugins.h
  * definitions for plugins structures
  *
- * $Id: plugins.h 35163 2010-12-09 15:20:14Z rbalint $
+ * $Id: plugins.h 37512 2011-06-01 21:48:17Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,10 +54,12 @@ extern void register_all_plugin_handoffs(void);
 extern void register_all_plugin_tap_listeners(void);
 extern void register_all_wiretap_modules(void);
 extern void register_all_codecs(void);
+extern void plugins_dump_all(void);
 
 typedef struct _wslua_plugin {
     gchar       *name;            /**< plugin name */
     gchar       *version;         /**< plugin version */
+    gchar       *filename;        /**< plugin filename */
     struct _wslua_plugin *next;
 } wslua_plugin;
 
