@@ -1,7 +1,7 @@
 /* reassemble.c
  * Routines for {fragment,segment} reassembly
  *
- * $Id: reassemble.c 39089 2011-09-22 15:57:41Z wmeier $
+ * $Id: reassemble.c 41216 2012-02-28 03:19:49Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -194,19 +194,16 @@ reassembled_hash(gconstpointer k)
 
 /*
  * For a fragment hash table entry, free the associated fragments.
- * If slices are used (GLIB >= 2.10) the entry value (fd_chain) is
- * freed herein and the entry is freed when fragment_free_key()
- * [or dcerpc_fragment_free_key()] is called (as a consequence of
- * returning TRUE from this function).
- * If mem_chunks are used, free the address data to which the key
- * refers.
+ * The entry value (fd_chain) is freed herein and the entry is freed
+ * when fragment_free_key() [or dcerpc_fragment_free_key()] is called
+ * (as a consequence of returning TRUE from this function).
  */
 static gboolean
 free_all_fragments(gpointer key_arg _U_, gpointer value, gpointer user_data _U_)
 {
 	fragment_data *fd_head, *tmp_fd;
 
-	/* If Glib version => 2.10 we do g_hash_table_new_full() and supply a function
+	/* g_hash_table_new_full() was used to supply a function
 	 * to free the key and the addresses.
 	 */
 	for (fd_head = value; fd_head != NULL; fd_head = tmp_fd) {
@@ -408,18 +405,10 @@ fragment_delete(const packet_info *pinfo, const guint32 id, GHashTable *fragment
 
 		if( !(fd->flags&FD_NOT_MALLOCED) )
 			g_free(fd->data);
-#if GLIB_CHECK_VERSION(2,10,0)
 		g_slice_free(fragment_data, fd);
-#else
-		g_mem_chunk_free(fragment_data_chunk, fd);
-#endif
 		fd=tmp_fd;
 	}
-#if GLIB_CHECK_VERSION(2,10,0)
 	g_slice_free(fragment_data, fd_head);
-#else
-	g_mem_chunk_free(fragment_data_chunk, fd_head);
-#endif
 	g_hash_table_remove(fragment_table, &key);
 
 	return data;
@@ -586,16 +575,6 @@ fragment_unhash(GHashTable *fragment_table, fragment_key *key)
 	/*
 	 * Free the key itself.
 	 */
-#if GLIB_CHECK_VERSION(2,10,0)
-#else
-	/*
-	 * Free up the copies of the addresses from the old key.
-	 */
-	g_free((gpointer)key->src.data);
-	g_free((gpointer)key->dst.data);
-
-	g_mem_chunk_free(fragment_key_chunk, key);
-#endif
 }
 
 /*
@@ -668,11 +647,7 @@ fragment_add_work(fragment_data *fd_head, tvbuff_t *tvb, const int offset,
 	unsigned char *old_data;
 
 	/* create new fd describing this fragment */
-#if GLIB_CHECK_VERSION(2,10,0)
 	fd = g_slice_new(fragment_data);
-#else
-	fd = g_mem_chunk_alloc(fragment_data_chunk);
-#endif
 	fd->next = NULL;
 	fd->flags = 0;
 	fd->frame = pinfo->fd->num;
@@ -976,11 +951,7 @@ fragment_add_common(tvbuff_t *tvb, const int offset, const packet_info *pinfo, c
 		 * addresses, allocating new buffers for the address
 		 * data.
 		 */
-#if GLIB_CHECK_VERSION(2,10,0)
 		new_key = g_slice_new(fragment_key);
-#else
-		new_key = g_mem_chunk_alloc(fragment_key_chunk);
-#endif
 		COPY_ADDRESS(&new_key->src, &key.src);
 		COPY_ADDRESS(&new_key->dst, &key.dst);
 		new_key->id = key.id;
@@ -1067,11 +1038,7 @@ fragment_add_check(tvbuff_t *tvb, const int offset, const packet_info *pinfo,
 		 * addresses, allocating new buffers for the address
 		 * data.
 		 */
-#if GLIB_CHECK_VERSION(2,10,0)
 		new_key = g_slice_new(fragment_key);
-#else
-		new_key = g_mem_chunk_alloc(fragment_key_chunk);
-#endif
 		COPY_ADDRESS(&new_key->src, &key.src);
 		COPY_ADDRESS(&new_key->dst, &key.dst);
 		new_key->id = key.id;
@@ -1233,11 +1200,7 @@ fragment_add_seq_work(fragment_data *fd_head, tvbuff_t *tvb, const int offset,
 
 
 	/* create new fd describing this fragment */
-#if GLIB_CHECK_VERSION(2,10,0)
 	fd = g_slice_new(fragment_data);
-#else
-	fd = g_mem_chunk_alloc(fragment_data_chunk);
-#endif
 	fd->next = NULL;
 	fd->flags = 0;
 	fd->frame = pinfo->fd->num;
@@ -1753,12 +1716,7 @@ fragment_start_seq_check(const packet_info *pinfo, const guint32 id, GHashTable
 
 	if (fd_head == NULL) {
 		/* Create list-head. */
-#if GLIB_CHECK_VERSION(2,10,0)
 		fd_head = g_slice_new(fragment_data);
-#else
-		fd_head = g_mem_chunk_alloc(fragment_data_chunk);
-#endif
-
 		fd_head->next = NULL;
 		fd_head->datalen = tot_len;
 		fd_head->offset = 0;
@@ -1940,7 +1898,8 @@ process_reassembled_data(tvbuff_t *tvb, const int offset, packet_info *pinfo,
  */
 static void
 show_fragment(fragment_data *fd, const int offset, const fragment_items *fit,
-	proto_tree *ft, proto_item *fi, const gboolean first_frag, const guint32 count, tvbuff_t *tvb)
+	proto_tree *ft, proto_item *fi, const gboolean first_frag,
+	const guint32 count, tvbuff_t *tvb, packet_info *pinfo)
 {
 	proto_item *fei=NULL;
 	int hf;
@@ -1984,6 +1943,7 @@ show_fragment(fragment_data *fd, const int offset, const fragment_items *fit,
 			plurality(fd->len, "", "s"));
 	}
 	PROTO_ITEM_SET_GENERATED(fei);
+	mark_frame_as_depended_upon(pinfo, fd->frame);
 	if (fd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT
 		|FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
 		/* this fragment has some flags set, create a subtree
@@ -2065,7 +2025,7 @@ show_fragment_tree(fragment_data *fd_head, const fragment_items *fit,
 		count++;
 	}
 	for (fd = fd_head->next; fd != NULL; fd = fd->next) {
-		show_fragment(fd, fd->offset, fit, ft, *fi, first_frag, count, tvb);
+		show_fragment(fd, fd->offset, fit, ft, *fi, first_frag, count, tvb, pinfo);
 		first_frag = FALSE;
 	}
 
@@ -2119,7 +2079,7 @@ show_fragment_seq_tree(fragment_data *fd_head, const fragment_items *fit,
 			next_offset += fd->len;
 		}
 		last_fd = fd;
-		show_fragment(fd, offset, fit, ft, *fi, first_frag, count, tvb);
+		show_fragment(fd, offset, fit, ft, *fi, first_frag, count, tvb, pinfo);
 		first_frag = FALSE;
 	}
 
