@@ -1,7 +1,7 @@
 /* reassemble.h
  * Declarations of outines for {fragment,segment} reassembly
  *
- * $Id: reassemble.h 37978 2011-07-11 20:32:19Z gerald $
+ * $Id: reassemble.h 40595 2012-01-19 22:55:37Z rbalint $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,9 @@
  * the flags field of fd_head !!!
  */
 
+#ifndef REASSEMBLE_H
+#define REASSEMBLE_H
+
 /* only in fd_head: packet is defragmented */
 #define FD_DEFRAGMENTED		0x0001
 
@@ -314,3 +317,5 @@ show_fragment_tree(fragment_data *ipfd_head, const fragment_items *fit,
 extern gboolean
 show_fragment_seq_tree(fragment_data *ipfd_head, const fragment_items *fit,
     proto_tree *tree, packet_info *pinfo, tvbuff_t *tvb, proto_item **fi);
+
+#endif
