@@ -1,7 +1,7 @@
 /* sctpppids.h
  * Declarations of SCTP payload protocol IDs.
  *
- * $Id: sctpppids.h 41556 2012-03-15 08:23:26Z tuexen $
+ * $Id: sctpppids.h 44506 2012-08-14 21:39:49Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -76,5 +76,8 @@
 #define PROTO_3GPP_M2AP_PROTOCOL_ID     43
 #define PROTO_3GPP_M3AP_PROTOCOL_ID     44
 #define SSH_PAYLOAD_PROTOCOL_ID         45
+#define DIAMETER_PROTOCOL_ID            46
+#define DIAMETER_DTLS_PROTOCOL_ID       47
+#define R14P_BER_PROTOCOL_ID            48
 #define M2TP_PAYLOAD_PROTOCOL_ID        99    /* s-link */
 #endif /* sctpppids.h */
