@@ -2,7 +2,7 @@
  * Declarations of routines to register "-z" command-line argument handlers
  * for stats
  *
- * $Id: stat_cmd_args.h 25559 2008-06-23 21:31:10Z guy $
+ * $Id: stat_cmd_args.h 38686 2011-08-23 13:16:44Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,8 +23,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef _STAT_H_
-#define _STAT_H_
+#ifndef __STAT_CMD_ARGS_H__
+#define __STAT_CMD_ARGS_H__
 
 extern void register_stat_cmd_arg(const char *cmd,
     void (*func)(const char *arg,void* userdata), void* userdata);
