@@ -1,7 +1,7 @@
 /* to_str.c
  * Routines for utilities to convert various other types to strings.
  *
- * $Id: to_str.c 41945 2012-04-04 21:54:22Z gerald $
+ * $Id: to_str.c 42458 2012-05-07 04:15:10Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -986,7 +986,7 @@ decode_bitfield_value(char *buf, const guint32 val, const guint32 mask, const in
 }
 
 /* Generate a string describing a Boolean bitfield (a one-bit field that
-   says something is either true of false). */
+   says something is either true or false). */
 const char *
 decode_boolean_bitfield(const guint32 val, const guint32 mask, const int width,
     const char *truedesc, const char *falsedesc)
