@@ -1,7 +1,7 @@
 /* to_str.h
  * Definitions for utilities to convert various other types to strings.
  *
- * $Id: to_str.h 37015 2011-05-08 10:23:53Z alagoutte $
+ * $Id: to_str.h 41945 2012-04-04 21:54:22Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -87,7 +87,7 @@ extern gchar*	rel_time_to_secs_str(const nstime_t*);
 extern gchar*	guid_to_str(const e_guid_t*);
 extern gchar*	guid_to_str_buf(const e_guid_t*, gchar*, int);
 
-extern char *decode_bits_in_field(const gint bit_offset, const gint no_of_bits, const guint64 value);
+extern char *decode_bits_in_field(const guint bit_offset, const gint no_of_bits, const guint64 value);
 
 extern char	*other_decode_bitfield_value(char *buf, const guint32 val, const guint32 mask,
     const int width);
