@@ -9,7 +9,7 @@
  *		the data of a backing tvbuff, or can be a composite of
  *		other tvbuffs.
  *
- * $Id: tvbuff.c 41968 2012-04-06 00:32:26Z gerald $
+ * $Id: tvbuff.c 42638 2012-05-15 21:56:02Z gerald $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -189,10 +189,10 @@ tvb_free_chain(tvbuff_t* tvb)
 {
 	tvbuff_t *next_tvb;
 	DISSECTOR_ASSERT(tvb);
-	DISSECTOR_ASSERT((tvb->previous==NULL) && "tvb_free_chain(): tvb must be initial tvb in chain");
+	DISSECTOR_ASSERT_HINT(tvb->previous==NULL, "tvb_free_chain(): tvb must be initial tvb in chain");
 	while (tvb) {
 		next_tvb=tvb->next;
-		DISSECTOR_ASSERT(((next_tvb==NULL) || (tvb==next_tvb->previous)) && "tvb_free_chain(): corrupt tvb chain ?");
+		DISSECTOR_ASSERT_HINT((next_tvb==NULL) || (tvb==next_tvb->previous), "tvb_free_chain(): corrupt tvb chain ?");
 		tvb_free_internal(tvb);
 		tvb  = next_tvb;
 	}
@@ -319,6 +319,7 @@ tvb_new_octet_aligned(tvbuff_t *tvb, guint32 bit_offset, gint32 no_of_bits)
 		return tvb_new_subset(tvb, byte_offset, datalen, -1);
 	}
 
+	DISSECTOR_ASSERT(datalen>0);
 	buf = ep_alloc0(datalen);
 
 	/* if at least one trailing byte is available, we must use the content
@@ -938,7 +939,7 @@ ensure_contiguous_no_exception(tvbuff_t *tvb, const gint offset, const gint leng
 static const guint8*
 ensure_contiguous(tvbuff_t *tvb, const gint offset, const gint length)
 {
-	int           exception;
+	int           exception = 0;
 	const guint8 *p;
 
 	p = ensure_contiguous_no_exception(tvb, offset, length, &exception);
@@ -2018,8 +2019,8 @@ tvb_strsize(tvbuff_t *tvb, const gint offset)
 	return (nul_offset - abs_offset) + 1;
 }
 
-/* Unicode (UTF-16) version of tvb_strsize */
-/* Returns number of *UTF-16 characters* (not bytes) excluding the null terminator */
+/* UTF-16/UCS-2 version of tvb_strsize */
+/* Returns number of bytes including the (two-bytes) null terminator */
 guint
 tvb_unicode_strsize(tvbuff_t *tvb, const gint offset)
 {
@@ -2034,7 +2035,7 @@ tvb_unicode_strsize(tvbuff_t *tvb, const gint offset)
 		i += 2;
 	} while(uchar != 0);
 
-	return i; /* Number of *UTF-16* characters */
+	return i;
 }
 
 /* Find length of string by looking for end of string ('\0'), up to
@@ -2328,6 +2329,7 @@ tvb_get_string(tvbuff_t *tvb, const gint offset, const gint length)
 
 /*
  * Unicode (UTF-16) version of tvb_get_string()
+ * XXX - this is UCS-2, not UTF-16, as it doesn't handle surrogate pairs
  *
  * Encoding paramter should be ENC_BIG_ENDIAN or ENC_LITTLE_ENDIAN
  *
@@ -2377,9 +2379,9 @@ tvb_get_unicode_string(tvbuff_t *tvb, const gint offset, gint length, const guin
 /*
  * Given a tvbuff, an offset, a length, and an encoding, allocate a
  * buffer big enough to hold a non-null-terminated string of that length
- * at that offset, plus a trailing '\0', copy the string into it, and
- * return a pointer to the string; if the encoding is EBCDIC, map
- * the string from EBCDIC to ASCII.
+ * at that offset, plus a trailing '\0', copy into the buffer the
+ * string as converted from the appropriate encoding to UTF-8, and
+ * return a pointer to the string.
  *
  * Throws an exception if the tvbuff ends before the string does.
  *
@@ -2391,34 +2393,95 @@ tvb_get_unicode_string(tvbuff_t *tvb, const gint offset, gint length, const guin
  */
 guint8 *
 tvb_get_ephemeral_string_enc(tvbuff_t *tvb, const gint offset,
-			     const gint length, const gint encoding)
+			     const gint length, const guint encoding)
 {
 	const guint8 *ptr;
-	guint8       *strbuf = NULL;
+	guint8       *strbuf;
 
-	tvb_ensure_bytes_exist(tvb, offset, length);
+	switch (encoding & ENC_CHARENCODING_MASK) {
 
-	ptr    = ensure_contiguous(tvb, offset, length);
-	strbuf = ep_alloc(length + 1);
-	if (length != 0) {
-		memcpy(strbuf, ptr, length);
+	case ENC_ASCII:
+	default:
+		/*
+		 * For now, we treat bogus values as meaning
+		 * "ASCII" rather than reporting an error,
+		 * for the benefit of old dissectors written
+		 * when the last argument to proto_tree_add_item()
+		 * was a gboolean for the byte order, not an
+		 * encoding value, and passed non-zero values
+		 * other than TRUE to mean "little-endian".
+		 *
+		 * XXX - should map all octets with the 8th bit
+		 * not set to a "substitute" UTF-8 character.
+		 */
+		strbuf = tvb_get_ephemeral_string(tvb, offset, length);
+		break;
+
+	case ENC_UTF_8:
+		/*
+		 * XXX - should map all invalid UTF-8 sequences
+		 * to a "substitute" UTF-8 character.
+		 */
+		strbuf = tvb_get_ephemeral_string(tvb, offset, length);
+		break;
+
+	case ENC_UTF_16:
+		/*
+		 * XXX - needs to handle surrogate pairs and to map
+		 * invalid characters and sequences to a "substitute"
+		 * UTF-8 character.
+		 */
+		strbuf = tvb_get_ephemeral_unicode_string(tvb, offset, length,
+		    encoding & ENC_LITTLE_ENDIAN);
+		break;
+
+	case ENC_UCS_2:
+		/*
+		 * XXX - needs to map values that are not valid UCS-2
+		 * characters (such as, I think, values used as the
+		 * components of a UTF-16 surrogate pair) to a
+		 * "substitute" UTF-8 character.
+		 */
+		strbuf = tvb_get_ephemeral_unicode_string(tvb, offset, length,
+		    encoding & ENC_LITTLE_ENDIAN);
+		break;
+
+	case ENC_EBCDIC:
+		/*
+		 * XXX - do the copy and conversion in one pass.
+		 *
+		 * XXX - multiple "dialects" of EBCDIC?
+		 */
+		tvb_ensure_bytes_exist(tvb, offset, length); /* make sure length = -1 fails */
+		strbuf = ep_alloc(length + 1);
+		if (length != 0) {
+			ptr = ensure_contiguous(tvb, offset, length);
+			memcpy(strbuf, ptr, length);
+			EBCDIC_to_ASCII(strbuf, length);
+		}
+		strbuf[length] = '\0';
+		break;
 	}
-	if ((encoding & ENC_CHARENCODING_MASK) == ENC_EBCDIC)
-		EBCDIC_to_ASCII(strbuf, length);
-	strbuf[length] = '\0';
 	return strbuf;
 }
 
 guint8 *
 tvb_get_ephemeral_string(tvbuff_t *tvb, const gint offset, const gint length)
 {
-	return tvb_get_ephemeral_string_enc(tvb, offset, length, ENC_UTF_8|ENC_NA);
+	guint8       *strbuf;
+
+	tvb_ensure_bytes_exist(tvb, offset, length); /* make sure length = -1 fails */
+	strbuf = ep_alloc(length + 1);
+	tvb_memcpy(tvb, strbuf, offset, length);
+	strbuf[length] = '\0';
+	return strbuf;
 }
 
 /*
  * Unicode (UTF-16) version of tvb_get_ephemeral_string()
+ * XXX - this is UCS-2, not UTF-16, as it doesn't handle surrogate pairs
  *
- * Encoding paramter should be ENC_BIG_ENDIAN or ENC_LITTLE_ENDIAN
+ * Encoding parameter should be ENC_BIG_ENDIAN or ENC_LITTLE_ENDIAN
  *
  * Specify length in bytes
  *
@@ -2502,7 +2565,7 @@ tvb_get_seasonal_string(tvbuff_t *tvb, const gint offset, const gint length)
  * string (including the terminating null) through a pointer.
  */
 guint8 *
-tvb_get_stringz_enc(tvbuff_t *tvb, const gint offset, gint *lengthp, gint encoding)
+tvb_get_stringz_enc(tvbuff_t *tvb, const gint offset, gint *lengthp, const guint encoding)
 {
 	guint   size;
 	guint8 *strptr;
@@ -2564,7 +2627,79 @@ tvb_get_const_stringz(tvbuff_t *tvb, const gint offset, gint *lengthp)
  * after the current packet has been dissected.
  */
 guint8 *
-tvb_get_ephemeral_stringz_enc(tvbuff_t *tvb, const gint offset, gint *lengthp, gint encoding)
+tvb_get_ephemeral_stringz_enc(tvbuff_t *tvb, const gint offset, gint *lengthp, const guint encoding)
+{
+	guint   size;
+	guint8 *strptr;
+
+	switch (encoding & ENC_CHARENCODING_MASK) {
+
+	case ENC_ASCII:
+	default:
+		/*
+		 * For now, we treat bogus values as meaning
+		 * "ASCII" rather than reporting an error,
+		 * for the benefit of old dissectors written
+		 * when the last argument to proto_tree_add_item()
+		 * was a gboolean for the byte order, not an
+		 * encoding value, and passed non-zero values
+		 * other than TRUE to mean "little-endian".
+		 *
+		 * XXX - should map all octets with the 8th bit
+		 * not set to a "substitute" UTF-8 character.
+		 */
+		strptr = tvb_get_ephemeral_stringz(tvb, offset, lengthp);
+		break;
+
+	case ENC_UTF_8:
+		/*
+		 * XXX - should map all invalid UTF-8 sequences
+		 * to a "substitute" UTF-8 character.
+		 */
+		strptr = tvb_get_ephemeral_stringz(tvb, offset, lengthp);
+		break;
+
+	case ENC_UTF_16:
+		/*
+		 * XXX - needs to handle surrogate pairs and to map
+		 * invalid characters and sequences to a "substitute"
+		 * UTF-8 character.
+		 */
+		strptr = tvb_get_ephemeral_unicode_stringz(tvb, offset, lengthp,
+		    encoding & ENC_LITTLE_ENDIAN);
+		break;
+
+	case ENC_UCS_2:
+		/*
+		 * XXX - needs to map values that are not valid UCS-2
+		 * characters (such as, I think, values used as the
+		 * components of a UTF-16 surrogate pair) to a
+		 * "substitute" UTF-8 character.
+		 */
+		strptr = tvb_get_ephemeral_unicode_stringz(tvb, offset, lengthp,
+		    encoding & ENC_LITTLE_ENDIAN);
+		break;
+
+	case ENC_EBCDIC:
+		/*
+		 * XXX - do the copy and conversion in one pass.
+		 *
+		 * XXX - multiple "dialects" of EBCDIC?
+		 */
+		size = tvb_strsize(tvb, offset);
+		strptr = ep_alloc(size);
+		tvb_memcpy(tvb, strptr, offset, size);
+		EBCDIC_to_ASCII(strptr, size);
+		if (lengthp)
+			*lengthp = size;
+		break;
+	}
+
+	return strptr;
+}
+
+guint8 *
+tvb_get_ephemeral_stringz(tvbuff_t *tvb, const gint offset, gint *lengthp)
 {
 	guint   size;
 	guint8 *strptr;
@@ -2572,19 +2707,11 @@ tvb_get_ephemeral_stringz_enc(tvbuff_t *tvb, const gint offset, gint *lengthp, g
 	size   = tvb_strsize(tvb, offset);
 	strptr = ep_alloc(size);
 	tvb_memcpy(tvb, strptr, offset, size);
-	if ((encoding & ENC_CHARENCODING_MASK) == ENC_EBCDIC)
-		EBCDIC_to_ASCII(strptr, size);
 	if (lengthp)
 		*lengthp = size;
 	return strptr;
 }
 
-guint8 *
-tvb_get_ephemeral_stringz(tvbuff_t *tvb, const gint offset, gint *lengthp)
-{
-	return tvb_get_ephemeral_stringz_enc(tvb, offset, lengthp, ENC_UTF_8|ENC_NA);
-}
-
 /*
  * Unicode (UTF-16) version of tvb_get_ephemeral_stringz()
  *
@@ -2834,7 +2961,7 @@ tvb_find_line_end(tvbuff_t *tvb, const gint offset, int len, gint *next_offset,
 	/*
 	 * Look either for a CR or an LF.
 	 */
-	eol_offset = tvb_pbrk_guint8(tvb, offset, len, (const guint8 *)"\r\n", &found_needle);
+	eol_offset = tvb_pbrk_guint8(tvb, offset, len, "\r\n", &found_needle);
 	if (eol_offset == -1) {
 		/*
 		 * No CR or LF - line is presumably continued in next packet.
@@ -2963,8 +3090,7 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, const gint offset, int len, gint *next
 			/*
 			 * Look either for a CR, an LF, or a '"'.
 			 */
-			char_offset = tvb_pbrk_guint8(tvb, cur_offset, len,
-				(const guint8 *)"\r\n\"", &c);
+			char_offset = tvb_pbrk_guint8(tvb, cur_offset, len, "\r\n\"", &c);
 		}
 		if (char_offset == -1) {
 			/*
