@@ -7,7 +7,7 @@
  * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  * (c) 2008, Balint Reczey <balint.reczey@ericsson.com>
  *
- * $Id: wslua.h 39744 2011-11-06 17:39:13Z stig $
+ * $Id: wslua.h 40456 2012-01-13 16:16:41Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -259,7 +259,7 @@ typedef struct _wslua_private_table* PrivateTable;
 C to##C(lua_State* L, int idx) { \
     C* v = (C*)lua_touserdata (L, idx); \
     if (!v) luaL_typerror(L,idx,#C); \
-    return *v; \
+    return v ? *v : NULL; \
 } \
 C check##C(lua_State* L, int idx) { \
     C* p; \
