@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: wslua_field.c 48120 2013-03-06 00:23:42Z gerald $
+ * $Id: wslua_field.c 38616 2011-08-19 08:36:02Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -131,6 +131,13 @@ WSLUA_METAMETHOD FieldInfo__call(lua_State* L) {
 			pushAddress(L,ipx);
 			return 1;
 		}
+		case FT_ABSOLUTE_TIME:
+		case FT_RELATIVE_TIME: {
+			NSTime nstime = g_malloc(sizeof(nstime_t));
+			*nstime = *(NSTime)fvalue_get(&(fi->value));
+			pushNSTime(L,nstime);
+			return 1;
+		}
 		case FT_STRING:
 		case FT_STRINGZ: {
 			gchar* repr = fvalue_to_string_repr(&fi->value,FTREPR_DISPLAY,NULL);
@@ -335,20 +342,6 @@ WSLUA_CLASS_DEFINE(Field,NOP,NOP);
  */
 
 static GPtrArray* wanted_fields = NULL;
-static dfilter_t* wslua_dfilter = NULL;
-
-/* We use a fake dfilter for Lua field extractors, so that 
- * epan_dissect_run() will populate the fields.  This won't happen
- * if the passed-in edt->tree is NULL, which it will be if the 
- * proto_tree isn't created by epan_dissect_init().  But that's by
- * design - if shark doesn't pass in a proto_tree, it's probably for
- * a good reason and we shouldn't override that. (right?)
- */
-void wslua_prime_dfilter(epan_dissect_t *edt) {
-    if (wslua_dfilter && edt && edt->tree) {
-        dfilter_prime_proto_tree(wslua_dfilter, edt->tree);
-    }
-}
 
 /*
  * field extractor registartion is tricky, In order to allow
@@ -400,9 +393,6 @@ void lua_prime_all_fields(proto_tree* tree _U_) {
             report_failure("while registering lua_fake_tap:\n%s",error->str);
             g_string_free(error,TRUE);
         }
-        else if (!dfilter_compile(fake_tap_filter->str, &wslua_dfilter)) {
-            report_failure("while compiling dfilter for wslua: '%s'", fake_tap_filter->str);
-        }
     }
 
 }
