@@ -6,7 +6,7 @@
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  *
- * $Id: wslua_proto.c 41035 2012-02-16 03:00:52Z morriss $
+ * $Id: wslua_proto.c 42845 2012-05-25 01:49:49Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -663,7 +663,7 @@ WSLUA_CONSTRUCTOR ProtoField_new(lua_State* L) { /* Creates a new field to be us
 }
 
 static int ProtoField_integer(lua_State* L, enum ftenum type) {
-    ProtoField f = g_malloc(sizeof(wslua_field_t));
+    ProtoField f;
     const gchar* abbr = luaL_checkstring(L,1);
     const gchar* name = luaL_optstring(L,2,abbr);
     base_display_e base = luaL_optint(L, 3, BASE_DEC);
@@ -694,6 +694,8 @@ static int ProtoField_integer(lua_State* L, enum ftenum type) {
       return 0;
     }
 
+    f = g_new(wslua_field_t,1);
+
     f->hfid = -2;
     f->ett = -1;
     f->name = g_strdup(name);
@@ -826,7 +828,7 @@ PROTOFIELD_INTEGER(int64,FT_INT64)
 PROTOFIELD_INTEGER(framenum,FT_FRAMENUM)
 
 static int ProtoField_boolean(lua_State* L, enum ftenum type) {
-    ProtoField f = g_malloc(sizeof(wslua_field_t));
+    ProtoField f;
     const gchar* abbr = luaL_checkstring(L,1);
     const gchar* name = luaL_optstring(L,2,abbr);
     base_display_e base = luaL_optint(L, 3, BASE_NONE);
@@ -851,6 +853,8 @@ static int ProtoField_boolean(lua_State* L, enum ftenum type) {
       return 0;
     }
 
+    f = g_new(wslua_field_t,1);
+
     f->hfid = -2;
     f->ett = -1;
     f->name = g_strdup(name);
@@ -884,7 +888,7 @@ static int ProtoField_boolean(lua_State* L, enum ftenum type) {
 PROTOFIELD_BOOL(bool,FT_BOOLEAN)
 
 static int ProtoField_time(lua_State* L,enum ftenum type) {
-    ProtoField f = g_malloc(sizeof(wslua_field_t));
+    ProtoField f;
     const gchar* abbr = luaL_checkstring(L,1);
     const gchar* name = luaL_optstring(L,2,abbr);
     absolute_time_display_e base = luaL_optint(L,3,ABSOLUTE_TIME_LOCAL);
@@ -902,6 +906,8 @@ static int ProtoField_time(lua_State* L,enum ftenum type) {
       }
     }
 
+    f = g_new(wslua_field_t,1);
+
     f->hfid = -2;
     f->ett = -1;
     f->name = g_strdup(name);
@@ -939,7 +945,7 @@ static int ProtoField_time(lua_State* L,enum ftenum type) {
 PROTOFIELD_TIME(absolute_time,FT_ABSOLUTE_TIME)
 
 static int ProtoField_other(lua_State* L,enum ftenum type) {
-    ProtoField f = g_malloc(sizeof(wslua_field_t));
+    ProtoField f;
     const gchar* abbr = luaL_checkstring(L,1);
     const gchar* name = luaL_optstring(L,2,abbr);
     const gchar* blob = luaL_optstring(L,3,NULL);
@@ -949,6 +955,8 @@ static int ProtoField_other(lua_State* L,enum ftenum type) {
       return 0;
     }
 
+    f = g_new(wslua_field_t,1);
+
     f->hfid = -2;
     f->ett = -1;
     f->name = g_strdup(name);
@@ -1566,12 +1574,10 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
 
     if(!(name && ui_name)) return 0;
 
-    name = g_strdup(name);
-    ui_name = g_strdup(ui_name);
-
     switch(type) {
         case FT_STRING:
             base = BASE_NONE;
+	    /* fallthrough */
         case FT_UINT8:
         case FT_UINT16:
         case FT_UINT24:
@@ -1579,6 +1585,9 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
         {
             DissectorTable dt = g_malloc(sizeof(struct _wslua_distbl_t));
 
+            name = g_strdup(name);
+            ui_name = g_strdup(ui_name);
+
             dt->table = register_dissector_table(name, ui_name, type, base);
             dt->name = name;
             pushDissectorTable(L, dt);
