@@ -7,7 +7,7 @@
  * (c) 2008, Balint Reczey <balint.reczey@ericsson.com>
  * (c) 2009, Stig Bjorlykke <stig@bjorlykke.org>
  *
- * $Id: wslua_tvb.c 39744 2011-11-06 17:39:13Z stig $
+ * $Id: wslua_tvb.c 43115 2012-06-05 15:26:09Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1017,11 +1017,11 @@ WSLUA_METHOD TvbRange_ether(lua_State* L) {
         return 0;
     }
 
-    addr = g_malloc(sizeof(address));
-
     if (tvbr->len != 6)
         WSLUA_ERROR(TvbRange_ether,"The range must be 6 bytes long");
 
+    addr = g_new(address,1);
+
     buff = tvb_memdup(tvbr->tvb->ws_tvb,tvbr->offset,tvbr->len);
 
     SET_ADDRESS(addr, AT_ETHER, 6, buff);
@@ -1033,7 +1033,7 @@ WSLUA_METHOD TvbRange_ether(lua_State* L) {
 WSLUA_METHOD TvbRange_nstime(lua_State* L) {
 	/* Obtain a nstime from a TvbRange */
     TvbRange tvbr = checkTvbRange(L,1);
-    NSTime nstime = g_malloc (sizeof(nstime_t));
+    NSTime nstime;
 
     if ( !(tvbr && tvbr->tvb)) return 0;
     if (tvbr->tvb->expired) {
@@ -1041,6 +1041,8 @@ WSLUA_METHOD TvbRange_nstime(lua_State* L) {
         return 0;
     }
 
+    nstime = g_new(nstime_t,1);
+
     if (tvbr->len == 4) {
       nstime->secs = tvb_get_ntohl(tvbr->tvb->ws_tvb, tvbr->offset);
       nstime->nsecs = 0;
@@ -1048,6 +1050,7 @@ WSLUA_METHOD TvbRange_nstime(lua_State* L) {
       nstime->secs = tvb_get_ntohl(tvbr->tvb->ws_tvb, tvbr->offset);
       nstime->nsecs = tvb_get_ntohl(tvbr->tvb->ws_tvb, tvbr->offset + 4);
     } else {
+      g_free(nstime);
       WSLUA_ERROR(TvbRange_nstime,"The range must be 4 or 8 bytes long");
       return 0;
     }
@@ -1060,7 +1063,7 @@ WSLUA_METHOD TvbRange_nstime(lua_State* L) {
 WSLUA_METHOD TvbRange_le_nstime(lua_State* L) {
 	/* Obtain a nstime from a TvbRange */
     TvbRange tvbr = checkTvbRange(L,1);
-    NSTime nstime = g_malloc (sizeof(nstime_t));
+    NSTime nstime;
 
     if ( !(tvbr && tvbr->tvb)) return 0;
     if (tvbr->tvb->expired) {
@@ -1068,6 +1071,8 @@ WSLUA_METHOD TvbRange_le_nstime(lua_State* L) {
         return 0;
     }
 
+    nstime = g_new(nstime_t,1);
+
     if (tvbr->len == 4) {
       nstime->secs = tvb_get_letohl(tvbr->tvb->ws_tvb, tvbr->offset);
       nstime->nsecs = 0;
@@ -1075,6 +1080,7 @@ WSLUA_METHOD TvbRange_le_nstime(lua_State* L) {
       nstime->secs = tvb_get_letohl(tvbr->tvb->ws_tvb, tvbr->offset);
       nstime->nsecs = tvb_get_letohl(tvbr->tvb->ws_tvb, tvbr->offset + 4);
     } else {
+      g_free(nstime);
       WSLUA_ERROR(TvbRange_nstime,"The range must be 4 or 8 bytes long");
       return 0;
     }
@@ -1232,9 +1238,12 @@ WSLUA_METHOD TvbRange_range(lua_State* L) {
 
     TvbRange tvbr = checkTvbRange(L,1);
     int offset = luaL_optint(L,WSLUA_OPTARG_TvbRange_range_OFFSET,0);
-    int len = luaL_optint(L,WSLUA_OPTARG_TvbRange_range_LENGTH,tvbr->len-offset);
-
+    int len;
+    
     if (!(tvbr && tvbr->tvb)) return 0;
+
+    len = luaL_optint(L,WSLUA_OPTARG_TvbRange_range_LENGTH,tvbr->len-offset);
+
     if (tvbr->tvb->expired) {
         luaL_error(L,"expired tvb");
         return 0;
