@@ -1,6 +1,6 @@
 /* wspy_register.c
  *
- * $Id: wspy_register.c 39546 2011-10-24 23:43:17Z gerald $
+ * $Id: wspy_register.c 39535 2011-10-24 16:37:07Z etxrab $
  *
  * Wireshark Protocol Python Binding
  *
@@ -152,7 +152,7 @@ void register_all_py_protocols_func(void)
 
   /* Execute the python register function */
   /* This function returns a sequence of python dissectors objects */
-  py_args = Py_BuildValue("(s)", get_wspython_dir());
+  py_args = Py_BuildValue("ss",  get_wspython_dir(), get_plugins_pers_dir());
   py_dissectors = PyObject_CallObject(register_fn, py_args);
 
   /* Check that the py_dissectors is really a sequence */
@@ -173,19 +173,11 @@ void register_all_py_protocols_func(void)
   }
 }
 
-tvbuff_t *py_tvbuff(void)
+void py_dissector_args(tvbuff_t ** tvb, packet_info ** pinfo, proto_tree ** tree)
 {
-  return g_tvb;
-}
-
-packet_info * py_pinfo(void)
-{
-  return g_pinfo;
-}
-
-proto_tree * py_tree(void)
-{
-  return g_tree;
+	*tvb = g_tvb;
+	*pinfo = g_pinfo;
+	*tree = g_tree;
 }
 
 /*
@@ -214,17 +206,9 @@ void py_dissect(tvbuff_t * tvb, packet_info * pinfo,
   PyObject_CallMethod(py_dissector, "pre_dissect", NULL);
 }
 
-/*
- * Return the pointer to the generic python dissector
- *
- * One could think that it could be a PyCObject but it is a
- * workaround because ctypes is used and it complains later -not
- * knowing how to conver the parameter - in the Python code when
- * calling back a C function with a PyCObject as parameter
- */
-dissector_t py_generic_dissector(void)
+dissector_handle_t py_create_dissector_handle(const int proto)
 {
-  return &py_dissect;
+		return create_dissector_handle(&py_dissect, proto);
 }
 
 static void register_all_py_handoffs_foreach(gpointer key _U_, gpointer value, gpointer user_data _U_)
