@@ -1,7 +1,7 @@
 /* file.h
  * Definitions for file structures and routines
  *
- * $Id: file.h 43396 2012-06-20 04:45:08Z guy $
+ * $Id: file.h 43478 2012-06-25 18:38:51Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -203,12 +203,12 @@ cf_read_status_t cf_finish_tail(capture_file *cf, int *err);
 
 /**
  * Determine whether this capture file (or a range of it) can be saved
- * (except by copying the raw file data).
+ * in any format using Wiretap rather than by copying the raw data.
  *
  * @param cf the capture file to check
  * @return TRUE if it can be saved, FALSE if it can't
  */
-gboolean cf_can_save_as(capture_file *cf);
+gboolean cf_can_write_with_wiretap(capture_file *cf);
 
 /**
  * Save all packets in a capture file to a new file, and, if that succeeds,
