@@ -1,9 +1,9 @@
 #
 # makenmake.pl - create a nmake file from a generic manifest file that will create the appropriate PortableApp structure
-# $Id: makenmake.pl 33880 2010-08-22 00:41:06Z gerald $
+# $Id: makenmake.pl 43245 2012-06-13 22:29:21Z gerald $
 #
 
-print "
+print q{
 include ../../../config.nmake
 include <win32.mak>
 
@@ -11,14 +11,15 @@ FILES 		= Files
 APP 		= App
 WIRESHARK 	= Wireshark
 
-TOPDIR	= ..\\..\\..
+TOPDIR	= ..\..\..
+STAGING_DIR = $(TOPDIR)\$(INSTALL_DIR)
 COPY	= xcopy
 MOVE    = mv
 MKDIR	= mkdir
 COPY_FLAGS	= /d /y 
 
 distribution:
-";
+};
 
 while($line = <>) {
     
