@@ -1,9 +1,9 @@
 #
 # makenmake.pl - create a nmake file from a generic manifest file that will create the appropriate U3 structure
-# $Id: makenmake.pl 32287 2010-03-25 22:22:45Z wmeier $
+# $Id: makenmake.pl 43245 2012-06-13 22:29:21Z gerald $
 #
 
-print "
+print q{
 include ../../../config.nmake
 include <win32.mak>
 
@@ -12,14 +12,16 @@ HOST 	= host
 MANIFEST= manifest
 DATA	= data
 
-TOPDIR	= ..\\..\\..
+TOPDIR	= ..\..\..
+STAGING_DIR = $(TOPDIR)\$(INSTALL_DIR)
+
 COPY	= xcopy
 MOVE    = mv
 MKDIR	= mkdir
 COPY_FLAGS	= /d /y 
 
 distribution:
-";
+};
 
 while($line = <>) {
     
