@@ -1,7 +1,7 @@
 /* asn1.c
  * Routines for ASN.1 BER dissection
  *
- * $Id: asn1.c 28064 2009-04-16 03:38:23Z gerald $
+ * $Id: asn1.c 29492 2009-08-21 14:36:27Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,10 +60,6 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
-
-#include <limits.h>
-
 #include <glib.h>
 
 #define subid_t guint32 /* ugly hack to get it to compile this symbol should be suppressed! */
