@@ -2,7 +2,7 @@
  * Routines for Baseline Privacy Key Management Response dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-bpkmrsp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-bpkmrsp.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,11 +84,11 @@ dissect_bpkmrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"BPKM Response Message");
       bpkmrsp_tree = proto_item_add_subtree (it, ett_docsis_bpkmrsp);
       proto_tree_add_item (bpkmrsp_tree, hf_docsis_bpkmrsp_code, tvb, 0, 1,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (bpkmrsp_tree, hf_docsis_bpkmrsp_ident, tvb, 1, 1,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (bpkmrsp_tree, hf_docsis_bpkmrsp_length, tvb, 2, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
     }
 
   /* Code to Call subdissector */
