@@ -2,7 +2,7 @@
  * Routines for DOCSIS 3.0 Dynamic Bonding Change Response Message dissection.
  * Copyright 2010, Guido Reismueller <g.reismueller[AT]avm.de>
  *
- * $Id: packet-dbcrsp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-dbcrsp.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -65,9 +65,9 @@ dissect_dbcrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 										   "Dynamic Bonding Change Response");
     dbcrsp_tree = proto_item_add_subtree (dbcrsp_item, ett_docsis_dbcrsp);
     proto_tree_add_item (dbcrsp_tree, hf_docsis_dbcrsp_tranid,
-						   tvb, 0, 2, FALSE);
+						   tvb, 0, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item( dbcrsp_tree, hf_docsis_dbcrsp_conf_code,
-						   tvb, 2, 1, FALSE );
+						   tvb, 2, 1, ENC_BIG_ENDIAN );
   }
   /* Call Dissector for Appendix C TLV's */
   next_tvb = tvb_new_subset_remaining (tvb, 3);
