@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Addition Request dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dsareq.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-dsareq.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -61,7 +61,7 @@ dissect_dsareq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"DSA Request");
       dsareq_tree = proto_item_add_subtree (it, ett_docsis_dsareq);
       proto_tree_add_item (dsareq_tree, hf_docsis_dsareq_tranid, tvb, 0, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
 
     }
     /* Call Dissector for Appendix C TLV's */
