@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Change Acknowledge dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dscack.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-dscack.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,9 +66,9 @@ dissect_dscack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"DSC Acknowledge");
       dscack_tree = proto_item_add_subtree (it, ett_docsis_dscack);
       proto_tree_add_item (dscack_tree, hf_docsis_dscack_tranid, tvb, 0, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (dscack_tree, hf_docsis_dscack_response, tvb, 2, 1,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
     }
     /* Call Dissector for Appendix C TLV's */
     next_tvb = tvb_new_subset_remaining (tvb, 3);
