@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Change Request dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dscreq.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-dscreq.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,7 +62,7 @@ dissect_dscreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"DSC Request");
       dscreq_tree = proto_item_add_subtree (it, ett_docsis_dscreq);
       proto_tree_add_item (dscreq_tree, hf_docsis_dscreq_tranid, tvb, 0, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
 
     }
     /* Call dissector for Appendix C TLV's */
