@@ -2,7 +2,7 @@
  * Routines for Intial Ranging Request Message dissection
  * Copyright 2003, Brian Wheeler <brian.wheeler[AT]arrisi.com>
  *
- * $Id: packet-intrngreq.c 32388 2010-04-05 20:04:52Z etxrab $
+ * $Id: packet-intrngreq.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,6 @@
 
 /* Initialize the protocol and registered fields */
 static int proto_docsis_intrngreq = -1;
-static int hf_docsis_intrngreq = -1;
 static int hf_docsis_intrngreq_down_chid = -1;
 static int hf_docsis_intrngreq_sid = -1;
 static int hf_docsis_intrngreq_up_chid = -1;
@@ -62,11 +61,11 @@ dissect_intrngreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"Initial Ranging Request");
       intrngreq_tree = proto_item_add_subtree (intrngreq_item, ett_docsis_intrngreq);
       proto_tree_add_item (intrngreq_tree, hf_docsis_intrngreq_sid, tvb, 0, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (intrngreq_tree, hf_docsis_intrngreq_down_chid, tvb, 2, 1,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (intrngreq_tree, hf_docsis_intrngreq_up_chid, tvb, 3,
-			   1, FALSE);
+			   1, ENC_BIG_ENDIAN);
     }
 
 
@@ -88,11 +87,6 @@ proto_register_docsis_intrngreq (void)
 
 /* Setup list of header fields  See Section 1.6.1 for details*/
   static hf_register_info hf[] = {
-    {&hf_docsis_intrngreq,
-     {"RNG-REQ Message", "docsis_intrngreq",
-      FT_BYTES, BASE_NONE, NULL, 0x0,
-      "Ranging Request Message", HFILL}
-     },
     {&hf_docsis_intrngreq_sid,
      {"Service Identifier", "docsis_intrngreq.sid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
@@ -139,6 +133,6 @@ proto_reg_handoff_docsis_intrngreq (void)
   dissector_handle_t docsis_intrngreq_handle;
 
   docsis_intrngreq_handle = find_dissector ("docsis_intrngreq");
-  dissector_add ("docsis_mgmt", 0x1E, docsis_intrngreq_handle);
+  dissector_add_uint ("docsis_mgmt", 0x1E, docsis_intrngreq_handle);
 
 }
