@@ -2,7 +2,7 @@
  * Routines for docsis Mac Management Header dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-macmgmt.c 35869 2011-02-08 00:24:10Z wmeier $
+ * $Id: packet-macmgmt.c 39490 2011-10-20 14:30:27Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -175,23 +175,23 @@ dissect_macmgmt (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
                                         "Mac Management");
       mgt_hdr_tree = proto_item_add_subtree (mgt_hdr_it, ett_docsis_mgmt);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_dst_addr, tvb, 0, 6,
-                           FALSE);
+                           ENC_NA);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_src_addr, tvb, 6, 6,
-                           FALSE);
+                           ENC_NA);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_msg_len, tvb, 12, 2,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_dsap, tvb, 14, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_ssap, tvb, 15, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_control, tvb, 16, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_version, tvb, 17, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_type, tvb, 18, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
       proto_tree_add_item (mgt_hdr_tree, hf_docsis_mgt_rsvd, tvb, 19, 1,
-                           FALSE);
+                           ENC_BIG_ENDIAN);
 
     }
   /* Code to Call subdissector */
