@@ -1,5 +1,5 @@
 /* packet-regreqmp.c
- * $Id: packet-regreqmp.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-regreqmp.c 39292 2011-10-06 14:46:34Z wmeier $
  * Routines for REG-REQ-MP Message dissection
  * Copyright 2007, Bruno Verstuyft  <bruno.verstuyft@excentis.com>
  *
@@ -61,9 +61,9 @@ dissect_regreqmp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 			it = proto_tree_add_protocol_format (tree, proto_docsis_regreqmp, tvb, 0, -1,"REG-REQ-MP Message");
 			regreqmp_tree = proto_item_add_subtree (it, ett_docsis_regreqmp);
 			
-			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_sid, tvb, 0, 2, FALSE);
-			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_number_of_fragments, tvb, 2, 1, FALSE);
-			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_fragment_sequence_number, tvb, 3, 1, FALSE);
+			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_sid, tvb, 0, 2, ENC_BIG_ENDIAN);
+			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_number_of_fragments, tvb, 2, 1, ENC_BIG_ENDIAN);
+			proto_tree_add_item (regreqmp_tree, hf_docsis_regreqmp_fragment_sequence_number, tvb, 3, 1, ENC_BIG_ENDIAN);
 
 		}
 		/* Call Dissector for Appendix C TLV's */
