@@ -2,7 +2,7 @@
  * Routines for Registration Response Message dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-regrsp.c 32398 2010-04-06 13:40:06Z morriss $
+ * $Id: packet-regrsp.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,7 +31,6 @@
 
 /* Initialize the protocol and registered fields */
 static int proto_docsis_regrsp = -1;
-static int hf_docsis_regrsp = -1;
 static int hf_docsis_regrsp_sid = -1;
 static int hf_docsis_regrsp_response = -1;
 static dissector_handle_t docsis_tlv_handle;
@@ -68,9 +67,9 @@ dissect_regrsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 					"Registration Response");
       regrsp_tree = proto_item_add_subtree (it, ett_docsis_regrsp);
       proto_tree_add_item (regrsp_tree, hf_docsis_regrsp_sid, tvb, 0, 2,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
       proto_tree_add_item (regrsp_tree, hf_docsis_regrsp_response, tvb, 2, 1,
-			   FALSE);
+			   ENC_BIG_ENDIAN);
     }
     /* Call Dissector for Appendix C TLV's */
     next_tvb = tvb_new_subset_remaining (tvb, 3);
@@ -91,11 +90,6 @@ proto_register_docsis_regrsp (void)
 
 /* Setup list of header fields  See Section 1.6.1 for details*/
   static hf_register_info hf[] = {
-    {&hf_docsis_regrsp,
-     {"Registration Response", "docsis_regrsp",
-      FT_BYTES, BASE_NONE, NULL, 0x0,
-      "Registration Request", HFILL}
-     },
     {&hf_docsis_regrsp_sid,
      {"Service Identifier", "docsis_regrsp.sid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
@@ -137,6 +131,6 @@ proto_reg_handoff_docsis_regrsp (void)
 
   docsis_regrsp_handle = find_dissector ("docsis_regrsp");
   docsis_tlv_handle = find_dissector ("docsis_tlv");
-  dissector_add ("docsis_mgmt", 0x07, docsis_regrsp_handle);
+  dissector_add_uint ("docsis_mgmt", 0x07, docsis_regrsp_handle);
 
 }
