@@ -2,7 +2,7 @@
  * Routines to Dissect TLV's for CM-Control Messages
  * Copyright 2010, Guido Reismueller <g.reismueller[AT]avm.de>
  *
- * $Id: packet-tlv-cmctrl.c 35869 2011-02-08 00:24:10Z wmeier $
+ * $Id: packet-tlv-cmctrl.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -85,7 +85,7 @@ dissect_ds_event(tvbuff_t * tvb, proto_tree *tree, int start, guint16 len)
       if (length == 1)
         {
           proto_tree_add_item (event_tree, hf_ds_event_ch_id,
-                               tvb, pos, length, FALSE);
+                               tvb, pos, length, ENC_BIG_ENDIAN);
         }
       else
         {
@@ -96,7 +96,7 @@ dissect_ds_event(tvbuff_t * tvb, proto_tree *tree, int start, guint16 len)
       if (length == 2)
         {
           proto_tree_add_item (event_tree, hf_ds_event_mask,
-                               tvb, pos, length, FALSE);
+                               tvb, pos, length, ENC_NA);
         }
       else
         {
@@ -130,7 +130,7 @@ dissect_us_event(tvbuff_t * tvb, proto_tree *tree, int start, guint16 len)
       if (length == 1)
         {
           proto_tree_add_item (event_tree, hf_us_event_ch_id,
-                               tvb, pos, length, FALSE);
+                               tvb, pos, length, ENC_BIG_ENDIAN);
         }
       else
         {
@@ -141,7 +141,7 @@ dissect_us_event(tvbuff_t * tvb, proto_tree *tree, int start, guint16 len)
       if (length == 2)
         {
           proto_tree_add_item (event_tree, hf_us_event_mask,
-                               tvb, pos, length, FALSE);
+                               tvb, pos, length, ENC_NA);
         }
       else
         {
@@ -180,7 +180,7 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
           if (length == 1)
             {
               proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_mute,
-                                   tvb, pos, length, FALSE);
+                                   tvb, pos, length, ENC_BIG_ENDIAN);
             }
           else
             {
@@ -191,7 +191,7 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
           if (length == 4 || length == 1) /* response TLV always with len 1 */
             {
               proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_mute_timeout,
-                                   tvb, pos, length, FALSE);
+                                   tvb, pos, length, ENC_BIG_ENDIAN);
             }
           else
             {
@@ -202,7 +202,7 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
           if (length == 1)
             {
               proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_reinit,
-                                   tvb, pos, length, FALSE);
+                                   tvb, pos, length, ENC_BIG_ENDIAN);
             }
           else
             {
@@ -213,7 +213,7 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
           if (length == 1)
             {
               proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_disable_fwd,
-                                   tvb, pos, length, FALSE);
+                                   tvb, pos, length, ENC_BIG_ENDIAN);
             }
           else
             {
@@ -223,14 +223,14 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
         case CM_CTRL_DS_EVENT:
           if (length == 1)
             proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_ds_event,
-                                 tvb, pos, length, FALSE);
+                                 tvb, pos, length, ENC_NA);
           else
             dissect_ds_event(tvb, tlv_tree, pos, length);
           break;
         case CM_CTRL_US_EVENT:
           if (length == 1)
             proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_ds_event,
-                                 tvb, pos, length, FALSE);
+                                 tvb, pos, length, ENC_NA);
           else
             dissect_us_event(tvb, tlv_tree, pos, length);
           break;
@@ -238,7 +238,7 @@ dissect_cmctrl_tlv (tvbuff_t * tvb, packet_info * pinfo _U_, proto_tree * tree)
           if (length == 2 || length == 1) /* response TLV always with len 1 */
             {
               proto_tree_add_item (tlv_tree, hf_cmctrl_tlv_event,
-                                   tvb, pos, length, FALSE);
+                                   tvb, pos, length, ENC_NA);
             }
           else
             {
