@@ -1,7 +1,7 @@
 /* packet-esl.c
  * Routines for EtherCAT Switch Link disassembly
  *
- * $Id: packet-esl.c 32324 2010-03-29 16:52:47Z wmeier $
+ * $Id: packet-esl.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Copyright (c) 2007 by Beckhoff Automation GmbH
  *
@@ -190,18 +190,18 @@ dissect_esl_header(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree) {
         {
             guint16 flags;
 
-            ti = proto_tree_add_item(tree, proto_esl, tvb, 0, SIZEOF_ESLHEADER, TRUE);
+            ti = proto_tree_add_item(tree, proto_esl, tvb, 0, SIZEOF_ESLHEADER, ENC_NA);
             esl_header_tree = proto_item_add_subtree(ti, ett_esl);
             offset+=6;
 
             flags =  tvb_get_letohs(tvb, offset);
             proto_tree_add_uint(esl_header_tree, hf_esl_port, tvb, offset, 2, flags_to_port(flags));
 
-            proto_tree_add_item(esl_header_tree, hf_esl_crcerror, tvb, offset, 2, TRUE);
-            proto_tree_add_item(esl_header_tree, hf_esl_alignerror, tvb, offset, 2, TRUE);
+            proto_tree_add_item(esl_header_tree, hf_esl_crcerror, tvb, offset, 2, ENC_LITTLE_ENDIAN);
+            proto_tree_add_item(esl_header_tree, hf_esl_alignerror, tvb, offset, 2, ENC_LITTLE_ENDIAN);
             offset+=2;
 
-            proto_tree_add_item(esl_header_tree, hf_esl_timestamp, tvb, offset, 8, TRUE);
+            proto_tree_add_item(esl_header_tree, hf_esl_timestamp, tvb, offset, 8, ENC_LITTLE_ENDIAN);
         }
     }
 }
