@@ -3,7 +3,7 @@
  * By Steve Limkemann <stevelim@dgtech.com>
  * Copyright 1998 Steve Limkemann
  *
- * $Id: packet-gryphon.c 39503 2011-10-21 02:10:19Z wmeier $
+ * $Id: packet-gryphon.c 42367 2012-04-30 23:03:51Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -336,8 +336,7 @@ dissect_gryphon_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     }
     if (offset < msgend) {
         i = msgend - offset;
-        proto_tree_add_text(gryphon_tree, tvb, offset, i, "padding");
-        offset += i;
+        proto_tree_add_text(gryphon_tree, tvb, offset, i, "Padding");
     }
 }
 
@@ -1386,12 +1385,9 @@ cmd_sched(tvbuff_t *tvb, int offset, proto_tree *pt)
 static int
 cmd_sched_rep(tvbuff_t *tvb, int offset, proto_tree *pt)
 {
-    int             msglen;
-    int             save_offset;
     unsigned int    x;
     const char      *type;
 
-    msglen = tvb_reported_length_remaining(tvb, offset);
     x = tvb_get_ntohl(tvb, offset);
     if (x & 0x80000000)
         type = "Critical";
@@ -1399,15 +1395,11 @@ cmd_sched_rep(tvbuff_t *tvb, int offset, proto_tree *pt)
         type = "Normal";
     proto_tree_add_text(pt, tvb, offset, 4, "%s schedule ID: %u", type, x);
     offset += 4;
-    msglen -= 4;
     x= tvb_get_guint8(tvb, offset);
     proto_tree_add_text(pt, tvb, offset, 1, "Message index: %d", x);
     proto_tree_add_text(pt, tvb, offset + 1, 3, "reserved");
     offset += 4;
-    msglen -= 4;
-    save_offset = offset;
     offset = decode_data(tvb, offset, pt);
-    msglen -= offset - save_offset;
     return offset;
 }
 
