@@ -2,7 +2,7 @@
  * Routines for IrCOMM dissection
  * Copyright 2003 Jan Kiszka <jan.kiszka@web.de>
  *
- * $Id: packet-ircomm.c 32388 2010-04-05 20:04:52Z etxrab $
+ * $Id: packet-ircomm.c 39503 2011-10-21 02:10:19Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -12,12 +12,12 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -190,15 +190,15 @@ static void dissect_cooked_ircomm(tvbuff_t* tvb, packet_info* pinfo, proto_tree*
     if (root)
     {
         /* create display subtree for the protocol */
-        proto_item* ti   = proto_tree_add_item(root, proto_ircomm, tvb, 0, -1, FALSE);
+        proto_item* ti   = proto_tree_add_item(root, proto_ircomm, tvb, 0, -1, ENC_NA);
         proto_tree* tree = proto_item_add_subtree(ti, ett_ircomm);
 
         proto_tree* ctrl_tree;
 
 
-        ti        = proto_tree_add_item(tree, hf_control, tvb, 0, clen + 1, FALSE);
+        ti        = proto_tree_add_item(tree, hf_control, tvb, 0, clen + 1, ENC_NA);
         ctrl_tree = proto_item_add_subtree(ti, ett_ircomm_ctrl);
-        proto_tree_add_item(ctrl_tree, hf_control_len, tvb, offset, 1, FALSE);
+        proto_tree_add_item(ctrl_tree, hf_control_len, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset++;
         {
             tvbuff_t *cvalue = tvb_new_subset(tvb, offset, clen, clen);
@@ -232,7 +232,7 @@ static void dissect_raw_ircomm(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
     if (root)
     {
         /* create display subtree for the protocol */
-        proto_item* ti   = proto_tree_add_item(root, proto_ircomm, tvb, 0, -1, FALSE);
+        proto_item* ti   = proto_tree_add_item(root, proto_ircomm, tvb, 0, -1, ENC_NA);
         proto_tree* tree = proto_item_add_subtree(ti, ett_ircomm);
 
         call_dissector(data_handle, tvb, pinfo, tree);
@@ -267,7 +267,7 @@ static gboolean dissect_ircomm_parameters(tvbuff_t* tvb, unsigned offset, packet
             guint8  p_len = tvb_get_guint8(tvb, offset + 1);
 
 
-            ti = proto_tree_add_item(tree, hf_ircomm_param, tvb, offset, p_len + 2, FALSE);
+            ti = proto_tree_add_item(tree, hf_ircomm_param, tvb, offset, p_len + 2, ENC_NA);
             p_tree = proto_item_add_subtree(ti, ett_param[list_index * MAX_PARAMETERS + n]);
 
             buf[0] = 0;
