@@ -3,7 +3,7 @@
  * @copyright Copyright 2004 Shaun Jackman
  * @license GPL
  *
- * $Id: packet-sir.c 35224 2010-12-20 05:35:29Z guy $
+ * $Id: packet-sir.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,7 +29,7 @@
 #endif
 
 #include <epan/packet.h>
-#include <epan/crc16.h>
+#include <epan/crc16-tvb.h>
 
 /** Serial infrared port. */
 #define TCP_PORT_SIR 6417
@@ -158,14 +158,14 @@ dissect_sir(tvbuff_t *tvb, packet_info *pinfo, proto_tree *root)
 				proto_tree* tree = proto_item_add_subtree(ti, ett_sir);
 				if (preamble_len > 0)
 					proto_tree_add_item(tree, hf_sir_preamble, tvb,
-							offset, preamble_len, FALSE);
+							offset, preamble_len, ENC_NA);
 				proto_tree_add_item(tree, hf_sir_bof, tvb,
-						bof_offset, 1, FALSE);
+						bof_offset, 1, ENC_BIG_ENDIAN);
 				proto_tree_add_uint(tree, hf_sir_length,
 						next_tvb, 0, data_len, data_len);
 				next_tvb = checksum_data(next_tvb, tree);
 				proto_tree_add_item(tree, hf_sir_eof, tvb,
-						eof_offset, 1, FALSE);
+						eof_offset, 1, ENC_BIG_ENDIAN);
 			} else {
 				next_tvb = checksum_data(next_tvb, NULL);
 			}
