@@ -3,7 +3,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate.h 38403 2011-08-08 09:39:30Z jmayer $
+* $Id: mate.h 40547 2012-01-16 19:05:32Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -32,11 +32,6 @@
 # include "config.h"
 #endif
 
-/* The mate dissector is using deprecated GMemChunk. Do not error out
- * when encountering it.
- */
-#undef G_DISABLE_DEPRECATED
-
 #ifndef ENABLE_STATIC
 #include "moduleinfo.h"
 #include <gmodule.h>
@@ -274,7 +269,6 @@ typedef struct _mate_config_frame {
 
 typedef struct _mate_runtime_data {
 	guint current_items; /* a count of items */
-	GMemChunk* mate_items;
 	float now;
 	guint highest_analyzed_frame;
 
