@@ -4,7 +4,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_util.c 40547 2012-01-16 19:05:32Z wmeier $
+* $Id: mate_util.c 43114 2012-06-05 15:20:31Z morriss $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -311,11 +311,16 @@ extern void avp_init(void) {
 extern AVP* new_avp_from_finfo(const gchar* name, field_info* finfo) {
 	AVP*   new = (AVP*)g_slice_new(any_avp_type);
 	gchar* value;
+	gchar* repr = NULL;
 
 	new->n = scs_subscribe(avp_strings, name);
 
 	if (finfo->value.ftype->val_to_string_repr) {
-		value = scs_subscribe(avp_strings, fvalue_to_string_repr(&finfo->value,FTREPR_DISPLAY,NULL));
+		repr = fvalue_to_string_repr(&finfo->value,FTREPR_DISPLAY,NULL);
+	}
+
+	if (repr) {
+		value = scs_subscribe(avp_strings, repr);
 #ifdef _AVP_DEBUGGING
 		dbg_print (dbg_avp,2,dbg_fp,"new_avp_from_finfo: from string: %s",value);
 #endif
