@@ -2,7 +2,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_util.h 42749 2012-05-21 16:14:46Z gerald $
+* $Id: mate_util.h 40547 2012-01-16 19:05:32Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -49,25 +49,17 @@ typedef struct _scs_collection SCS_collection;
 #define SCS_LARGE_SIZE 4096
 #define SCS_HUGE_SIZE 65536
 
-#define SCS_SMALL_CHUNK_SIZE 4096
-#define SCS_MEDIUM_CHUNK_SIZE 1024
-#define SCS_LARGE_CHUNK_SIZE 256
-#define SCS_HUGE_CHUNK_SIZE 128
-
-extern void destroy_scs_collection(SCS_collection* c);
-extern SCS_collection* scs_init(void);
 extern gchar* scs_subscribe(SCS_collection* collection, const gchar* s);
 extern void scs_unsubscribe(SCS_collection* collection, gchar* s);
 extern gchar* scs_subscribe_printf(SCS_collection* collection, gchar* fmt, ...);
 
 /******* AVPs & Co. *********/
-#define AVP_CHUNK_SIZE 4096
 
 /* these are the defined oreators of avps */
 #define AVP_OP_EQUAL		'='
 #define AVP_OP_NOTEQUAL		'!'
 #define AVP_OP_STARTS		'^'
-#define AVP_OP_ENDS			'$'
+#define AVP_OP_ENDS		'$'
 #define AVP_OP_CONTAINS		'~'
 #define AVP_OP_LOWER		'<'
 #define AVP_OP_HIGHER		'>'
