@@ -1,5 +1,5 @@
 /******************************************************************************
-** $Id: opcua_application_layer.c 36283 2011-03-23 08:03:02Z stig $
+** $Id: opcua_application_layer.c 39292 2011-10-06 14:46:34Z wmeier $
 **
 ** Copyright (C) 2006-2007 ascolab GmbH. All Rights Reserved.
 ** Web: http://www.ascolab.com
@@ -79,28 +79,28 @@ int parseServiceNodeId(proto_tree *tree, tvbuff_t *tvb, gint *pOffset)
     guint32 Numeric = 0;
 
     EncodingMask = tvb_get_guint8(tvb, iOffset);
-    proto_tree_add_item(tree, hf_opcua_nodeid_encodingmask, tvb, iOffset, 1, TRUE);
+    proto_tree_add_item(tree, hf_opcua_nodeid_encodingmask, tvb, iOffset, 1, ENC_LITTLE_ENDIAN);
     iOffset++;
 
     switch(EncodingMask)
     {
     case 0x00: /* two byte node id */
         Numeric = tvb_get_guint8(tvb, iOffset);
-        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 1, TRUE);
+        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 1, ENC_LITTLE_ENDIAN);
         iOffset+=1;
         break;
     case 0x01: /* four byte node id */
-        proto_tree_add_item(tree, hf_opcua_app_nsid, tvb, iOffset, 1, TRUE);
+        proto_tree_add_item(tree, hf_opcua_app_nsid, tvb, iOffset, 1, ENC_LITTLE_ENDIAN);
         iOffset+=1;
         Numeric = tvb_get_letohs(tvb, iOffset);
-        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 2, TRUE);
+        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 2, ENC_LITTLE_ENDIAN);
         iOffset+=2;
         break;
     case 0x02: /* numeric, that does not fit into four bytes */
-        proto_tree_add_item(tree, hf_opcua_app_nsid, tvb, iOffset, 4, TRUE);
+        proto_tree_add_item(tree, hf_opcua_app_nsid, tvb, iOffset, 4, ENC_LITTLE_ENDIAN);
         iOffset+=4;
         Numeric = tvb_get_letohl(tvb, iOffset);
-        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 4, TRUE);
+        proto_tree_add_item(tree, hf_opcua_app_numeric, tvb, iOffset, 4, ENC_LITTLE_ENDIAN);
         iOffset+=4;
         break;
     case 0x03: /* string */
