@@ -1,7 +1,7 @@
 /* packet-dcom-cba.c
  * Routines for DCOM CBA
  *
- * $Id: packet-dcom-cba.c 39262 2011-10-05 01:00:06Z wmeier $
+ * $Id: packet-dcom-cba.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,11 +26,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/emem.h>
