@@ -2,7 +2,7 @@
  * Routines for PN-DCP (PROFINET Discovery and basic Configuration Protocol) 
  * packet dissection.
  *
- * $Id: packet-pn-dcp.c 39262 2011-10-05 01:00:06Z wmeier $
+ * $Id: packet-pn-dcp.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,11 +27,6 @@
 #include "config.h"
 #endif
 
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <glib.h>
