@@ -2,7 +2,7 @@
  * Routines for PN-MRP (PROFINET Media Redundancy Protocol)
  * packet dissection.
  *
- * $Id: packet-pn-mrp.c 41645 2012-03-18 22:24:24Z wmeier $
+ * $Id: packet-pn-mrp.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,11 +27,6 @@
 #include "config.h"
 #endif
 
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/dissectors/packet-dcerpc.h>
