@@ -2,7 +2,7 @@
  * Routines for PN-PTCP (PROFINET Precision Time Clock Protocol)
  * packet dissection.
  *
- * $Id: packet-pn-ptcp.c 39262 2011-10-05 01:00:06Z wmeier $
+ * $Id: packet-pn-ptcp.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,10 +28,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/dissectors/packet-dcerpc.h>
