@@ -1,7 +1,7 @@
 /* packet-pn.c
  * Common functions for other PROFINET protocols like IO, CBA, DCP, ...
  *
- * $Id: packet-pn.c 38250 2011-07-29 07:24:15Z tuexen $
+ * $Id: packet-pn.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,11 +27,6 @@
 #include "config.h"
 #endif
 
-
-#ifdef HAVE_SYS_TYPES_H
-/*#include <sys/types.h>*/
-#endif
-
 #include <string.h>
 
 #include <glib.h>
