@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_hd_type1_decoder.c 39292 2011-10-06 14:46:34Z wmeier $
+ * $Id: mac_hd_type1_decoder.c 42004 2012-04-10 10:20:20Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,7 +66,7 @@ enum
 	TYPE_I_SUBTYPE_MAX
 } TYPE_I_SUBTYPE;
 
-static char *type1_subtype_abbrv[TYPE_I_SUBTYPE_MAX] =
+static const char *type1_subtype_abbrv[TYPE_I_SUBTYPE_MAX] =
 {
 	"BR INCREMENTAL",            /* 0 */
 	"BR AGGREGATE",              /* 1 */
