@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_hd_type2_decoder.c 39292 2011-10-06 14:46:34Z wmeier $
+ * $Id: mac_hd_type2_decoder.c 42004 2012-04-10 10:20:20Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -72,7 +72,7 @@ enum
 	TYPE_II_FB_TYPE_MAX
 } TYPE_II_FB_TYPE;
 
-static char *type2_fb_type_abbrv[TYPE_II_FB_TYPE_MAX] =
+static const char *type2_fb_type_abbrv[TYPE_II_FB_TYPE_MAX] =
 {
 	"CQI and MIMO Feedback",
 	"DL average CINR",
