@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_mgmt_msg_decoder.c 39262 2011-10-05 01:00:06Z wmeier $
+ * $Id: mac_mgmt_msg_decoder.c 42004 2012-04-10 10:20:20Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -111,7 +111,7 @@ static gint proto_mac_mgmt_msg_decoder = -1;
 static gint ett_mac_mgmt_msg_decoder = -1;
 
 /* WIMAX MAC Management message type info */
-char *mgt_msg_abbrv[MAC_MGMT_MSG_TYPE_MAX] =
+static const char *mgt_msg_abbrv[MAC_MGMT_MSG_TYPE_MAX] =
 {
 	"UCD",		/* 0 */
 	"DCD",
