@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_clk_cmp.c 29296 2009-08-04 19:01:34Z wmeier $
+ * $Id: msg_clk_cmp.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -75,22 +75,22 @@ void dissect_mac_mgmt_msg_clk_cmp_decoder(tvbuff_t *tvb, packet_info *pinfo _U_,
 		/* add MAC CLK_CMP subtree */
 		clk_cmp_tree = proto_item_add_subtree(clk_cmp_item, ett_mac_mgmt_msg_clk_cmp_decoder);
 		/* display the Message Type */
-		proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* set the offset for clock count */
 		offset ++;
 		/* get the clock count */
 		clock_count = tvb_get_guint8(tvb, offset);
 		/* display the clock count */
-		proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_count, tvb, offset, 1, FALSE);
+		proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_count, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* set the offset for clock comparison */
 		offset++;
 		for (i = 0; i < clock_count; i++ )
 		{	/* display the Clock ID */
-			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_id, tvb, offset++, 1, FALSE);
+			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_id, tvb, offset++, 1, ENC_BIG_ENDIAN);
 			/* display the sequence number */
-			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_seq_number, tvb, offset++, 1, FALSE);
+			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_seq_number, tvb, offset++, 1, ENC_BIG_ENDIAN);
 			/* display the comparison value */
-			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_comparison_value, tvb, offset++, 1, FALSE);
+			proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_comparison_value, tvb, offset++, 1, ENC_BIG_ENDIAN);
 		}
 	}
 }
