@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_dsa.c 29299 2009-08-04 23:14:40Z guy $
+ * $Id: msg_dsa.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -87,11 +87,11 @@ void dissect_mac_mgmt_msg_dsa_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsa_tree = proto_item_add_subtree(dsa_item, ett_mac_mgmt_msg_dsa_req_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsa_tree, hf_dsa_req_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_req_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* display the Transaction ID */
-		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* process DSA-REQ message TLV Encode Information */
@@ -122,15 +122,15 @@ void dissect_mac_mgmt_msg_dsa_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsa_tree = proto_item_add_subtree(dsa_item, ett_mac_mgmt_msg_dsa_rsp_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsa_tree, hf_dsa_rsp_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_rsp_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* display the Transaction ID */
-		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* display the Confirmation Code */
-		proto_tree_add_item(dsa_tree, hf_dsa_confirmation_code, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_confirmation_code, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* process DSA RSP message TLV Encode Information */
@@ -161,15 +161,15 @@ void dissect_mac_mgmt_msg_dsa_ack_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsa_tree = proto_item_add_subtree(dsa_item, ett_mac_mgmt_msg_dsa_ack_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsa_tree, hf_dsa_ack_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_ack_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* display the Transaction ID */
-		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* display the Confirmation Code */
-		proto_tree_add_item(dsa_tree, hf_dsa_confirmation_code, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsa_tree, hf_dsa_confirmation_code, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* process DSA-REQ message TLV Encode Information */
