@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: msg_dsc.c 29300 2009-08-05 00:13:38Z guy $
+ * $Id: msg_dsc.c 39292 2011-10-06 14:46:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -68,7 +68,6 @@ void dissect_mac_mgmt_msg_dsc_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 {
 	guint offset = 0;
 	guint tvb_len, payload_type;
-	guint dsc_transaction_id;
 	proto_item *dsc_item = NULL;
 	proto_tree *dsc_tree = NULL;
 
@@ -88,13 +87,11 @@ void dissect_mac_mgmt_msg_dsc_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsc_tree = proto_item_add_subtree(dsc_item, ett_mac_mgmt_msg_dsc_req_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsc_tree, hf_dsc_req_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_req_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
-		/* get the Configuration Change Count */
-		dsc_transaction_id = tvb_get_ntohs(tvb, offset);
 		/* display the Transaction ID */
-		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* process DSC REQ message TLV Encode Information */
@@ -106,7 +103,6 @@ void dissect_mac_mgmt_msg_dsc_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 {
 	guint offset = 0;
 	guint tvb_len, payload_type;
-	guint dsc_transaction_id;
 	proto_item *dsc_item = NULL;
 	proto_tree *dsc_tree = NULL;
 
@@ -126,17 +122,15 @@ void dissect_mac_mgmt_msg_dsc_rsp_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsc_tree = proto_item_add_subtree(dsc_item, ett_mac_mgmt_msg_dsc_rsp_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsc_tree, hf_dsc_rsp_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_rsp_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
-		/* get the Configuration Change Count */
-		dsc_transaction_id = tvb_get_ntohs(tvb, offset);
 		/* display the Transaction ID */
-		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* display the Confirmation Code */
-		proto_tree_add_item(dsc_tree, hf_dsc_confirmation_code, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_confirmation_code, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* process DSC RSP message TLV Encode Information */
@@ -148,7 +142,6 @@ void dissect_mac_mgmt_msg_dsc_ack_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 {
 	guint offset = 0;
 	guint tvb_len, payload_type;
-	guint dsc_transaction_id;
 	proto_item *dsc_item = NULL;
 	proto_tree *dsc_tree = NULL;
 
@@ -168,17 +161,15 @@ void dissect_mac_mgmt_msg_dsc_ack_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		dsc_tree = proto_item_add_subtree(dsc_item, ett_mac_mgmt_msg_dsc_ack_decoder);
 		/* Decode and display the Uplink Channel Descriptor (UCD) */
 		/* display the Message Type */
-		proto_tree_add_item(dsc_tree, hf_dsc_ack_message_type, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_ack_message_type, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
-		/* get the Configuration Change Count */
-		dsc_transaction_id = tvb_get_ntohs(tvb, offset);
 		/* display the Transaction ID */
-		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_transaction_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset += 2;
 		/* display the Confirmation Code */
-		proto_tree_add_item(dsc_tree, hf_dsc_confirmation_code, tvb, offset, 1, FALSE);
+		proto_tree_add_item(dsc_tree, hf_dsc_confirmation_code, tvb, offset, 1, ENC_BIG_ENDIAN);
 		/* move to next field */
 		offset++;
 		/* process DSC ACK message TLV Encode Information */
