@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: packet-wmx.c 47332 2013-01-28 22:34:37Z gerald $
+ * $Id: packet-wmx.c 37889 2011-07-04 14:33:22Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,7 +54,7 @@ extern void proto_register_wimax_compact_ulmap_ie(void);
 
 /* Global functions */
 /* void proto_reg_handoff_wimax(void); */
-gboolean is_down_link(address *src_address);
+gboolean is_down_link(packet_info *pinfo);
 
 /* Global variables */
 gint    proto_wimax = -1;
@@ -638,10 +638,6 @@ proto_tree *add_tlv_subtree(tlv_info_t *this, gint idx, proto_tree *tree, int hf
 	size_of_tlv_length_field = get_tlv_size_of_length(this);
 	tlv_type = get_tlv_type(this);
 
-	/* Make sure we're dealing with a valid TLV here */
-	if (get_tlv_type(this) < 0)
-		return tree;
-
 	/* display the TLV name and display the value in hex. Highlight type, length, and value. */
 	tlv_item = proto_tree_add_item(tree, hfindex, tvb, start, tlv_value_length, little_endian);
 
@@ -727,10 +723,6 @@ proto_tree *add_protocol_subtree(tlv_info_t *this, gint idx, proto_tree *tree, i
 	gchar *message = NULL;
 	gchar *hex_fmt;
 
-	/* Make sure we're dealing with a valid TLV here */
-	if (get_tlv_type(this) < 0)
-		return tree;
-    
 	/* Retrieve the necessary TLV information */
 	tlv_val_offset = get_tlv_value_offset(this);
 	start_of_tlv = start - tlv_val_offset;
@@ -808,11 +800,13 @@ static void dissect_wimax(tvbuff_t *tvb _U_, packet_info *pinfo, proto_tree *tre
 	col_clear(pinfo->cinfo, COL_INFO);
 }
 
-gboolean is_down_link(address *src_address)
+gboolean is_down_link(packet_info *pinfo)
 {
-	if(bs_address.len && !CMP_ADDRESS(&bs_address, src_address))
+	if (pinfo->p2p_dir == P2P_DIR_RECV)
 		return TRUE;
-
+	if (pinfo->p2p_dir == P2P_DIR_UNKNOWN)
+		if(bs_address.len && !CMP_ADDRESS(&bs_address, &pinfo->src))
+			return TRUE;
 	return FALSE;
 }
 
