@@ -5,7 +5,7 @@
  *
  * Author: Mike Harvey <michael.harvey@intel.com>
  *
- * $Id: wimax_bits.h 25528 2008-06-23 09:24:32Z martinm $
+ * $Id: wimax_bits.h 35590 2011-01-19 22:53:46Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -222,11 +222,5 @@
 #define NIB_TO_BYTE(n)  ((n) / 2)
 #define NIB_TO_BIT(n)   ((n) * 4)
 
-
-
-#ifndef UNREFERENCED_PARAMETER
-#define UNREFERENCED_PARAMETER(x) (x) = (x)
-#endif
-
 #endif
 
