@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: wimax_pdu_decoder.c 32426 2010-04-08 15:21:07Z etxrab $
+ * $Id: wimax_pdu_decoder.c 39262 2011-10-05 01:00:06Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,7 @@ extern void dissect_mac_header_generic_decoder(tvbuff_t *tvb, packet_info *pinfo
 extern void dissect_mac_header_type_1_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 extern void dissect_mac_header_type_2_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 extern void dissector_wimax_harq_map_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
-extern gboolean is_down_link(address *src_address);
+extern gboolean is_down_link(packet_info *pinfo);
 extern gint wimax_decode_dlmap_reduced_aas(tvbuff_t *tvb, packet_info *pinfo, proto_tree *base_tree);
 extern gint wimax_decode_dlmapc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *pdu_tree);
 
@@ -113,7 +113,7 @@ static void dissect_wimax_pdu_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 			/* add subtree */
 		        pdu_tree = proto_item_add_subtree(pdu_item, ett_wimax_pdu_decoder);
 			/* display the padding in Hex */
-			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, FALSE);
+			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, ENC_NA);
 			break;
 		}
 		else if((first_byte & WIMAX_MAP_TYPE_MASK) == WIMAX_HARQ_MAP_MSG_IND)
@@ -130,7 +130,7 @@ static void dissect_wimax_pdu_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 		}
 		else if((first_byte & WIMAX_MAP_TYPE_MASK) == WIMAX_COMPRESSED_DL_MAP_IND)
 		{
-			if(is_down_link(&pinfo->src))
+			if(is_down_link(pinfo))
 			{	/* decode compressed dl-map without mac header */
 				if ((first_byte & REDUCED_PRIVATE_MAP_MASK) == REDUCED_PRIVATE_MAP_MASK)
 				{
@@ -153,7 +153,7 @@ static void dissect_wimax_pdu_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 			/* add subtree */
 			pdu_tree = proto_item_add_subtree(pdu_item, ett_wimax_pdu_decoder);
 				/* display the invalid MAC Header in Hex */
-			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, FALSE);
+			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, ENC_NA);
 			break;
 		}
 		/* calculate the MAC header HCS */
@@ -170,7 +170,7 @@ static void dissect_wimax_pdu_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
 			/* add subtree */
 		        pdu_tree = proto_item_add_subtree(pdu_item, ett_wimax_pdu_decoder);
 			/* display the bad MAC Header in Hex */
-			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, FALSE);
+			proto_tree_add_item(pdu_tree, hf_wimax_value_bytes, tvb, offset, length, ENC_NA);
 			break;
 		}
 		/* get the Header Type (HT) */
