@@ -1,7 +1,7 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c 40204 2011-12-14 21:13:06Z cmaynard $
+ * $Id: print.c 42053 2012-04-13 20:22:31Z darkjames $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -1671,7 +1671,7 @@ const gchar* get_node_field_value(field_info* fi, epan_dissect_t* edt)
                 return fi->rep->representation;
             } else {
                 /* Just print out the protocol abbreviation */
-                return fi->hfinfo->abbrev;;
+                return fi->hfinfo->abbrev;
             }
         case FT_NONE:
             /* Return "1" so that the presence of a field of type
