@@ -1,7 +1,7 @@
 /* proto_hier_stats.c
  * Routines for calculating statistics based on protocol.
  *
- * $Id: proto_hier_stats.c 36881 2011-04-27 02:54:44Z guy $
+ * $Id: proto_hier_stats.c 40529 2012-01-16 01:07:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 
 #include "globals.h"
 #include "proto_hier_stats.h"
-#include "progress_dlg.h"
+#include "ui/progress_dlg.h"
 #include <epan/epan_dissect.h>
 #include <wtap.h>
 
