@@ -4,7 +4,7 @@
  * Creates random packet traces. Useful for debugging sniffers by testing
  * assumptions about the veracity of the data found in the packet.
  *
- * $Id: randpkt.c 38856 2011-09-02 00:16:14Z gerald $
+ * $Id: randpkt.c 38437 2011-08-09 21:02:10Z morriss $
  *
  * Copyright (C) 1999 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -47,6 +47,7 @@
 #include <string.h>
 #include <glib.h>
 #include "wiretap/wtap.h"
+#include "wsutil/file_util.h"
 
 #ifdef _WIN32
 #include <wsutil/unicode-utils.h>
@@ -703,7 +704,7 @@ seed(void)
 	 *
 	 * XXX - Use CryptGenRandom on Windows?
 	 */
-	fd = open(RANDOM_DEV, O_RDONLY);
+	fd = ws_open(RANDOM_DEV, O_RDONLY);
 	if (fd == -1) {
 		if (errno != ENOENT) {
 			fprintf(stderr,
@@ -714,7 +715,7 @@ seed(void)
 		goto fallback;
 	}
 
-	ret = read(fd, &randomness, sizeof randomness);
+	ret = ws_read(fd, &randomness, sizeof randomness);
 	if (ret == -1) {
 		fprintf(stderr,
 		    "randpkt: Could not read from " RANDOM_DEV ": %s\n",
@@ -728,6 +729,7 @@ seed(void)
 		exit(2);
 	}
 	srand(randomness);
+	ws_close(fd);
 	return;
 
 fallback:
