@@ -2,7 +2,7 @@
  * Low-level synchronization pipe routines for use by Wireshark/TShark
  * and dumpcap
  *
- * $Id: sync_pipe.h 32843 2010-05-17 18:40:23Z guy $
+ * $Id: sync_pipe.h 40366 2012-01-04 03:02:13Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -78,4 +78,10 @@ extern void
 sync_pipe_errmsg_to_parent(int pipe_fd, const char *error_msg,
                            const char *secondary_error_msg);
 
+/** Has the parent signalled the child to stop? */
+#define SIGNAL_PIPE_CTRL_ID_NONE "none"
+#ifdef _WIN32
+#define SIGNAL_PIPE_FORMAT "\\\\.\\pipe\\wireshark.%s.signal"
+#endif
+
 #endif /* sync_pipe.h */
