@@ -4,7 +4,7 @@
  * Copyright 2008 Ericsson AB
  * By Balint Reczey <balint.reczey@ericsson.com>
  *
- * $Id: tap-megaco-common.c 35706 2011-01-30 21:56:05Z wmeier $
+ * $Id: tap-megaco-common.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,10 +29,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <epan/packet_info.h>
