@@ -1,17 +1,20 @@
 #!/bin/bash
 
+
 # Compare ABIs of two Wireshark working copies
-# $Id: $
+# $Id: compare-abis.sh 40597 2012-01-19 22:55:52Z rbalint $
+
+# Tested with abi-compliance-checker 1.96.1
 
 function acc () {
 	LIBNAME=$1
 	DIR=$2
 	# compare only dumped ABI descriptions first, then fall back to full comparison
 	# if no difference is found
-	if abi-compliance-checker -separately -l $LIBNAME \
+	if abi-compliance-checker -l $LIBNAME \
 		-d1 $V1_PATH/$DIR/.libs/$LIBNAME.abi.tar.gz \
 		-d2 $V2_PATH/$DIR/.libs/$LIBNAME.abi.tar.gz ; then
-		abi-compliance-checker -separately -l $LIBNAME \
+		abi-compliance-checker -l $LIBNAME \
 			-d1 $V1_PATH/$DIR/abi-descriptor.xml -relpath1 $V1_PATH/$DIR \
 			-v1 `ls  $V1_PATH/$DIR/.libs/$LIBNAME.so.?.?.?|sed 's/.*\.so\.//'` \
 			-d2 $V2_PATH/$DIR/abi-descriptor.xml -relpath2 $V2_PATH/$DIR \
@@ -29,8 +32,8 @@ V2_PATH=$2
 
 acc libwiretap wiretap $V1_PATH $V2_PATH
 RET=$?
-acc libwsutil wsutil $V1_PATH $V2_PATH 
+acc libwsutil wsutil $V1_PATH $V2_PATH
 RET=$(($RET + $?))
-acc libwireshark epan $V1_PATH $V2_PATH 
+acc libwireshark epan $V1_PATH $V2_PATH
 exit $(($RET + $?))
 
