@@ -1,7 +1,7 @@
 /* u3.h
  * u3   2006 Graeme Lunt
  *
- * $Id: u3.h 35046 2010-11-28 00:15:21Z sfisher $
+ * $Id: u3.h 40633 2012-01-21 18:56:01Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,6 +25,10 @@
 #ifndef __U3_H__
 #define __U3_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 gboolean u3_active(void);
 
 void u3_runtime_info(GString *str);
@@ -35,4 +39,8 @@ void u3_deregister_pid(void);
 char * u3_expand_device_path(char *path);
 char * u3_contract_device_path(char *path);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* __U3_H__ */
