@@ -2,7 +2,7 @@
  * Routines to put up various "standard" alert boxes used in multiple
  * places
  *
- * $Id: alert_box.c 41436 2012-03-08 17:30:02Z guy $
+ * $Id: alert_box.c 43322 2012-06-17 22:33:11Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,7 +44,7 @@
 void
 failure_alert_box(const char *msg_format, va_list ap)
 {
-  vsimple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, msg_format, ap);
+  vsimple_error_message_box(msg_format, ap);
 }
 
 /*
@@ -62,8 +62,13 @@ failure_alert_box(const char *msg_format, va_list ap)
 void
 open_failure_alert_box(const char *filename, int err, gboolean for_writing)
 {
-  simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                file_open_error_message(err, for_writing), filename);
+  gchar *display_basename;
+
+  display_basename = g_filename_display_basename(filename);
+  simple_message_box(ESD_TYPE_ERROR, NULL, NULL,
+                     file_open_error_message(err, for_writing),
+                     display_basename);
+  g_free(display_basename);
 }
 
 /*
@@ -73,9 +78,13 @@ open_failure_alert_box(const char *filename, int err, gboolean for_writing)
 void
 read_failure_alert_box(const char *filename, int err)
 {
-  simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                "An error occurred while reading from the file \"%s\": %s.",
-                filename, g_strerror(err));
+  gchar *display_basename;
+
+  display_basename = g_filename_display_basename(filename);
+  simple_message_box(ESD_TYPE_ERROR, NULL, NULL,
+                     "An error occurred while reading from the file \"%s\": %s.",
+                     display_basename, g_strerror(err));
+  g_free(display_basename);
 }
 
 /*
@@ -92,43 +101,27 @@ read_failure_alert_box(const char *filename, int err)
 void
 write_failure_alert_box(const char *filename, int err)
 {
+  gchar *display_basename;
+
+  display_basename = g_filename_display_basename(filename);
   if (err < 0) {
     switch (err) {
 
     case WTAP_ERR_SHORT_WRITE:
-      simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                    "A full write couldn't be done to the file \"%s\".",
-                    filename);
+      simple_message_box(ESD_TYPE_ERROR, NULL, NULL,
+                         "A full write couldn't be done to the file \"%s\".",
+                         display_basename);
       break;
     
     default:
-      simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                    "An error occurred while writing to the file \"%s\": %s.",
-                    filename, wtap_strerror(err));
+      simple_message_box(ESD_TYPE_ERROR, NULL, NULL,
+                         "An error occurred while writing to the file \"%s\": %s.",
+                         display_basename, wtap_strerror(err));
       break;
     }
   } else {
-    simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                  file_write_error_message(err), filename);
+    simple_message_box(ESD_TYPE_ERROR, NULL, NULL,
+                       file_write_error_message(err), display_basename);
   }
-}
-
-/*
- * Alert box for an invalid display filter expression.
- * Assumes "dfilter_error_msg" has been set by "dfilter_compile()" to the
- * error message for the filter.
- *
- * XXX - should this have a "Help" button that pops up the display filter
- * help?
- */
-void
-bad_dfilter_alert_box(const char *dftext)
-{
-  simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, 
-                "%s%s%s\n"
-                "\n"
-                "The filter expression \"%s\" isn't a valid display filter.\n"
-                "See the help for a description of the display filter syntax.",
-                simple_dialog_primary_start(), dfilter_error_msg,
-                simple_dialog_primary_end(), dftext);
+  g_free(display_basename);
 }
