@@ -2,7 +2,7 @@
  * Routines to put up various "standard" alert boxes used in multiple
  * places
  *
- * $Id: alert_box.h 40529 2012-01-16 01:07:52Z guy $
+ * $Id: alert_box.h 43081 2012-06-04 20:08:59Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -56,13 +56,6 @@ extern void read_failure_alert_box(const char *filename, int err);
  */
 extern void write_failure_alert_box(const char *filename, int err);
 
-/*
- * Alert box for an invalid display filter expression.
- * Assumes "dfilter_error_msg" has been set by "dfilter_compile()" to the
- * error message for the filter.
- */
-extern void bad_dfilter_alert_box(const char *dftext);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
