@@ -2,7 +2,7 @@
  * Based on
  * smbstat   2003 Ronnie Sahlberg
  *
- * $Id: tap-afpstat.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-afpstat.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,10 +29,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <epan/packet_info.h>
 #include <epan/tap.h>
