@@ -2,7 +2,7 @@
  * camel message counter for tshark
  * Copyright 2006 Florent DROUIN
  *
- * $Id: tap-camelcounter.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-camelcounter.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * This part of code is extracted from tap-h225counter.c from Lars Roland
  *
@@ -31,10 +31,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include "epan/packet.h"
 #include "epan/packet_info.h"
