@@ -3,7 +3,7 @@
  * Copyright 2008 Vincenzo Condoleo, Christophe Dirac, Reto Ruoss
  * supported by HSR (Hochschule Rapperswil)
  *
- * $Id: tap-comparestat.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-comparestat.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,10 +39,6 @@
 #include <stdio.h>
 #include <math.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include "epan/packet_info.h"
 #include <epan/in_cksum.h>
@@ -315,7 +311,7 @@ call_foreach_merge_settings(gpointer value, gpointer arg)
 	if((fInfo->num==tot_packet_amount)&&(cs->stop_packet_nr_first!=G_MAXINT32)){
 		/* calculate missing stop number */
 		swap=cs->stop_packet_nr_first;
-		cs->stop_packet_nr_first=tot_packet_amount-cs->second_file_amount;;
+		cs->stop_packet_nr_first=tot_packet_amount-cs->second_file_amount;
 		cs->stop_packet_nr_second=swap;
 	}
 
