@@ -1,7 +1,7 @@
 /* tap-diameter-avp.c
  * Copyright 2010 Andrej Kuehnal <andrejk@freenet.de>
  *
- * $Id: tap-diameter-avp.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-diameter-avp.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,10 +42,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include "epan/packet_info.h"
 #include <epan/tap.h>
