@@ -1,7 +1,7 @@
 /* tap-icmpv6stat.c
  * icmpv6stat   2011 Christopher Maynard
  *
- * $Id: tap-icmpv6stat.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-icmpv6stat.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,10 +35,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include "epan/packet_info.h"
 #include <epan/tap.h>
@@ -124,27 +120,28 @@ icmpv6stat_packet(void *tapdata, packet_info *pinfo _U_, epan_dissect_t *edt _U_
 {
     icmpv6stat_t *icmpv6stat = tapdata;
     const icmp_transaction_t *trans = data;
-    double *rt;
+    double resp_time, *rt;
 
     if (trans == NULL)
         return 0;
 
     if (trans->resp_frame) {
+        resp_time = nstime_to_msec(&trans->resp_time);
         rt = g_malloc(sizeof(double));
         if (rt == NULL)
             return 0;
-        *rt = trans->resp_time;
+        *rt = resp_time;
         icmpv6stat->rt_list = g_slist_insert_sorted(icmpv6stat->rt_list, rt, compare_doubles);
         icmpv6stat->num_resps++;
-        if (icmpv6stat->min_msecs > trans->resp_time) {
+        if (icmpv6stat->min_msecs > resp_time) {
             icmpv6stat->min_frame = trans->resp_frame;
-            icmpv6stat->min_msecs = trans->resp_time;
+            icmpv6stat->min_msecs = resp_time;
         }
-        if (icmpv6stat->max_msecs < trans->resp_time) {
+        if (icmpv6stat->max_msecs < resp_time) {
             icmpv6stat->max_frame = trans->resp_frame;
-            icmpv6stat->max_msecs = trans->resp_time;
+            icmpv6stat->max_msecs = resp_time;
         }
-        icmpv6stat->tot_msecs += trans->resp_time;
+        icmpv6stat->tot_msecs += resp_time;
     } else if (trans->rqst_frame)
         icmpv6stat->num_rqsts++;
     else
