@@ -1,7 +1,7 @@
 /* tap-macltestat.c
  * Copyright 2011 Martin Mathieson
  *
- * $Id: tap-macltestat.c 41948 2012-04-05 00:53:01Z martinm $
+ * $Id: tap-macltestat.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,10 +29,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <epan/packet.h>
 #include <epan/packet_info.h>
