@@ -1,7 +1,7 @@
 /* tap-rtp.c
  * RTP TAP for tshark
  *
- * $Id: tap-rtp.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-rtp.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Copyright 2008, Ericsson AB
  * By Balint Reczey <balint.reczey@ericsson.com>
@@ -39,10 +39,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <locale.h>
 #include "epan/packet_info.h"
