@@ -1,6 +1,6 @@
 /* tap-scsistat.c	2010 Chris Costa and Cal Turney
  *
- * $Id: tap-scsistat.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-scsistat.c 42446 2012-05-05 21:29:13Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <epan/packet_info.h>
 #include <epan/epan.h>
