@@ -1,7 +1,7 @@
 /* tap-sv.c
  * Copyright 2008 Michael Bernhard
  *
- * $Id: tap-sv.c 41047 2012-02-17 12:30:27Z jmayer $
+ * $Id: tap-sv.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,10 +30,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <epan/packet_info.h>
 #include <epan/tap.h>
