@@ -1,6 +1,6 @@
 /* about_dlg.c
  *
- * $Id: about_dlg.c 41893 2012-04-02 11:35:53Z etxrab $
+ * $Id: about_dlg.c 43125 2012-06-05 22:19:20Z gerald $
  *
  * Ulf Lamping <ulf.lamping@web.de>
  *
@@ -55,7 +55,7 @@
 #include "ui/gtk/plugins_dlg.h"
 #include "ui/gtk/gui_utils.h"
 
-#include "../../image/wssplash-dev.xpm"
+#include "../../image/wssplash.xpm"
 #include "webbrowser.h"
 
 /*
@@ -235,7 +235,7 @@ splash_update(register_action_e action, const char *message, gpointer client_dat
 	action_msg = "Loading configuration files ...";
 	break;
       default:
-	action_msg = "(Unknown action)";;
+	action_msg = "(Unknown action)";
 	break;
       }
       splash_update_label(win, action_msg);
