@@ -1,7 +1,7 @@
 /* bootp_stat.c
  * boop_stat   2003 Jean-Michel FAYARD
  *
- * $Id: bootp_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: bootp_stat.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -222,7 +222,7 @@ dhcpstat_init(const char *optarg, void *userdata _U_)
 	gtk_window_set_destroy_with_parent (GTK_WINDOW(sp->win), TRUE);
 	g_free(title);
 
-	vbox = gtk_vbox_new(FALSE, 3);
+	vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_add(GTK_CONTAINER(sp->win), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
