@@ -2,7 +2,7 @@
  * camel message counter for Wireshark
  * Copyright 2006 Florent Drouin (based on h225_counter.c from Lars Roland)
  *
- * $Id: camel_counter.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: camel_counter.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,9 +27,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -176,7 +173,7 @@ static void gtk_camelcounter_init(const char *optarg, void *userdata _U_)
 
 	gtk_window_set_default_size(GTK_WINDOW(p_camelcounter->win), 500, 300);
 
-  p_camelcounter->vbox=gtk_vbox_new(FALSE, 3);
+  p_camelcounter->vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(p_camelcounter->vbox), 12);
 
   init_main_stat_window(p_camelcounter->win, p_camelcounter->vbox, "CAMEL Messages Counters", filter);
