@@ -1,7 +1,7 @@
 /* capture_if_dlg.h
  * Definitions for packet capture interface windows
  *
- * $Id: capture_if_dlg.h 41105 2012-02-21 11:59:41Z tuexen $
+ * $Id: capture_if_dlg.h 43283 2012-06-16 18:17:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,13 +25,17 @@
 #ifndef __CAPTURE_IF_DLG_H__
 #define __CAPTURE_IF_DLG_H__
 
-/** User requested the "Capture Interfaces" dialog box by menu or toolbar.
+/** A live capture has started or stopped.
  *
  * @param capture_in_progress capture is in progress
  */
 void
 set_capture_if_dialog_for_capture_in_progress(gboolean capture_in_progress);
 
+/** A live capture is being stopped.
+ */
+void set_capture_if_dialog_for_capture_stopping(void);
+
 /** User requested the "Capture Interfaces" dialog box by menu or toolbar.
  *
  * @param widget parent widget (unused)
