@@ -1,7 +1,7 @@
 /* capture_info_dlg.c
  * Routines for packet capture info dialog
  *
- * $Id: capture_info_dlg.c 40518 2012-01-15 21:59:11Z jmayer $
+ * $Id: capture_info_dlg.c 43009 2012-06-02 23:53:04Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,10 +28,6 @@
 
 #ifdef HAVE_LIBPCAP
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <time.h>
 
@@ -204,7 +200,7 @@ capture_options *capture_opts)
   g_free(cap_w_title);
 
   /* Container for capture display widgets */
-  main_vb = gtk_vbox_new(FALSE, 1);
+  main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 1, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
   gtk_container_add(GTK_CONTAINER(info->cap_w), main_vb);
   gtk_widget_show(main_vb);
