@@ -1,7 +1,7 @@
 /* conversations_sctp.c
  * conversations_sctp   2005 Oleg Terletsky <oleg.terletsky@comverse.com>
  *
- * $Id: conversations_sctp.c 40518 2012-01-15 21:59:11Z jmayer $
+ * $Id: conversations_sctp.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,9 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
 #include <string.h>
 
 #include <gtk/gtk.h>
