@@ -1,6 +1,6 @@
 /* decode_as_ber.c
  *
- * $Id: decode_as_ber.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: decode_as_ber.c 42161 2012-04-20 14:56:24Z etxrab $
  *
  * Routines to modify BER decoding on the fly.
  *
@@ -121,12 +121,12 @@ decode_ber_add_page (packet_info *pinfo _U_)
     GtkWidget	*page_hb, *info_vb, *label, *scrolled_window;
 
     /* create page content */
-    page_hb = gtk_hbox_new(FALSE, 5);
+    page_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     g_object_set_data(G_OBJECT(page_hb), E_PAGE_ACTION, decode_ber);
     g_object_set_data(G_OBJECT(page_hb), E_PAGE_TABLE, "ASN.1");
     g_object_set_data(G_OBJECT(page_hb), E_PAGE_TITLE, "ASN.1");
 
-    info_vb = gtk_vbox_new(FALSE, 5);
+    info_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 5, FALSE);
     gtk_box_pack_start(GTK_BOX(page_hb), info_vb, TRUE, TRUE, 0);
 
     /* Always enabled */
