@@ -1,6 +1,6 @@
 /* decode_as_dlg.c
  *
- * $Id: decode_as_dlg.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: decode_as_dlg.c 42991 2012-06-01 21:18:59Z morriss $
  *
  * Routines to modify dissector tables on the fly.
  *
@@ -679,6 +679,7 @@ decode_show_save_cb (GtkWidget *win _U_, gpointer user_data _U_)
       "Can't create directory\n\"%s\"\nfor recent file: %s.", pf_dir_path,
       g_strerror(errno));
      g_free(pf_dir_path);
+     return;
   }
 
   daf_path = get_persconffile_path(DECODE_AS_ENTRIES_FILE_NAME, TRUE, TRUE);
@@ -687,6 +688,7 @@ decode_show_save_cb (GtkWidget *win _U_, gpointer user_data _U_)
       "Can't open decode_as_entries file\n\"%s\": %s.", daf_path,
       g_strerror(errno));
     g_free(daf_path);
+    return;
   }
 
   fputs("# \"Decode As\" entries file for Wireshark " VERSION ".\n"
@@ -736,7 +738,7 @@ decode_show_cb (GtkWidget *w _U_, gpointer user_data _U_)
     gtk_window_set_default_size(GTK_WINDOW(decode_show_w), -1, E_DECODE_MIN_HEIGHT);
 
     /* Container for each row of widgets */
-    main_vb = gtk_vbox_new(FALSE, 2);
+    main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 2, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
     gtk_container_add(GTK_CONTAINER(decode_show_w), main_vb);
 
@@ -1214,7 +1216,7 @@ decode_add_yes_no (void)
     GtkWidget   *format_vb, *radio_button;
     GSList      *format_grp;
 
-    format_vb = gtk_vbox_new(FALSE, 2);
+    format_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 2, FALSE);
 
     radio_button = gtk_radio_button_new_with_label(NULL, "Decode");
     format_grp = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radio_button));
@@ -1303,19 +1305,18 @@ decode_add_ppid_combo_box (GtkWidget *page)
 
     combo_box = ws_combo_box_new_text_and_pointer();
 
-    g_snprintf(tmp, sizeof(tmp), "PPID (%u)", 0);
-    ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(combo_box),
-                                         tmp, GINT_TO_POINTER(E_DECODE_PPID));
-    ws_combo_box_set_active(GTK_COMBO_BOX(combo_box), 0);  /* default */
-
     for(number_of_ppid = 0; number_of_ppid < MAX_NUMBER_OF_PPIDS; number_of_ppid++) {
-      if (cfile.edt->pi.ppids[number_of_ppid] != 0) {
-          g_snprintf(tmp, sizeof(tmp), "PPID (%u)", cfile.edt->pi.ppids[number_of_ppid]);
-          ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(combo_box),
-                                               tmp, GINT_TO_POINTER(E_DECODE_PPID + 1 + number_of_ppid));
-      } else
-          break;
+        if (cfile.edt->pi.ppids[number_of_ppid] != LAST_PPID) {
+            g_snprintf(tmp, sizeof(tmp), "PPID (%u)", cfile.edt->pi.ppids[number_of_ppid]);
+            ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(combo_box),
+                                                 tmp, GINT_TO_POINTER(E_DECODE_PPID + 1 + number_of_ppid));
+        } else
+            break;
     }
+
+    if (number_of_ppid)
+        ws_combo_box_set_active(GTK_COMBO_BOX(combo_box), 0);  /* default */
+
     g_object_set_data(G_OBJECT(page), E_COMBO_BOX_SRCDST, combo_box);
     return(combo_box);
 }
@@ -1581,7 +1582,7 @@ decode_add_simple_page (const gchar *prompt, const gchar *title, const gchar *ta
 {
     GtkWidget  *page, *label, *scrolled_window;
 
-    page = gtk_hbox_new(FALSE, 5);
+    page = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     g_object_set_data(G_OBJECT(page), E_PAGE_ACTION, decode_simple);
     g_object_set_data(G_OBJECT(page), E_PAGE_TABLE, (gchar *) table_name);
     g_object_set_data(G_OBJECT(page), E_PAGE_TITLE, (gchar *) title);
@@ -1631,7 +1632,7 @@ decode_add_tcpudp_page (const gchar *prompt, const gchar *table_name)
 {
     GtkWidget  *page, *label, *scrolled_window, *combo_box;
 
-    page = gtk_hbox_new(FALSE, 5);
+    page = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     g_object_set_data(G_OBJECT(page), E_PAGE_ACTION, decode_transport);
     g_object_set_data(G_OBJECT(page), E_PAGE_TABLE, (gchar *) table_name);
     g_object_set_data(G_OBJECT(page), E_PAGE_TITLE, "Transport");
@@ -1701,18 +1702,18 @@ decode_sctp_update_ppid_combo_box(GtkWidget *w _U_, GtkWidget *page)
     sctp_combo_box = g_object_get_data(G_OBJECT(page), E_COMBO_BOX_SRCDST);
     ws_combo_box_clear_text_and_pointer(GTK_COMBO_BOX(sctp_combo_box));
 
-    g_snprintf(tmp, sizeof(tmp), "PPID (%u)", 0);
-    ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(sctp_combo_box), tmp, GINT_TO_POINTER(E_DECODE_PPID));
-    ws_combo_box_set_active(GTK_COMBO_BOX(sctp_combo_box), 0); /* default */
-
     for(number_of_ppid = 0; number_of_ppid < MAX_NUMBER_OF_PPIDS; number_of_ppid++) {
-      if (cfile.edt->pi.ppids[number_of_ppid] != 0) {
-        g_snprintf(tmp, sizeof(tmp), "PPID (%u)", cfile.edt->pi.ppids[number_of_ppid]);
-        ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(sctp_combo_box),
-                                             tmp, GINT_TO_POINTER(E_DECODE_PPID + 1 + number_of_ppid));
-      }
+        if (cfile.edt->pi.ppids[number_of_ppid] != LAST_PPID) {
+            g_snprintf(tmp, sizeof(tmp), "PPID (%u)", cfile.edt->pi.ppids[number_of_ppid]);
+            ws_combo_box_append_text_and_pointer(GTK_COMBO_BOX(sctp_combo_box),
+                                                 tmp, GINT_TO_POINTER(E_DECODE_PPID + 1 + number_of_ppid));
+        } else
+            break;
     }
 
+    if (number_of_ppid)
+        ws_combo_box_set_active(GTK_COMBO_BOX(sctp_combo_box), 0); /* default */
+
     g_object_set_data(G_OBJECT(page), E_PAGE_TABLE, "sctp.ppi");
 
     sctp_store = g_object_get_data(G_OBJECT(G_OBJECT(decode_w)), "sctp_data");
@@ -1759,7 +1760,7 @@ decode_sctp_add_port_ppid (GtkWidget *page)
     GtkWidget *format_vb, *radio_button;
     GSList *format_grp;
 
-    format_vb = gtk_vbox_new(FALSE, 2);
+    format_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 2, FALSE);
 
     radio_button = gtk_radio_button_new_with_label(NULL, "PPID");
     format_grp = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radio_button));
@@ -1782,17 +1783,17 @@ decode_add_sctp_page (const gchar *prompt, const gchar *table_name)
 {
     GtkWidget  *page, *label, *scrolled_window,  *radio, *vbox, *alignment, *sctpbox, *sctp_combo_box;
 
-    page = gtk_hbox_new(FALSE, 5);
+    page = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     g_object_set_data(G_OBJECT(page), E_PAGE_ACTION, decode_transport);
     g_object_set_data(G_OBJECT(page), E_PAGE_TABLE, (gchar *) table_name);
     g_object_set_data(G_OBJECT(page), E_PAGE_TITLE, "Transport");
 
-    vbox = gtk_vbox_new(FALSE, 5);
+    vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 5, FALSE);
     radio = decode_sctp_add_port_ppid(page);
     gtk_box_pack_start(GTK_BOX(vbox), radio, TRUE, TRUE, 0);
 
     /* Always enabled */
-    sctpbox = gtk_hbox_new(FALSE, 5);
+    sctpbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     label = gtk_label_new(prompt);
     gtk_box_pack_start(GTK_BOX(sctpbox), label, TRUE, TRUE, 0);
     sctp_combo_box = decode_add_ppid_combo_box(page);
@@ -1956,12 +1957,12 @@ decode_as_cb (GtkWidget * w _U_, gpointer user_data _U_)
     gtk_window_set_default_size(GTK_WINDOW(decode_w), -1, E_DECODE_MIN_HEIGHT);
 
     /* Container for each row of widgets */
-    main_vb = gtk_vbox_new(FALSE, 2);
+    main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 2, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
     gtk_container_add(GTK_CONTAINER(decode_w), main_vb);
 
     /* First row - Buttons and Notebook */
-    format_hb = gtk_hbox_new(FALSE, 5);
+    format_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     gtk_box_pack_start(GTK_BOX(main_vb), format_hb, TRUE, TRUE, 10);
 
     button_vb = decode_add_yes_no();
@@ -1975,7 +1976,7 @@ decode_as_cb (GtkWidget * w _U_, gpointer user_data _U_)
     GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 #endif
     gtk_box_pack_start(GTK_BOX(button_vb), button, FALSE, FALSE, 0);
-	gtk_widget_set_tooltip_text(button, "Open a dialog showing the current settings.\n" 
+	gtk_widget_set_tooltip_text(button, "Open a dialog showing the current settings.\n"
 		"Note you need to select and press apply first to be able to save the current setting");
 
     button = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
