@@ -1,7 +1,7 @@
 /* dlg_utils.c
  * Utilities to use when constructing dialogs
  *
- * $Id: dlg_utils.c 41412 2012-03-08 01:24:31Z gerald $
+ * $Id: dlg_utils.c 42186 2012-04-21 20:45:35Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -222,16 +222,16 @@ dlg_button_row_new(const gchar *stock_id_first, ...)
     }
     va_end(stock_id_list);
 
-    hbox = gtk_hbox_new(FALSE, 0);
+    hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_widget_show(hbox);
 
-    button_hbox = gtk_hbutton_box_new();
+    button_hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_end(GTK_BOX(hbox), button_hbox, TRUE, TRUE, 0);
     g_object_set_data(G_OBJECT(hbox), BUTTON_HBOX_KEY, button_hbox);
     gtk_widget_show(button_hbox);
     gtk_box_set_spacing(GTK_BOX(button_hbox), DLG_BUTTON_SPACING);
 
-    help_hbox = gtk_hbutton_box_new();
+    help_hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_end(GTK_BOX(hbox), help_hbox, FALSE, FALSE, 0);
     gtk_widget_show(help_hbox);
     gtk_box_set_spacing(GTK_BOX(help_hbox), DLG_BUTTON_SPACING);
