@@ -2,7 +2,7 @@
  * Common routines for tracking & saving objects found in streams of data
  * Copyright 2007, Stephen Fisher (see AUTHORS file)
  *
- * $Id: export_object.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: export_object.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -455,7 +455,7 @@ export_object_window(const gchar *tapname, const gchar *name, tap_packet_cb tap_
 	gtk_window_set_default_size(GTK_WINDOW(object_list->dlg),
 				    DEF_WIDTH, DEF_HEIGHT);
 
-	vbox = gtk_vbox_new(FALSE, 5);
+	vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 5, FALSE);
 
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(object_list->dlg), vbox);
