@@ -1,7 +1,7 @@
 /* file_dlg.c
  * Utilities to use when constructing file selection dialogs
  *
- * $Id: file_dlg.c 40518 2012-01-15 21:59:11Z jmayer $
+ * $Id: file_dlg.c 43383 2012-06-19 19:22:47Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,6 +32,10 @@
 
 #include <wsutil/file_util.h>
 
+#ifndef _WIN32
+#include <epan/filesystem.h>
+#endif
+
 #include "ui/gtk/gtkglobals.h"
 #include "ui/gtk/gui_utils.h"
 #include "ui/gtk/file_dlg.h"
@@ -153,6 +157,111 @@ file_selection_set_extra_widget(GtkWidget *fs, GtkWidget *extra)
   gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(fs), extra);
 }
 
+#ifndef _WIN32
+/* If the specified file doesn't exist, return TRUE.
+   If it exists and is neither user-immutable nor not writable, return
+   TRUE.
+   Otherwise, as the user whether they want to overwrite it anyway, and
+   return TRUE if the file should be overwritten and FALSE otherwise. */
+gboolean
+file_target_unwritable_ui(GtkWidget *chooser_w, char *cf_name)
+{
+  GtkWidget     *msg_dialog;
+  gchar         *display_basename;
+  gint           response;
+  ws_statb64     statbuf;
+
+  /* Check whether the file has all the write permission bits clear
+     and, on systems that have the 4.4-Lite file flags, whether it
+     has the "user immutable" flag set.  Treat both of those as an
+     indication that the user wants to protect the file from
+     casual overwriting, and ask the user if they want to override
+     that.
+
+     (Linux's "immutable" flag, as fetched and set by the appropriate
+     ioctls (FS_IOC_GETFLAGS/FS_IOC_SETFLAGS in newer kernels,
+     EXT2_IOC_GETFLAGS/EXT2_IOC_SETFLAGS in older kernels - non-ext2
+     file systems that support those ioctls use the same values as ext2
+     does), appears to be more like the *BSD/OS X "system immutable"
+     flag, as it can be set only by the superuser or by processes with
+     CAP_LINUX_IMMUTABLE, so it sounds as if it's not intended for
+     arbitrary users to set or clear. */
+  if (ws_stat64(cf_name, &statbuf) == -1) {
+    /* Either the file doesn't exist or we can't get its attributes.
+       In the former case, we have no reason to bother the user.
+       In the latter case, we don't have enough information to
+       know whether to bother the user, so we don't. */
+    return TRUE;
+  }
+
+  /* OK, we have the permission bits and, if HAVE_ST_FLAGS is defined,
+     the flags.  (If we don't, we don't worry about it.) */
+#ifdef HAVE_ST_FLAGS
+  if (statbuf.st_flags & UF_IMMUTABLE) {
+    display_basename = g_filename_display_basename(cf_name);
+    msg_dialog = gtk_message_dialog_new(GTK_WINDOW(chooser_w),
+                                        GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        GTK_MESSAGE_QUESTION,
+                                        GTK_BUTTONS_NONE,
+#ifdef __APPLE__
+    /* Stuff in the OS X UI calls files with the "user immutable" bit
+       "locked"; pre-OS X Mac software might have had that notion and
+       called it "locked". */
+                                        "The file \"%s\" is locked.",
+#else /* __APPLE__ */
+    /* Just call it "immutable" in *BSD. */
+                                        "The file \"%s\" is immutable.",
+#endif /* __APPLE__ */
+                                        display_basename);
+    g_free(display_basename);
+  } else
+#endif /* HAVE_ST_FLAGS */
+  if ((statbuf.st_mode & (S_IWUSR|S_IWGRP|S_IWOTH)) == 0) {
+    display_basename = g_filename_display_basename(cf_name);
+    msg_dialog = gtk_message_dialog_new(GTK_WINDOW(chooser_w),
+                                        GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        GTK_MESSAGE_QUESTION,
+                                        GTK_BUTTONS_NONE,
+                                        "The file \"%s\" is read-only.",
+                                        display_basename);
+    g_free(display_basename);
+  } else {
+    /* No problem, just drive on. */
+    msg_dialog = NULL;
+  }
+  if (msg_dialog != NULL) {
+    /* OK, ask the user if they want to overwrite the file. */
+    gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msg_dialog),
+        "Do you want to overwrite it anyway?");
+
+    gtk_dialog_add_buttons(GTK_DIALOG(msg_dialog),
+                           "Overwrite", GTK_RESPONSE_ACCEPT,
+                           "Don't overwrite", GTK_RESPONSE_REJECT,
+                           NULL);
+    gtk_dialog_set_default_response(GTK_DIALOG(msg_dialog), GTK_RESPONSE_REJECT);
+
+    response = gtk_dialog_run(GTK_DIALOG(msg_dialog));
+    gtk_widget_destroy(msg_dialog);
+
+    if (response != GTK_RESPONSE_ACCEPT) {
+      /* The user doesn't want to overwrite this file. */
+      return FALSE;
+    }
+
+#ifdef HAVE_ST_FLAGS
+    /* OK, they want to overwrite the file.  If it has the "user
+       immutable" flag, we have to turn that off first, so we
+       can move on top of, or overwrite, the file. */
+    if (statbuf.st_flags & UF_IMMUTABLE) {
+      /* If this fails, the attempt to save will fail, so just
+         let that happen and pop up a "you lose" dialog. */
+      chflags(cf_name, statbuf.st_flags & ~UF_IMMUTABLE);
+    }
+#endif
+  }
+  return TRUE;
+}
+#endif
 
 /*
  * A generic select_file routine that is intended to be connected to
