@@ -2,7 +2,7 @@
  * Dialog to setup for import of a text file, like text2pcap
  * November 2010, Jaap Keuter <jaap.keuter@xs4all.nl>
  *
- * $Id: file_import_dlg.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: file_import_dlg.c 42855 2012-05-25 21:25:55Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -771,50 +771,19 @@ setup_file_import(GtkWidget *main_w)
 
 /*****************************************************************************/
 
-static void
-file_import_answered_cb(gpointer dialog _U_, gint btn, gpointer data)
-{
-    text_import_info_t *text_import_info;
-
-    switch (btn) {
-    case ESD_BTN_SAVE:
-        /* save file first */
-        file_save_as_cmd(after_save_no_action, NULL, FALSE);
-        break;
-    case ESD_BTN_DONT_SAVE:
-        cf_close(&cfile);
-        break;
-    case ESD_BTN_CANCEL:
-        return;
-    default:
-        g_assert_not_reached();
-    }
-
-    text_import_info = setup_file_import(data);
-    if (text_import_info)
-        file_import_open(text_import_info);
-}
-
 static void
 file_import_ok_cb(GtkWidget *widget _U_, gpointer data)
 {
     text_import_info_t *text_import_info;
 
-    if((cfile.state != FILE_CLOSED) && !cfile.user_saved && prefs.gui_ask_unsaved) {
-        gpointer dialog;
-        /* user didn't save his current file, ask him */
-        dialog = simple_dialog(ESD_TYPE_CONFIRMATION, ESD_BTNS_SAVE_DONTSAVE_CANCEL,
-                "%sSave capture file before opening a new one?%s\n\n"
-                "If you open a new capture file without saving, your capture data will be discarded.",
-                simple_dialog_primary_start(), simple_dialog_primary_end());
-        simple_dialog_set_cb(dialog, file_import_answered_cb, data);
-    } else {
-        /* unchanged file, just open a new one */
+    /* If there's unsaved data, let the user save it first.
+       If they cancel out of it, don't open the file. */
+    if (do_file_close(&cfile, FALSE, " before opening a new capture file")) {
+        /* open the new file */
         text_import_info = setup_file_import(data);
         if (text_import_info)
             file_import_open(text_import_info);
     }
-
 }
 
 /*****************************************************************************/
@@ -853,7 +822,7 @@ file_import_dlg_new(void)
     main_w = dlg_window_new("Wireshark: Import from Text");
     gtk_window_set_default_size(GTK_WINDOW(main_w), 400, 300);
 
-    main_vb = gtk_vbox_new(FALSE, 0);
+    main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(main_vb), 3);
     gtk_container_add(GTK_CONTAINER(main_w), main_vb);
 
@@ -864,7 +833,7 @@ file_import_dlg_new(void)
 
     g_object_set_data(G_OBJECT(main_w), INPUT_FRM_KEY, input_frm);
 
-    input_vb = gtk_vbox_new(FALSE, 0);
+    input_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(input_frm), input_vb);
 
     input_tb = gtk_table_new(2, 3, FALSE);
@@ -874,7 +843,7 @@ file_import_dlg_new(void)
     gtk_table_set_col_spacings(GTK_TABLE(input_tb), 5);
 
     /* Filename */
-    filename_hb = gtk_hbox_new(FALSE, 3);
+    filename_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(filename_hb), 3);
 
     filename_lbl = gtk_label_new("Filename:");
@@ -893,18 +862,18 @@ file_import_dlg_new(void)
     g_signal_connect(browse_bt, "clicked", G_CALLBACK(browse_file_cb), filename_te);
 
     /* Offsets */
-    offset_hb = gtk_hbox_new(FALSE, 3);
+    offset_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(offset_hb), 3);
     gtk_box_pack_start(GTK_BOX(input_vb), offset_hb, FALSE, FALSE, 0);
 
-    offset_lbl_vb = gtk_vbox_new(FALSE, 0);
+    offset_lbl_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(offset_hb), offset_lbl_vb, FALSE, FALSE, 0);
 
     offset_lbl = gtk_label_new("Offsets:");
     gtk_misc_set_alignment(GTK_MISC(offset_lbl), 1.0f, 0.0f);
     gtk_table_attach(GTK_TABLE(input_tb), offset_lbl, 0, 1, 1, 2, 0, 0, 0, 0);
 
-    offset_rb_vb = gtk_vbox_new(FALSE, 0);
+    offset_rb_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_table_attach_defaults(GTK_TABLE(input_tb), offset_rb_vb, 1, 2, 1, 2);
 
     /* First entry in the group */
@@ -927,7 +896,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(input_frm), INPUT_OFFSET_DEC_RB_KEY, offset_dec_rb);
 
     /* Time format */
-    timefmt_hb = gtk_hbox_new(FALSE, 3);
+    timefmt_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(timefmt_hb), 3);
     gtk_box_pack_start(GTK_BOX(input_vb), timefmt_hb, FALSE, FALSE, 0);
 
@@ -959,11 +928,11 @@ file_import_dlg_new(void)
 
     g_object_set_data(G_OBJECT(main_w), IMPORT_FRM_KEY, import_frm);
 
-    import_vb = gtk_vbox_new(FALSE, 0);
+    import_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(import_frm), import_vb);
 
     /* Encapsulation */
-    encap_hb = gtk_hbox_new(FALSE, 3);
+    encap_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(encap_hb), 3);
     gtk_box_pack_start(GTK_BOX(import_vb), encap_hb, FALSE, FALSE, 0);
 
@@ -987,15 +956,15 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(import_frm), IMPORT_HEADER_FRM_KEY, header_frm);
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_CB_KEY, header_cb);
 
-    header_hb = gtk_hbox_new(FALSE, 3);
+    header_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(header_hb), 3);
     gtk_container_add(GTK_CONTAINER(header_frm), header_hb);
 
-    header_rblbl_vb = gtk_vbox_new(FALSE, 0);
+    header_rblbl_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_hb), header_rblbl_vb, TRUE, TRUE, 0);
 
     /* Line 1 */
-    header_rblbl_1_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_1_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_1_hb, FALSE, FALSE, 2);
 
     /* First entry in the group */
@@ -1018,7 +987,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_ETYPE_TE_KEY, etype_te);
 
     /* Line 2 */
-    header_rblbl_2_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_2_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_2_hb, FALSE, FALSE, 2);
 
     header_ipv4_rb = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(header_eth_rb), "IPv4");
@@ -1040,7 +1009,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_PROT_TE_KEY, protocol_te);
 
     /* Line 3 */
-    header_rblbl_3_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_3_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_3_hb, FALSE, FALSE, 2);
 
     header_udp_rb = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(header_eth_rb), "UDP");
@@ -1062,7 +1031,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_SRC_PORT_TE_KEY, src_port_te);
 
     /* Line 4 */
-    header_rblbl_4_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_4_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_4_hb, FALSE, FALSE, 2);
 
     header_tcp_rb = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(header_eth_rb), "TCP");
@@ -1084,7 +1053,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_DST_PORT_TE_KEY, dst_port_te);
 
     /* Line 5 */
-    header_rblbl_5_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_5_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_5_hb, FALSE, FALSE, 2);
 
     header_sctp_rb = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(header_eth_rb), "SCTP");
@@ -1106,7 +1075,7 @@ file_import_dlg_new(void)
     g_object_set_data(G_OBJECT(header_frm), IMPORT_HEADER_TAG_TE_KEY, tag_te);
 
     /* Line 6 */
-    header_rblbl_6_hb = gtk_hbox_new(FALSE, 0);
+    header_rblbl_6_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_box_pack_start(GTK_BOX(header_rblbl_vb), header_rblbl_6_hb, FALSE, FALSE, 2);
 
     header_sctp_data_rb = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(header_eth_rb), "SCTP (DATA)");
@@ -1137,7 +1106,7 @@ file_import_dlg_new(void)
     g_signal_connect(encap_co, "changed", G_CALLBACK(encap_co_changed), header_frm);
 
     /* Frame length */
-    framelen_hb = gtk_hbox_new(FALSE, 3);
+    framelen_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(framelen_hb), 3);
     gtk_box_pack_start(GTK_BOX(import_vb), framelen_hb, FALSE, FALSE, 0);
 
