@@ -1,6 +1,6 @@
 /* firewall_rules_dlg.c
  *
- * $Id: firewall_dlg.c 40561 2012-01-18 19:38:34Z guy $
+ * $Id: firewall_dlg.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -139,8 +139,8 @@ static void sf_pf_ipv4_port(GString *rtxt, gchar *addr, guint32 port, port_type
 static void sf_netsh_ipv4_port(GString *rtxt, gchar *addr, guint32 port, port_type ptype, gboolean inbound, gboolean deny);
 
 typedef struct _fw_product_t {
-    gchar *name;
-    gchar *comment_pfx;
+    const gchar *name;
+    const gchar *comment_pfx;
     syntax_func mac_func;
     syntax_func ipv4_func;
     syntax_func port_func;
@@ -220,11 +220,11 @@ firewall_rule_cb(GtkWidget *w _U_, gpointer data _U_)
     gtk_container_set_border_width(GTK_CONTAINER(rule_w), 6);
 
     /* setup the container */
-    vbox = gtk_vbox_new(FALSE, 6);
+    vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     gtk_container_add(GTK_CONTAINER(rule_w), vbox);
 
     /* rule type selectors hbox */
-    hbox = gtk_hbox_new(FALSE, 1);
+    hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 1, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     /* product selector */
