@@ -5,7 +5,7 @@
  *
  * MUCH code modified from service_response_time_table.c.
  *
- * $Id: gsm_a_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: gsm_a_stat.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -406,7 +406,7 @@ gsm_a_stat_gtk_win_create(
     gtk_window_set_destroy_with_parent (GTK_WINDOW(dlg_p->win), TRUE);
     gtk_window_set_default_size(GTK_WINDOW(dlg_p->win), 490, 500);
 
-    vbox = gtk_vbox_new(FALSE, 3);
+    vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
     gtk_container_add(GTK_CONTAINER(dlg_p->win), vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
