@@ -6,7 +6,7 @@
  *
  * Modified from summary_dlg.c
  *
- * $Id: gsm_map_summary.c 41187 2012-02-26 08:02:02Z guy $
+ * $Id: gsm_map_summary.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,10 +31,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <gtk/gtk.h>
 
 #include <wiretap/wtap.h>
@@ -97,7 +93,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_window_set_destroy_with_parent (GTK_WINDOW(sum_open_w), TRUE);
 
   /* Container for each row of widgets */
-  main_vb = gtk_vbox_new(FALSE, 3);
+  main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
   gtk_container_add(GTK_CONTAINER(sum_open_w), main_vb);
   gtk_widget_show(main_vb);
@@ -107,7 +103,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_container_add(GTK_CONTAINER(main_vb), file_fr);
   gtk_widget_show(file_fr);
 
-  file_box = gtk_vbox_new(FALSE, 3);
+  file_box = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(file_fr), file_box);
   gtk_widget_show(file_box);
 
@@ -134,7 +130,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_container_add(GTK_CONTAINER(main_vb), data_fr);
   gtk_widget_show(data_fr);
 
-  data_box = gtk_vbox_new(FALSE, 3);
+  data_box = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(data_fr), data_box);
   gtk_widget_show(data_box);
 
@@ -179,7 +175,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_container_add(GTK_CONTAINER(main_vb), invoke_fr);
   gtk_widget_show(invoke_fr);
 
-  invoke_box = gtk_vbox_new(FALSE, 3);
+  invoke_box = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(invoke_fr), invoke_box);
   gtk_widget_show(invoke_box);
 
@@ -235,7 +231,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_container_add(GTK_CONTAINER(main_vb), rr_fr);
   gtk_widget_show(rr_fr);
 
-  rr_box = gtk_vbox_new(FALSE, 3);
+  rr_box = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(rr_fr), rr_box);
   gtk_widget_show(rr_box);
 
@@ -291,7 +287,7 @@ void gsm_map_stat_gtk_sum_cb(GtkAction *action _U_, gpointer user_data _U_)
   gtk_container_add(GTK_CONTAINER(main_vb), tot_fr);
   gtk_widget_show(tot_fr);
 
-  tot_box = gtk_vbox_new(FALSE, 3);
+  tot_box = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(tot_fr), tot_box);
   gtk_widget_show(tot_box);
 
