@@ -1,7 +1,7 @@
 /* gui_utils.h
  * Declarations of GTK+-specific UI utility routines
  *
- * $Id: gui_utils.h 41893 2012-04-02 11:35:53Z etxrab $
+ * $Id: gui_utils.h 43081 2012-06-04 20:08:59Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -167,6 +167,7 @@ extern gboolean window_delete_event_cb(GtkWidget *win, GdkEvent *event _U_, gpoi
  * @todo if main uses the window_new_with_geom() to save size and such, make this function static
  */
 extern void window_get_geometry(GtkWidget *win, window_geometry_t *geom);
+
 /** Set the geometry of a window.
  *
  * @param win the window from window_new()
@@ -187,6 +188,15 @@ extern void reactivate_window(GtkWidget *win);
 
 /** @} */
 
+/** Alert box for an invalid display filter expression.
+ * Assumes "dfilter_error_msg" has been set by "dfilter_compile()" to the
+ * error message for the filter.
+ *
+ * @param parent parent window from which the display filter came
+ * @param dftext text of the display filter
+ */
+extern void bad_dfilter_alert_box(GtkWidget *parent, const char *dftext);
+
 /** Create a GtkScrolledWindow, set its scrollbar placement appropriately,
  *  and remember it.
  *
@@ -297,11 +307,13 @@ extern void copy_binary_to_clipboard(const guint8* data_p, int len);
  */
 extern gchar *create_user_window_title(const gchar *caption);
 
-/** Construct the main window's title with the current main_window_name optionally appended
- *  with the user-specified title and/or wireshark version. 
- *  Display the result in the main window's title bar and in its icon title
+/** Set the title of a window based on a supplied caption and the
+ * display name for the capture file.
+ *
+ * @param win the window whose title is to be set
+ * @param caption caption string for the window
  */
-extern void update_main_window_title(void);
+extern void set_window_title(GtkWidget *win, const gchar *caption);
 
 /** Renders a float with two decimals precission, called from gtk_tree_view_column_set_cell_data_func().
  * the user data must be the colum number.
@@ -517,4 +529,11 @@ GdkPixbuf *gdk_pixbuf_get_from_surface (cairo_surface_t *surface,
  */
 GtkWidget * ws_gtk_box_new(GtkOrientation orientation, gint spacing, gboolean homogeneous);
 
-#endif /* __GUI_UTIL__H__ */
+#if !GTK_CHECK_VERSION(3,0,0)
+GtkWidget * gtk_button_box_new(GtkOrientation orientation);
+GtkWidget * gtk_scrollbar_new(GtkOrientation orientation, GtkAdjustment *adjustment);
+GtkWidget * gtk_paned_new(GtkOrientation orientation);
+GtkWidget * gtk_separator_new (GtkOrientation orientation);
+#endif /* GTK_CHECK_VERSION(3,0,0) */
+
+#endif /* __GUI_UTIL_H__ */
