@@ -1,7 +1,7 @@
 /* io_stat.c
  * io_stat   2002 Ronnie Sahlberg
  *
- * $Id: io_stat.c 41888 2012-04-01 18:16:15Z tuexen $
+ * $Id: io_stat.c 43081 2012-06-04 20:08:59Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
@@ -202,14 +198,10 @@ static void filter_callback(GtkWidget *widget _U_, gpointer user_data);
 static void
 io_stat_set_title(io_stat_t *io)
 {
-	char		*title;
-
 	if(!io->window){
 		return;
 	}
-	title = g_strdup_printf("Wireshark IO Graphs: %s", cf_get_display_name(&cfile));
-	gtk_window_set_title(GTK_WINDOW(io->window), title);
-	g_free(title);
+	set_window_title(io->window, "Wireshark IO Graphs");
 }
 
 static void
@@ -418,7 +410,7 @@ tap_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, const void *
 						}
 						j--;
 						t -= pt;
-						if(t > io->interval * 1000) {
+						if(t > (guint64) io->interval * 1000) {
 							pt = (guint64) io->interval * 1000;
 						} else {
 							pt = t;
@@ -441,6 +433,15 @@ tap_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, const void *
 					nstime_add(&it->time_tot, new_time);
 					it->fields++;
 				}
+				break;
+			default:
+				/*
+				 * "Can't happen"; see the "check that the
+				 * type is compatible" check in
+				 * filter_callback().
+				 */
+				g_assert_not_reached();
+				break;
 			}
 		}
 	}
@@ -1140,7 +1141,9 @@ io_stat_draw(io_stat_t *io)
 						mavg_right--;
 					}
 				}
-				val = mavg_cumulated / mavg_in_average_count;
+				if (mavg_in_average_count > 0) {
+					val = mavg_cumulated / mavg_in_average_count;
+				}
 			}
 
 			if (val>max_y) {
@@ -1690,7 +1693,7 @@ create_draw_area(io_stat_t *io, GtkWidget *box)
 
 	/* create the associated scrollbar */
 	io->scrollbar_adjustment=(GtkAdjustment *)gtk_adjustment_new(0,0,0,0,0,0);
-	io->scrollbar=gtk_hscrollbar_new(io->scrollbar_adjustment);
+	io->scrollbar=gtk_scrollbar_new(GTK_ORIENTATION_HORIZONTAL, io->scrollbar_adjustment);
 	gtk_widget_show(io->scrollbar);
 	gtk_box_pack_start(GTK_BOX(box), io->scrollbar, FALSE, FALSE, 0);
 	g_signal_connect(io->scrollbar_adjustment, "value-changed", G_CALLBACK(scrollbar_changed), io);
@@ -1913,7 +1916,7 @@ create_ctrl_menu(io_stat_t *io, GtkWidget *box, const char *name, GtkWidget * (*
 	GtkWidget *label;
 	GtkWidget *combo_box;
 
-	hbox=gtk_hbox_new(FALSE, 0);
+	hbox=ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(box), hbox);
 	gtk_box_set_child_packing(GTK_BOX(box), hbox, FALSE, FALSE, 0, GTK_PACK_START);
 	gtk_widget_show(hbox);
@@ -1945,7 +1948,7 @@ create_ctrl_area(io_stat_t *io, GtkWidget *box)
 	GtkWidget *vbox;
 	GtkWidget *view_cb;
 
-	frame_vbox=gtk_vbox_new(FALSE, 0);
+	frame_vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_box_pack_start(GTK_BOX(box), frame_vbox, FALSE, FALSE, 0);
 	gtk_widget_show(frame_vbox);
 
@@ -1953,7 +1956,7 @@ create_ctrl_area(io_stat_t *io, GtkWidget *box)
 	gtk_container_add(GTK_CONTAINER(frame_vbox), frame);
 	gtk_widget_show(frame);
 
-	vbox=gtk_vbox_new(FALSE, 0);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
 	gtk_box_set_child_packing(GTK_BOX(box), vbox, FALSE, FALSE, 0, GTK_PACK_END);
@@ -1972,7 +1975,7 @@ create_ctrl_area(io_stat_t *io, GtkWidget *box)
 	gtk_container_add(GTK_CONTAINER(frame_vbox), frame);
 	gtk_widget_show(frame);
 
-	vbox=gtk_vbox_new(FALSE, 0);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
 	gtk_box_set_child_packing(GTK_BOX(box), vbox, FALSE, FALSE, 0, GTK_PACK_END);
@@ -1986,7 +1989,7 @@ create_ctrl_area(io_stat_t *io, GtkWidget *box)
 }
 
 static void
-filter_callback(GtkWidget *widget _U_, gpointer user_data)
+filter_callback(GtkWidget *widget, gpointer user_data)
 {
 	io_stat_graph_t *gio = user_data;
 	const char *filter;
@@ -2097,7 +2100,8 @@ filter_callback(GtkWidget *widget _U_, gpointer user_data)
 	/* first check if the filter string is valid. */
 	filter=gtk_entry_get_text(GTK_ENTRY(gio->filter_field));
 	if(!dfilter_compile(filter, &dfilter)) {
-		bad_dfilter_alert_box(filter);
+		bad_dfilter_alert_box(gtk_widget_get_toplevel(widget),
+		    filter);
 		disable_graph(gio);
 		io_stat_redraw(gio->io);
 		return;
@@ -2156,7 +2160,7 @@ create_advanced_menu(io_stat_graph_t *gio, GtkWidget *box, const char *name,  Gt
 	GtkWidget *label;
 	GtkWidget *combo_box;
 
-	hbox=gtk_hbox_new(FALSE, 0);
+	hbox=ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(box), hbox);
 	gtk_box_set_child_packing(GTK_BOX(box), hbox, FALSE, FALSE, 0, GTK_PACK_START);
 	gtk_widget_show(hbox);
@@ -2192,7 +2196,7 @@ create_advanced_box(io_stat_graph_t *gio, GtkWidget *box)
 {
 	GtkWidget *hbox;
 
-	hbox=gtk_hbox_new(FALSE, 0);
+	hbox=ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
 	gio->advanced_buttons=hbox;
 	gtk_container_add(GTK_CONTAINER(box), hbox);
 	gtk_box_set_child_packing(GTK_BOX(box), hbox, TRUE, TRUE, 0, GTK_PACK_START);
@@ -2221,7 +2225,7 @@ create_filter_box(io_stat_graph_t *gio, GtkWidget *box, int num)
 	char str[256];
 	int i;
 
-	hbox=gtk_hbox_new(FALSE, 3);
+	hbox=ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_container_add(GTK_CONTAINER(box), hbox);
 	gtk_box_set_child_packing(GTK_BOX(box), hbox, FALSE, FALSE, 0, GTK_PACK_START);
 	gtk_widget_show(hbox);
@@ -2315,7 +2319,7 @@ create_filter_area(io_stat_t *io, GtkWidget *box)
 	gtk_box_pack_start(GTK_BOX(box), frame, TRUE, TRUE, 0);
 	gtk_widget_show(frame);
 
-	vbox=gtk_vbox_new(FALSE, 1);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 1, FALSE);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
 	gtk_box_set_child_packing(GTK_BOX(box), vbox, FALSE, FALSE, 0, GTK_PACK_START);
@@ -2377,13 +2381,13 @@ init_io_stat_window(io_stat_t *io)
 	io->window = dlg_window_new("I/O Graphs");
 	gtk_window_set_destroy_with_parent (GTK_WINDOW(io->window), TRUE);
 
-	vbox=gtk_vbox_new(FALSE, 0);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(io->window), vbox);
 	gtk_widget_show(vbox);
 
 	create_draw_area(io, vbox);
 
-	hbox=gtk_hbox_new(FALSE, 3);
+	hbox=ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 3);
 	gtk_box_set_child_packing(GTK_BOX(vbox), hbox, FALSE, FALSE, 0, GTK_PACK_START);
