@@ -2,7 +2,7 @@
  * Copyright 2009 Martin Mathieson
  * (originally based upon wlan_stat_dlg.c)
  *
- * $Id: mac_lte_stat_dlg.c 41948 2012-04-05 00:53:01Z martinm $
+ * $Id: mac_lte_stat_dlg.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,10 +28,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -220,15 +216,18 @@ static void mac_lte_stat_reset(void *phs)
 {
     mac_lte_stat_t* mac_lte_stat = (mac_lte_stat_t *)phs;
     mac_lte_ep_t* list = mac_lte_stat->ep_list;
+    char *display_name;
     gchar title[256];
     GtkListStore *store;
     gint i, n;
 
     /* Set the title */
     if (mac_lte_stat->mac_lte_stat_dlg_w != NULL) {
+        display_name = cf_get_display_name(&cfile);
         g_snprintf(title, sizeof(title), "Wireshark: LTE MAC Traffic Statistics: %s (filter=\"%s\")",
-                   cf_get_display_name(&cfile),
+                   display_name,
                    strlen(mac_lte_stat->filter) ? mac_lte_stat->filter : "none");
+        g_free(display_name);
         gtk_window_set_title(GTK_WINDOW(mac_lte_stat->mac_lte_stat_dlg_w), title);
     }
 
@@ -642,6 +641,7 @@ static void mac_lte_stat_draw(void *phs)
 {
     gchar   buff[32];
     guint16 number_of_ues = 0;
+    char *display_name;
     gchar title[256];
 
     /* Look up the statistics window */
@@ -684,11 +684,13 @@ static void mac_lte_stat_draw(void *phs)
     gtk_frame_set_label(GTK_FRAME(hs->mac_lte_stat_ues_lb), title);
 
     /* Update title to include number of UEs and frames */
+    display_name = cf_get_display_name(&cfile);
     g_snprintf(title, sizeof(title), "Wireshark: LTE MAC Traffic Statistics: %s (%u UEs, %u frames) (filter=\"%s\")",
-               cf_get_display_name(&cfile),
+               display_name,
                number_of_ues,
                hs->common_stats.all_frames,
                strlen(hs->filter) ? hs->filter : "none");
+    g_free(display_name);
     gtk_window_set_title(GTK_WINDOW(hs->mac_lte_stat_dlg_w), title);
 
 
@@ -845,8 +847,7 @@ static void set_filter_expression(guint16  ueid,
 
     /* Close () if open */
     if (showDCTErrors) {
-            offset += g_snprintf(buffer+offset, MAX_FILTER_LEN-offset,
-                                 ")");
+        /*offset +=*/ g_snprintf(buffer+offset, MAX_FILTER_LEN-offset, ")");
     }
 
     /* Set its value to our new string */
@@ -1012,6 +1013,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     GtkCellRenderer   *renderer;
     GtkTreeViewColumn *column;
     GtkTreeSelection  *sel;
+    gchar *display_name;
     gchar title[256];
     gint i, n;
 
@@ -1039,8 +1041,10 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     }
 
     /* Set title */
+    display_name = cf_get_display_name(&cfile);
     g_snprintf(title, sizeof(title), "Wireshark: LTE MAC Statistics: %s",
-               cf_get_display_name(&cfile));
+               display_name);
+    g_free(display_name);
 
     /* Create top-level window */
     hs->mac_lte_stat_dlg_w = window_new_with_geom(GTK_WINDOW_TOPLEVEL, title, "LTE MAC Statistics");
@@ -1049,7 +1053,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     gtk_window_set_default_size(GTK_WINDOW(hs->mac_lte_stat_dlg_w), 750, 300);
 
     /* Will stack widgets vertically inside dlg */
-    top_level_vbox = gtk_vbox_new(FALSE, 3);       /* FALSE = not homogeneous */
+    top_level_vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);       /* FALSE = not homogeneous */
     gtk_container_add(GTK_CONTAINER(hs->mac_lte_stat_dlg_w), top_level_vbox);
 
     gtk_container_set_border_width(GTK_CONTAINER(top_level_vbox), 6);
@@ -1062,7 +1066,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     mac_lte_stat_system_lb = gtk_frame_new("System Data");
 
     /* Add max UEs/TTI counts in one row */
-    system_row_hbox = gtk_hbox_new(FALSE, 0);
+    system_row_hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(mac_lte_stat_system_lb), system_row_hbox);
     gtk_container_set_border_width(GTK_CONTAINER(system_row_hbox), 5);
 
@@ -1086,7 +1090,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     mac_lte_stat_common_channel_lb = gtk_frame_new("Common Channel Data");
 
     /* Will add BCH and PCH counters into one row */
-    common_row_hbox = gtk_hbox_new(FALSE, 0);
+    common_row_hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(mac_lte_stat_common_channel_lb), common_row_hbox);
     gtk_container_set_border_width(GTK_CONTAINER(common_row_hbox), 5);
 
@@ -1128,7 +1132,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     /**********************************************/
 
     hs->mac_lte_stat_ues_lb = gtk_frame_new("UL/DL-SCH Data (0 UEs)");
-    ues_vb = gtk_vbox_new(FALSE, 0);
+    ues_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(hs->mac_lte_stat_ues_lb), ues_vb);
     gtk_container_set_border_width(GTK_CONTAINER(ues_vb), 5);
 
@@ -1193,13 +1197,13 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
 
     mac_lte_stat_selected_ue_lb = gtk_frame_new("Selected UE details");
 
-    selected_ue_hb = gtk_hbox_new(FALSE, 6);
+    selected_ue_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6, FALSE);
     gtk_container_add(GTK_CONTAINER(mac_lte_stat_selected_ue_lb), selected_ue_hb);
     gtk_container_set_border_width(GTK_CONTAINER(selected_ue_hb), 5);
 
     /********************************/
     /* First (row titles) column    */
-    selected_ue_vbox[0] = gtk_vbox_new(FALSE, 0);
+    selected_ue_vbox[0] = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(selected_ue_hb), selected_ue_vbox[0]);
 
     selected_ue_column_titles[0] = gtk_label_new("");
@@ -1217,7 +1221,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     /*************************/
     /* Other columns         */
     for (i=CCCH_COLUMN; i < NUM_CHANNEL_COLUMNS; i++) {
-        selected_ue_vbox[i] = gtk_vbox_new(FALSE, 0);
+        selected_ue_vbox[i] = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
         gtk_container_add(GTK_CONTAINER(selected_ue_hb), selected_ue_vbox[i]);
 
         /* Channel title */
@@ -1243,7 +1247,7 @@ static void gtk_mac_lte_stat_init(const char *optarg, void *userdata _U_)
     mac_lte_stat_filters_lb = gtk_frame_new("Filter on UE");
 
     /* Horizontal row of filter controls */
-    filter_buttons_hb = gtk_hbox_new(FALSE, 6);
+    filter_buttons_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6, FALSE);
     gtk_container_add(GTK_CONTAINER(mac_lte_stat_filters_lb), filter_buttons_hb);
     gtk_container_set_border_width(GTK_CONTAINER(filter_buttons_hb), 2);
 
