@@ -1,7 +1,7 @@
 /* main.h
  * Global defines, etc.
  *
- * $Id: main.h 43053 2012-06-04 03:15:05Z guy $
+ * $Id: main.h 44410 2012-08-10 00:08:03Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -124,11 +124,10 @@ typedef enum {
 /** User requested one of "Apply as Filter" or "Prepare a Filter" functions
  *  by menu or context menu of protocol tree.
  *
- * @param widget parent widget
  * @param data parent widget
  * @param action the function to use
  */
-extern void match_selected_ptree_cb(GtkWidget *widget, gpointer data, MATCH_SELECTED_E action);
+extern void match_selected_ptree_cb(gpointer data, MATCH_SELECTED_E action);
 
 /** "Copy ..." action type. */
 typedef enum {
@@ -167,11 +166,10 @@ extern void colorize_selected_ptree_cb(GtkWidget *w, gpointer data, guint8 filt_
 /** User requested one of "Apply as Filter" or "Prepare a Filter" functions
  *  by context menu of packet list.
  *
- * @param widget parent widget (unused)
  * @param data parent widget
  * @param action the function to use
  */
-extern void match_selected_plist_cb(GtkWidget *widget, gpointer data, MATCH_SELECTED_E action);
+extern void match_selected_plist_cb(gpointer data, MATCH_SELECTED_E action);
 
 /** User requested "Quit" by menu or toolbar.
  *
