@@ -1,7 +1,7 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: main_proto_draw.c 41322 2012-03-02 13:31:16Z etxrab $
+ * $Id: main_proto_draw.c 43289 2012-06-16 19:27:24Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,7 +67,6 @@
 
 #include "ui/gtk/keys.h"
 #include "ui/gtk/color_utils.h"
-#include "ui/gtk/capture_file_dlg.h"
 #include "ui/gtk/packet_win.h"
 #include "ui/gtk/file_dlg.h"
 #include "ui/gtk/gui_utils.h"
@@ -133,9 +132,11 @@ get_byte_view_data_and_length(GtkWidget *byte_view, guint *data_len)
     if (byte_view_tvb == NULL)
         return NULL;
 
-    data_ptr = tvb_get_ptr(byte_view_tvb, 0, -1);
-    *data_len = tvb_length(byte_view_tvb);
-    return data_ptr;
+    if ((*data_len = tvb_length(byte_view_tvb))) {
+        data_ptr = tvb_get_ptr(byte_view_tvb, 0, -1);
+        return data_ptr;
+    } else
+        return "";
 }
 
 /*
@@ -594,7 +595,7 @@ highlight_field(tvbuff_t *tvb, gint byte, GtkTreeView *tree_view,
     }
 
     /* Refresh the display so that the expanded trees are visible */
-    main_proto_tree_draw(tree);
+    proto_tree_draw(tree, GTK_WIDGET(tree_view));
 
     /* select our field's row */
     gtk_tree_selection_select_path(gtk_tree_view_get_selection(tree_view),
@@ -1564,6 +1565,7 @@ packet_hex_update(GtkWidget *bv, const guint8 *pd, int len, int bstart,
 {
     GtkTextView   *bv_text_view = GTK_TEXT_VIEW(bv);
     GtkTextBuffer *buf = gtk_text_view_get_buffer(bv_text_view);
+    GtkTextBuffer *buf_tmp;
     GtkTextMark   *mark;
     int ndigits;
 
@@ -1591,7 +1593,9 @@ packet_hex_update(GtkWidget *bv, const guint8 *pd, int len, int bstart,
      *       to display the real buffer until it has been
      *       completely generated).
      */
-    gtk_text_view_set_buffer(bv_text_view, gtk_text_buffer_new(NULL));
+    buf_tmp = gtk_text_buffer_new(NULL);
+    gtk_text_view_set_buffer(bv_text_view, buf_tmp);
+    g_object_unref(buf_tmp);
 
     packet_hex_print_common(buf, bv, pd, len, encoding);
 
@@ -1669,16 +1673,16 @@ packet_hex_print(GtkWidget *bv, const guint8 *pd, frame_data *fd,
             /* XXX, mask has only 32 bit, later we can store bito&bitc, and use them (which should be faster) */
             if (bitt > 0 && bitt < 32) {
 
-                bmask = ((1 << bitc) - 1) << (8-(bitt & 0x7)); /* always? */
+                bmask = ((1 << bitc) - 1) << ((8-bitt) & 7);
                 bmask_le = 0; /* ? */
             }
         }
     }
 
-    if (bstart >= 0 && blen > 0) {
+    if (bstart >= 0 && blen > 0 && (guint)bstart < len) {
         bend = bstart + blen;
     }
-    if (astart >= 0 && alen > 0) {
+    if (astart >= 0 && alen > 0 && (guint)astart < len) {
         aend = astart + alen;
     }
 
