@@ -1,6 +1,6 @@
 /* main_statusbar.c
  *
- * $Id: main_statusbar.c 41521 2012-03-13 08:36:25Z guy $
+ * $Id: main_statusbar.c 43101 2012-06-05 06:52:18Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -299,7 +299,7 @@ statusbar_new(void)
     GtkWidget *status_hbox;
 
     /* Status hbox */
-    status_hbox = gtk_hbox_new(FALSE, 1);
+    status_hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 1, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(status_hbox), 0);
 
     /* info (main) statusbar */
@@ -318,9 +318,9 @@ statusbar_new(void)
     status_capture_comment_new();
 
     /* Pane for the statusbar */
-    status_pane_left = gtk_hpaned_new();
+    status_pane_left = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show(status_pane_left);
-    status_pane_right = gtk_hpaned_new();
+    status_pane_right = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show(status_pane_right);
 
     return status_hbox;
@@ -738,16 +738,16 @@ statusbar_cf_file_closed_cb(capture_file *cf _U_)
 
 
 static void
-statusbar_cf_file_read_started_cb(capture_file *cf)
+statusbar_cf_file_read_started_cb(capture_file *cf, const char *action)
 {
-    const gchar *name_ptr;
+    gchar *name_ptr;
 
     /* Ensure we pop any previous loaded filename */
     statusbar_pop_file_msg();
 
-    name_ptr = get_basename(cf->filename);
-
-    statusbar_push_file_msg(" Loading: %s", name_ptr);
+    name_ptr = g_filename_display_basename(cf->filename);
+    statusbar_push_file_msg(" %s: %s", action, name_ptr);
+    g_free(name_ptr);
 }
 
 
@@ -926,7 +926,7 @@ static void
 statusbar_cf_file_save_started_cb(gchar *filename)
 {
     statusbar_pop_file_msg();
-    statusbar_push_file_msg(" Saving: %s...", get_basename(filename));
+    statusbar_push_file_msg(" Saving: %s...", g_filename_display_basename(filename));
 }
 
 static void
@@ -937,15 +937,42 @@ statusbar_cf_file_save_finished_cb(gpointer data _U_)
 }
 
 static void
-statusbar_cf_file_reload_finished_cb(capture_file *cf)
+statusbar_cf_file_save_failed_cb(gpointer data _U_)
 {
+    /* Pop the "Saving:" message off the status bar. */
     statusbar_pop_file_msg();
-    statusbar_set_filename(cf->filename, cf->f_datalen, &(cf->elapsed_time));
 }
 
+static void
+statusbar_cf_file_save_stopped_cb(gpointer data _U_)
+{
+    /* Pop the "Saving:" message off the status bar. */
+    statusbar_pop_file_msg();
+}
 
 static void
-statusbar_cf_file_save_failed_cb(gpointer data _U_)
+statusbar_cf_file_export_specified_packets_started_cb(gchar *filename)
+{
+    statusbar_pop_file_msg();
+    statusbar_push_file_msg(" Exporting to: %s...", g_filename_display_basename(filename));
+}
+
+static void
+statusbar_cf_file_export_specified_packets_finished_cb(gpointer data _U_)
+{
+    /* Pop the "Exporting to:" message off the status bar. */
+    statusbar_pop_file_msg();
+}
+
+static void
+statusbar_cf_file_export_specified_packets_failed_cb(gpointer data _U_)
+{
+    /* Pop the "Exporting to:" message off the status bar. */
+    statusbar_pop_file_msg();
+}
+
+static void
+statusbar_cf_file_export_specified_packets_stopped_cb(gpointer data _U_)
 {
     /* Pop the "Saving:" message off the status bar. */
     statusbar_pop_file_msg();
@@ -964,11 +991,25 @@ statusbar_cf_callback(gint event, gpointer data, gpointer user_data _U_)
         statusbar_cf_file_closed_cb(data);
         break;
     case(cf_cb_file_read_started):
-        statusbar_cf_file_read_started_cb(data);
+        statusbar_cf_file_read_started_cb(data, "Loading");
         break;
     case(cf_cb_file_read_finished):
         statusbar_cf_file_read_finished_cb(data);
         break;
+    case(cf_cb_file_reload_started):
+        statusbar_cf_file_read_started_cb(data, "Reloading");
+        break;
+    case(cf_cb_file_reload_finished):
+        statusbar_cf_file_read_finished_cb(data);
+        break;
+    case(cf_cb_file_rescan_started):
+        statusbar_cf_file_read_started_cb(data, "Rescanning");
+        break;
+    case(cf_cb_file_rescan_finished):
+        statusbar_cf_file_read_finished_cb(data);
+        break;
+    case(cf_cb_file_fast_save_finished):
+        break;
     case(cf_cb_packet_selected):
         break;
     case(cf_cb_packet_unselected):
@@ -982,12 +1023,24 @@ statusbar_cf_callback(gint event, gpointer data, gpointer user_data _U_)
     case(cf_cb_file_save_finished):
         statusbar_cf_file_save_finished_cb(data);
         break;
-    case(cf_cb_file_save_reload_finished):
-        statusbar_cf_file_reload_finished_cb(data);
-        break;
     case(cf_cb_file_save_failed):
         statusbar_cf_file_save_failed_cb(data);
         break;
+    case(cf_cb_file_save_stopped):
+        statusbar_cf_file_save_stopped_cb(data);
+        break;
+    case(cf_cb_file_export_specified_packets_started):
+        statusbar_cf_file_export_specified_packets_started_cb(data);
+        break;
+    case(cf_cb_file_export_specified_packets_finished):
+        statusbar_cf_file_export_specified_packets_finished_cb(data);
+        break;
+    case(cf_cb_file_export_specified_packets_failed):
+        statusbar_cf_file_export_specified_packets_failed_cb(data);
+        break;
+    case(cf_cb_file_export_specified_packets_stopped):
+        statusbar_cf_file_export_specified_packets_stopped_cb(data);
+        break;
     default:
         g_warning("statusbar_cf_callback: event %u unknown", event);
         g_assert_not_reached();
