@@ -2,7 +2,7 @@
  * Definitions for toolbar utility routines
  * Copyright 2003, Ulf Lamping <ulf.lamping@web.de>
  *
- * $Id: main_toolbar.h 40769 2012-01-30 13:05:27Z stig $
+ * $Id: main_toolbar.h 43283 2012-06-16 18:17:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,35 +40,16 @@ GtkWidget *toolbar_new(void);
 /** Redraw the main toolbar. Used, when user changes preferences. */
 void toolbar_redraw_all(void);
 
-/** The "Colorize Packet List" option has changed.
- */
-void toolbar_colorize_changed(gboolean packet_list_colorize);
-
-#ifdef HAVE_LIBPCAP
-/** The "Auto Scroll in Live Capture" option has changed.
- */
-void toolbar_auto_scroll_live_changed(gboolean auto_scroll_live);
-#endif
-
-/** We have (or don't have) a capture file now.
- *
- * @param have_capture_file TRUE, if we have a capture file
- * @param can_save_as TRUE, if we can save this capture file
- */
-void set_toolbar_for_capture_file(gboolean have_capture_file, gboolean can_save_as);
-
-/** We have (or don't have) an unsaved capture file now.
- *
- * @param have_unsaved_capture_file TRUE, if we have an unsaved capture file
- */
-void set_toolbar_for_unsaved_capture_file(gboolean have_unsaved_capture_file);
-
 /** We have (or don't have) a capture in progress now.
  *
  * @param have_capture_file TRUE, if we have a capture in progress file
  */
 void set_toolbar_for_capture_in_progress(gboolean have_capture_file);
 
+/** The capture is in the process of being stopped.
+ */
+void set_toolbar_for_capture_stopping(void);
+
 /** We have (or don't have) captured packets now.
  *
  * @param have_captured_packets TRUE, if we have captured packets
