@@ -1,7 +1,7 @@
 /* menus.h
  * Menu definitions
  *
- * $Id: menus.h 40561 2012-01-18 19:38:34Z guy $
+ * $Id: menus.h 43283 2012-06-16 18:17:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,19 +50,11 @@ extern void menu_recent_read_finished(void);
 /** One of the name resolution menu items changed. */
 extern void menu_name_resolution_changed(void);
 
-/** The "Colorize Packet List" option changed. */
-extern void menu_colorize_changed(gboolean packet_list_colorize);
-
 /* Reset preferences menu on profile or preference change. */
 extern void menu_prefs_reset(void);
 
 extern void rebuild_visible_columns_menu (void);
 
-#ifdef HAVE_LIBPCAP
-/** The "Auto Scroll Packet List in Live Capture" option changed. */
-extern void menu_auto_scroll_live_changed(gboolean auto_scroll_in);
-#endif
-
 /** Create a new menu.
  *
  * @param accel the created accelerator group
@@ -125,16 +117,15 @@ extern GtkWidget *menus_get_profiles_change_menu (void);
 void set_menus_for_selected_tree_row(capture_file *cf);
 
 
-/* Enable or disable menu items based on whether you have a capture file
-   you've finished reading and, if you have one, whether it's been saved
-   and whether it could be saved except by copying the raw packet data. */
-void set_menus_for_capture_file(capture_file *);
-
-
 /* Enable or disable menu items based on whether there's a capture in
    progress. */
 void set_menus_for_capture_in_progress(gboolean);
 
+/* Disable menu items while we're waiting for the capture child to
+   finish.  We disallow quitting until it finishes, and also disallow
+   stopping or restarting the capture. */
+void set_menus_for_capture_stopping(void);
+
 /* Enable or disable menu items based on whether you have some captured
    packets. */
 void set_menus_for_captured_packets(gboolean);
