@@ -2,7 +2,7 @@
  * mgcp-statistics for Wireshark
  * Copyright 2003 Lars Roland
  *
- * $Id: mgcp_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: mgcp_stat.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -268,7 +264,7 @@ gtk_mgcpstat_init(const char *optarg, void *userdata _U_)
 
 	gtk_window_set_default_size(GTK_WINDOW(ms->win), 550, 150);
 
-	ms->vbox=gtk_vbox_new(FALSE, 3);
+	ms->vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 
 	init_main_stat_window(ms->win, ms->vbox, "MGCP Service Response Time (SRT) Statistics", ms->filter);
 
