@@ -1,7 +1,7 @@
 /* ncp_stat.c
  * ncp_stat   2005 Greg Morris
  *
- * $Id: ncp_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: ncp_stat.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,10 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -270,12 +266,7 @@ static const value_string ncp_nds_verb_vals[] = {
 static void
 ncpstat_set_title(ncpstat_t *ss)
 {
-	char *title;
-
-	title = g_strdup_printf("NCP Service Response Time statistics: %s",
-	    cf_get_display_name(&cfile));
-	gtk_window_set_title(GTK_WINDOW(ss->win), title);
-	g_free(title);
+	set_window_title(ss->win, "NCP Service Response Time statistics");
 }
 
 static void
@@ -522,7 +513,7 @@ gtk_ncpstat_init(const char *optarg, void *userdata _U_)
 
     ncpstat_set_title(ss);
 
-    vbox=gtk_vbox_new(FALSE, 3);
+    vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
     gtk_container_add(GTK_CONTAINER(ss->win), vbox);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
@@ -537,7 +528,7 @@ gtk_ncpstat_init(const char *optarg, void *userdata _U_)
 
     main_nb = gtk_notebook_new();
     gtk_box_pack_start(GTK_BOX(vbox), main_nb, TRUE, TRUE, 0);
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label = gtk_label_new("Groups");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
 
@@ -549,7 +540,7 @@ gtk_ncpstat_init(const char *optarg, void *userdata _U_)
     init_srt_table(&ss->ncp_srt_table, 256, temp_page, "ncp.group");
 
     /* NCP Functions */
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label = gtk_label_new("Functions");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("NCP Functions without Subfunctions");
@@ -558,115 +549,115 @@ gtk_ncpstat_init(const char *optarg, void *userdata _U_)
 
     /* NCP Subfunctions */
 
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label = gtk_label_new("17");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 17");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_17_srt_table, 256, temp_page, "ncp.func==17 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("21");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 21");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_21_srt_table, 256, temp_page, "ncp.func==21 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("22");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 22");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_22_srt_table, 256, temp_page, "ncp.func==22 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("23");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 23");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_23_srt_table, 256, temp_page, "ncp.func==23 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("32");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 32");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_32_srt_table, 256, temp_page, "ncp.func==32 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("34");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 34");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_34_srt_table, 256, temp_page, "ncp.func==34 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("35");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 35");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_35_srt_table, 256, temp_page, "ncp.func==35 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page =ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("36");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 36");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_36_srt_table, 256, temp_page, "ncp.func==36 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("86");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 86");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_86_srt_table, 256, temp_page, "ncp.func==86 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("87");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 87");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_87_srt_table, 256, temp_page, "ncp.func==87 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("89");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 89 (Extended NCP's with UTF8 Support)");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_89_srt_table, 256, temp_page, "ncp.func==89 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("90");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 90");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_90_srt_table, 256, temp_page, "ncp.func==90 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("92");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 92 (Secret Store Services)");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_92_srt_table, 256, temp_page, "ncp.func==92 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("94");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 94 (Novell Modular Authentication Services)");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_94_srt_table, 256, temp_page, "ncp.func==94 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("104");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 104");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_104_srt_table, 256, temp_page, "ncp.func==104 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("111");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 111");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_111_srt_table, 256, temp_page, "ncp.func==111 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("114");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 114");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_114_srt_table, 256, temp_page, "ncp.func==114 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("123");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 123");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sub_123_srt_table, 256, temp_page, "ncp.func==123 && ncp.subfunc");
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("131");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Subfunctions for NCP 131");
@@ -674,21 +665,21 @@ gtk_ncpstat_init(const char *optarg, void *userdata _U_)
     init_srt_table(&ss->sub_131_srt_table, 256, temp_page, "ncp.func==131 && ncp.subfunc");
 
     /* NDS Verbs */
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("NDS");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("NDS Verbs");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->nds_srt_table, 256, temp_page, "ncp.ndsverb");
     /* Secret Store Verbs */
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("SSS");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("Secret Store Verbs");
     gtk_box_pack_start(GTK_BOX(temp_page), label, FALSE, FALSE, 0);
     init_srt_table(&ss->sss_srt_table, 256, temp_page, "sss.subverb");
     /* NMAS Verbs */
-    temp_page = gtk_vbox_new(FALSE, 6);
+    temp_page = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 6, FALSE);
     label=gtk_label_new("NMAS");
     gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), temp_page, label);
     label=gtk_label_new("NMAS Verbs");
