@@ -3,7 +3,7 @@
  *
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet_win.c 40561 2012-01-18 19:38:34Z guy $
+ * $Id: packet_win.c 42460 2012-05-07 10:51:14Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,10 +35,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #if GTK_CHECK_VERSION(3,0,0)
@@ -612,7 +608,7 @@ not_supported:
 	DataPtr->repr = native_repr;
 
 	frame = gtk_frame_new("Hex edit");
-	frame_vbox = gtk_vbox_new(TRUE, 1);
+	frame_vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 1, TRUE);
 
 	/* raw hex edit */
 	if (finfo->start >= 0 && finfo->length > 0) {
@@ -920,13 +916,13 @@ void new_packet_window(GtkWidget *w _U_, gboolean editable _U_)
 	gtk_window_set_default_size(GTK_WINDOW(main_w), DEF_WIDTH, -1);
 
 	/* Container for paned windows  */
-	main_vbox = gtk_vbox_new(FALSE, 1);
+	main_vbox = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 1, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 1);
 	gtk_container_add(GTK_CONTAINER(main_w), main_vbox);
 	gtk_widget_show(main_vbox);
 
 	/* Panes for the tree and byte view */
-	pane = gtk_vpaned_new();
+	pane = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
 	gtk_container_add(GTK_CONTAINER(main_vbox), pane);
 	gtk_widget_show(pane);
 
