@@ -1,7 +1,7 @@
 /* column_prefs.c
  * Dialog box for column preferences
  *
- * $Id: prefs_column.c 40518 2012-01-15 21:59:11Z jmayer $
+ * $Id: prefs_column.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -119,11 +119,11 @@ column_prefs_show(GtkWidget *prefs_window) {
     gint               first_row = TRUE;
 
     /* Container for each row of widgets */
-    main_vb = gtk_vbox_new(FALSE, 5);
+    main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 5, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
     gtk_widget_show(main_vb);
 
-    list_vb = gtk_vbox_new (FALSE, 0);
+    list_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_set_border_width  (GTK_CONTAINER (list_vb), 5);
     gtk_widget_show (list_vb);
     gtk_box_pack_start (GTK_BOX (main_vb), list_vb, TRUE, TRUE, 0);
@@ -207,12 +207,12 @@ column_prefs_show(GtkWidget *prefs_window) {
     g_object_unref(G_OBJECT(store));
 
     /* Bottom row: Add/remove buttons and properties */
-    bottom_hb = gtk_hbox_new(FALSE, 5);
+    bottom_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     gtk_box_pack_start (GTK_BOX (main_vb), bottom_hb, FALSE, TRUE, 0);
     gtk_widget_show(bottom_hb);
 
     /* Add / remove buttons */
-    add_remove_vb = gtk_vbox_new (TRUE, 0);
+    add_remove_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, TRUE);
     gtk_container_set_border_width (GTK_CONTAINER (add_remove_vb), 5);
     gtk_box_pack_start (GTK_BOX (bottom_hb), add_remove_vb, FALSE, FALSE, 0);
     gtk_widget_show(add_remove_vb);
@@ -249,7 +249,7 @@ column_prefs_show(GtkWidget *prefs_window) {
     gtk_widget_set_tooltip_text(lb, "Select which packet information to present in the column.");
     gtk_widget_show(lb);
 
-    props_hb = gtk_hbox_new(FALSE, 5);
+    props_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5, FALSE);
     gtk_table_attach(GTK_TABLE(tb), props_hb, 1, 2, 0, 1, GTK_FILL, GTK_SHRINK, 0, 0);
     gtk_widget_set_tooltip_text(props_hb, "Select which packet information to present in the column.");
     gtk_widget_show(props_hb);
