@@ -2,7 +2,7 @@
  * Dialog box for profiles editing
  * Stig Bjorlykke <stig@bjorlykke.org>, 2008
  *
- * $Id: profile_dlg.c 40561 2012-01-18 19:38:34Z guy $
+ * $Id: profile_dlg.c 42187 2012-04-21 21:13:13Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -793,19 +793,19 @@ profile_dialog_new(void)
   main_w = dlg_conf_window_new("Wireshark: Configuration Profiles");
   gtk_window_set_default_size(GTK_WINDOW(main_w), 400, 400);
 
-  main_vb = gtk_vbox_new(FALSE, 0);
+  main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
   gtk_container_add(GTK_CONTAINER(main_w), main_vb);
   gtk_widget_show(main_vb);
 
   /* Container for each row of widgets */
-  profile_vb = gtk_vbox_new(FALSE, 0);
+  profile_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(profile_vb), 0);
   gtk_container_add(GTK_CONTAINER(main_vb), profile_vb);
   gtk_widget_show(profile_vb);
 
   /* Top row: Buttons and profile list */
-  top_hb = gtk_hbox_new(FALSE, 0);
+  top_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0, FALSE);
   gtk_container_add(GTK_CONTAINER(profile_vb), top_hb);
   gtk_widget_show(top_hb);
 
@@ -813,7 +813,7 @@ profile_dialog_new(void)
   gtk_box_pack_start(GTK_BOX(top_hb), edit_fr, FALSE, FALSE, 0);
   gtk_widget_show(edit_fr);
 
-  list_bb = gtk_vbox_new(TRUE, 0);
+  list_bb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, TRUE);
   gtk_container_set_border_width(GTK_CONTAINER(list_bb), 5);
   gtk_container_add(GTK_CONTAINER(edit_fr), list_bb);
   gtk_widget_show(list_bb);
@@ -885,13 +885,13 @@ profile_dialog_new(void)
   gtk_box_pack_start(GTK_BOX(profile_vb), props_fr, FALSE, FALSE, 0);
   gtk_widget_show(props_fr);
 
-  props_vb = gtk_vbox_new(FALSE, 3);
+  props_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(props_vb), 5);
   gtk_container_add(GTK_CONTAINER(props_fr), props_vb);
   gtk_widget_show(props_vb);
 
   /* row: Profile name entry */
-  middle_hb = gtk_hbox_new(FALSE, 3);
+  middle_hb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
   gtk_container_add(GTK_CONTAINER(props_vb), middle_hb);
   gtk_widget_show(middle_hb);
 
@@ -1217,7 +1217,7 @@ profile_name_edit_dlg (gint operation)
   gtk_window_set_resizable(GTK_WINDOW(win),FALSE);
   gtk_window_resize(GTK_WINDOW(win), 400, 100);
 
-  main_vb = gtk_vbox_new(FALSE, 5);
+  main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 5, FALSE);
   gtk_container_add(GTK_CONTAINER(win), main_vb);
   gtk_container_set_border_width(GTK_CONTAINER(main_vb), 6);
 
