@@ -1,7 +1,7 @@
 /* rtp_stream.c
  * RTP streams summary addition for Wireshark
  *
- * $Id: rtp_stream.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: rtp_stream.c 42443 2012-05-05 20:51:14Z wmeier $
  *
  * Copyright 2003, Alcatel Business Systems
  * By Lars Ruoff <lars.ruoff@gmx.net>
@@ -36,11 +36,6 @@
 #include <fcntl.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-
 #include <epan/epan.h>
 #include <epan/packet.h>
 #include <epan/tap.h>
