@@ -1,7 +1,7 @@
 /* rtp_stream_dlg.c
  * RTP streams summary addition for Wireshark
  *
- * $Id: rtp_stream_dlg.c 40561 2012-01-18 19:38:34Z guy $
+ * $Id: rtp_stream_dlg.c 42187 2012-04-21 21:13:13Z etxrab $
  *
  * Copyright 2003, Alcatel Business Systems
  * By Lars Ruoff <lars.ruoff@gmx.net>
@@ -975,7 +975,7 @@ rtpstream_dlg_create (void)
     rtpstream_dlg_w = dlg_window_new("Wireshark: RTP Streams");
     gtk_window_set_default_size(GTK_WINDOW(rtpstream_dlg_w), 620, 400);
 
-    main_vb = gtk_vbox_new (FALSE, 0);
+    main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
     gtk_container_add(GTK_CONTAINER(rtpstream_dlg_w), main_vb);
     gtk_container_set_border_width (GTK_CONTAINER (main_vb), 12);
 
@@ -997,7 +997,7 @@ rtpstream_dlg_create (void)
     gtk_box_pack_start (GTK_BOX (main_vb), label_rev, FALSE, FALSE, 0);
 
     /* button row */
-    hbuttonbox = gtk_hbutton_box_new ();
+    hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start (GTK_BOX (main_vb), hbuttonbox, FALSE, FALSE, 0);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 0);
