@@ -1,7 +1,7 @@
 /* scsi_stat.c
  * scsi_stat   2006 Ronnie Sahlberg
  *
- * $Id: scsi_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: scsi_stat.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,10 +82,13 @@ enum
 static char *
 scsistat_gen_title(scsistat_t *rs)
 {
+	char *display_name;
 	char *title;
 
+	display_name = cf_get_display_name(&cfile);
 	title = g_strdup_printf("SCSI Service Response Time statistics for %s: %s",
-	    rs->prog, cf_get_display_name(&cfile));
+	    rs->prog, display_name);
+	g_free(display_name);
 	return title;
 }
 
@@ -230,7 +233,7 @@ gtk_scsistat_init(const char *optarg, void* userdata _U_)
 	gtk_window_set_default_size(GTK_WINDOW(rs->win), 550, 400);
 	scsistat_set_title(rs);
 
-	vbox=gtk_vbox_new(FALSE, 3);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_add(GTK_CONTAINER(rs->win), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
