@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_assoc_analyse.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: sctp_assoc_analyse.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -94,7 +94,6 @@ on_destroy(GObject *object _U_, gpointer user_data)
 			child_data = (struct sctp_udata *)list->data;
 			gtk_grab_remove(GTK_WIDGET(child_data->io->window));
 			gtk_widget_destroy(GTK_WIDGET(child_data->io->window));
-			list = g_list_previous(list);
 		}
 		g_list_free(u_data->children);
 		u_data->children = NULL;
@@ -450,12 +449,15 @@ sctp_set_filter (GtkButton *button _U_, struct sctp_analyse* u_data)
 
 static void analyse_window_set_title(struct sctp_analyse *u_data)
 {
+	char *display_name;
 	char *title;
 
 	if(!u_data->window){
 		return;
 	}
-	title = g_strdup_printf("SCTP Analyse Association: %s Port1 %u  Port2 %u", cf_get_display_name(&cfile), u_data->assoc->port1, u_data->assoc->port2);
+	display_name = cf_get_display_name(&cfile);
+	title = g_strdup_printf("SCTP Analyse Association: %s Port1 %u  Port2 %u", display_name, u_data->assoc->port1, u_data->assoc->port2);
+	g_free(display_name);
 	gtk_window_set_title(GTK_WINDOW(u_data->window), title);
 	g_free(title);
 }
@@ -517,7 +519,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	g_signal_connect(window, "destroy", G_CALLBACK(on_destroy), u_data);
 
 	/* Container for each row of widgets */
-	main_vb = gtk_vbox_new(FALSE, 2);
+	main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 2, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(main_vb), 2);
 	gtk_container_add(GTK_CONTAINER(window), main_vb);
 	gtk_widget_show(main_vb);
@@ -528,7 +530,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	g_object_set_data(G_OBJECT(window), "notebook", notebook);
 	g_signal_connect(notebook, "switch_page", G_CALLBACK(on_notebook_switch_page), NULL);
 
-	page1 = gtk_vbox_new(FALSE, 8);
+	page1 = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL,8, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(page1), 8);
 
 	u_data->analyse_nb->checktype = gtk_label_new("");
@@ -570,7 +572,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_box_pack_start(GTK_BOX(page1), u_data->analyse_nb->bytes_ep2, TRUE, TRUE, 0);
 	gtk_misc_set_alignment (GTK_MISC(u_data->analyse_nb->bytes_ep2),0,0);
 
-	hbox = gtk_hbutton_box_new();
+	hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(page1), hbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_SPREAD);
@@ -598,7 +600,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 
 
 	/*  page for endpoint 1 */
-	page2 = gtk_vbox_new(FALSE, 8);
+	page2 = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 8, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(page2), 8);
 
 	u_data->analyse_nb->page2 = g_malloc(sizeof(struct page));
@@ -606,7 +608,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	u_data->analyse_nb->page2->addr_frame = gtk_frame_new(NULL);
 	gtk_container_add(GTK_CONTAINER(page2), u_data->analyse_nb->page2->addr_frame);
 
-	addr_hb = gtk_hbox_new(FALSE, 3);
+	addr_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(addr_hb), 5);
 	gtk_container_add(GTK_CONTAINER(u_data->analyse_nb->page2->addr_frame), addr_hb);
 
@@ -624,23 +626,23 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	stat_fr = gtk_frame_new(NULL);
 	gtk_container_add(GTK_CONTAINER(page2), stat_fr);
 
-	hbox = gtk_hbox_new(FALSE,3);
+	hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_container_add(GTK_CONTAINER(stat_fr), hbox);
 
-	vbox_l = gtk_vbox_new(FALSE, 3);
+	vbox_l = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox_l, TRUE, TRUE, 0);
 
 
 
-	hbox_l1 = gtk_hbox_new(FALSE,3);
+	hbox_l1 = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox_l), hbox_l1, TRUE, TRUE, 0);
 
 	u_data->analyse_nb->page2->port = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(hbox_l1), u_data->analyse_nb->page2->port, TRUE, TRUE, 0);
 	gtk_misc_set_alignment (GTK_MISC(u_data->analyse_nb->page2->port),0,0);
 
-	hbox_l2 = gtk_hbox_new(FALSE,3);
+	hbox_l2 = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox_l), hbox_l2, TRUE, TRUE, 0);
 
 
@@ -650,7 +652,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_misc_set_alignment (GTK_MISC(u_data->analyse_nb->page2->veritag),0,0);
 	gtk_widget_show(vbox_l);
 
-	vbox_r = gtk_vbox_new(FALSE, 3);
+	vbox_r = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox_r, TRUE, TRUE, 0);
 
 	u_data->analyse_nb->page2->max_in = gtk_label_new("");
@@ -670,7 +672,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 
 	gtk_widget_show(vbox_r);
 
-	h_button_box=gtk_hbutton_box_new();
+	h_button_box=gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(page2), h_button_box, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(h_button_box), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (h_button_box), GTK_BUTTONBOX_SPREAD);
@@ -706,14 +708,14 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 
 	/* same page for endpoint 2*/
 
-	page3 = gtk_vbox_new(FALSE, 8);
+	page3 = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 8, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(page3), 8);
 	u_data->analyse_nb->page3 = g_malloc(sizeof(struct page));
 	u_data->analyse_nb->page3->addr_frame = gtk_frame_new(NULL);
 
 	gtk_container_add(GTK_CONTAINER(page3), u_data->analyse_nb->page3->addr_frame);
 
-	addr_hb = gtk_hbox_new(FALSE, 3);
+	addr_hb = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(addr_hb), 5);
 	gtk_container_add(GTK_CONTAINER(u_data->analyse_nb->page3->addr_frame), addr_hb);
 
@@ -732,21 +734,21 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	stat_fr = gtk_frame_new(NULL);
 	gtk_container_add(GTK_CONTAINER(page3), stat_fr);
 
-	hbox = gtk_hbox_new(FALSE,3);
+	hbox = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_container_add(GTK_CONTAINER(stat_fr), hbox);
 
-	vbox_l = gtk_vbox_new(FALSE, 3);
+	vbox_l = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox_l, TRUE, TRUE, 0);
 
-	hbox_l1 = gtk_hbox_new(FALSE,3);
+	hbox_l1 = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox_l), hbox_l1, TRUE, TRUE, 0);
 
 	u_data->analyse_nb->page3->port = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(hbox_l1), u_data->analyse_nb->page3->port, TRUE, TRUE, 0);
 	gtk_misc_set_alignment (GTK_MISC(u_data->analyse_nb->page3->port),0,0);
 
-	hbox_l2 = gtk_hbox_new(FALSE,3);
+	hbox_l2 = ws_gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox_l), hbox_l2, TRUE, TRUE, 0);
 
 
@@ -755,7 +757,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 	gtk_misc_set_alignment (GTK_MISC(u_data->analyse_nb->page3->veritag),0,0);
 	gtk_widget_show(vbox_l);
 
-	vbox_r=gtk_vbox_new(FALSE, 3);
+	vbox_r=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox_r, TRUE, TRUE, 0);
 
 	u_data->analyse_nb->page3->max_in = gtk_label_new("");
@@ -774,7 +776,7 @@ static void create_analyse_window(struct sctp_analyse* u_data)
 
 	gtk_widget_show(vbox_r);
 
-	h_button_box=gtk_hbutton_box_new();
+	h_button_box=gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(page3), h_button_box, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(h_button_box), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (h_button_box), GTK_BUTTONBOX_SPREAD);
