@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_byte_graph_dlg.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: sctp_byte_graph_dlg.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,7 @@
 #include "ui/simple_dialog.h"
 
 #include "ui/gtk/dlg_utils.h"
+#include "ui/gtk/gui_utils.h"
 #include "ui/gtk/main.h"
 #include "ui/gtk/sctp_stat.h"
 
@@ -361,7 +362,6 @@ static void sctp_graph_draw(struct sctp_udata *u_data)
 	cairo_fill (cr);
 	cairo_destroy (cr);
 
-	distance = 5;
 	/* x_axis */
 #if GTK_CHECK_VERSION(2,22,0)
 	cr = cairo_create (u_data->io->surface);
@@ -1255,7 +1255,7 @@ static void init_sctp_graph_window(struct sctp_udata *u_data)
 	u_data->io->window = dlg_window_new("SCTP Graphics");  /* transient_for top_level */
 	gtk_window_set_destroy_with_parent (GTK_WINDOW(u_data->io->window), TRUE);
 
-	vbox=gtk_vbox_new(FALSE, 0);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(u_data->io->window), vbox);
 	gtk_widget_show(vbox);
 
@@ -1263,7 +1263,7 @@ static void init_sctp_graph_window(struct sctp_udata *u_data)
 
 	sctp_graph_set_title(u_data);
 
-	hbox = gtk_hbutton_box_new();
+	hbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 10);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_SPREAD);
@@ -1315,14 +1315,17 @@ static void init_sctp_graph_window(struct sctp_udata *u_data)
 
 static void sctp_graph_set_title(struct sctp_udata *u_data)
 {
+	char *display_name;
 	char *title;
 
 	if(!u_data->io->window)
 	{
 		return;
 	}
+	display_name = cf_get_display_name(&cfile);
 	title = g_strdup_printf("SCTP Data and Adv.Rcv.Window over Time: %s Port1 %u Port2 %u Endpoint %u",
-	                        cf_get_display_name(&cfile), u_data->parent->assoc->port1, u_data->parent->assoc->port2, u_data->dir);
+	                        display_name, u_data->parent->assoc->port1, u_data->parent->assoc->port2, u_data->dir);
+	g_free(display_name);
 	gtk_window_set_title(GTK_WINDOW(u_data->io->window), title);
 	g_free(title);
 }
