@@ -1,7 +1,7 @@
 /* smb2_stat.c
  * smb2_stat   2005 Ronnie Sahlberg
  *
- * $Id: smb2_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: smb2_stat.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,9 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -63,12 +60,7 @@ typedef struct _smb2stat_t {
 static void
 smb2stat_set_title(smb2stat_t *ss)
 {
-	char *title;
-
-	title = g_strdup_printf("SMB2 Service Response Time statistics: %s",
-	    cf_get_display_name(&cfile));
-	gtk_window_set_title(GTK_WINDOW(ss->win), title);
-	g_free(title);
+	set_window_title(ss->win, "SMB2 Service Response Time statistics");
 }
 
 static void
@@ -151,7 +143,7 @@ gtk_smb2stat_init(const char *optarg, void *userdata _U_)
 	gtk_window_set_default_size(GTK_WINDOW(ss->win), 550, 400);
 	smb2stat_set_title(ss);
 
-	vbox=gtk_vbox_new(FALSE, 3);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_add(GTK_CONTAINER(ss->win), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
