@@ -1,7 +1,7 @@
 /* smb_stat.c
  * smb_stat   2003 Ronnie Sahlberg
  *
- * $Id: smb_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: smb_stat.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,9 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -65,12 +62,7 @@ typedef struct _smbstat_t {
 static void
 smbstat_set_title(smbstat_t *ss)
 {
-	char *title;
-
-	title = g_strdup_printf("SMB Service Response Time statistics: %s",
-	    cf_get_display_name(&cfile));
-	gtk_window_set_title(GTK_WINDOW(ss->win), title);
-	g_free(title);
+	set_window_title(ss->win, "SMB Service Response Time statistics");
 }
 
 static void
@@ -173,7 +165,7 @@ gtk_smbstat_init(const char *optarg, void *userdata _U_)
 	gtk_window_set_default_size(GTK_WINDOW(ss->win), 550, 600);
 	smbstat_set_title(ss);
 
-	vbox=gtk_vbox_new(FALSE, 3);
+	vbox=ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_add(GTK_CONTAINER(ss->win), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
