@@ -1,7 +1,7 @@
 /* text_page_utils.c
  *  Construct a simple text page widget from a file.
  *
- * $Id: text_page_utils.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: text_page_utils.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Ulf Lamping
  *
@@ -56,7 +56,7 @@ GtkWidget * text_page_new(const char *absolute_path)
 {
   GtkWidget *page_vb, *txt_scrollw, *txt;
 
-  page_vb = gtk_vbox_new(FALSE, 0);
+  page_vb =ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
   gtk_container_set_border_width(GTK_CONTAINER(page_vb), 1);
   txt_scrollw = scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(txt_scrollw),
