@@ -1,7 +1,7 @@
 /* voip_calls_dlg.c
  * VoIP calls summary addition for Wireshark
  *
- * $Id: voip_calls_dlg.c 41544 2012-03-14 09:53:33Z etxrab $
+ * $Id: voip_calls_dlg.c 43047 2012-06-03 22:03:05Z guy $
  *
  * Copyright 2004, Ericsson , Spain
  * By Francisco Alcoba <francisco.alcoba@ericsson.com>
@@ -678,17 +678,18 @@ voip_calls_dlg_create(void)
 	GtkWidget *hbuttonbox;
 	GtkWidget *bt_close;
 	GtkWidget *bt_select_all;
-	const gchar *title_name_ptr;
+	gchar *title_name_ptr;
 	gchar *win_name;
 
 	title_name_ptr = cf_get_display_name(&cfile);
 	win_name = g_strdup_printf("%s - VoIP Calls", title_name_ptr);
+	g_free(title_name_ptr);
 	voip_calls_dlg_w = dlg_window_new(win_name);  /* transient_for top_level */
 	gtk_window_set_destroy_with_parent(GTK_WINDOW(voip_calls_dlg_w), TRUE);
 
 	gtk_window_set_default_size(GTK_WINDOW(voip_calls_dlg_w), 1000, 350);
 
-	main_vb = gtk_vbox_new(FALSE, 0);
+	main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
 	gtk_container_add(GTK_CONTAINER(voip_calls_dlg_w), main_vb);
 	gtk_container_set_border_width(GTK_CONTAINER (main_vb), 12);
 
@@ -706,7 +707,7 @@ voip_calls_dlg_create(void)
 	gtk_box_pack_start(GTK_BOX(main_vb), status_label, FALSE, FALSE, 8);
 
 	/* button row */
-	hbuttonbox = gtk_hbutton_box_new();
+	hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start(GTK_BOX(main_vb), hbuttonbox, FALSE, FALSE, 0);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
 	gtk_box_set_spacing(GTK_BOX(hbuttonbox), 30);
