@@ -1,7 +1,7 @@
 /* wsp_stat.c
  * wsp_stat   2003 Jean-Michel FAYARD
  *
- * $Id: wsp_stat.c 40529 2012-01-16 01:07:52Z guy $
+ * $Id: wsp_stat.c 42176 2012-04-21 16:40:14Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -362,7 +362,7 @@ gtk_wspstat_init(const char *optarg, void *userdata _U_)
 	g_free(title);
 
 	/* container for the two frames */
-	main_vb = gtk_vbox_new(FALSE, 3);
+	main_vb = ws_gtk_box_new(GTK_ORIENTATION_VERTICAL, 3, FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(main_vb), 12);
 	gtk_container_add(GTK_CONTAINER(sp->win), main_vb);
 
