@@ -1,7 +1,7 @@
 /* win32_file_dlg.h
  * Native Windows file dialog routines
  *
- * $Id: file_dlg_win32.h 37446 2011-05-28 18:17:50Z sake $
+ * $Id: file_dlg_win32.h 43445 2012-06-23 08:42:29Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,10 +43,23 @@ gboolean win32_open_file (HWND h_wnd);
 /** Open the "Save As" dialog box.
  *
  * @param h_wnd HWND of the parent window.
- * @param action_after_save The action to take, when save completed
- * @param action_after_save_data Data for action_after_save
+ * @param cf capture_file structure for the capture to be saved
+ * @param must_support_comments TRUE if the file format list should
+ * include only file formats that support comments
+ * @param dont_reopen TRUE if the file is to be closed after it's
+ * saved, so we don't need to reopen it after saving it
+ *
+ * @return TRUE if packets were discarded when saving, FALSE otherwise
  */
-void win32_save_as_file(HWND h_wnd, action_after_save_e action_after_save, gpointer action_after_save_data);
+gboolean win32_save_as_file(HWND h_wnd, capture_file *cf,
+                            gboolean must_support_comments,
+                            gboolean dont_reopen);
+
+/** Open the "Export Specified Packets" dialog box.
+ *
+ * @param h_wnd HWND of the parent window.
+ */
+void win32_export_specified_packets_file(HWND h_wnd);
 
 /** Open the "Merge" dialog box.
  *
