@@ -2,7 +2,7 @@
  * Definitions for routines common to multiple modules in the Lucent/Ascend
  * capture file reading code code, but not used outside that code.
  *
- * $Id: ascend-int.h 32009 2010-02-25 20:45:59Z guy $
+ * $Id: ascend-int.h 37543 2011-06-04 21:20:57Z rbalint $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,12 @@
 #ifndef __ASCEND_INT_H__
 #define __ASCEND_INT_H__
 
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
+#include <glib.h>
+
 typedef struct {
   time_t start_time;
   time_t secs;
