@@ -1,6 +1,6 @@
 /* catapult_dct2000.c
  *
- * $Id: catapult_dct2000.c 41900 2012-04-03 01:49:27Z martinm $
+ * $Id: catapult_dct2000.c 42998 2012-06-02 14:13:14Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -211,7 +211,7 @@ catapult_dct2000_open(wtap *wth, int *err, gchar **err_info _U_)
     /* Need entry in file_externals table                                */
 
     /* Allocate a new file_externals structure for this file */
-    file_externals = g_malloc(sizeof(dct2000_file_externals_t));
+    file_externals = g_new(dct2000_file_externals_t,1);
     memset((void*)file_externals, '\0', sizeof(dct2000_file_externals_t));
 
     /* Copy this first line into buffer so could write out later */
@@ -281,7 +281,7 @@ static gboolean
 catapult_dct2000_read(wtap *wth, int *err, gchar **err_info _U_,
                                gint64 *data_offset)
 {
-    gint64 offset = wth->data_offset;
+    gint64 offset = file_tell(wth->fh);
     long dollar_offset, before_time_offset, after_time_offset;
     packet_direction_t direction;
     int encap;
@@ -309,7 +309,7 @@ catapult_dct2000_read(wtap *wth, int *err, gchar **err_info _U_,
         gchar outhdr_name[MAX_OUTHDR_NAME+1];
 
         /* Are looking for first packet after 2nd line */
-        if (wth->data_offset == 0) {
+        if (file_tell(wth->fh) == 0) {
             this_offset += (file_externals->firstline_length+1+
                             file_externals->secondline_length+1);
         }
@@ -351,9 +351,6 @@ catapult_dct2000_read(wtap *wth, int *err, gchar **err_info _U_,
             */
             *data_offset = this_offset;
 
-            /* This is the position in the file where the next _read() will be called from */
-            wth->data_offset = this_offset + line_length + 1;
-
             /* Fill in timestamp (capture base + packet offset) */
             wth->phdr.ts.secs = file_externals->start_secs + seconds;
             if ((file_externals->start_usecs + useconds) >= 1000000) {
@@ -406,7 +403,7 @@ catapult_dct2000_read(wtap *wth, int *err, gchar **err_info _U_,
             }
 
             /* Store the packet prefix in the hash table */
-            line_prefix_info = g_malloc(sizeof(line_prefix_info_t));
+            line_prefix_info = g_new(line_prefix_info_t,1);
 
             /* Create and use buffer for contents before time */
             line_prefix_info->before_time = g_malloc(before_time_offset+2);
@@ -458,7 +455,7 @@ catapult_dct2000_seek_read(wtap *wth, gint64 seek_off,
                            union wtap_pseudo_header *pseudo_header, guint8 *pd,
                            int length, int *err, gchar **err_info)
 {
-    gint64 offset = wth->data_offset;
+    gint64 offset = 0;
     long dollar_offset, before_time_offset, after_time_offset;
     static gchar linebuff[MAX_LINE_LENGTH+1];
     gchar aal_header_chars[AAL_HEADER_CHARS];
@@ -752,7 +749,7 @@ catapult_dct2000_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
     }
 
     if (!is_comment) {
-        /* Each binary byte is written out as 2 hex string chars */ 
+        /* Each binary byte is written out as 2 hex string chars */
         for (; n < phdr->len; n++) {
             gchar c[2];
             c[0] = char_from_hex((guint8)(pd[n] >> 4));
@@ -1491,7 +1488,7 @@ packet_offset_equal(gconstpointer v, gconstpointer v2)
 static guint
 packet_offset_hash_func(gconstpointer v)
 {
-    /* Use low-order bits of git64 offset value */
+    /* Use low-order bits of gint64 offset value */
     return (guint)(*(const gint64*)v);
 }
 
@@ -1592,4 +1589,3 @@ free_line_prefix_info(gpointer key, gpointer value,
     /* Item will always be removed from table */
     return TRUE;
 }
-
