@@ -2,7 +2,7 @@
  * Routines for opening CommView file format packet captures
  * Copyright 2007, Stephen Fisher (see AUTHORS file)
  *
- * $Id: commview.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: commview.c 42423 2012-05-04 16:56:18Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -59,7 +59,7 @@ typedef struct commview_header {
 	guint32		usecs;
 	guint8		flags;		/* Bit-field positions defined below */
 	guint8		signal_level_percent;
-	guint8		rate;
+	guint16		rate;
 	guint8		band;
 	guint8		channel;
 	guint8		direction;	/* Or for WiFi, high order byte of
@@ -124,7 +124,6 @@ int commview_open(wtap *wth, int *err, gchar **err_info)
 	wth->subtype_read = commview_read;
 	wth->subtype_seek_read = commview_seek_read;
 
-	wth->data_offset = 0;
 	wth->file_type = WTAP_FILE_COMMVIEW;
 	wth->file_encap = WTAP_ENCAP_PER_PACKET;
 	wth->tsprecision = WTAP_FILE_TSPREC_USEC;
@@ -162,13 +161,11 @@ commview_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 	struct tm tm;
 	int bytes_read;
 
-	*data_offset = wth->data_offset;
+	*data_offset = file_tell(wth->fh);
 
 	if(!commview_read_header(&cv_hdr, wth->fh, err, err_info))
 		return FALSE;
 
-	wth->data_offset += COMMVIEW_HEADER_SIZE;
-
 	switch(cv_hdr.flags & FLAGS_MEDIUM) {
 
 	case MEDIUM_ETHERNET :
@@ -210,8 +207,6 @@ commview_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 	tm.tm_sec = cv_hdr.seconds;
 	tm.tm_isdst = -1;
 
-	wth->data_offset += cv_hdr.data_len;
-
 	wth->phdr.presence_flags = WTAP_HAS_TS;
 
 	wth->phdr.len = cv_hdr.data_len;
