@@ -1,6 +1,6 @@
 /* csids.c
  *
- * $Id: csids.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: csids.c 42423 2012-05-04 16:56:18Z guy $
  *
  * Copyright (c) 2000 by Mike Hall <mlh@io.com>
  * Copyright (c) 2000 by Cisco Systems
@@ -33,7 +33,7 @@
 #include <string.h>
 
 /*
- * This module reads the output from the Cisco Secure Intrustion Detection
+ * This module reads the output from the Cisco Secure Intrusion Detection
  * System iplogging facility. The term iplogging is misleading since this
  * logger will only output TCP. There is no link layer information.
  * Packet format is 4 byte timestamp (seconds since epoch), and a 4 byte size
@@ -136,7 +136,6 @@ int csids_open(wtap *wth, int *err, gchar **err_info)
   if (file_seek(wth->fh, 0, SEEK_SET, err) == -1)
     return -1;
 
-  wth->data_offset = 0;
   csids = (csids_t *)g_malloc(sizeof(csids_t));
   wth->priv = (void *)csids;
   csids->byteswapped = byteswap;
@@ -159,7 +158,7 @@ static gboolean csids_read(wtap *wth, int *err, gchar **err_info,
   int bytesRead = 0;
   struct csids_header hdr;
 
-  *data_offset = wth->data_offset;
+  *data_offset = file_tell(wth->fh);
 
   bytesRead = file_read( &hdr, sizeof( struct csids_header) , wth->fh );
   if( bytesRead != sizeof( struct csids_header) ) {
@@ -171,8 +170,6 @@ static gboolean csids_read(wtap *wth, int *err, gchar **err_info,
   hdr.seconds = pntohl(&hdr.seconds);
   hdr.caplen = pntohs(&hdr.caplen);
 
-  wth->data_offset += sizeof( struct csids_header );
-
   /* Make sure we have enough room for the packet */
   buffer_assure_space(wth->frame_buffer, hdr.caplen);
   buf = buffer_start_ptr(wth->frame_buffer);
@@ -185,8 +182,6 @@ static gboolean csids_read(wtap *wth, int *err, gchar **err_info,
     return FALSE;
   }
 
-  wth->data_offset += hdr.caplen;
-
   wth->phdr.presence_flags = WTAP_HAS_TS;
   wth->phdr.len = hdr.caplen;
   wth->phdr.caplen = hdr.caplen;
@@ -194,9 +189,14 @@ static gboolean csids_read(wtap *wth, int *err, gchar **err_info,
   wth->phdr.ts.nsecs = 0;
 
   if( csids->byteswapped ) {
-    PBSWAP16(buf);   /* the ip len */
-    PBSWAP16(buf+2); /* ip id */
-    PBSWAP16(buf+4); /* ip flags and fragoff */
+    if( hdr.caplen >= 2 ) {
+      PBSWAP16(buf);   /* the ip len */
+      if( hdr.caplen >= 4 ) {
+        PBSWAP16(buf+2); /* ip id */
+        if( hdr.caplen >= 6 )
+          PBSWAP16(buf+4); /* ip flags and fragoff */
+      }
+    }
   }
 
   return TRUE;
@@ -247,9 +247,14 @@ csids_seek_read (wtap *wth,
   }
 
   if( csids->byteswapped ) {
-    PBSWAP16(pd);   /* the ip len */
-    PBSWAP16(pd+2); /* ip id */
-    PBSWAP16(pd+4); /* ip flags and fragoff */
+    if( hdr.caplen >= 2 ) {
+      PBSWAP16(pd);   /* the ip len */
+      if( hdr.caplen >= 4 ) {
+        PBSWAP16(pd+2); /* ip id */
+        if( hdr.caplen >= 6 )
+          PBSWAP16(pd+4); /* ip flags and fragoff */
+      }
+    }
   }
 
   return TRUE;
