@@ -1,6 +1,6 @@
 /* dbs-etherwatch.c
  *
- * $Id: dbs-etherwatch.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: dbs-etherwatch.c 42658 2012-05-16 16:29:12Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 2001 by Marc Milgram <ethereal@mmilgram.NOSPAMmail.net>
@@ -201,7 +201,6 @@ int dbs_etherwatch_open(wtap *wth, int *err, gchar **err_info)
 			return -1;
 	}
 
-	wth->data_offset = 0;
 	wth->file_encap = WTAP_ENCAP_ETHERNET;
 	wth->file_type = WTAP_FILE_DBS_ETHERWATCH;
 	wth->snapshot_length = 0;	/* not known */
@@ -239,7 +238,6 @@ static gboolean dbs_etherwatch_read(wtap *wth, int *err, gchar **err_info,
 	 */
 	wth->pseudo_header.eth.fcs_len = 0;
 
-	wth->data_offset = offset;
 	*data_offset = offset;
 	return TRUE;
 }
@@ -334,6 +332,7 @@ parse_dbs_etherwatch_packet(wtap *wth, FILE_T fh, guint8* buf, int *err,
 	int	count, line_count;
 
 	eth_hdr_len = 0;
+	memset(&tm, 0, sizeof(tm));
 	/* Our file pointer should be on the first line containing the
 	 * summary information for a packet. Read in that line and
 	 * extract the useful information
@@ -408,7 +407,7 @@ parse_dbs_etherwatch_packet(wtap *wth, FILE_T fh, guint8* buf, int *err,
 		*err_info = g_strdup("dbs_etherwatch: header line not valid");
 		return -1;
 	}
-	
+
 	/* Determine whether it is Ethernet II or IEEE 802 */
 	if(strncmp(&line[ETH_II_CHECK_POS], ETH_II_CHECK_STR,
 		strlen(ETH_II_CHECK_STR)) == 0) {
@@ -576,7 +575,7 @@ parse_single_hex_dump_line(char* rec, guint8 *buf, int byte_offset) {
 	else
 	{
 		pos = COUNT_POS_HEX;
-	}	
+	}
 
 	/* Check that the record is as least as long as the start position */
 	while(i < pos)
