@@ -1,6 +1,6 @@
 /* eyesdn.h
  *
- * $Id: eyesdn.h 37543 2011-06-04 21:20:57Z rbalint $
+ * $Id: eyesdn.h 41915 2012-04-04 07:33:39Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -37,7 +37,8 @@ enum EyeSDN_TYPES {
     EYESDN_ENCAP_MTP2,
     EYESDN_ENCAP_DPNSS,
     EYESDN_ENCAP_DASS2,
-    EYESDN_ENCAP_BACNET
+    EYESDN_ENCAP_BACNET,
+    EYESDN_ENCAP_V5_EF
 };
 
 gboolean eyesdn_dump_open(wtap_dumper *wdh, int *err);
