@@ -1,6 +1,6 @@
 /* file_wrappers.h
  *
- * $Id: file_wrappers.h 37543 2011-06-04 21:20:57Z rbalint $
+ * $Id: file_wrappers.h 42961 2012-06-01 08:05:12Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -27,22 +27,24 @@
 #include <wtap.h>
 #include <wsutil/file_util.h>
 
+extern FILE_T file_open(const char *path);
+extern FILE_T file_fdopen(int fildes);
+extern void file_set_random_access(FILE_T stream, gboolean random, GPtrArray *seek);
 extern gint64 file_seek(FILE_T stream, gint64 offset, int whence, int *err);
+extern gint64 file_skip(FILE_T file, gint64 delta, int *err);
 extern gint64 file_tell(FILE_T stream);
 extern gint64 file_tell_raw(FILE_T stream);
 extern int file_fstat(FILE_T stream, ws_statb64 *statb, int *err);
-extern int file_error(FILE_T fh, gchar **err_info);
-
-extern FILE_T file_open(const char *path);
-extern FILE_T filed_open(int fildes);
+extern gboolean file_iscompressed(FILE_T stream);
 extern int file_read(void *buf, unsigned int count, FILE_T file);
-extern int file_close(FILE_T file);
 extern int file_getc(FILE_T stream);
 extern char *file_gets(char *buf, int len, FILE_T stream);
 extern int file_eof(FILE_T stream);
+extern int file_error(FILE_T fh, gchar **err_info);
 extern void file_clearerr(FILE_T stream);
-
-extern void file_set_random_access(FILE_T stream, gboolean random, GPtrArray *seek);
+extern void file_fdclose(FILE_T file);
+extern int file_fdreopen(FILE_T file, const char *path);
+extern void file_close(FILE_T file);
 
 #ifdef HAVE_LIBZ
 typedef struct wtap_writer *GZWFILE_T;
