@@ -11,7 +11,7 @@
  * The "MIME file" dissector does the reassembly, and hands the result
  * off to heuristic dissectors to try to identify the file's contents.
  *
- * $Id: mime_file.c 41944 2012-04-04 20:52:52Z darkjames $
+ * $Id: mime_file.c 42423 2012-05-04 16:56:18Z guy $
  *
  * Wiretap Library
  * This program is free software; you can redistribute it and/or
@@ -102,7 +102,7 @@ mime_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 	wth->phdr.ts.secs = 0;
 	wth->phdr.ts.nsecs = 0;
 
-	*data_offset = wth->data_offset;
+	*data_offset = file_tell(wth->fh);
 
 	/* try to read max WTAP_MAX_PACKET_SIZE bytes */
 	packet_size = file_read(_buf, sizeof(_buf), wth->fh);
@@ -123,7 +123,6 @@ mime_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 	buf = buffer_start_ptr(wth->frame_buffer);
 	memcpy(buf, _buf, packet_size);
 
-	wth->data_offset += packet_size;
 	wth->phdr.caplen = packet_size;
 	wth->phdr.len = packet_size;
 	return TRUE;
