@@ -4,7 +4,7 @@
  * Written by Shaun Jackman <sjackman@gmail.com>
  * Copyright 2007 Shaun Jackman
  *
- * $Id: mpeg.c 41294 2012-03-02 10:17:36Z guy $
+ * $Id: mpeg.c 42423 2012-05-04 16:56:18Z guy $
  *
  * Wiretap Library
  * This program is free software; you can redistribute it and/or
@@ -225,13 +225,12 @@ mpeg_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 				return FALSE;
 		}
 	}
-	*data_offset = wth->data_offset;
+	*data_offset = file_tell(wth->fh);
 
 	buffer_assure_space(wth->frame_buffer, packet_size);
 	if (!mpeg_read_rec_data(wth->fh, buffer_start_ptr(wth->frame_buffer),
 				packet_size, err, err_info))
 		return FALSE;
-	wth->data_offset += packet_size;
 	/* XXX - relative, not absolute, time stamps */
 	wth->phdr.presence_flags = WTAP_HAS_TS;
 	wth->phdr.ts = ts;
