@@ -1,6 +1,6 @@
 /* netscaler.c
  *
- * $Id: netscaler.c 41740 2012-03-22 15:36:37Z etxrab $
+ * $Id: netscaler.c 42998 2012-06-02 14:13:14Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 2006 by Ravi Kondamuru <Ravi.Kondamuru@citrix.com>
@@ -433,34 +433,34 @@ typedef struct  nspr_pktracepart_v24
 
 typedef struct {
 	gchar *pnstrace_buf;
+	gint64 xxx_offset;
 	gint32 nstrace_buf_offset;
 	gint32 nstrace_buflen;
 	/* Performance Monitor Time variables */
 	guint32	nspm_curtime;		/* current time since 1970 */
-	guint64	nspm_curtimemsec;	/* current time in mili second */
-	guint64	nspm_curtimelastmsec;	/* nspm_curtime last update time in milisec */
+	guint64	nspm_curtimemsec;	/* current time in milliseconds */
+	guint64	nspm_curtimelastmsec;	/* nspm_curtime last update time in milliseconds */
 	guint64 nsg_creltime;
 	guint64 file_size;
 } nstrace_t;
 
-guint32 nspm_signature_version(wtap*, gchar*, gint32);
-gboolean nstrace_read(wtap *wth, int *err, gchar **err_info,
+static guint32 nspm_signature_version(wtap*, gchar*, gint32);
+static gboolean nstrace_read(wtap *wth, int *err, gchar **err_info,
 		 gint64 *data_offset);
-gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info,
+static gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info,
 		 gint64 *data_offset);
-gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info,
+static gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info,
 		 gint64 *data_offset);
-gboolean nstrace_seek_read(wtap *wth, gint64 seek_off,
+static gboolean nstrace_seek_read(wtap *wth, gint64 seek_off,
 		      union wtap_pseudo_header *pseudo_header,
 		      guint8 *pd, int length,
 		      int *err, gchar **err_info);
-void nstrace_close(wtap *wth);
-void nstrace_sequential_close(wtap *wth);
+static void nstrace_close(wtap *wth);
 
-gboolean nstrace_set_start_time_v10(wtap *wth);
-gboolean nstrace_set_start_time_v20(wtap *wth);
-gboolean nstrace_set_start_time(wtap *wth);
-guint64	ns_hrtime2nsec(guint32 tm);
+static gboolean nstrace_set_start_time_v10(wtap *wth);
+static gboolean nstrace_set_start_time_v20(wtap *wth);
+static gboolean nstrace_set_start_time(wtap *wth);
+static guint64 ns_hrtime2nsec(guint32 tm);
 
 static gboolean nstrace_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
 	const union wtap_pseudo_header *pseudo_header, const guint8 *pd, int *err);
@@ -469,14 +469,14 @@ static gboolean nstrace_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
 #define GET_READ_PAGE_SIZE(remaining_file_size) ((gint32)((remaining_file_size>NSPR_PAGESIZE)?NSPR_PAGESIZE:remaining_file_size))
 
 
-guint64	ns_hrtime2nsec(guint32 tm)
+static guint64 ns_hrtime2nsec(guint32 tm)
 {
 	guint32	val = tm & NSPR_HRTIME_MASKTM;
 	switch(tm & NSPR_HRTIME_MASKFMT)
 	{
 	case NSPR_HRTIME_SEC:	return (guint64)val*1000000000;
 	case NSPR_HRTIME_MSEC:	return (guint64)val*1000000;
-	case NSPR_HRTIME_USEC:	return (guint32)val*1000;
+	case NSPR_HRTIME_USEC:	return (guint64)val*1000;
 	case NSPR_HRTIME_NSEC:	return val;
 	}
 	return tm;
@@ -499,7 +499,7 @@ int nstrace_open(wtap *wth, int *err, gchar **err_info)
 	if ((file_size = wtap_file_size(wth, err)) == -1)
 		return 0;
 
-	nstrace_buf = g_malloc(NSPR_PAGESIZE);
+	nstrace_buf = (gchar *)g_malloc(NSPR_PAGESIZE);
 	page_size = GET_READ_PAGE_SIZE(file_size);
 
 	switch ((wth->file_type = nspm_signature_version(wth, nstrace_buf, page_size)))
@@ -541,6 +541,7 @@ int nstrace_open(wtap *wth, int *err, gchar **err_info)
 	nstrace = (nstrace_t *)g_malloc(sizeof(nstrace_t));
 	wth->priv = (void *)nstrace;
 	nstrace->pnstrace_buf = nstrace_buf;
+	nstrace->xxx_offset = 0;
 	nstrace->nstrace_buflen = page_size;
 	nstrace->nstrace_buf_offset = 0;
 	nstrace->nspm_curtime = 0;
@@ -586,7 +587,7 @@ int nstrace_open(wtap *wth, int *err, gchar **err_info)
 
 
 #define nspm_signature_func(ver) \
-	guint32 nspm_signature_isv##ver(gchar *sigp) {\
+	static guint32 nspm_signature_isv##ver(gchar *sigp) {\
 		return strncmp(sigp,NSPR_SIGSTR_V##ver,(sizeof(NSPR_SIGSTR_V##ver)-1));\
 	}
 
@@ -599,7 +600,7 @@ nspm_signature_func(20)
 ** we might not be at the first page. So after a call to this function, there
 ** has to be a file seek to return to the start of the first page.
 */
-guint32
+static guint32
 nspm_signature_version(wtap *wth, gchar *nstrace_buf, gint32 len)
 {
 	gchar *dp = nstrace_buf;
@@ -669,8 +670,8 @@ nspm_signature_version(wtap *wth, gchar *nstrace_buf, gint32 len)
 				}\
 			}\
 			nstrace_buf_offset = 0;\
-			wth->data_offset += nstrace_buflen;\
-			nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - wth->data_offset));\
+			nstrace->xxx_offset += nstrace_buflen;\
+			nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - nstrace->xxx_offset));\
 		}while((nstrace_buflen > 0) && (bytes_read = file_read(nstrace_buf, nstrace_buflen, wth->fh)) && bytes_read == nstrace_buflen); \
 		return FALSE;\
 	}
@@ -688,7 +689,7 @@ nstrace_set_start_time_ver(20)
 ** the next record after the ABSTIME record. Inorder to report correct time values, all trace
 ** records before the ABSTIME record are ignored.
 */
-gboolean nstrace_set_start_time(wtap *wth)
+static gboolean nstrace_set_start_time(wtap *wth)
 {
 	if (wth->file_type == WTAP_FILE_NETSCALER_1_0)
 		return nstrace_set_start_time_v10(wth);
@@ -715,7 +716,7 @@ gboolean nstrace_set_start_time(wtap *wth)
 /*
 ** Netscaler trace format read routines.
 */
-gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
+static gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 {
 	nstrace_t *nstrace = (nstrace_t *)wth->priv;
 	guint64 nsg_creltime = nstrace->nsg_creltime;
@@ -757,7 +758,7 @@ gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 
 				buffer_assure_space(wth->frame_buffer, wth->phdr.caplen);
 				memcpy(buffer_start_ptr(wth->frame_buffer), fp, wth->phdr.caplen);
-				*data_offset = wth->data_offset + nstrace_buf_offset;
+				*data_offset = nstrace->xxx_offset + nstrace_buf_offset;
 
 				nstrace->nstrace_buf_offset = nstrace_buf_offset + wth->phdr.len;
 				nstrace->nstrace_buflen = nstrace_buflen;
@@ -782,7 +783,7 @@ gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 
 				buffer_assure_space(wth->frame_buffer, wth->phdr.caplen);
 				memcpy(buffer_start_ptr(wth->frame_buffer), pp, wth->phdr.caplen);
-				*data_offset = wth->data_offset + nstrace_buf_offset;
+				*data_offset = nstrace->xxx_offset + nstrace_buf_offset;
 
 				nstrace->nstrace_buf_offset = nstrace_buf_offset + wth->phdr.caplen;
 				nstrace->nsg_creltime = nsg_creltime;
@@ -815,8 +816,8 @@ gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 		}
 
 		nstrace_buf_offset = 0;
-		wth->data_offset += nstrace_buflen;
-		nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - wth->data_offset));
+		nstrace->xxx_offset += nstrace_buflen;
+		nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - nstrace->xxx_offset));
 	}while((nstrace_buflen > 0) && (bytes_read = file_read(nstrace_buf, nstrace_buflen, wth->fh)) && (bytes_read == nstrace_buflen));
 
 	return FALSE;
@@ -873,7 +874,7 @@ gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 		TRACE_V##ver##_REC_LEN_OFF(enumprefix,type,structname);\
 		buffer_assure_space(wth->frame_buffer, wth->phdr.caplen);\
 		memcpy(buffer_start_ptr(wth->frame_buffer), fp, wth->phdr.caplen);\
-		*data_offset = wth->data_offset + nstrace_buf_offset;\
+		*data_offset = nstrace->xxx_offset + nstrace_buf_offset;\
 		nstrace->nstrace_buf_offset = nstrace_buf_offset + nspr_getv20recordsize((nspr_hd_v20_t *)fp);\
 		nstrace->nstrace_buflen = nstrace_buflen;\
 		nstrace->nsg_creltime = nsg_creltime;\
@@ -881,7 +882,7 @@ gboolean nstrace_read_v10(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 		return TRUE;\
 	}while(0)
 
-gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
+static gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 {
 	nstrace_t *nstrace = (nstrace_t *)wth->priv;
 	guint64 nsg_creltime = nstrace->nsg_creltime;
@@ -974,11 +975,11 @@ gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 					break;
 				}
 			}
-    	}
+		}
 
 		nstrace_buf_offset = 0;
-	    wth->data_offset += nstrace_buflen;
-    	nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - wth->data_offset));
+		nstrace->xxx_offset += nstrace_buflen;
+		nstrace_buflen = GET_READ_PAGE_SIZE((nstrace->file_size - nstrace->xxx_offset));
 	}while((nstrace_buflen > 0) && (bytes_read = file_read(nstrace_buf, nstrace_buflen, wth->fh)) && (bytes_read == nstrace_buflen));
 
 	return FALSE;
@@ -991,7 +992,7 @@ gboolean nstrace_read_v20(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 
 
 
-gboolean nstrace_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
+static gboolean nstrace_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 {
 
 	if (wth->file_type == WTAP_FILE_NETSCALER_1_0)
@@ -1006,7 +1007,7 @@ gboolean nstrace_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset
 #define __TNO(enumprefix,structprefix,structname,hdrname,structfieldname) \
 	pseudo_header->nstr.hdrname##_offset = (guint8) enumprefix##_##hdrname##_offset;
 #define __TNL(enumprefix,structprefix,structname,hdrname,structfieldname) \
-	pseudo_header->nstr.hdrname##_len = (guint8) enumprefix##_##hdrname##_len;;
+	pseudo_header->nstr.hdrname##_len = (guint8) enumprefix##_##hdrname##_len;
 
 #define __TNV1O(enumprefix,structprefix,structname,hdrname,structfieldname) \
 	__TNO(enumprefix,structprefix,structname,hdrname,structfieldname)
@@ -1014,7 +1015,7 @@ gboolean nstrace_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset
 	__TNL(enumprefix,structprefix,structname,hdrname,structfieldname)
 
 
-gboolean nstrace_seek_read(wtap *wth, gint64 seek_off,
+static gboolean nstrace_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guint8 *pd, int length,
     int *err, gchar **err_info)
 {
@@ -1107,7 +1108,7 @@ gboolean nstrace_seek_read(wtap *wth, gint64 seek_off,
 /*
 ** Netscaler trace format close routines.
 */
-void nstrace_close(wtap *wth)
+static void nstrace_close(wtap *wth)
 {
 	nstrace_t *nstrace = (nstrace_t *)wth->priv;
 
