@@ -1,6 +1,6 @@
 /* pppdump.c
  *
- * $Id: pppdump.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: pppdump.c 43000 2012-06-02 15:32:34Z etxrab $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -299,7 +299,7 @@ pppdump_open(wtap *wth, int *err, gchar **err_info)
 	wth->subtype_close = pppdump_close;
 	wth->tsprecision = WTAP_FILE_TSPREC_DSEC;
 
-	state->seek_state = g_malloc(sizeof(pppdump_t));
+	state->seek_state = g_new(pppdump_t,1);
 
 	/* If we have a random stream open, we're going to be reading
 	   the file randomly; set up a GPtrArray of pointers to
@@ -326,7 +326,7 @@ pppdump_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 	buffer_assure_space(wth->frame_buffer, PPPD_BUF_SIZE);
 	buf = buffer_start_ptr(wth->frame_buffer);
 
-	state = wth->priv;
+	state = (pppdump_t *)wth->priv;
 
 	/* If we have a random stream open, allocate a structure to hold
 	   the information needed to read this packet's data again. */
@@ -721,9 +721,9 @@ pppdump_seek_read(wtap *wth,
 	pkt_id		*pid;
 	gint64		num_bytes_to_skip;
 
-	state = wth->priv;
+	state = (pppdump_t *)wth->priv;
 
-	pid = g_ptr_array_index(state->pids, seek_off);
+	pid = (pkt_id *)g_ptr_array_index(state->pids, seek_off);
 	if (!pid) {
 		*err = WTAP_ERR_BAD_FILE;	/* XXX - better error? */
 		*err_info = g_strdup("pppdump: PID not found for record");
