@@ -2,7 +2,7 @@
  *
  * Transport-Neutral Encapsulation Format (TNEF) file reading
  *
- * $Id: tnef.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: tnef.c 42423 2012-05-04 16:56:18Z guy $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,17 +37,20 @@
 
 static gboolean tnef_read(wtap *wth, int *err, gchar **err_info, gint64 *data_offset)
 {
+  gint64 offset;
   guint8 *buf;
   gint64 file_size;
   int packet_size;
 
   *err = 0;
 
+  offset = file_tell(wth->fh);
+
   /* there is only ever one packet */
-  if(wth->data_offset)
+  if (offset)
     return FALSE;
 
-  *data_offset = wth->data_offset;
+  *data_offset = offset;
 
   if ((file_size = wtap_file_size(wth, err)) == -1)
     return FALSE;
@@ -69,8 +72,6 @@ static gboolean tnef_read(wtap *wth, int *err, gchar **err_info, gint64 *data_of
 
   wtap_file_read_expected_bytes(buf, packet_size, wth->fh, err, err_info);
 
-  wth->data_offset += packet_size;
-
   wth->phdr.presence_flags = 0; /* no time stamp, no "real length" */
 
   wth->phdr.caplen = packet_size;
