@@ -2,7 +2,7 @@
  * File read and write routines for Visual Networks cap files.
  * Copyright (c) 2001, Tom Nisbet  tnisbet@visualnetworks.com
  *
- * $Id: visual.c 41185 2012-02-25 23:24:34Z guy $
+ * $Id: visual.c 43000 2012-06-02 15:32:34Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -266,10 +266,6 @@ int visual_open(wtap *wth, int *err, gchar **err_info)
     wth->file_encap = encap;
     wth->snapshot_length = pletohs(&vfile_hdr.max_length);
 
-    /* Save the pointer to the beginning of the packet data so
-       that the later seek_reads work correctly. */
-    wth->data_offset = CAPTUREFILE_HEADER_SIZE;
-
     /* Set up the pointers to the handlers for this file type */
     wth->subtype_read = visual_read;
     wth->subtype_seek_read = visual_seek_read;
@@ -326,7 +322,6 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
         }
         return FALSE;
     }
-    wth->data_offset += phdr_size;
 
     /* Get the included length of data. This includes extra headers + payload */
     packet_size = pletohs(&vpkt_hdr.incl_len);
@@ -346,7 +341,6 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
            }
            return FALSE;
        }
-       wth->data_offset += ahdr_size;
        
        /* Remove ATM header from length of included bytes in capture, as 
           this header was appended by the processor doing the packet reassembly,
@@ -365,7 +359,7 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
         return FALSE;
     }
     buffer_assure_space(wth->frame_buffer, packet_size);
-    *data_offset = wth->data_offset;
+    *data_offset = file_tell(wth->fh);
     errno = WTAP_ERR_CANT_READ;
     bytes_read = file_read(buffer_start_ptr(wth->frame_buffer),
             packet_size, wth->fh);
@@ -377,7 +371,6 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
             *err = WTAP_ERR_SHORT_READ;
         return FALSE;
     }
-    wth->data_offset += packet_size;
 
     wth->phdr.presence_flags = WTAP_HAS_TS|WTAP_HAS_CAP_LEN;
 
@@ -706,7 +699,7 @@ gboolean visual_dump_open(wtap_dumper *wdh, int *err)
 static gboolean visual_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
     const union wtap_pseudo_header *pseudo_header, const guint8 *pd, int *err)
 {
-    struct visual_write_info * visual = wdh->priv;
+    struct visual_write_info * visual = (struct visual_write_info *)wdh->priv;
     struct visual_pkt_hdr vpkt_hdr;
     size_t hdr_size = sizeof vpkt_hdr;
     unsigned delta_msec;
@@ -730,7 +723,7 @@ static gboolean visual_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
         visual->start_time = (guint32) phdr->ts.secs;
 
         /* Initialize the index table */
-        visual->index_table = g_malloc(1024 * sizeof *visual->index_table);
+        visual->index_table = (guint32 *)g_malloc(1024 * sizeof *visual->index_table);
         visual->index_table_size = 1024;
     }
 
@@ -800,7 +793,7 @@ static gboolean visual_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
     {
         /* End of table reached.  Reallocate with a larger size */
         visual->index_table_size *= 2;
-        visual->index_table = g_realloc(visual->index_table,
+        visual->index_table = (guint32 *)g_realloc(visual->index_table,
             visual->index_table_size * sizeof *visual->index_table);
     }
     visual->index_table[visual->index_table_index] = htolel(visual->next_offset);
@@ -817,7 +810,7 @@ static gboolean visual_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
    Returns TRUE on success, FALSE on failure. */
 static gboolean visual_dump_close(wtap_dumper *wdh, int *err)
 {
-    struct visual_write_info * visual = wdh->priv;
+    struct visual_write_info * visual = (struct visual_write_info *)wdh->priv;
     size_t n_to_write;
     struct visual_file_hdr vfile_hdr;
     const char *magicp;
@@ -901,7 +894,7 @@ static gboolean visual_dump_close(wtap_dumper *wdh, int *err)
 /* Free the memory allocated by a visual file writer. */
 static void visual_dump_free(wtap_dumper *wdh)
 {
-    struct visual_write_info * visual = wdh->priv;
+    struct visual_write_info * visual = (struct visual_write_info *)wdh->priv;
 
     if (visual)
     {
