@@ -1,6 +1,6 @@
 /* wtap.c
  *
- * $Id: wtap.c 41969 2012-04-06 03:42:32Z guy $
+ * $Id: wtap.c 42963 2012-06-01 08:45:39Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -78,6 +78,12 @@ wtap_file_type(wtap *wth)
 	return wth->file_type;
 }
 
+gboolean
+wtap_iscompressed(wtap *wth)
+{
+	return file_iscompressed((wth->fh == NULL) ? wth->random_fh : wth->fh);
+}
+
 guint
 wtap_snapshot_length(wtap *wth)
 {
@@ -206,17 +212,17 @@ static struct encap_type_info encap_table_base[] = {
 	/* WTAP_ENCAP_IEEE_802_11 */
 	{ "IEEE 802.11 Wireless LAN", "ieee-802-11" },
 
-	/* WTAP_ENCAP_PRISM_HEADER */
-	{ "IEEE 802.11 plus Prism II monitor mode header", "prism" },
+	/* WTAP_ENCAP_IEEE_802_11_PRISM */
+	{ "IEEE 802.11 plus Prism II monitor mode radio header", "ieee-802-11-prism" },
 
 	/* WTAP_ENCAP_IEEE_802_11_WITH_RADIO */
 	{ "IEEE 802.11 Wireless LAN with radio information", "ieee-802-11-radio" },
 
-	/* WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP */
-	{ "IEEE 802.11 plus radiotap WLAN header", "ieee-802-11-radiotap" },
+	/* WTAP_ENCAP_IEEE_802_11_RADIOTAP */
+	{ "IEEE 802.11 plus radiotap radio header", "ieee-802-11-radiotap" },
 
-	/* WTAP_ENCAP_IEEE_802_11_WLAN_AVS */
-	{ "IEEE 802.11 plus AVS WLAN header", "ieee-802-11-avs" },
+	/* WTAP_ENCAP_IEEE_802_11_AVS */
+	{ "IEEE 802.11 plus AVS radio header", "ieee-802-11-avs" },
 
 	/* WTAP_ENCAP_SLL */
 	{ "Linux cooked-mode capture", "linux-sll" },
@@ -381,7 +387,7 @@ static struct encap_type_info encap_table_base[] = {
 	{ "GCOM Serial", "gcom-serial" },
 
 	/* WTAP_ENCAP_NETTL_X25 */
-	{ "X25 with nettl headers", "x25-nettl" },
+	{ "X.25 with nettl headers", "x25-nettl" },
 
 	/* WTAP_ENCAP_K12 */
 	{ "K12 protocol analyzer", "k12" },
@@ -408,7 +414,7 @@ static struct encap_type_info encap_table_base[] = {
 	{ "Juniper GGSN", "juniper-ggsn" },
 
 	/* WTAP_ENCAP_LINUX_LAPD */
-	{ "LAPD", "lapd" },
+	{ "LAPD with Linux pseudo-header", "linux-lapd" },
 
 	/* WTAP_ENCAP_CATAPULT_DCT2000 */
 	{ "Catapult DCT2000", "dct2000" },
@@ -521,7 +527,7 @@ static struct encap_type_info encap_table_base[] = {
 	/* WTAP_ENCAP_SOCKETCAN */
 	{ "SocketCAN", "socketcan" },
 
-	/* WTAP_ENCAP_IEEE802_11_NETMON_RADIO */
+	/* WTAP_ENCAP_IEEE_802_11_NETMON */
 	{ "IEEE 802.11 plus Network Monitor radio header", "ieee-802-11-netmon" },
 
 	/* WTAP_ENCAP_IEEE802_15_4_NOFCS */
@@ -537,7 +543,7 @@ static struct encap_type_info encap_table_base[] = {
 	{ "Raw IPv6", "rawip6" },
 
 	/* WTAP_ENCAP_LAPD */
-	{ "Lapd header", "lapd" },
+	{ "LAPD", "lapd" },
 
 	/* WTAP_ENCAP_DVBCI */
 	{ "DVB-CI (Common Interface)", "dvbci"},
@@ -570,10 +576,16 @@ static struct encap_type_info encap_table_base[] = {
 	{ "NFLOG", "nflog" },
 
 	/* WTAP_ENCAP_V5_EF */
-	{ "V5 Enveope Function", "v5-ef" },
+	{ "V5 Envelope Function", "v5-ef" },
 
 	/* WTAP_ENCAP_BACNET_MS_TP_WITH_PHDR */
 	{ "BACnet MS/TP with Directional Info", "bacnet-ms-tp-with-direction" },
+ 
+ 	/* WTAP_ENCAP_IXVERIWAVE */
+ 	{ "IxVeriWave header and stats block", "ixveriwave" },
+
+	/* WTAP_ENCAP_IEEE_802_11_AIROPEEK */
+	{ "IEEE 802.11 plus AiroPeek radio header", "ieee-802-11-airopeek" },
 };
 
 gint wtap_num_encap_types = sizeof(encap_table_base) / sizeof(struct encap_type_info);
@@ -727,6 +739,21 @@ g_fast_seek_item_free(gpointer data, gpointer user_data _U_)
 	g_free(data);
 }
 
+/*
+ * Close the file descriptors for the sequential and random streams, but
+ * don't discard any information about those streams.  Used on Windows if
+ * we need to rename a file that we have open or if we need to rename on
+ * top of a file we have open.
+ */
+void
+wtap_fdclose(wtap *wth)
+{
+	if (wth->fh != NULL)
+		file_fdclose(wth->fh);
+	if (wth->random_fh != NULL)
+		file_fdclose(wth->random_fh);
+}
+
 void
 wtap_close(wtap *wth)
 {
