@@ -1,6 +1,6 @@
 /* wtap.h
  *
- * $Id: wtap.h 43316 2012-06-17 16:45:32Z guy $
+ * $Id: wtap.h 43863 2012-07-20 17:35:49Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -1098,6 +1098,12 @@ void wtap_close(wtap *wth);
 gboolean wtap_dump_can_open(int filetype);
 gboolean wtap_dump_can_write_encap(int filetype, int encap);
 
+/**
+ * Given a GArray of WTAP_ENCAP_ types, return the per-file encapsulation
+ * type that would be needed to write out a file with those types.
+ */
+int wtap_dump_file_encap_type(const GArray *file_encaps);
+
 /**
  * Return TRUE if a capture with a given GArray of WTAP_ENCAP_ types
  * can be written in a specified format, and FALSE if it can't.
