@@ -1,6 +1,6 @@
 /* file_util.c
  *
- * $Id: file_util.c 36547 2011-04-10 20:59:10Z guy $
+ * $Id: file_util.c 38592 2011-08-17 19:46:13Z stig $
  *
  * (Originally part of the Wiretap Library, now part of the Wireshark
  *  utility library)
@@ -487,10 +487,11 @@ ws_init_dll_search_path()
       gboolean dll_dir_set = FALSE;
       wchar_t *program_path_w;
 
-      typedef BOOL (*SetDllDirectoryHandler)(LPCTSTR);
+      typedef BOOL (WINAPI *SetDllDirectoryHandler)(LPCTSTR);
       SetDllDirectoryHandler PSetDllDirectory;
 
-      if (PSetDllDirectory = (SetDllDirectoryHandler) GetProcAddress(GetModuleHandle(_T("kernel32.dll")), "SetDllDirectoryW")) {
+      PSetDllDirectory = (SetDllDirectoryHandler) GetProcAddress(GetModuleHandle(_T("kernel32.dll")), "SetDllDirectoryW");
+      if (PSetDllDirectory) {
 	    dll_dir_set = PSetDllDirectory(_T(""));
       }
 
@@ -594,7 +595,6 @@ getenv_utf8(const char *varname)
 	envvar = getenv(varname);
 
 	/* since GLib 2.6 we need an utf8 version of the filename */
-#if GLIB_CHECK_VERSION(2,6,0)
 	/* using the wide char version of getenv should work under all circumstances */
 
 	/* convert given varname to utf16, needed by _wgetenv */
@@ -613,8 +613,6 @@ getenv_utf8(const char *varname)
 	/* convert value to utf8 */
 	envvar = g_utf16_to_utf8(envvarw, -1, NULL, NULL, NULL);
 	/* XXX - memleak */
-#endif
 
 	return envvar;
 }
-
